-- File:Omega_CA_02_08_01_Eval_Env.sql
-- Author:DATAPLUS
-- Name:Omega Core Audit - Evaluation Environment 01.01.01
-- Doc. Reference: Omega Core Audit Deployment Guide
-- Warranty: This script is provided as it its, without warranty of any kind.
-- -------------------------------------------------------------------------
-- Notes:
-- 1. Do not change or modify this script without contacting support.
-- 2. Run only with SYS/SYSDBA or DBA privileges!
-- -------------------------------------------------------------------------

 
SPOOL Omega_CA_02_08_01_Eval_Env.log
   
SET SQLBLANKLINES ON
SET SERVEROUTPUT ON
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK 


-- Omega Core Audit - Evaluation Environment INSTALL
prompt Omega Core Audit - Evaluation Environment INSTALL
prompt ==================================================
prompt


-- 01. Omega CA Evaluation Environment - Dropp existing objects (if any)
prompt 01. Omega CA Evaluation Environment - Dropp existing objects (if any)
prompt =====================================================================
prompt

DECLARE 
  cursor C1 is select * from dba_users
  where username in ('OMEGACATESTAPP01', 'OMEGACATESTDEV01', 'OMEGACATESTDEV02', 'OMEGACATESTDBA01');
BEGIN
  for rec in C1 loop
  EXECUTE IMMEDIATE 'drop user ' || rec.username || ' cascade';
  end loop;
END;
/


-- 02. Omega CA Evaluation Environment - Create Users
prompt 02. Omega CA Evaluation Environment - Create Users
prompt ==================================================
prompt


-- 02.01. Omega CA Evaluation Environment - Create Application User 01
prompt 02.01. Omega CA Evaluation Environment - Create Application User 01
prompt ===================================================================
prompt

create user OMEGACATESTAPP01 default tablespace OMEGACA_TS identified by Omegaca123;

alter user OMEGACATESTAPP01 quota unlimited on OMEGACA_TS;
grant CREATE SESSION to OMEGACATESTAPP01;
grant CREATE PROCEDURE to OMEGACATESTAPP01;
grant ALTER ANY PROCEDURE to OMEGACATESTAPP01;
grant CREATE VIEW to OMEGACATESTAPP01;
grant ALTER ANY TABLE to OMEGACATESTAPP01;


-- 02.02. Omega CA Evaluation Environment - Create Developer User 01
prompt 02.02. Omega CA Evaluation Environment - Create Developer User 01
prompt =================================================================
prompt

create user OMEGACATESTDEV01 default tablespace OMEGACA_TS identified by Omegaca123;

grant CREATE SESSION to OMEGACATESTDEV01;
grant CREATE ANY PROCEDURE to OMEGACATESTDEV01;
grant ALTER ANY PROCEDURE to OMEGACATESTDEV01;
grant CREATE ANY VIEW to OMEGACATESTDEV01;
grant ALTER ANY TABLE to OMEGACATESTDEV01;


-- 02.03. Omega CA Evaluation Environment - Create Developer User 02
prompt 02.03. Omega CA Evaluation Environment - Create Developer User 02
prompt =================================================================
prompt

create user OMEGACATESTDEV02 default tablespace OMEGACA_TS identified by Omegaca123;

grant CREATE SESSION to OMEGACATESTDEV02;
grant CREATE ANY PROCEDURE to OMEGACATESTDEV02;
grant ALTER ANY PROCEDURE to OMEGACATESTDEV02;
grant CREATE ANY VIEW to OMEGACATESTDEV02;
grant ALTER ANY TABLE to OMEGACATESTDEV02;


-- 02.04. Omega CA Evaluation Environment - Create DBA User 01
prompt 02.04. Omega CA Evaluation Environment - Create DBA User 01
prompt ===========================================================
prompt

create user OMEGACATESTDBA01 default tablespace OMEGACA_TS identified by Omegaca123;

grant DBA to OMEGACATESTDBA01;


-- 03. Omega CA Evaluation Environment - Create Application User Objects
prompt 03. Omega CA Evaluation Environment - Create Application User Objects
prompt =====================================================================
prompt

-- Create table
create table OMEGACATESTAPP01.DEPT
(
  DEPT_ID      NUMBER(9) not null,
  DEPT_NAME    VARCHAR2(100) not null,
  LOCATION     VARCHAR2(100) not null,
  DATE_UPD     DATE,
  DATE_CREATED DATE default SYSDATE not null
)
tablespace OMEGACA_TS
  pctfree 10
  initrans 1
  maxtrans 255
  storage
  (
    initial 64K
    next 1M
    minextents 1
    maxextents unlimited
  );

-- Create/Recreate primary, unique and foreign key constraints 
alter table OMEGACATESTAPP01.DEPT
  add constraint DEPT_PK primary key (DEPT_ID)
  using index 
  tablespace OMEGACA_TS
  pctfree 10
  initrans 2
  maxtrans 255
  storage
  (
    initial 64K
    next 1M
    minextents 1
    maxextents unlimited
  );
alter table OMEGACATESTAPP01.DEPT
  add constraint DEPT_UN unique (DEPT_NAME)
  using index 
  tablespace OMEGACA_TS
  pctfree 10
  initrans 2
  maxtrans 255
  storage
  (
    initial 64K
    next 1M
    minextents 1
    maxextents unlimited
  );


-- Create table
create table OMEGACATESTAPP01.EMP
(
  EMP_ID     NUMBER(9) not null,
  FIRST_NAME VARCHAR2(100) not null,
  LAST_NAME  VARCHAR2(100) not null,
  DEPT_ID    NUMBER(9) not null,
  HIRE_DATE  DATE not null,
  SALARY     NUMBER(15,3) not null
)
tablespace OMEGACA_TS
  pctfree 10
  initrans 1
  maxtrans 255
  storage
  (
    initial 64K
    next 1M
    minextents 1
    maxextents unlimited
  );
-- Create/Recreate primary, unique and foreign key constraints 
alter table OMEGACATESTAPP01.EMP
  add constraint SSSS foreign key (DEPT_ID)
  references OMEGACATESTAPP01.DEPT (DEPT_ID);


create or replace procedure OMEGACATESTAPP01.P_PROC_01
as
begin
if 1 <> 1 then
raise_application_error(-20010, 'Error');
end if;
end;
/

create or replace procedure OMEGACATESTAPP01.P_PROC_02
as
begin
if 1 <> 1 then
raise_application_error(-20010, 'Error');
end if;
end;
/

create or replace function OMEGACATESTAPP01.F_VAL_EXPR_TEST (
                           p_factor_id in integer
                           )
return boolean is
begin
--return TRUE;
return FALSE;
end;
/

create or replace view OMEGACATESTAPP01.V_EMP as
select 
a.emp_id, a.first_name, a.last_name,
a.dept_id, b.dept_name, b.location,
a.hire_date, a.salary
from EMP a, DEPT b
where a.dept_id = b.dept_id
/   


-- 04. Omega CA Evaluation Environment - Insert Application Data
prompt 04. Omega CA Evaluation Environment - Insert Application Data
prompt =============================================================
prompt

insert into OMEGACATESTAPP01.dept (dept_id, dept_name, location) values (1, 'IT', 'Sweetwater');
insert into OMEGACATESTAPP01.dept (dept_id, dept_name, location) values (2, 'Operations', 'Sweetwater');
insert into OMEGACATESTAPP01.dept (dept_id, dept_name, location) values (3, 'Finance', 'Sweetwater');
insert into OMEGACATESTAPP01.dept (dept_id, dept_name, location) values (4, 'Marketing', 'Sweetwater');

insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (1, 'Chuck', 'Inblood',  2, SYSDATE, 1200);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (2, 'Colbert', 'Benson',  2, SYSDATE, 1500);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (3, 'Dave', 'Jenkins',  2, SYSDATE, 1800);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (4, 'Jim', 'Cooper',  2, SYSDATE, 2200);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (5, 'Jill', 'McBain',  4, SYSDATE, 2700);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (6, 'Frank', 'Morton',  3, SYSDATE, 3100);
insert into OMEGACATESTAPP01.emp 
(emp_id, first_name, last_name, dept_id, hire_date, salary) values (7, 'Cheyenne', 'Harmonica',  1, SYSDATE, 3500);

Commit;


-- 05. Omega CA Evaluation Environment - Grant Application Objects Privileges
prompt 05. Omega CA Evaluation Environment - Grant Application Objects Privileges
prompt ==========================================================================
prompt

grant INSERT on OMEGACATESTAPP01.EMP to OMEGACATESTDEV01;
grant DELETE on OMEGACATESTAPP01.EMP to OMEGACATESTDEV01;
grant SELECT on OMEGACATESTAPP01.EMP to OMEGACATESTDEV01;
grant UPDATE on OMEGACATESTAPP01.EMP to OMEGACATESTDEV01;

grant INSERT on OMEGACATESTAPP01.EMP to OMEGACATESTDEV02;
grant DELETE on OMEGACATESTAPP01.EMP to OMEGACATESTDEV02;
grant SELECT on OMEGACATESTAPP01.EMP to OMEGACATESTDEV02;
grant UPDATE on OMEGACATESTAPP01.EMP to OMEGACATESTDEV02;


-- Purge Recycle Bin
purge recyclebin;
   
SPOOL OFF