-- File:Omega_CA_02_08_01_Install.sql
-- Author:DATAPLUS
-- Name:Omega Core Audit 02.08.01 Install
-- Doc. Reference: Omega Core Audit User Guide, chapter Deployment
-- Warranty: This script is provided as it its, without warranty of any kind.
-- -------------------------------------------------------------------------
-- Notes:
-- 1. Do not change or modify this script without contacting support.
-- 2. Run only with SYS/SYSDBA privileges!
-- -------------------------------------------------------------------------
   
   
SPOOL Omega_CA_02_08_01_Install.log
   
SET SQLBLANKLINES ON
SET SERVEROUTPUT ON
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK
   
   
-- Omega Core Audit - INSTALL 02.08.01
prompt Omega Core Audit - INSTALL 02.08.01
prompt ==================================================
prompt
   
-- 01. Omega CA - Set Current Schema to SYS
prompt 01. Omega CA - Set Current Schema to SYS
prompt ==================================================
prompt
   
alter session set current_schema = SYS;
   
-- 02. Omega CA - Repository TableSpace, commented!
prompt 02. Omega CA - Repository TableSpace, commented!
prompt ==================================================
prompt
   
/*
-- Create Omega CA Tablespace OMEGACA_TS 
CREATE TABLESPACE OMEGACA_TS 
LOGGING 
DATAFILE <DATA_FILE> SIZE <INIT_SIZE> 
REUSE AUTOEXTEND ON NEXT <NEXT_SIZE> 
MAXSIZE UNLIMITED 
EXTENT MANAGEMENT LOCAL;
*/

   
-- 03. Omega CA - Repository Schema
prompt 03. Omega CA - Repository Schema
prompt ==================================================
prompt
   
-- 03.01. Omega CA - Tablespace Check
prompt 03.01. Omega CA - Tablespace Check
prompt ==================================================
prompt
   
DECLARE
tbs_cnt integer;
BEGIN

select count(*) into tbs_cnt 
from DBA_TABLESPACES
where TABLESPACE_NAME = 'OMEGACA_TS';

IF tbs_cnt = 0 THEN
RAISE_APPLICATION_ERROR(-20000, 'Tablespace OMEGACA_TS does not exist! '); 
END IF;
END;
/

   
-- 03.02. Omega CA - Repository Schema Create
prompt 03.02. Omega CA - Repository Schema Create
prompt ==================================================
prompt
   
-- Create Omega CA Schema
create user OMEGACA
  identified by Omegaca123
  default tablespace OMEGACA_TS
  quota unlimited on OMEGACA_TS;

   
-- 04. Omega CA - Repository Schema Object Privileges
prompt 04. Omega CA - Repository Schema Object Privileges
prompt ==================================================
prompt
   
-- Grant Omega CA Schema Object Privileges 
grant select on DBA_AUDIT_POLICIES to OMEGACA with grant option;
grant select on DBA_AUDIT_POLICY_COLUMNS to OMEGACA with grant option;
grant select on DBA_JOBS to OMEGACA with grant option;
grant select on DBA_OBJECTS to OMEGACA with grant option;
grant select on DBA_OBJ_AUDIT_OPTS to OMEGACA with grant option;
grant select on DBA_PROFILES to OMEGACA with grant option;
grant select on DBA_ROLES to OMEGACA with grant option;
grant select on DBA_ROLE_PRIVS to OMEGACA with grant option;
grant select on DBA_SCHEDULER_JOBS to OMEGACA with grant option;
grant select on DBA_SCHEDULER_JOB_RUN_DETAILS to OMEGACA with grant option;
grant select on DBA_STMT_AUDIT_OPTS to OMEGACA with grant option;
grant select on DBA_SYS_PRIVS to OMEGACA with grant option;
grant select on DBA_TABLESPACES to OMEGACA with grant option;
grant select on DBA_TAB_COLS to OMEGACA with grant option;
grant select on DBA_TAB_PRIVS to OMEGACA with grant option;
grant select on DBA_TRIGGERS to OMEGACA with grant option;
grant select on DBA_TS_QUOTAS to OMEGACA with grant option;
grant select on DBA_USERS to OMEGACA with grant option;
grant select on PROFNAME$ to OMEGACA with grant option;
grant select on STMT_AUDIT_OPTION_MAP to OMEGACA with grant option;
grant select on SYSTEM_PRIVILEGE_MAP to OMEGACA with grant option;
grant select on V_$PARAMETER to OMEGACA with grant option;

   
-- 05. Omega CA - Roles
prompt 05. Omega CA - Roles
prompt ==================================================
prompt
   
-- Create Omega CA Roles

create role OMEGACA_ACCTMGR;
grant create session to OMEGACA_ACCTMGR;

create role OMEGACA_ADMIN;
grant create session to OMEGACA_ADMIN;

create role OMEGACA_AUDIT;
grant create session to OMEGACA_AUDIT;

create role OMEGACA_SECANALYST;
grant create session to OMEGACA_SECANALYST;

   
-- 06. Omega CA - Engine Package
prompt 06. Omega CA - Engine Package
prompt ==================================================
prompt
   

  CREATE OR REPLACE PACKAGE "SYS"."OMEGA_CORE_AUDIT" IS

--  ------------------------------------------------------------------------------------------
-- This source is part of the Omega Core Audit Software System and is copyrighted by DATAPLUS.
--
-- All rights reserved.  No part of this work may be reproduced, stored in a retrieval system,
-- adopted or transmitted in any form or by any means, electronic or otherwise, translated
-- in any language or computer language, without the prior written permission of DATAPLUS.
--
-- DATAPLUS.
-- Tirana, Albania.
-- Street Address: Bul. Zog I, P. Edicom, 8F.
-- Web:    www.dataplus-al.com
-- e-Mail: info@dataplus-al.com
-- Copyright  2015 by DATAPLUS.
--  ------------------------------------------------------------------------------------------

-- VERSION
-- 02.08.01

-- BEGIN SYS FACTOR
-- ===========================================================
-- ===========================================================
FUNCTION F_SYS_FACTOR_GET_VALUE (
         p_factor_id in integer,
         p_policy_type_id in integer
         )
RETURN VARCHAR2;


FUNCTION F_SYS_FACTOR_GET_VAL_VARCHAR2 (
         p_factor_id in integer,
         --p_factor_code in varchar2,
         p_policy_type_id in integer
         )
RETURN VARCHAR2;


FUNCTION F_SYS_FACTOR_GET_VAL_DATE (
         p_factor_id in integer,
         p_policy_type_id in integer
         )
RETURN DATE;


FUNCTION F_SYS_FACTOR_GET_VAL_NUMBER (
         p_factor_id in integer,
         p_policy_type_id in integer
         )
RETURN  NUMBER;


FUNCTION F_SYS_FACTOR_GET_TRUST_LEVEL (
         p_factor_id in integer,
         p_policy_type_id in integer
         )
RETURN  INTEGER;
-- ===========================================================
-- ===========================================================
-- END SYS FACTOR


-- BEGIN ACC
-- ===========================================================
-- ===========================================================

FUNCTION F_SYS_FACTOR_OPERAND_CMD (
          p_cond_id in integer,
         p_policy_type_id in integer
          )
RETURN VARCHAR2;

FUNCTION F_ACC_POL_COND_EVAL (
          p_cond_id in integer
          )
RETURN VARCHAR2;


FUNCTION F_ACC_POL_RULE_EVAL (
            p_rule_id in integer
            )
RETURN VARCHAR2;

PROCEDURE P_ACC_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          );

PROCEDURE P_ACC_UNF_TRAIL(
          p_timestamp_sts in timestamp,
          p_timestamp_utc in timestamp,
          p_returncode in number,
          p_trail_eval in varchar2,
          p_dbid in number
          );          

PROCEDURE P_ACC_DB_AF_LOGON;

-- ===========================================================
-- ===========================================================
-- END ACC


-- BEGIN ACM
-- ===========================================================
-- ===========================================================

PROCEDURE P_ACM_PRIV_SYS_GRANT (
          p_grantee in varchar2,
          p_sys_priv in varchar2,
          p_admin_option in integer
          );

PROCEDURE P_ACM_PRIV_SYS_REVOKE (
          p_grantee in varchar2,
          p_sys_priv in varchar2
          );

PROCEDURE P_ACM_PRIV_OBJ_GRANT (
          p_grantee in varchar2,
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_priv in varchar2,
          p_grant_option in integer
          );

PROCEDURE P_ACM_PRIV_OBJ_REVOKE (
          p_grantee in varchar2,
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_priv in varchar2
          );

PROCEDURE P_ACM_PRIV_ROLE_GRANT (
          p_grantee in varchar2,
          p_granted_role in varchar2,
          p_admin_option in integer
          );

PROCEDURE P_ACM_PRIV_ROLE_REVOKE (
          p_grantee in varchar2,
          p_granted_role in varchar2
          );

PROCEDURE P_ACM_PRIV_ROLE_DEFAULT (
          p_user in varchar2,
          p_role in varchar2,
          p_def_role in integer
          );

PROCEDURE P_ACM_ROLE_ALTER (
          p_role in varchar2,
          p_identification in integer,
          p_password in varchar2
          );

PROCEDURE P_ACM_ROLE_CREATE (
          p_role in varchar2,
          p_identification in integer,
          p_password in varchar2
          );

PROCEDURE P_ACM_ROLE_DROP (
          p_role in varchar2
          );

PROCEDURE P_ACM_USER_ALTER (
          p_user in varchar2,
          p_profile in varchar2,
          p_acc_locked in integer,
          p_default_tbs in varchar2,
          p_temp_tbs in varchar2
          );

PROCEDURE P_ACM_USER_CREATE (
          p_user in varchar2,
          p_profile in varchar2,
          p_identified_mode in varchar2,
          p_password in varchar2,
          p_global_external_name in varchar2,
          p_pass_expire in integer,
          p_acc_locked in integer,
          p_default_tbs in varchar2,
          p_temp_tbs in varchar2
          );

PROCEDURE P_ACM_USER_DROP (
          p_user in varchar2,
          p_cascade in integer
          );

PROCEDURE P_ACM_USER_PASS_EXPIRE (
          p_user in varchar2
          );

PROCEDURE P_ACM_USER_PASS_OWN (
          p_password in varchar2
          );

PROCEDURE P_ACM_USER_PASS_SET (
          p_user in varchar2,
          p_password in varchar2
          );

PROCEDURE P_ACM_USER_QUOTA (
          p_user in varchar2,
          p_tablespace in varchar2,
          p_unlimited in integer,
          p_quota in number
          );
-- ===========================================================
-- ===========================================================
-- END ACM


-- BEGIN AUD
-- ===========================================================
-- ===========================================================

PROCEDURE P_AUD_STMT_GEN (
          p_aud_stmt_id in integer,
          -- Statement[Privilege] Current
          p_audit_option_old in varchar2,
          p_audit_by_user_old in varchar2,
          p_success_failure_old in integer,
          -- Statement[Privilege] New
          p_audit_option_new in varchar2,
          p_audit_by_user_new in varchar2,
          p_success_failure_new in integer,
          -- Action
          p_action_code in integer -- 1-INS,2-UPD,3-DEL
          );

PROCEDURE P_AUD_OBJ_GEN (
          p_aud_obj_id in integer,
          -- Object (obj, dir, mining) Current
          p_sql_operation_old in varchar2,
          p_object_owner_old in varchar2,
          p_object_type_old in varchar2,
          p_object_name_old in varchar2,
          p_success_failure_old in integer,
          -- Object (obj, dir, mining) New
          p_sql_operation_new in varchar2,
          p_object_owner_new in varchar2,
          p_object_type_new in varchar2,
          p_object_name_new in varchar2,
          p_success_failure_new in integer,
          -- Action
          p_action_code in integer -- 1-INS,2-UPD,3-DEL
          );

PROCEDURE P_AUD_PRIV_SYS_DEF_AUDIT (
          p_priv in varchar2,
          p_status_id in integer
          );

PROCEDURE P_AUD_PRIV_SYS_NOAUDIT (
          p_priv in varchar2,
          p_user in varchar2
          );

PROCEDURE P_AUD_PRIV_OBJ_NOAUDIT (
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_type in varchar2,
          p_obj_priv_audited in varchar2
          );

PROCEDURE P_AUD_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          );
          
PROCEDURE P_AUD_UNF_TRAIL (
          p_TIMESTAMP_UTC in TIMESTAMP,
          p_USERNAME in varchar2,
          p_SESSIONID in number,
          p_OS_USER in varchar2,
          p_USERHOST in varchar2,
          p_ACTION_ID in number,
          p_OBJECT_OWNER in varchar2,
          p_OBJECT_NAME in varchar2,
          p_PRIVILEGE_ID in number,
          p_NEW_OWNER in varchar2,
          p_NEW_NAME in varchar2,
          p_AUTH_PRIVILEGES in varchar2,
          p_LOGOFF_DEAD in number,
          p_GRANTEE in varchar2,
          p_SES_ACTIONS in varchar2,
          p_LOGOFF_TIME in DATE,
          p_LOGOFF_LREAD in number,
          p_LOGOFF_PREAD in number,
          p_LOGOFF_LWRITE in number,
          p_CLIENT_ID in varchar2,
          p_TERMINAL in varchar2,          
          p_DBID in number,
          p_DB_NAME in varchar2,
          p_INSTANCE_NUMBER in number,
          p_STATEMENTID in number,
          p_ENTRYID in number,
          p_TRANSACTIONID in raw,
          p_SCN in number,
          p_PROXY_SESSIONID in number,
          p_GLOBAL_UID in varchar2,
          p_ECONTEXT_ID in varchar2,
          p_COMMENT_TEXT in varchar2,
          p_OS_PROCESS in varchar2,
          p_SESSIONCPU in varchar2,
          p_RETURNCODE in number,
          p_SQL_BIND in clob,
          p_SQL_TEXT in clob,
          p_OBJ_EDITION in varchar2,
          p_trail_eval in varchar2
				  );             

PROCEDURE P_AUD_TRAIL_PURGE;

-- ===========================================================
-- ===========================================================
-- END AUD


-- BEGIN RTP DDL
-- ===========================================================
-- ===========================================================

FUNCTION F_RTP_DDL_POL_COND_EVAL (
         p_cond_id in integer
         )
RETURN VARCHAR2;


FUNCTION F_RTP_DDL_POL_RULE_EVAL (
         p_rule_id in integer
         )
RETURN VARCHAR2;


PROCEDURE P_RTP_DDL_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          );

PROCEDURE P_RTP_DDL_UNF_TRAIL (
          p_timestamp_sts in timestamp,
          p_timestamp_utc in timestamp,
          p_ora_owner in varchar2,
          p_ora_object_name in varchar2,
          p_ora_object_type in varchar2,
          p_ora_sys_event in varchar2,
          p_ddl_body in clob,
          p_ddl_cmd in clob,
          p_returncode in number,
          p_return_message in varchar2,
          p_trail_eval in varchar2,
          p_dbid in number
				  );          
          
FUNCTION  F_RTP_DDL_TRAIL_DDL_BODY
          RETURN CLOB;

FUNCTION  F_RTP_DDL_TRAIL_DDL_CMD
          RETURN CLOB;

PROCEDURE P_RTP_DB_BF_DDL;

-- ===========================================================
-- ===========================================================
-- END RTP DDL


-- BEGIN RTP DML
-- ===========================================================
-- ===========================================================

FUNCTION F_RTP_DML_POL_COND_EVAL (
         p_cond_id in integer
         )
RETURN VARCHAR2;


FUNCTION F_RTP_DML_POL_RULE_EVAL (
         p_rule_id in integer
         )
RETURN VARCHAR2;

PROCEDURE P_RTP_DML_POL_CACHE_INS (
          p_rule_id in integer,
          p_rule_factor_str in varchar2,
          p_policy_result in varchar2
          );


FUNCTION F_RTP_DML_POL_RULE_AUD_POL_CND (
         p_rule_id in integer
         )
-- called by P_RTP_POLICY_RULE_DML_GEN  as fga policy's
--  audit_condition dbms_fga.add_policy param !!!!!!!!
-- analogue with Trigger RTP_DB_DDL_BF of RTP DDL !!!
-- HARDCODE set on every RTP-DML FGA policy as audit_condition !!!
RETURN VARCHAR2;


PROCEDURE P_RTP_DML_AUD_POL_ADD(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2,
          p_audit_condition in varchar2,
          p_audit_column in varchar2,
          p_handler_schema in varchar2,
          p_handler_module in varchar2,
          p_enable in boolean,
          p_statement_types in varchar2,
          p_audit_trail in integer,
          p_audit_col_opt in integer,
          p_audit_condition_priv_run in integer -- 0 - do not run, 1 - run
          );

PROCEDURE P_RTP_DML_AUD_POL_DROP(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2,
          p_audit_condition_priv_run in integer -- 0 - do not run, 1 - run
          );

PROCEDURE P_RTP_DML_AUD_POL_ENABLE(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2
          );

PROCEDURE P_RTP_DML_AUD_POL_DISABLE(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2
          );

PROCEDURE P_RTP_DML_POL_RULE_GEN (
          p_rule_id in integer,
          p_rule_status_id in integer,
          -- FGA options
          p_object_owner in varchar2,
          p_object_name in varchar2,
          p_fga_policy_name in varchar2,
          p_audit_condition_type in integer,
          p_audit_condition in varchar2,
          p_audit_column    in varchar2,
          p_statement_SEL   in integer,
          p_statement_INS   in integer,
          p_statement_UPD   in integer,
          p_statement_DEL   in integer,
          p_audit_trail     in integer,
          p_audit_col_opt   in integer,
          p_action_code     in integer -- 1-INS,2-UPD,3-DEL
          );

PROCEDURE P_RTP_DML_POL_RULE_STAT (
          p_object_owner in varchar2,
          p_object_name in varchar2,
          p_fga_policy_name in varchar2,
          p_status_id in integer
          );

PROCEDURE P_RTP_DML_POL_RULE_AUD_POL_HND (
          p_object_owner VARCHAR2,
          p_object_name VARCHAR2,
          p_fga_policy_name VARCHAR2
				  );
       
PROCEDURE P_RTP_DML_UNF_TRAIL (
          p_TIMESTAMP_UTC in TIMESTAMP,
          p_USERNAME in varchar2,
          p_SESSIONID in number,
          p_OS_USER in varchar2,
          p_USERHOST in varchar2,
          p_ACTION_ID in number,
          p_OBJECT_OWNER in varchar2,
          p_OBJECT_NAME in varchar2,
          p_CLIENT_ID in varchar2,
          p_DBID in number,
          p_DB_NAME in varchar2,
          p_INSTANCE_NUMBER in number,
          p_STATEMENTID in number,
          p_ENTRYID in number,
          p_TRANSACTIONID in raw,
          p_SCN in number,
          p_PROXY_SESSIONID in number,
          p_GLOBAL_UID in varchar2,
          p_ECONTEXT_ID in varchar2,
          p_COMMENT_TEXT in varchar2,
          p_OS_PROCESS in varchar2,
          p_RETURNCODE in number,
          p_RETURN_MESSAGE in varchar2,
          p_SQL_BIND in clob,
          p_SQL_TEXT in clob,
          p_FGA_POLICY_NAME in varchar2,
          p_EXT_NAME in varchar2,
          p_OBJ_EDITION in varchar2,
          p_trail_eval in varchar2
				  );    

PROCEDURE P_RTP_DML_TRAIL_PURGE;

-- ===========================================================
-- ===========================================================
-- END RTP DML



-- BEGIN SYS_MANAGE
-- ===========================================================
-- ===========================================================

PROCEDURE P_SYS_UNF_TRAIL_MARK_SNG (
p_row_id in varchar2,
p_issue_id in integer
);

PROCEDURE P_SYS_UNF_TRAIL_MARK_MLT (
p_trail_condition in varchar2,
p_issue_id in integer
);

FUNCTION F_SYS_USER_IS_OMEGACA_ADMIN
RETURN INTEGER;

PROCEDURE P_SYS_POL_DEBUG (
          p_username in varchar2,
          p_policy_type_id in integer,
          p_policy_id in integer,
          p_policy_name in varchar2,
          p_rule_id in integer,
          p_rule_name in varchar2,
          p_cond_id in integer,
          p_cond_code in varchar2,
          p_eval_result in varchar2,
          p_debug_log in varchar2
          );

PROCEDURE P_SYS_ERROR_LOG (
          p_error_data in varchar2
          );

PROCEDURE P_SYS_TRAIL_TRANS;


PROCEDURE P_SYS_MANAGE_ACC (
          p_trigger_status in integer
          );


PROCEDURE P_SYS_MANAGE_AUD (
          p_audit_trail_param_value in varchar2
          );


PROCEDURE P_SYS_MANAGE_AUD_SCHED_JOB (
          p_scheduler_job_status in integer
          );


PROCEDURE P_SYS_MANAGE_RTP_DDL (
          p_trigger_status in integer
          );


PROCEDURE P_SYS_ORACLE_VERSION_INFO(
          p_oracle_version_no       out integer,
          p_oracle_mntn_release_no  out integer,
          p_oracle_patchset_no      out integer
          );

-- ===========================================================
-- ===========================================================
-- END SYS_MANAGE


END;
-- END PACKAGE SPECIFICATIONS
/
   

  CREATE OR REPLACE PACKAGE BODY "SYS"."OMEGA_CORE_AUDIT" AS

--  ------------------------------------------------------------------------------------------
-- This source is part of the Omega Core Audit Software System and is copyrighted by DATAPLUS.
--
-- All rights reserved.  No part of this work may be reproduced, stored in a retrieval system,
-- adopted or transmitted in any form or by any means, electronic or otherwise, translated
-- in any language or computer language, without the prior written permission of DATAPLUS.
--
-- DATAPLUS.
-- Tirana, Albania.
-- Street Address: Bul. Zog I, P. Edicom, 8F.
-- Web:    www.dataplus-al.com
-- e-Mail: info@dataplus-al.com
-- Copyright  2015 by DATAPLUS.
--  ------------------------------------------------------------------------------------------

-- VERSION
-- 02.08.01

-- BEGIN SYS FACTOR
-- ===========================================================
-- ===========================================================

FUNCTION F_SYS_FACTOR_GET_VALUE (
         p_factor_id in integer,
         p_policy_type_id in integer
         )
  -- Return Factor Value as STRING hardcode-formated
  -- by OMEGA CA Standart !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   return  Varchar2 is

V_FACTOR_VALUE          varchar2(4000);

v_factor_value_varchar2      varchar2(4000);
v_factor_value_date          date;
v_factor_value_number        number;

v_ret_data_type              OMEGACA.sys_factor.ret_data_type%TYPE;

begin

-- Get Factor Return Data Type
select ret_data_type into v_ret_data_type
from OMEGACA.sys_factor where factor_id = p_factor_id;


-- BEGIN GET FACTOR BY RETURN DATA TYPE

-- Begin Make VARCHAR2 Factor
if    v_ret_data_type = 'VARCHAR2' then
v_factor_value_varchar2 := F_SYS_FACTOR_GET_VAL_VARCHAR2(
                           p_factor_id,
                           --v_factor_code,
                           p_policy_type_id
                           );
V_FACTOR_VALUE := v_factor_value_varchar2 ;
-- End Make VARCHAR2 Factor


-- Begin Make DATE Factor
elsif v_ret_data_type = 'DATE' then
v_factor_value_date := F_SYS_FACTOR_GET_VAL_DATE(
                       p_factor_id,
                       p_policy_type_id
                       );
V_FACTOR_VALUE :=  to_char(v_factor_value_date, 'DD-MM-YYYY');
V_FACTOR_VALUE := 'TO_DATE(' || '''' || v_factor_value || '''' || ', ' || '''DD-MM-YYYY''' || ')' ;
-- End Make DATE Factor


-- Begin Make NUMBER Factor
elsif v_ret_data_type = 'NUMBER' then
v_factor_value_number := F_SYS_FACTOR_GET_VAL_NUMBER(
                         p_factor_id,
                         p_policy_type_id
                         );
V_FACTOR_VALUE := to_char(v_factor_value_number);
-- End Make NUMBER Factor


-- Begin non-declared Factor DATATYPE
else
raise_application_error(-20020, 'Unknown factor return data type !');
end if;
-- End non-declared Factor DATATYPE

-- END GET FACTOR BY RETURN DATA TYPE


return V_FACTOR_VALUE;

end ; -- end proc

-- ================================================================

FUNCTION F_SYS_FACTOR_GET_VAL_VARCHAR2 (
         p_factor_id in integer,
         --p_factor_code in varchar2,
         p_policy_type_id in integer
         )

   return  varchar2 is

V_SQL                varchar2(1000);
v_retrieval_expr     OMEGACA.sys_factor_pol_type.retrieval_expr%TYPE;

v_factor_value       varchar2(4000);

begin

-- get retrieval_expr
select retrieval_expr into v_retrieval_expr
from OMEGACA.sys_factor_pol_type
where factor_id = p_factor_id
and policy_type_id = p_policy_type_id;


-- Prepare Factor retrieval Sql and execute
V_SQL := 'DECLARE
         BEGIN
         :p1 := '|| v_retrieval_expr || ';
         END;';
EXECUTE IMMEDIATE V_SQL using out v_factor_value;

-- !!! CLEAR chr(0) BUG in SYSCONTEXT of client version 9  ??????????????????
v_factor_value := translate(v_factor_value, 'a' || chr(0), 'a');

return v_factor_value;

end ; -- end proc

-- ================================================================

FUNCTION F_SYS_FACTOR_GET_VAL_DATE (
         p_factor_id in integer,
         p_policy_type_id in integer
         )

   return  Date is

V_SQL                varchar2(2000);
v_retrieval_expr     OMEGACA.sys_factor_pol_type.retrieval_expr%TYPE;

v_factor_value       Date;

begin

-- get retrieval_expr
select retrieval_expr into v_retrieval_expr
from OMEGACA.sys_factor_pol_type
where factor_id = p_factor_id
and policy_type_id = p_policy_type_id;


-- Prepare Factor retrieval Sql and execute
V_SQL := 'DECLARE
         BEGIN
         :p1 := '|| v_retrieval_expr || ';
         END;';
EXECUTE IMMEDIATE V_SQL using out v_factor_value;

return v_factor_value;

end ; -- end proc

-- ==================================================================

FUNCTION F_SYS_FACTOR_GET_VAL_NUMBER (
         p_factor_id in integer,
         p_policy_type_id in integer
         )

   return  Number is

V_SQL                varchar2(2000);
v_retrieval_expr     OMEGACA.sys_factor_pol_type.retrieval_expr%TYPE;

v_factor_value       Number;

begin

-- get retrieval_expr
select retrieval_expr into v_retrieval_expr
from OMEGACA.sys_factor_pol_type
where factor_id = p_factor_id
and policy_type_id = p_policy_type_id;


-- Prepare Factor retrieval Sql and execute
V_SQL := 'DECLARE
         BEGIN
         :p1 := '|| v_retrieval_expr || ';
         END;';
EXECUTE IMMEDIATE V_SQL using out v_factor_value;

return v_factor_value;

end ; -- end proc

-- ==================================================================

FUNCTION F_SYS_FACTOR_GET_TRUST_LEVEL (
         p_factor_id in integer,
         p_policy_type_id in integer
         )

   return  integer is

v_ret_data_type      OMEGACA.sys_factor.ret_data_type%TYPE;

v_factor_value        varchar2(4000);
v_factor_value_date   date;

v_factor_trust_level  OMEGACA.sys_factor_identity.trust_level_no%TYPE;

begin

-- Get Factor Return Data Type
select ret_data_type into v_ret_data_type
from OMEGACA.sys_factor where factor_id = p_factor_id;


-- begin get factor value by return_data_type
if    v_ret_data_type = 'VARCHAR2' then
v_factor_value := F_SYS_FACTOR_GET_VAL_VARCHAR2(
                  p_factor_id,
                  --v_factor_code,
                  p_policy_type_id
                  );

elsif v_ret_data_type = 'DATE' then
v_factor_value_date := F_SYS_FACTOR_GET_VAL_DATE(
                    p_factor_id,
                    p_policy_type_id
                    );
v_factor_value := TO_CHAR(v_factor_value_date, 'DD-MM-YYYY');

elsif v_ret_data_type = 'NUMBER' then
v_factor_value := F_SYS_FACTOR_GET_VAL_NUMBER(
                  p_factor_id,
                  p_policy_type_id
                  );
else
raise_application_error(-20020, 'Unknown Factor return data Type !');
end if;


-- get factor trust level
BEGIN
select trust_level_no into v_factor_trust_level
from OMEGACA.sys_factor_identity
where factor_id = p_factor_id
and factor_value = v_factor_value;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_factor_trust_level := -1; -- -1 = Undefined
END;

return v_factor_trust_level;

end ; -- end proc

-- ================================================================

FUNCTION F_SYS_FACTOR_OPERAND_CMD (
         p_cond_id in integer,
         p_policy_type_id in integer
         )
return  Varchar2 is

V_COND_EVAL_OPR_CMD          varchar2(4000);

v_factor_id                  integer;
v_opr_code_id                integer;
v_code_symbol                OMEGACA.sys_operation_code.code_symbol%TYPE;
v_operand_1                  varchar2(1000);
v_operand_2                  varchar2(1000);

-- Init and use variable - no hard parse
  p_cond_list_status_id integer := 1; -- Active
-- ACC Active Cond List Cursor
cursor C_ACC is
select * from OMEGACA.acc_pol_cond_list
where cond_id = p_cond_id
and status_id = p_cond_list_status_id
order by list_id;
-- RTP_DDL Active Cond List Cursor
cursor C_RTP_DDL is
select * from OMEGACA.rtp_ddl_pol_cond_list
where cond_id = p_cond_id
and status_id = p_cond_list_status_id
order by list_id;
-- RTP_DML Active Cond List Cursor
cursor C_RTP_DML is
select * from OMEGACA.rtp_dml_pol_cond_list
where cond_id = p_cond_id
and status_id = p_cond_list_status_id
order by list_id;

v_rule_id                    integer;

v_factor_value               varchar2(4000);
v_factor_value_varchar2      varchar2(4000);
v_factor_value_date          date;
v_factor_value_number        number;

v_ret_data_type              OMEGACA.sys_factor.ret_data_type%TYPE;

begin

-- get ACC cond details
if p_policy_type_id = 1 then -- Pol Type = 1 = ACC
select rule_id, factor_id, opr_code_id, operand_1, operand_2
into v_rule_id, v_factor_id, v_opr_code_id, v_operand_1, v_operand_2
from OMEGACA.acc_pol_cond
where cond_id = p_cond_id;
-- get RTP DDL cond details
elsif p_policy_type_id = 3 then -- Pol Type = 3 = RTP DDL
select rule_id, factor_id, opr_code_id, operand_1, operand_2
into v_rule_id, v_factor_id, v_opr_code_id, v_operand_1, v_operand_2
from OMEGACA.rtp_ddl_pol_cond
where cond_id = p_cond_id;
-- get RTP DDL cond details
elsif p_policy_type_id = 4 then -- Pol Type = 4 = RTP DDL
select rule_id, factor_id, opr_code_id, operand_1, operand_2
into v_rule_id, v_factor_id, v_opr_code_id, v_operand_1, v_operand_2
from OMEGACA.rtp_dml_pol_cond
where cond_id = p_cond_id;
-- Raise if non 1,3,4
else
raise_application_error(-20020, 'Policy type not in 1-ACC, 3-RTP_DDL or 4-RTP_DML !');
end if;


-- get code_symbol
select code_symbol into v_code_symbol
from OMEGACA.sys_operation_code
where code_id = v_opr_code_id;

-- Get Factor Return Data Type
select ret_data_type into v_ret_data_type
from OMEGACA.sys_factor where factor_id = v_factor_id;


-- BEGIN GET FACTOR BY RETURN DATA TYPE

-- Begin Make VARCHAR2 Factor
if    v_ret_data_type = 'VARCHAR2' then
v_factor_value_varchar2 := F_SYS_FACTOR_GET_VAL_VARCHAR2(
                           v_factor_id,
                           --v_factor_code,
                           p_policy_type_id
                           );
v_factor_value := '''' || v_factor_value_varchar2 || '''';

if v_code_symbol in ('IN', 'NOT IN') then

   -- begin loop acc_pol_cond_list
   if p_policy_type_id = 1 then -- Pol Type = 1 = ACC
   for rec in C_ACC loop
   v_operand_1 := v_operand_1 || '''' || rec.operand_1 || '''' || ',';
   end loop;
   end if;
   -- end loop acc_pol_cond_list
   -- begin loop rtp_ddl_pol_cond_list
   if p_policy_type_id = 3 then -- Pol Type = 3 = RTP DDL
   for rec in C_RTP_DDL loop
   v_operand_1 := v_operand_1 || '''' || rec.operand_1 || '''' || ',';
   end loop;
   end if;
   -- end loop rtp_ddl_pol_cond_list
   -- begin loop rtp_dml_pol_cond_list
   if p_policy_type_id = 4 then -- Pol Type = 4 = RTP DDL
   for rec in C_RTP_DML loop
   v_operand_1 := v_operand_1 || '''' || rec.operand_1 || '''' || ',';
   end loop;
   end if;
   -- end loop rtp_dml_pol_cond_list

v_operand_1 := Substr(v_operand_1, 1, length(v_operand_1)-1); -- Cut last Comma (,)

else
-- Format Operands 1 and 2 as Text when not done from [NOT] IN
v_operand_1 := '''' || v_operand_1 || '''';
v_operand_2 := '''' || v_operand_2 || '''';
end if;
-- End Make VARCHAR2 Factor


-- Begin Make DATE Factor
elsif v_ret_data_type = 'DATE' then
v_factor_value_date := F_SYS_FACTOR_GET_VAL_DATE(
                       v_factor_id,
                       p_policy_type_id
                       );
v_factor_value :=  to_char(v_factor_value_date, 'DD-MM-YYYY');
v_factor_value := 'TO_DATE(' || '''' || v_factor_value || '''' || ', ' || '''DD-MM-YYYY''' || ')' ;

if v_code_symbol in ('IN', 'NOT IN') then

   -- begin loop acc_pol_cond_list
   if p_policy_type_id = 1 then -- Pol Type = 1 = ACC
   for rec in C_ACC loop
   v_operand_1 := v_operand_1 || 'TO_DATE(' ||  '''' || rec.operand_1 || '''' || ', ' || '''DD-MM-YYYY''' || ')' ||  ',';
   end loop;
   end if;
   -- end loop acc_pol_cond_list
   -- begin loop rtp_ddl_pol_cond_list
   if p_policy_type_id = 3 then -- Pol Type = 3 = RTP DDL
   for rec in C_RTP_DDL loop
   v_operand_1 := v_operand_1 || 'TO_DATE(' ||  '''' || rec.operand_1 || '''' || ', ' || '''DD-MM-YYYY''' || ')' ||  ',';
   end loop;
   end if;
   -- end loop rtp_ddl_pol_cond_list
   -- begin loop rtp_dml_pol_cond_list
   if p_policy_type_id = 4 then -- Pol Type = 4 = RTP DML
   for rec in C_RTP_DML loop
   v_operand_1 := v_operand_1 || 'TO_DATE(' ||  '''' || rec.operand_1 || '''' || ', ' || '''DD-MM-YYYY''' || ')' ||  ',';
   end loop;
   end if;
   -- end loop rtp_dml_pol_cond_list

v_operand_1 := Substr(v_operand_1, 1, length(v_operand_1)-1); -- Cut last Comma (,)

else
-- Format Operands 1 and 2 as Date when not done from [NOT] IN
v_operand_1 := 'TO_DATE(' || '''' || v_operand_1 || '''' || ', ' || '''DD-MM-YYYY''' || ')' ;
v_operand_2 := 'TO_DATE(' || '''' || v_operand_2 || '''' || ', ' || '''DD-MM-YYYY''' || ')' ;
end if;
-- End Make DATE Factor


-- Begin Make NUMBER Factor
elsif v_ret_data_type = 'NUMBER' then
v_factor_value_number := F_SYS_FACTOR_GET_VAL_NUMBER(
                         v_factor_id,
                         p_policy_type_id
                         );
v_factor_value := to_char(v_factor_value_number);

if v_code_symbol in ('IN', 'NOT IN') then

   -- begin loop acc_pol_cond_list
   if p_policy_type_id = 1 then -- Pol Type = 1 = ACC
   for rec in C_ACC loop
   v_operand_1 := v_operand_1 || rec.operand_1 || ',';
   end loop;
   end if;
   -- end loop loop acc_pol_cond_list
   -- begin loop rtp_ddl_pol_cond_list
   if p_policy_type_id = 3 then -- Pol Type = 3 = RTP DDL
   for rec in C_RTP_DDL loop
   v_operand_1 := v_operand_1 || rec.operand_1 || ',';
   end loop;
   end if;
   -- end loop loop rtp_ddl_pol_cond_list
   -- begin loop rtp_dml_pol_cond_list
   if p_policy_type_id = 4 then -- Pol Type = 4 = RTP DML
   for rec in C_RTP_DML loop
   v_operand_1 := v_operand_1 || rec.operand_1 || ',';
   end loop;
   end if;
   -- end loop loop rtp_dml_pol_cond_list

v_operand_1 := Substr(v_operand_1, 1, length(v_operand_1)-1); -- Cut last Comma (,)
end if;
-- No need to Format Operands 1 and 2 as Number when not done from [NOT] IN
-- End Make NUMBER Factor


-- Begin non-declared Factor DATATYPE
else
raise_application_error(-20020, 'Unknown factor return data type !');
end if;
-- End non-declared Factor DATATYPE

-- END GET FACTOR BY RETURN DATA TYPE


-- BEGIN DECIDE BY OPERATION CODE
if v_code_symbol in ('BETWEEN', 'NOT BETWEEN') then
V_COND_EVAL_OPR_CMD := v_factor_value
                       || ' ' || v_code_symbol
                       || ' ' || v_operand_1
                       || ' and ' || v_operand_2 ;

elsif v_code_symbol in ('IS NULL', 'IS NOT NULL') then
V_COND_EVAL_OPR_CMD := v_factor_value
                       || ' ' || v_code_symbol ;

elsif v_code_symbol in ('IN', 'NOT IN') then
V_COND_EVAL_OPR_CMD := v_factor_value
                       || ' ' || v_code_symbol
                       || ' (' ||  v_operand_1 || ')' ;

else
V_COND_EVAL_OPR_CMD := v_factor_value
                       || ' ' || v_code_symbol
                       || ' ' ||  v_operand_1 ;
end if;
-- END DECIDE BY OPERATION CODE


return V_COND_EVAL_OPR_CMD;

end ; -- end proc

-- ===========================================================
-- ===========================================================
-- END SYS FACTOR


-- BEGIN ACC
-- ================================================================
-- ================================================================

FUNCTION F_ACC_POL_COND_EVAL (
         p_cond_id in integer
         )

RETURN VARCHAR2 IS

v_rule_id                      OMEGACA.acc_pol_cond.rule_id%TYPE;

v_cond_eval                    OMEGACA.acc_pol_cond.cond_eval%TYPE;
v_min_trust_level_no           OMEGACA.acc_pol_cond.min_trust_level_no%TYPE;
v_validate_expr_owner          OMEGACA.acc_pol_cond.validate_expr_owner%TYPE;
v_validate_expr_object         OMEGACA.acc_pol_cond.validate_expr_object%TYPE;
v_factor_id                    OMEGACA.acc_pol_cond.factor_id%TYPE;

v_policy_id                    OMEGACA.acc_pol_rule.policy_id%TYPE;
v_rule_name                    OMEGACA.acc_pol_rule.rule_name%TYPE;

v_policy_name                  OMEGACA.acc_pol.policy_name%TYPE;
v_policy_audit_option          OMEGACA.acc_pol.audit_option%TYPE;
v_policy_debug_log             OMEGACA.acc_pol.debug_log%TYPE;

V_COND_EVAL_OPR_CMD            Varchar2(4000);
v_cond_trust_level             integer;

v_expr_factor_code             OMEGACA.sys_factor.factor_code%TYPE;
v_expr_factor_value            Varchar2(4000);

V_SQL                          Varchar2(2000);
V_COND_LOG_DETAIL              Varchar2(4000);

V_COND_RESULT                  OMEGACA.sys_pol_debug.eval_result%TYPE;

BEGIN

-- get rule_id and cond details
select rule_id, cond_eval, min_trust_level_no,
validate_expr_owner, validate_expr_object, factor_id
into v_rule_id, v_cond_eval, v_min_trust_level_no,
v_validate_expr_owner, v_validate_expr_object, v_factor_id
from OMEGACA.acc_pol_cond
where cond_id = p_cond_id;

-- get policy_id
select policy_id, rule_name
into v_policy_id, v_rule_name
from OMEGACA.acc_pol_rule
where rule_id = v_rule_id;

-- get policy data
select policy_name, audit_option, debug_log
into v_policy_name, v_policy_audit_option, v_policy_debug_log
from OMEGACA.acc_pol
where policy_id = v_policy_id;


-- Begin Condition is Operand evaluated
if v_cond_eval = 1 then -- 1 = Operand

V_COND_EVAL_OPR_CMD := F_SYS_FACTOR_OPERAND_CMD(
                       p_cond_id,
                       1 -- Pol Type = 1 = ACC
                       );

V_SQL := 'DECLARE
          BEGIN
          if ' || V_COND_EVAL_OPR_CMD || ' then
          :p1 := ''TRUE'';
          else
          :p1 := ''FALSE'';
          end if;
          END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Operand: ' || V_COND_EVAL_OPR_CMD
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Operand evaluated


-- Begin Condition is Trust Level evaluated
elsif v_cond_eval = 2 then -- 2 = Trust Level
v_cond_trust_level := F_SYS_FACTOR_GET_TRUST_LEVEL(
                      v_factor_id,
                      1 -- policy_type_id = 1 = ACC = Access Control
                      );

if v_cond_trust_level < v_min_trust_level_no then
V_COND_RESULT := 'FALSE';
else
V_COND_RESULT := 'TRUE';
end if;

V_COND_LOG_DETAIL := 'Trust Level Found: ' || to_char(v_cond_trust_level)
                  || ', Min. Trust Level required: ' || to_char(v_min_trust_level_no)
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Trust Level evaluated


-- Begin Condition is Validate Expression evaluated
elsif v_cond_eval = 3 then -- 3 = Validate Expression

-- Get Factor Code - First (1st) Val Expr Function Param
select factor_code into v_expr_factor_code
from OMEGACA.sys_factor
where factor_id = v_factor_id;

-- Make Factor Value - Second (2d) Val Expr Function Param
v_expr_factor_value := F_SYS_FACTOR_GET_VALUE(
                       v_factor_id,
                       1 -- Pol Type = 1 = ACC
                       );

-- Prepare Validation Expression Exec Command
V_SQL := 'DECLARE
      res boolean;
      BEGIN
      res := '|| v_validate_expr_owner || '.' || v_validate_expr_object
      || '('
      || '''' || to_char(v_expr_factor_code) || '''' -- string (quoted)
      || ','
      || '''' || to_char(v_expr_factor_value) || '''' -- string (quoted)
      || ')'
      ||';
      if res then
      :p1 := ''TRUE'';
      else
      :p1 := ''FALSE'';
      end if;
      END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Validate Expression: ' || V_SQL
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Validate Expression evaluated


-- Begin Unknown Cond_Eval, Raise
else
raise_application_error(-20020, 'Access Control Condition Evaluation method not in 1-Operand, 2-Trust Level, 3-Validate Expression !');
end if;
-- End Unknown Cond_Eval, Raise


-- Insert Condition Log if policy_log = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
1, -- 1 = ACC
v_policy_id,
v_policy_name,
v_rule_id,
v_rule_name,
p_cond_id,
Lpad(p_cond_id, 7, '0'), -- COND_CODE LENGTH = 7
V_COND_RESULT,
v_cond_log_detail
);
End if;


RETURN V_COND_RESULT;

END ;

-- ================================================================

FUNCTION F_ACC_POL_RULE_EVAL (
         p_rule_id in integer
         )

RETURN VARCHAR2 IS

v_policy_id             OMEGACA.acc_pol_rule.policy_id%TYPE;
v_cond_eval             OMEGACA.acc_pol_rule.cond_eval%TYPE;

v_rule_name             OMEGACA.acc_pol_rule.rule_name%TYPE;
v_rule_formula          OMEGACA.acc_pol_rule.formula%TYPE;

S                       varchar2(1024);
I                       integer;
x                       integer;
y                       integer;
V_FORMULA               varchar2(1024);

v_cond_id               OMEGACA.acc_pol_cond.cond_id%TYPE;
v_cond_status           OMEGACA.acc_pol_cond.status_id%TYPE;
v_cond_result           OMEGACA.sys_pol_debug.eval_result%TYPE;
v_rule_log_detail       varchar2(4000);

v_policy_name           OMEGACA.acc_pol.policy_name%TYPE;
v_policy_audit_option   OMEGACA.acc_pol.audit_option%TYPE;
v_policy_debug_log      OMEGACA.acc_pol.debug_log%TYPE;

V_RULE_RESULT           OMEGACA.sys_pol_debug.eval_result%TYPE;

-- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
-- Cond Cursor
cursor C_Cond is select * from OMEGACA.acc_pol_cond
where rule_id = p_rule_id
and status_id = p_cond_status_id
order by cond_id ;

begin

-- get rule data
select policy_id, cond_eval, formula, rule_name
into v_policy_id, v_cond_eval, v_rule_formula, v_rule_name
from OMEGACA.acc_pol_rule
where rule_id = p_rule_id;

-- Get Policy Data
select policy_name, audit_option, debug_log
into v_policy_name, v_policy_audit_option, v_policy_debug_log
from OMEGACA.acc_pol
where policy_id = v_policy_id;


-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
1, -- 1 = ACC
v_policy_Id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
'UNSET',
'Rule: evaluation...'
);
end if;


-- Initialize Rule Result default FALSE
V_RULE_RESULT := 'FALSE';


-- BEGIN ANY TRUE
if v_cond_eval = 1 then -- 1 = Any True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_ACC_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'TRUE' then
V_RULE_RESULT := 'TRUE';
Exit; -- Exit Condition Loop when TRUE on Any True found
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ANY TRUE - ' || V_RULE_RESULT;
-- END ANY TRUE


-- BEGIN ALL TRUE
elsif v_cond_eval = 2 then -- 2 = All True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_ACC_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'FALSE' then
V_RULE_RESULT := 'FALSE';
Exit; -- Exit Condition Loop when FALSE on All True found
else
V_RULE_RESULT := 'TRUE'; -- Continue Loop, remain last if no FALSE
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ALL TRUE - ' || V_RULE_RESULT;
-- END ALL TRUE


-- BEGIN FORMULA
elsif v_cond_eval = 3 then -- 3 = Formula

-- BEGIN LOOP FORMULA STRING SEARCHING For DATA INSIDE []
for I in 1..100 loop

x := INSTR(v_rule_formula, '[', 1, 1);

if X = 0 then
exit;
end if;

y := 9; -- COND_CODE LENGTH 7 + 2
--dbms_output.put_line('x' || I ||'=' || x);
--dbms_output.put_line('y' || I ||'=' || y);
S:= SUBSTR(v_rule_formula, x, y);
--dbms_output.put_line('S'  || I ||'=' || S);
v_cond_id := To_Number( substr(S, 2, 7) ); -- COND_CODE LENGTH 7 !!!

-- Begin Check Inactive Condition status_id=0
select status_id into v_cond_status
from OMEGACA.acc_pol_cond
where cond_id = v_cond_id;

if v_cond_status = 0 then
-- Raise Error
raise_application_error(-20020, 'Access Control Policy: ' || v_policy_name
                                || ', Rule: ' || v_rule_name
                                || ' - Inactive Condition ' || S || ' included in formula !');

end if;
-- End Check Inactive Condition status_id=0

v_cond_result := F_ACC_POL_COND_EVAL(
                 v_cond_id
                 );

v_rule_formula := REPLACE(v_rule_formula, S, v_cond_result);

end loop;
-- END LOOP FORMULA STRING SEARCHING For DATA INSIDE []

V_FORMULA := 'DECLARE
            res boolean;
            BEGIN
               res := '|| v_rule_formula ||';
               if res then
                  :p1 := ''TRUE'';
               else
                  :p1 := ''FALSE'';
               end if;
            END;';
v_rule_log_detail := 'FORMULA - ' || v_rule_formula;

EXECUTE IMMEDIATE V_FORMULA using out V_RULE_RESULT;
-- END FORMULA


else -- raise if none
raise_application_error(-20020, 'Access Control Rule Condition Evaluation not in 1-Any True, 2-All True, 3-Formula !');
end if;


-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
1, -- 1 = ACC
v_policy_Id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
V_RULE_RESULT,
'Rule: ' || v_rule_log_detail
);
End if;


RETURN V_RULE_RESULT;

end; -- end proc

-- ================================================================
PROCEDURE P_ACC_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          )

AS

begin

-- Insert acc_pol_cache
insert into OMEGACA.acc_pol_cache
(
policy_id,
policy_factor_str,
policy_result
)
values
(
p_policy_id,
p_policy_factor_str,
p_policy_result
);

end; -- end proc

-- ===========================================================

PROCEDURE P_ACC_UNF_TRAIL(
          p_timestamp_sts in timestamp,
          p_timestamp_utc in timestamp,
          p_returncode in number,
          p_trail_eval in varchar2,
          p_dbid in number
          )
as

v_return_message varchar2(2000);

begin

-- Make Return Message
if p_returncode = 0 then
v_return_message := 'ORA-00000: normal, successful completion';
elsif p_returncode = -20010 then
v_return_message := 'Access Control Policy non-compliance';
else
v_return_message := To_Char(p_returncode);
end if;

-- Insert UNF Trail for ACC
insert into OMEGACA.sys_unf_trail
(
TIMESTAMP_STS,
TIMESTAMP_UTC,
POLICY_TYPE_ID,
USERNAME,
SESSIONID,
OS_USER,
USERHOST,
ACTION_NAME,
TERMINAL,
IP_ADDRESS,
NETWORK_PROTOCOL,
DBID,
DB_NAME,
INSTANCE_NUMBER,
AUTHENTICATION_METHOD,
IDENTIFICATION_TYPE,
ISDBA,
MODULE,
BG_JOB_ID,
FG_JOB_ID,
RETURNCODE,
RETURN_MESSAGE,
ISSUE_ID,
TRAIL_EVAL
)
values
(
p_timestamp_sts,
p_timestamp_utc,
1, -- Default Pol Type 1=ACC
USER,
SYS_CONTEXT('USERENV', 'SESSIONID'),
SYS_CONTEXT('USERENV', 'OS_USER'),
SYS_CONTEXT('USERENV', 'HOST'),
'LOGON', -- ACTION_NAME
SYS_CONTEXT('USERENV', 'TERMINAL'),
SYS_CONTEXT('USERENV', 'IP_ADDRESS'),
SYS_CONTEXT('USERENV', 'NETWORK_PROTOCOL'),
p_dbid,
SYS_CONTEXT('USERENV', 'DB_NAME'),
SYS_CONTEXT('USERENV', 'INSTANCE'),
NULL, -- AUTHENTICATION_METHOD,
SYS_CONTEXT('USERENV', 'IDENTIFICATION_TYPE'),
SYS_CONTEXT('USERENV', 'ISDBA'),
SYS_CONTEXT('USERENV', 'MODULE'),
SYS_CONTEXT('USERENV', 'BG_JOB_ID'),
SYS_CONTEXT('USERENV', 'FG_JOB_ID'),
p_returncode,
v_return_message,
0, -- 0 = Issue_Id UNMARKED,
p_trail_eval
);

end;

-- ===========================================================

PROCEDURE P_ACC_DB_AF_LOGON
as

  POLICY_USER_GO           Boolean;
  POLICY_CACHE_REC_FOUND   Boolean;
  SINGLE_TRUE_POLICY_FOUND Boolean; -- least one TRUE Policy

  V_POLICY_RESULT        OMEGACA.sys_pol_debug.eval_result%TYPE;
  
  v_policy_formula       OMEGACA.acc_pol.formula%TYPE;
  v_policy_log_detail    Varchar2(4000);

  S                      varchar2(1024);
  I                      integer;
  x                      integer;
  y                      integer;
  V_FORMULA              varchar2(1024);

  v_rule_id              OMEGACA.acc_pol_rule.rule_id%TYPE;
  v_rule_status          OMEGACA.acc_pol_rule.status_id%TYPE;
  v_rule_result          OMEGACA.sys_pol_debug.eval_result%TYPE;

  -- Init and use variable - no hard parse
  p_policy_status_id integer := 1; -- Active
  -- Policy Cursor
  cursor C_Policy is select * from OMEGACA.acc_pol
  where status_id = p_policy_status_id
  order by policy_id ;

  -- Init and use variable - no hard parse
  p_rule_status_id integer := 1; -- Active
  -- Rule Cursor
  cursor C_Rule (Pls_Id in integer) is select * from OMEGACA.acc_pol_rule
  where policy_id = Pls_Id
  and status_id = p_rule_status_id
  order by rule_id ;

  v_factor_value          varchar2(4000);
  v_policy_factor_str     OMEGACA.acc_pol_cache.policy_factor_str%TYPE;

  -- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
  p_rule_sts_id integer := 1; -- Active
  -- Distincted Factor_Id Conditions of Policy - Cursor
  cursor C_Cond_Cache (Pol_Id in integer) is
  select distinct factor_id from OMEGACA.v_acc_pol_cond_ids
  where policy_id = Pol_Id
  and status_id = p_cond_status_id
  and rule_status_id = p_rule_sts_id
  order by factor_id;

v_db_open_mode            sys.V$DATABASE.OPEN_MODE%TYPE;
v_dbid                    sys.V$DATABASE.DBID%TYPE;

v_acc_silent              OMEGACA.sys_param.PARAM_VALUE%TYPE;
-- Parameter ID = 1 = ACCSLNT
p_param_id_ACCSLNT        integer :=1 ; 

v_trail_pol_tmp           varchar2(1000);
v_trail_pol               varchar2(2000);
TRAIL_INS                 Boolean;
v_returncode              OMEGACA.sys_unf_trail.RETURNCODE%TYPE;

v_timestamp_sts           OMEGACA.sys_unf_trail.TIMESTAMP_STS%TYPE;
v_timestamp_utc           OMEGACA.sys_unf_trail.TIMESTAMP_UTC%TYPE;

-- Policy User Variables
cnt_policy_user_apply    integer;
cnt_policy_user_exclude  integer;
p_pol_user_apply         integer :=1 ; -- 1 = Apply
p_pol_user_exclude       integer :=2 ; -- 2 = Exclude

PRAGMA AUTONOMOUS_TRANSACTION;

begin

-- ACC TIMESTAMPS - FIRST ACTION
v_timestamp_sts := SYSTIMESTAMP;
v_timestamp_utc := SYS_EXTRACT_UTC(SYSTIMESTAMP);


-- BEGIN CHECK DB OPEN MODE
-- Get Database Data
select open_mode, dbid
into v_db_open_mode, v_dbid
from sys.V$DATABASE;
-- Check Read-Write Status
if v_db_open_mode <> 'READ WRITE' then
RETURN;    -- Quit Further Processing - Return Proc
end if;
-- END CHECK DB OPEN MODE


-- BEGIN MAIN BEGIN-EXCEPTION-END
BEGIN


-- Set default SINGLE_TRUE_POLICY_FOUND to False
SINGLE_TRUE_POLICY_FOUND := False;
-- Set default TRAIL_INS to False
TRAIL_INS := False;

-- BEGIN LOOP C_POLICY
for Rec_Policy in C_Policy loop


-- Begin Evaluate POLICY_USER_GO
if Rec_Policy.User_Apply = 0 then -- 0 Policy goes to all users

POLICY_USER_GO := True;


elsif Rec_Policy.User_Apply = 1 then -- 1 Policy goes only for apply users

select count(*) into cnt_policy_user_apply
from OMEGACA.acc_pol_user
where policy_id = Rec_Policy.Policy_Id
and user_id = USER
and user_apply = p_pol_user_apply; -- 1=Apply

if cnt_policy_user_apply = 1 then
POLICY_USER_GO := True;
else
POLICY_USER_GO := False;
end if;


elsif Rec_Policy.User_Apply = 2 then -- 2 Policy goes not for exlude users

select count(*) into cnt_policy_user_exclude
from OMEGACA.acc_pol_user
where policy_id = Rec_Policy.Policy_Id
and user_id = USER
and user_apply = p_pol_user_exclude; -- 2=Exclude;

if cnt_policy_user_exclude = 1 then
POLICY_USER_GO := False;
else
POLICY_USER_GO := True;
end if;


else
raise_application_error(-20020, 'Access Control Policy User Appliance option not in 0-All Users, 1-Users Apply, 2-Users Exclude !');
end if;
-- End Evaluate POLICY_USER_GO



-- BEGIN PROCESS POLICY ONLY IF POLICY_USER_GO is TRUE
if POLICY_USER_GO then


-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
1, -- 1 = ACC
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
'UNSET',
'Policy: evaluation...'
);
end if;


-- ============= BEGIN PROCESS CACHE ====================
if Rec_Policy.Use_Cache = 1 then

-- Initialize Factor String to NULL
v_policy_factor_str := '';
-- Begin Loop Distincted factor for Cache
for rec1 in C_Cond_Cache(Rec_Policy.Policy_Id) loop
v_factor_value := F_SYS_FACTOR_GET_VALUE(
                  rec1.factor_id,
                  1 -- Pol Type = 1 = ACC
                  );
v_policy_factor_str := v_policy_factor_str || '~' || v_factor_value;
end loop;
-- End Loop Distincted factor for Cache

-- Begin Check and raise Empty Factor String = No Active Rule-Condition
if v_policy_factor_str is null then
raise_application_error(-20020, 'Access Control Policy: ' || Rec_Policy.Policy_Name
                                || ' - no Active Condition[s] found !');
end if;
-- End Check and raise Empty Factor String = No Active Rule-Condition

BEGIN
select policy_result into V_POLICY_RESULT
from OMEGACA.acc_pol_cache
where policy_id = Rec_Policy.Policy_Id
and policy_factor_str = v_policy_factor_str;
POLICY_CACHE_REC_FOUND := True;
EXCEPTION
WHEN NO_DATA_FOUND then
POLICY_CACHE_REC_FOUND := False;
END;

end if;
-- ============= END PROCESS CACHE ====================



-- BEGIN PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]
if Rec_Policy.Use_Cache = 0 or
(Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False ) then

-- BEGIN POLICY EVALUATION

-- Initialize Policy Result default FALSE
V_POLICY_RESULT := 'FALSE';


-- BEGIN ANY TRUE
if Rec_Policy.Rule_Eval = 1 then -- 1 = Any True

-- Begin Loop Rules
for rec_rule in C_Rule(Rec_Policy.Policy_Id) loop

v_rule_result := F_ACC_POL_RULE_EVAL(
                 rec_rule.rule_id
                 );

if v_rule_result = 'TRUE' then
V_POLICY_RESULT := 'TRUE';
Exit; -- Exit Rule Loop when TRUE on Any True found
end if;

end loop;
-- End Loop Rules

v_policy_log_detail := 'ANY TRUE - ' || V_POLICY_RESULT;
-- END ANY TRUE


-- BEGIN ALL TRUE
elsif Rec_Policy.Rule_Eval = 2 then -- 2 = All True

-- Begin Loop Rules
for rec_rule in C_Rule(Rec_Policy.Policy_Id) loop

v_rule_result := F_ACC_POL_RULE_EVAL(
                 rec_rule.rule_id
                 );

if v_rule_result = 'FALSE' then
V_POLICY_RESULT := 'FALSE';
Exit; -- Exit Rule Loop when FALSE on All True found
else
V_POLICY_RESULT := 'TRUE'; -- Continue Loop, remain last if no FALSE
end if;

end loop;
-- End Loop Rules

v_policy_log_detail := 'ALL TRUE - ' || V_POLICY_RESULT;
-- END ALL TRUE


-- BEGIN FORMULA
elsif Rec_Policy.Rule_Eval = 3 then -- 3 = Formula

v_policy_formula := Rec_Policy.Formula;

-- BEGIN LOOP FORMULA STRING SEARCHING For DATA INSIDE []
for I in 1..100 loop

x := INSTR(v_policy_formula, '[', 1, 1);

if X = 0 then
exit;
end if;

y := 9; -- COND_CODE LENGTH 7 + 2
S:= SUBSTR(v_policy_formula, x, y);
v_rule_id := To_Number( substr(S, 2, 7) ); -- COND_CODE LENGTH 7


-- Begin Check Inactive Rule status_id=0
select status_id into v_rule_status
from OMEGACA.acc_pol_rule
where rule_id = v_rule_id;

if v_rule_status = 0 then
-- Raise Error
raise_application_error(-20020, 'Access Control Policy: ' || Rec_Policy.Policy_Name
                                || ' - Inactive Rule ' || S || ' included in formula !');
end if;
-- End Check Inactive Rule status_id=0

v_rule_result := F_ACC_POL_RULE_EVAL(
                 v_rule_id
                 );

v_policy_formula := REPLACE(v_policy_formula, S, v_rule_result);

end loop;
-- END LOOP FORMULA STRING SEARCHING For DATA INSIDE []

V_FORMULA := 'DECLARE
            res boolean;
            BEGIN
               res := '|| v_policy_formula ||';
               if res then
                  :p1 := ''TRUE'';
               else
                  :p1 := ''FALSE'';
               end if;
            END;';

v_policy_log_detail := 'FORMULA - ' || v_policy_formula;

EXECUTE IMMEDIATE V_FORMULA using out V_POLICY_RESULT;
-- END FORMULA


else -- raise if none
raise_application_error(-20020, 'Access Control Policy Rule Evaluation not in 1-Any True, 2-All True, 3-Formula !');
end if;

-- END POLICY EVALUATION



-- BEGIN INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]
if Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False then

-- Insert Cache
P_ACC_POL_CACHE_INS(
Rec_Policy.Policy_Id,
v_policy_factor_str,
V_POLICY_RESULT
);

end if;
-- END INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]


end if;
-- END PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]



-- BEGIN UPDATE LOG IF POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then

-- Make Detail if cache
If Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND then
v_policy_log_detail := 'CACHE - ' || V_POLICY_RESULT;
end if;

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
1, -- 1 = ACC
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
V_POLICY_RESULT,
'Policy: ' || v_policy_log_detail
);

end if;
-- END UPDATE LOG IF POLICY_LOG = 1


-- BEGIN DO ACCESS CONTROL TRAIL

-- Begin 1 - Audit On Failure.
if Rec_Policy.Audit_Option = 1 then
if V_POLICY_RESULT = 'FALSE'  then
TRAIL_INS := True;
end if;
end if;
-- End 1 - Audit On Failure.

-- Begin 2 - Audit On Success/Failure.
if Rec_Policy.Audit_Option = 2 then
TRAIL_INS := True;
end if;
-- End 2 - Audit On Success/Failure.


-- Begin Make Trail Policies
v_trail_pol_tmp :=
'<Policy>'
|| Chr(10)
|| '<Id>'       || Rec_Policy.Policy_Id     || '</Id>'
|| Chr(10)
|| '<Name>'     || Rec_Policy.Policy_Name   || '</Name>'
|| Chr(10)
|| '<Result>'   || V_POLICY_RESULT          || '</Result>'
|| Chr(10)
|| '</Policy>';

if v_trail_pol is null then
v_trail_pol := v_trail_pol_tmp;
else
v_trail_pol := v_trail_pol
               || Chr(10)
               || v_trail_pol_tmp;
end if;
-- End Make Trail Policies

-- END DO ACCESS CONTROL TRAIL


-- Set SINGLE_TRUE_POLICY_FOUND if TRUE
if V_POLICY_RESULT = 'TRUE' then
SINGLE_TRUE_POLICY_FOUND := True;
EXIT; -- Exit Policy loop when first TRUE found !
end if;


end if;
-- END PROCESS POLICY ONLY IF POLICY_USER_GO is TRUE


end loop;
-- END LOOP C_POLICY


-- Begin Insert Trail if Param Set TRUE
if TRAIL_INS or SINGLE_TRUE_POLICY_FOUND = False then

   if SINGLE_TRUE_POLICY_FOUND = False then
      -- Parameter_Id = 1 = ACCSLNT = Silent Access Control
      select param_value into v_acc_silent
      from OMEGACA.sys_param
      where parameter_id = p_param_id_ACCSLNT;
            -- Begin set v_returncode by ACCSLNT 1=Silent
            if v_acc_silent <> 1 then
            v_returncode := -20010;
            else
            v_returncode := 0;
            end if;
            -- End set v_returncode by ACCSLNT 1=Silent
   else -- TRUE_POLICY_FOUND = TRUE
   v_returncode := 0;
   end if;

-- Insert UNF Trail for ACC
P_ACC_UNF_TRAIL(
v_timestamp_sts,
v_timestamp_utc,
v_returncode,
v_trail_pol,
v_dbid
);

end if;
-- End Insert Trail if Param Set TRUE


-- Raise Error if -20010
if v_returncode = -20010 then
raise_application_error(-20010, 'Access Control Policy non-compliance !');
end if;


COMMIT;  -- MAIN COMMIT, last before MAIN EXCEPTION

EXCEPTION -- MAIN EXCEPTION

WHEN OTHERS THEN

If SQLCODE = -20010 then
COMMIT;
RAISE;
elsif SQLCODE = -20020 then
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
RAISE;
else -- non Omegaca 20010,20020
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
end if;

END;
-- END MAIN BEGIN-EXCEPTION-END

end;

-- ===========================================================
-- ===========================================================
-- END ACC


-- BEGIN ACM
-- ===========================================================
-- ===========================================================

PROCEDURE P_ACM_PRIV_SYS_GRANT (
          p_grantee in varchar2,
          p_sys_priv in varchar2,
          p_admin_option in integer
          ) is

v_admin_option varchar2(200);
v_grant_cmd    varchar2(2000);

begin

-- No Operations on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'System Privilege Grant not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'System Privilege Grant not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'System Privilege Grant not allowed on Omega CA Roles !' );
end if;


-- Make Admin Option
if p_admin_option = 1 then
v_admin_option := ' with admin option ' ;
end if;

-- Make Cmd
v_grant_cmd := 'grant ' || p_sys_priv
                  || ' to ' || p_grantee
                  || v_admin_option ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_PRIV_SYS_REVOKE (
          p_grantee in varchar2,
          p_sys_priv in varchar2
          ) is

v_grant_cmd    varchar2(2000);

begin

-- no Operation on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'System Privilege Revoke not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'System Privilege Revoke not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'System Privilege Revoke not allowed on Omega CA Roles !' );
end if;


-- Make Cmd
v_grant_cmd := 'revoke ' || p_sys_priv
                  || ' from ' || p_grantee ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_PRIV_OBJ_GRANT (
          p_grantee in varchar2,
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_priv in varchar2,
          p_grant_option in integer
          ) is

v_grant_option varchar2(200);
v_grant_cmd    varchar2(2000);

begin

-- No Operations on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'Object Privilege Grant not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'Object Privilege Grant not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'Object Privilege Grant not allowed on Omega CA Roles !' );
end if;

-- No Operations on Omega CA Objects
if p_obj_owner = 'OMEGACA' then
raise_application_error(-20010, 'Object Privilege Grant not allowed on Omega CA Objects !' );
end if;


-- Make Grant Option
if p_grant_option = 1 then
v_grant_option := ' with grant option ' ;
end if;

-- Make Cmd
v_grant_cmd := 'grant ' || p_obj_priv
                  || ' on ' || p_obj_owner || '.' || p_obj_name
                  || ' to ' || p_grantee
                  || v_grant_option ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;
-- ===========================================================

PROCEDURE P_ACM_PRIV_OBJ_REVOKE (
          p_grantee in varchar2,
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_priv in varchar2
          ) is

v_grant_cmd    varchar2(2000);

begin

-- No Operations on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'Object Privilege Revoke not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'Object Privilege Revoke not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'Object Privilege Revoke not allowed on Omega CA Roles !' );
end if;

-- No Operations on Omega CA Objects
if p_obj_owner = 'OMEGACA' then
raise_application_error(-20010, 'Object Privilege Revoke not allowed on Omega CA Objects !' );
end if;


-- Make Cmd
v_grant_cmd := 'revoke ' || p_obj_priv
                  || ' on ' || p_obj_owner || '.' || p_obj_name
                  || ' from ' || p_grantee ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_PRIV_ROLE_GRANT (
          p_grantee in varchar2,
          p_granted_role in varchar2,
          p_admin_option in integer
          ) is

v_admin_option varchar2(200);
v_grant_cmd    varchar2(2000);

begin

-- No Operations on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'Role Privilege Grant not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'Role Privilege Grant not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'Role Privilege Grant not allowed on Omega CA Roles !' );
end if;

-- Omega CA Roles Granted only by Omega CA Admin
if p_granted_role in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrator can grant Omega CA Roles !' );
end if;
end if;


-- Make Admin Option
if p_admin_option = 1 then
v_admin_option := ' with admin option ' ;
end if;

-- Make Cmd
v_grant_cmd := 'grant ' || p_granted_role
                  || ' to ' || p_grantee
                  || v_admin_option ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_PRIV_ROLE_REVOKE (
          p_grantee in varchar2,
          p_granted_role in varchar2
          ) is

v_grant_cmd    varchar2(2000);

begin

-- No Operations on SYS
if p_grantee = 'SYS' then
raise_application_error(-20010, 'Role Privilege Revoke not allowed on SYS Account !' );
end if;

-- No Operations on Omega CA Repository
if p_grantee = 'OMEGACA' then
raise_application_error(-20010, 'Role Privilege Revoke not allowed on Omega CA Repository Account !' );
end if;

-- No Operations on Omega CA Roles
if p_grantee in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
raise_application_error(-20010, 'Role Privilege Revoke not allowed on Omega CA Roles !' );
end if;

-- Omega CA Roles Revoked only by Omega CA Admin
if p_granted_role in ('OMEGACA_ACCTMGR', 'OMEGACA_ADMIN', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST') then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrator can revoke Omega CA Roles !' );
end if;
end if;


-- Make Cmd
v_grant_cmd := 'revoke ' || p_granted_role
                  || ' from ' || p_grantee ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_PRIV_ROLE_DEFAULT (
          p_user in varchar2,
          p_role in varchar2,
          p_def_role in integer -- 0-Default No, 1-Default Yes
          ) is

v_default_role      varchar2(2000);

cursor C1 is select * from DBA_ROLE_PRIVS
where grantee = p_user
order by granted_role;

v_grant_cmd    varchar2(2000);

begin

-- Check Default Role Mode
if p_def_role not in (0,1) then
raise_application_error(-20010, 'Default Role Mode not in 0-Default No, 1-Default Yes !' );
end if;


-- Begin loop DBA_ROLE_PRIVS
for rec in C1 loop
-- Begin Role is Granted Default=YES
if rec.default_role = 'YES' then

   if p_role <> rec.granted_role then
     if v_default_role is null then
     v_default_role := rec.granted_role;
     else
     v_default_role := v_default_role || + ', ' || rec.granted_role;
     end if;
   end if;

end if;
-- End Role is Granted Default=YES
end loop;
-- End loop DBA_ROLE_PRIVS

-- Add role to Default list if 1-Default Yes
if p_def_role = 1 then
   if v_default_role is null then
   v_default_role := p_role;
   else
   v_default_role := p_role || + ', ' || v_default_role;
   end if;
end if;


-- Make Cmd
v_grant_cmd := 'alter user ' || p_user
                  || ' default role ' || v_default_role ;

-- Execute Command
EXECUTE IMMEDIATE v_grant_cmd ;

end;

-- ===========================================================

PROCEDURE P_ACM_ROLE_ALTER (
          p_role in varchar2,
          p_identification in integer,
          p_password in varchar2
          ) is

v_identification varchar2(200);
v_role_cmd    varchar2(2000);

begin

if p_identification = 1 and p_password is null then
raise_application_error(-20010, 'Provide a Password for Password Identification !');
end if;

if p_identification = 0 then
v_identification := ' not identified' ;
elsif p_identification = 1 then
v_identification := ' identified by ' || p_password ;
elsif p_identification = 2 then
v_identification := ' identified externally' ;
else
raise_application_error(-20010, 'Unknown Identification Option !');
end if;


-- Make Cmd
v_role_cmd := 'alter role ' || p_role
                  || v_identification ;

-- Execute Command
EXECUTE IMMEDIATE v_role_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_ROLE_CREATE (
          p_role in varchar2,
          p_identification in integer,
          p_password in varchar2
          ) is

v_identification varchar2(200);
v_role_cmd    varchar2(2000);

begin

if p_identification = 1 and p_password is null then
raise_application_error(-20010, 'Provide a Password for Password Identification !');
end if;

if p_identification = 0 then
v_identification := '' ;
elsif p_identification = 1 then
v_identification := ' identified by ' || p_password ;
elsif p_identification = 2 then
v_identification := ' identified externally' ;
else
raise_application_error(-20010, 'Unknown Identification Option !');
end if;

-- Make Cmd
v_role_cmd := 'create role ' || p_role
                  || v_identification ;

-- Execute Command
EXECUTE IMMEDIATE v_role_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_ROLE_DROP (
          p_role in varchar2
          ) is

v_role_cmd    varchar2(2000);

begin

-- Make Cmd
v_role_cmd := 'drop role ' || p_role ;

-- Execute Command
EXECUTE IMMEDIATE v_role_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_ALTER (
          p_user in varchar2,
          p_profile in varchar2,
          p_acc_locked in integer,
          p_default_tbs in varchar2,
          p_temp_tbs in varchar2
          ) is

v_acc_locked varchar2(200);
v_user_cmd    varchar2(2000);

begin

-- check no operation on SYS
if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account cannot be modified !' );
end if;


if p_acc_locked = 0 then
v_acc_locked := ' account unlock ';
elsif p_acc_locked = 1 then
v_acc_locked := ' account lock ';
else
raise_application_error(-20010, 'Wrong Lock Value, 0/1 only permited !' );
end if;


-- Make Cmd
v_user_cmd := 'alter user ' || p_user
                  || ' profile ' || p_profile
                  || ' default tablespace ' || p_default_tbs
                  || ' temporary tablespace ' || p_temp_tbs
                  || v_acc_locked ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_CREATE (
          p_user in varchar2,
          p_profile in varchar2,
          p_identified_mode in varchar2,
          p_password in varchar2,
          p_global_external_name in varchar2,
          p_pass_expire in integer,
          p_acc_locked in integer,
          p_default_tbs in varchar2,
          p_temp_tbs in varchar2
          ) is

v_pass_expire varchar2(200);
v_acc_locked varchar2(200);
v_identified_mode varchar2(200);
v_user_cmd    varchar2(2000);

begin

if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account ??? !' );
end if;

if p_identified_mode = 'BY' then
v_identified_mode := ' identified by ' || p_password ;

elsif p_identified_mode = 'EXTERNALLY' then
v_identified_mode := ' identified externally ' ;
   if p_global_external_name is not null then
   v_identified_mode := v_identified_mode
   || ' as ' || '''' || p_global_external_name || '''' ;
   end if;

elsif p_identified_mode = 'GLOBALLY' then
v_identified_mode := ' identified globally ';
   if p_global_external_name is not null then
   v_identified_mode := v_identified_mode
   || ' as ' || '''' || p_global_external_name || '''' ;
   end if;
end if;

if p_pass_expire = 1 then
v_pass_expire := ' password expire ';
end if;

if p_acc_locked = 1 then
v_acc_locked := ' account lock ';
end if;

-- Make Cmd
v_user_cmd := 'create user ' || p_user
                  || v_identified_mode
                  || ' profile ' || p_profile
                  || ' default tablespace ' || p_default_tbs
                  || ' temporary tablespace ' || p_temp_tbs
                  || v_pass_expire
                  || v_acc_locked ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_DROP (
          p_user in varchar2,
          p_cascade in integer
          ) is

v_cascade varchar2(200);
v_user_cmd    varchar2(2000);

begin

-- check no operation on SYS
if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account cannot be dropped !' );
end if;

-- check no operation on OMEGACA
if p_user = 'OMEGACA' then
raise_application_error(-20010, 'OMEGACA account cannot be dropped !' );
end if;


if p_cascade = 0 then
v_cascade := '';
elsif p_cascade = 1 then
v_cascade := ' cascade ';
else
raise_application_error(-20010, 'Wrong Cascade 1/0 value !' );
end if;

-- Make Cmd
v_user_cmd := 'drop user ' || p_user || v_cascade ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_PASS_EXPIRE (
          p_user in varchar2
          ) is

v_user_cmd    varchar2(2000);

begin

if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account cannot be expired !' );
end if;

-- Make Cmd
v_user_cmd := 'alter user ' || p_user || ' password expire' ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_PASS_OWN (
          p_password in varchar2
          ) is

v_user_cmd    varchar2(2000);

begin

-- Make Cmd
v_user_cmd := 'alter user '
                  || USER
                  || ' identified by '
                  || p_password ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_PASS_SET (
          p_user in varchar2,
          p_password in varchar2
          ) is

v_user_cmd    varchar2(2000);

begin

if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account cannot be changed !' );
end if;

-- Make Cmd
v_user_cmd := 'alter user '
                  || p_user
                  || ' identified by '
                  || p_password ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================

PROCEDURE P_ACM_USER_QUOTA (
          p_user in varchar2,
          p_tablespace in varchar2,
          p_unlimited in integer,
          p_quota in number
          ) is

v_quota       varchar2(100);
v_user_cmd    varchar2(2000);

begin

-- Check No change on SYS user
if p_user = 'SYS' then
raise_application_error(-20010, 'SYS account cannot be changed !' );
end if;

-- Check Unlimted
if p_unlimited = 0 then
v_quota := to_char(p_quota) || 'M';
elsif p_unlimited = 1 then
v_quota := 'Unlimited';
else
raise_application_error(-20010, 'Wrong Unlimited 1/0 value !');
end if;

-- Make Cmd
v_user_cmd := 'alter user '
                  || p_user
                  || ' quota '
                  || v_quota
                  || ' on '
                  || p_tablespace ;

-- Execute Command
EXECUTE IMMEDIATE v_user_cmd ;

end ;

-- ===========================================================
-- ===========================================================
-- END ACM


-- BEGIN AUD
-- ===========================================================
-- ===========================================================

PROCEDURE P_AUD_STMT_GEN (
          p_aud_stmt_id in integer,
          -- Statement[Privilege] Current
          p_audit_option_old in varchar2,
          p_audit_by_user_old in varchar2,
          p_success_failure_old in integer,
          -- Statement[Privilege] New
          p_audit_option_new in varchar2,
          p_audit_by_user_new in varchar2,
          p_success_failure_new in integer,
          -- Action
          p_action_code in integer -- 1-INS,2-UPD,3-DEL
          )
          is

-- No ddl auto-commit in the DML of the calling proc
-- Pragma AT does not see original DML changes
PRAGMA AUTONOMOUS_TRANSACTION;

-- mind Metalink 429814.1 - Cannot Audit On Dictionary Views if
-- other then SYS  O7_DICTIONARY_ACCESSIBILITY must be TRUE
-- Not only for Audit but for all commands SYS Object stays hidden

-- Oracle Version Variables
v_oracle_version_no       integer;
v_oracle_mntn_release_no  integer;
v_oracle_patchset_no      integer;

v_success_failure_clause_old  varchar2(200);
v_success_failure_clause_new  varchar2(200);

cnt_SF_rem_1  integer := 0;
cnt_S_rem_2   integer := 0;
cnt_F_rem_3   integer := 0;

-- Init and use variable - no hard parse
p_aud_stmt_status_id integer := 1; -- Active
-- Remaining Stmt Audits cursor
cursor c_aud_rem is select success_failure
from OMEGACA.aud_pol_stmt
where audit_option = p_audit_option_old
and audit_by_user = p_audit_by_user_old
and aud_stmt_id <> p_aud_stmt_id
and status_id = p_aud_stmt_status_id;

DO_DROP_AUDIT  boolean := false;

v_audit_cmd    varchar2(2000);

begin

-- check Action Code
if p_action_code not in (1,2,3) then
raise_application_error(-20010, 'Wrong INS/UPD/DEL Action Code not in 1/2/3 !');
end if;


-- BEGIN Check for Action Code in 2-UPD, 3-DEL
if p_action_code in (2,3) then
-- BEGIN SUCCESS/FAILURE Old

-- Omega CA Repository Account can be noaudited only by Omega CA Administrator
if p_audit_by_user_old = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Account can be noaudited only by Omega CA Administrator !');
end if;
end if;

-- Check p_success_failure
if p_success_failure_old not in (1,2,3) or p_success_failure_old is null then
raise_application_error(-20010, 'Success/Failure not in 1-Success/Failure, 2-Success, 3-Failure !');
end if;
-- END SUCCESS/FAILURE Old

end if;
-- END Check for Action Code in 2-UPD, 3-DEL


-- BEGIN Check for Action Code in 1-INS, 2-UPD
if p_action_code in (1,2) then

-- Omega CA Repository Account can be audited only by Omega CA Administrator
if p_audit_by_user_new = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Account can be audited only by Omega CA Administrator !');
end if;
end if;

-- BEGIN SUCCESS/FAILURE New
-- Check p_success_failure
if p_success_failure_new not in (1,2,3) or p_success_failure_new is null then
raise_application_error(-20010, 'Success/Failure not in 1-Success/Failure, 2-Success, 3-Failure !');
end if;
-- END SUCCESS/FAILURE New

-- Make 2 = ALL STATEMENTS
if p_audit_option_new = 'ALL STATEMENTS' then

-- Get Version info
P_SYS_ORACLE_VERSION_INFO(
v_oracle_version_no,
v_oracle_mntn_release_no,
v_oracle_patchset_no
);

-- Check Ora Version for Feature Compatibility for 11g R2!
if v_oracle_mntn_release_no < 1102 then
raise_application_error(-20010, 'ALL STATEMENTS not available before 11g R2 !');
end if;

end if;

end if;
-- END Check for Action Code in 1-INS, 2-UPD


-- BEGIN NOAUDIT if Action Code in 2-UPD, 3-DEL
if p_action_code in (2,3) then

-- Begin Load Audit Settings to cnt_%
for rec_aud_rem in c_aud_rem loop

if rec_aud_rem.success_failure = 1 then
cnt_SF_rem_1 := cnt_SF_rem_1 + 1;
elsif rec_aud_rem.success_failure = 2 then
cnt_S_rem_2 := cnt_S_rem_2 + 1;
elsif rec_aud_rem.success_failure = 3 then
cnt_F_rem_3 := cnt_F_rem_3 + 1;
end if;

end loop;
-- End Load Audit Settings to cnt_%


-- Begin Make Noaudit drop counting cnt-s
-- -------------------------------------------
if cnt_SF_rem_1 = 0 and cnt_S_rem_2 = 0 and cnt_F_rem_3 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := '';
elsif cnt_SF_rem_1 = 0 and cnt_S_rem_2 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := ' whenever successful';
elsif cnt_SF_rem_1 = 0 and cnt_F_rem_3 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := ' whenever not successful';
else
DO_DROP_AUDIT := false;
end if;
-- -------------------------------------------
-- Begin Make Noaudit drop counting cnt-s


-- Begin NoAudit Statement if DO_DROP_AUDIT is True
if DO_DROP_AUDIT then
v_audit_cmd := 'noaudit '
            || p_audit_option_old
            || ' by ' || p_audit_by_user_old
            || v_success_failure_clause_old;

EXECUTE IMMEDIATE v_audit_cmd;
end if;
-- End NoAudit Statement if DO_DROP_AUDIT is True

end if;
-- END NOAUDIT if Action Code in 2-UPD, 3-DEL


-- BEGIN AUDIT if Action Code in 1-INS, 2-UPD
if p_action_code in (1,2) then

-- Make whenever successful/whenever not successful
if p_success_failure_new = 1 then
v_success_failure_clause_new := ''; -- empty = both
-- Make whenever successful
elsif p_success_failure_new = 2 then
v_success_failure_clause_new := ' whenever successful' ;
-- Make whenever not successful
elsif p_success_failure_new = 3 then
v_success_failure_clause_new := ' whenever not successful';
end if;


-- Begin Do AUDIT
v_audit_cmd := 'audit '
            || p_audit_option_new
            || ' by ' || p_audit_by_user_new
            || ' by access'  -- default
            || v_success_failure_clause_new;

EXECUTE IMMEDIATE v_audit_cmd ;
-- End Do AUDIT

end if;
-- END AUDIT if Action Code in 1-INS, 2-UPD

end ;

-- ============================================================

PROCEDURE P_AUD_OBJ_GEN (
          p_aud_obj_id in integer,
          -- Object (obj, dir, mining) Current
          p_sql_operation_old in varchar2,
          p_object_owner_old in varchar2,
          p_object_type_old in varchar2,
          p_object_name_old in varchar2,
          p_success_failure_old in integer,
          -- Object (obj, dir, mining) New
          p_sql_operation_new in varchar2,
          p_object_owner_new in varchar2,
          p_object_type_new in varchar2,
          p_object_name_new in varchar2,
          p_success_failure_new in integer,
          -- Action
          p_action_code in integer -- 1-INS,2-UPD,3-DEL
          )
          is

-- No ddl auto-commit in the DML of the calling proc
-- Pragma AT does not see original DML changes
PRAGMA AUTONOMOUS_TRANSACTION;

-- mind Metalink 429814.1 - Cannot Audit On Dictionary Views if
-- other then SYS  O7_DICTIONARY_ACCESSIBILITY must be TRUE
-- Not only for Audit but for all commands SYS Object stays hidden

v_auditing_on_clause          varchar2(1000);

v_success_failure_clause_old  varchar2(200);
v_success_failure_clause_new  varchar2(200);

cnt_SF_rem_1  integer := 0;
cnt_S_rem_2   integer := 0;
cnt_F_rem_3   integer := 0;

-- Init and use variable - no hard parse
p_aud_obj_status_id integer := 1; -- Active
-- Remaining Object Audits cursor
cursor c_aud_rem is select success_failure
from OMEGACA.aud_pol_obj
where object_owner = p_object_owner_old
and object_type = p_object_type_old
and object_name = p_object_name_old
and sql_operation = p_sql_operation_old
and aud_obj_id <> p_aud_obj_id
and status_id = p_aud_obj_status_id;

DO_DROP_AUDIT  boolean := false;

v_audit_cmd   varchar2(2000);

begin

-- check Action Code
if p_action_code not in (1,2,3) then
raise_application_error(-20010, 'Wrong INS/UPD/DEL Action Code not in 1/2/3 !');
end if;


-- BEGIN Check for Action Code in 2-UPD, 3-DEL
if p_action_code in (2,3) then

-- Omega CA Repository Objects can be noaudited only by Omega CA Administrator
if p_object_owner_old = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Objects can be noaudited only by Omega CA Administrator !' );
end if;
end if;

-- Begin Check AUDIT_SCHEMA_OBJECT_CLAUSE OLD
if p_object_type_old = 'MINING MODEL' then
raise_application_error(-20010, 'MINING MODEL Feature not available on noaudit !');
-- NEXT VERSION
end if;
-- End Check AUDIT_SCHEMA_OBJECT_CLAUSE OLD

-- BEGIN SUCCESS/FAILURE OLD
-- Check p_success_failure
if p_success_failure_old not in (1,2,3) or p_success_failure_old is null then
raise_application_error(-20010, 'Success/Failure not in 1-Success/Failure, 2-Success, 3-Failure !');
end if;
-- END SUCCESS/FAILURE OLD

end if;
-- END Check for Action Code in 2-UPD, 3-DEL


-- BEGIN Check for Action Code in 1-INS, 2-UPD
if p_action_code in (1,2) then

-- Omega CA Repository Objects can be audited only by Omega CA Administrator
if p_object_owner_new = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Objects can be audited only by Omega CA Administrator !' );
end if;
end if;

-- Begin Check AUDIT_SCHEMA_OBJECT_CLAUSE NEW
if p_object_type_new = 'MINING MODEL' then
raise_application_error(-20010, 'MINING MODEL Feature not available on audit !');
-- NEXT VERSION
end if;
-- End Check AUDIT_SCHEMA_OBJECT_CLAUSE NEW

-- BEGIN SUCCESS/FAILURE NEW
-- Check p_success_failure
if p_success_failure_new not in (1,2,3) or p_success_failure_new is null then
raise_application_error(-20010, 'Success/Failure not in 1-Success/Failure, 2-Success, 3-Failure !');
end if;
-- END SUCCESS/FAILURE NEW

end if;
-- END Check for Action Code in 1-INS, 2-UPD


-- BEGIN NOAUDIT if Action Code in 2-UPD, 3-DEL
if p_action_code in (2,3) then

-- Begin Make AUDIT_SCHEMA_OBJECT_CLAUSE OLD
-- Make 1 = Make Schema.Object
if p_object_type_old not in ('DIRECTORY', 'MINING MODEL') then
v_auditing_on_clause := ' on ' || p_object_owner_old || '.' || p_object_name_old;
-- Make 2 = DIRECTORY Directory_Name
elsif p_object_type_old = 'DIRECTORY' then
-- No Owner needed, directory always owned by SYS
v_auditing_on_clause := ' on DIRECTORY ' || p_object_name_old;
-- Make 3 = MINING MODEL Schema.Model
elsif p_object_type_old = 'MINING MODEL' then
v_auditing_on_clause := ' on MINING MODEL '
                     || p_object_owner_old || '.' || p_object_name_old ;
end if;
-- End Make AUDIT_SCHEMA_OBJECT_CLAUSE OLD


-- Begin Load Audit Settings to cnt_%
for rec_aud_rem in c_aud_rem loop

if rec_aud_rem.success_failure = 1 then
cnt_SF_rem_1 := cnt_SF_rem_1 + 1;
elsif rec_aud_rem.success_failure = 2 then
cnt_S_rem_2 := cnt_S_rem_2 + 1;
elsif rec_aud_rem.success_failure = 3 then
cnt_F_rem_3 := cnt_F_rem_3 + 1;
else
raise_application_error(-20010, 'Success/Failure not in 1-Success/Failure, 2-Success, 3-Failure !');
end if;

end loop;
-- End Load Audit Settings to cnt_%


-- Begin Make Noaudit drop counting cnt-s
-- -------------------------------------------
if cnt_SF_rem_1 = 0 and cnt_S_rem_2 = 0 and cnt_F_rem_3 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := '';
elsif cnt_SF_rem_1 = 0 and cnt_S_rem_2 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := ' whenever successful';
elsif cnt_SF_rem_1 = 0 and cnt_F_rem_3 = 0 then
DO_DROP_AUDIT := true;
v_success_failure_clause_old := ' whenever not successful';
else
DO_DROP_AUDIT := false;
end if;
-- -------------------------------------------
-- End Make Noaudit drop counting cnt-s


-- Begin NoAudit Statement if DO_DROP_AUDIT is True
if DO_DROP_AUDIT then
v_audit_cmd := 'noaudit '
            || p_sql_operation_old
            || v_auditing_on_clause
            || v_success_failure_clause_old;

EXECUTE IMMEDIATE v_audit_cmd;
end if;
-- End NoAudit Statement if DO_DROP_AUDIT is True

end if;
-- END NOAUDIT if Action Code in 2-UPD, 3-DEL


-- BEGIN INS AUDIT if Action Code in 1-INS, 2-UPD
if p_action_code in (1,2) then

-- Begin Make AUDIT_SCHEMA_OBJECT_CLAUSE NEW
-- Make 1 = Make Schema.Object
if p_object_type_new not in ('DIRECTORY', 'MINING MODEL') then
v_auditing_on_clause := ' on ' || p_object_owner_new || '.' || p_object_name_new;
-- Make 2 = DIRECTORY Directory_Name
elsif p_object_type_new = 'DIRECTORY' then
-- No Owner needed, directory always owned by SYS
v_auditing_on_clause := ' on DIRECTORY ' || p_object_name_new;
-- Make 3 = MINING MODEL Schema.Model
elsif p_object_type_new = 'MINING MODEL' then
v_auditing_on_clause := ' on MINING MODEL '
                     || p_object_owner_new || '.' || p_object_name_new ;
end if;
-- End Make AUDIT_SCHEMA_OBJECT_CLAUSE NEW


-- Make whenever successful/whenever not successful
if p_success_failure_new = 1 then
v_success_failure_clause_new := ''; -- empty = both
-- Make whenever successful
elsif p_success_failure_new = 2 then
v_success_failure_clause_new := ' whenever successful';
-- Make whenever not successful
elsif p_success_failure_new = 3 then
v_success_failure_clause_new := ' whenever not successful';
end if;

-- Begin Do AUDIT
v_audit_cmd := 'audit '
            || p_sql_operation_new
            || v_auditing_on_clause
            || ' by access'  -- default
            || v_success_failure_clause_new;

EXECUTE IMMEDIATE v_audit_cmd ;
-- Endin Do AUDIT

end if;
-- END INS AUDIT if Action Code in 1-INS, 2-UPD

end ;

-- ============================================================

PROCEDURE P_AUD_PRIV_SYS_DEF_AUDIT (
          p_priv in varchar2,
          p_status_id in integer
          ) is

v_audit_cmd   varchar2(2000);

begin

if p_status_id = 0 then -- 0 noaudit
v_audit_cmd := 'noaudit ' || p_priv;
else                 -- 1 audit
v_audit_cmd := 'audit ' || p_priv || ' by access';
end if;

EXECUTE IMMEDIATE v_audit_cmd;

end ;

-- ============================================================

PROCEDURE P_AUD_PRIV_SYS_NOAUDIT (
          p_priv in varchar2,
          p_user in varchar2
          ) is

v_user   varchar2(200);
v_audit_cmd   varchar2(2000);

begin

-- Omega CA Repository Account can be noaudited only by Omega CA Administrator
if p_user = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Account can be noaudited only by Omega CA Administrator !');
end if;
end if;

-- Begin User is null/not null
if p_user is NULL then
v_user := '';
else
v_user := ' by ' || p_user ;
end if;
-- End User is null/not null

v_audit_cmd := 'noaudit ' || p_priv
                  || v_user;

EXECUTE IMMEDIATE v_audit_cmd;

end ;

-- ============================================================

PROCEDURE P_AUD_PRIV_OBJ_NOAUDIT (
          p_obj_owner in varchar2,
          p_obj_name in varchar2,
          p_obj_type in varchar2,
          p_obj_priv_audited in varchar2
          ) is

v_audit_cmd   varchar2(2000);

begin

-- Omega CA Repository Objects can be noaudited only by Omega CA Administrator
if p_obj_owner = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Omega CA Repository Objects can be noaudited only by Omega CA Administrator !' );
end if;
end if;


-- Begin Make NoAudit Cmd by object Type
if p_obj_type = 'DIRECTORY' then -- Make Directory
v_audit_cmd := 'noaudit ' || p_obj_priv_audited
            || ' on DIRECTORY ' || p_obj_name ;
elsif p_obj_type = 'MINING MODEL' then -- Make Mining Model
v_audit_cmd := 'noaudit ' || p_obj_priv_audited
            || ' on MINING MODEL ' || p_obj_owner || '.' || p_obj_name ;
else -- non DIRECTORY/MINING MODEL
v_audit_cmd := 'noaudit ' || p_obj_priv_audited
            || ' on ' || p_obj_owner || '.' || p_obj_name ;
end if;
-- End Make NoAudit Cmd by object Type

EXECUTE IMMEDIATE v_audit_cmd;

end ;

-- =================================================================

PROCEDURE P_AUD_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          )

AS

begin

-- Insert aud_pol_cache
insert into OMEGACA.aud_pol_cache
(
policy_id,
policy_factor_str,
policy_result
)
values
(
p_policy_id,
p_policy_factor_str,
p_policy_result
);

end; -- end proc

-- ===========================================================

PROCEDURE P_AUD_UNF_TRAIL (
          p_TIMESTAMP_UTC in TIMESTAMP,
          p_USERNAME in varchar2,
          p_SESSIONID in number,
          p_OS_USER in varchar2,
          p_USERHOST in varchar2,
          p_ACTION_ID in number,
          p_OBJECT_OWNER in varchar2,
          p_OBJECT_NAME in varchar2,
          p_PRIVILEGE_ID in number,
          p_NEW_OWNER in varchar2,
          p_NEW_NAME in varchar2,
          p_AUTH_PRIVILEGES in varchar2,
          p_LOGOFF_DEAD in number,
          p_GRANTEE in varchar2,
          p_SES_ACTIONS in varchar2,
          p_LOGOFF_TIME in DATE,
          p_LOGOFF_LREAD in number,
          p_LOGOFF_PREAD in number,
          p_LOGOFF_LWRITE in number,
          p_CLIENT_ID in varchar2,
          p_TERMINAL in varchar2,          
          p_DBID in number,
          p_DB_NAME in varchar2,
          p_INSTANCE_NUMBER in number,          
          p_STATEMENTID in number,
          p_ENTRYID in number,
          p_TRANSACTIONID in raw,
          p_SCN in number,
          p_PROXY_SESSIONID in number,
          p_GLOBAL_UID in varchar2,
          p_ECONTEXT_ID in varchar2,
          p_COMMENT_TEXT in varchar2,
          p_OS_PROCESS in varchar2,
          p_SESSIONCPU in varchar2,
          p_RETURNCODE in number,
          p_SQL_BIND in clob,
          p_SQL_TEXT in clob,
          p_OBJ_EDITION in varchar2,
          p_trail_eval in varchar2
				  )
          
AS  

v_timestamp_sts      OMEGACA.sys_unf_trail.timestamp_sts%TYPE; 
v_action_name        OMEGACA.aud_sys_action.action_name%TYPE;

v_system_privilege   OMEGACA.sys_system_privilege_map.NAME%TYPE;
v_return_message     OMEGACA.sys_unf_trail.return_message%TYPE;

v_obj_privilege     OMEGACA.sys_unf_trail.obj_privilege%TYPE;
v_sys_privilege     OMEGACA.sys_unf_trail.sys_privilege%TYPE;
v_admin_option      OMEGACA.sys_unf_trail.admin_option%TYPE;

v_audit_option      OMEGACA.sys_unf_trail.audit_option%TYPE;

v_logoff_dlock      OMEGACA.sys_unf_trail.logoff_dlock%TYPE;

begin

-- Make Local SysTimeStamp
v_timestamp_sts := from_tz(p_TIMESTAMP_UTC,'00:00') at local;

-- Make Return Message by Oracle ReturnCode
v_return_message := substr(SQLERRM(0 - p_RETURNCODE), 1, 2000);


-- Begin make Action Name
BEGIN
select action_name into v_action_name
from OMEGACA.aud_sys_action
where action_id = P_ACTION_ID;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_action_name := '<UNDECLARED>';
END;
-- End make Action Name

-- Begin make Privilege_Id_Used
if p_PRIVILEGE_ID is not null then

BEGIN
select name into v_system_privilege
from OMEGACA.sys_system_privilege_map
where privilege = p_PRIVILEGE_ID;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_system_privilege := '<UNDECLARED>';
END;

else -- is null
v_system_privilege := ''; -- Privilege Unused
end if;
-- End make Privilege_Id_Used


-- Begin Make Object Privilege
if p_ACTION_ID in (108, 109, 114, 115) then
v_obj_privilege := '';
else
v_obj_privilege := p_AUTH_PRIVILEGES;
end if;
-- End Make Object Privilege


-- Begin Make Sys Privilege
if p_ACTION_ID in (108, 109) then

BEGIN
select name into v_sys_privilege
from OMEGACA.sys_system_privilege_map
where privilege = p_LOGOFF_DEAD;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_sys_privilege := '<UNDECLARED>';
END;

else
v_sys_privilege := '';
end if;
-- End Make Sys Privilege


-- Begin Make Admin Option
if p_ACTION_ID in (108, 109, 114, 115) then
v_admin_option := substr(p_AUTH_PRIVILEGES, 1, 1);
else
v_admin_option := '';
end if;
-- End Make Admin Option


-- Begin Make Audit Option
if p_ACTION_ID in (104, 105) then

BEGIN
select option_name into v_audit_option
from OMEGACA.aud_sys_stmt_opt
where option_id = p_LOGOFF_DEAD;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_audit_option := '<UNDECLARED>';
END;

else
v_audit_option := '';
end if;
-- End Make Audit Privilege


-- Begin Make AUD Logoff DLock
if p_ACTION_ID in (104, 105, 108, 109, 114, 115) then
v_logoff_dlock := '';
else
v_logoff_dlock := p_LOGOFF_DEAD;
end if;
-- End Make AUD Sys Privilege


-- Insert UNF Trail for AUD
insert into OMEGACA.sys_unf_trail (
TIMESTAMP_STS,
TIMESTAMP_UTC,
POLICY_TYPE_ID,
USERNAME,
SESSIONID,
OS_USER,
USERHOST,
ACTION_ID,
ACTION_NAME,
OBJECT_OWNER,
OBJECT_NAME,
PRIVILEGE_ID,
SYSTEM_PRIVILEGE,
NEW_OWNER,
NEW_NAME,
AUTH_PRIVILEGES,
OBJ_PRIVILEGE,
LOGOFF_DEAD,
SYS_PRIVILEGE,
ADMIN_OPTION,
GRANTEE,
AUDIT_OPTION,
SES_ACTIONS,
LOGOFF_TIME,
LOGOFF_LREAD,
LOGOFF_PREAD,
LOGOFF_LWRITE,
LOGOFF_DLOCK,
CLIENT_ID,
TERMINAL,
DBID,
DB_NAME,
INSTANCE_NUMBER,
STATEMENTID,
ENTRYID,
TRANSACTIONID,
SCN,
PROXY_SESSIONID,
GLOBAL_UID,
ECONTEXT_ID,
COMMENT_TEXT,
OS_PROCESS,
SESSIONCPU,
RETURNCODE,
RETURN_MESSAGE,
SQL_BIND,
SQL_TEXT,
OBJ_EDITION,
ISSUE_ID,
TRAIL_EVAL
)
values
(
v_timestamp_sts,
p_TIMESTAMP_UTC,
2, -- Default Pol Type 2=AUD
p_USERNAME,
p_SESSIONID,
p_OS_USER,
p_USERHOST,
p_ACTION_ID,
v_action_name,
p_OBJECT_OWNER,
p_OBJECT_NAME,
p_PRIVILEGE_ID,
v_system_privilege,
p_NEW_OWNER,
p_NEW_NAME,
p_AUTH_PRIVILEGES,
v_obj_privilege,
p_LOGOFF_DEAD,
v_sys_privilege,
v_admin_option,
p_GRANTEE,
v_audit_option,
p_SES_ACTIONS,
p_LOGOFF_TIME,
p_LOGOFF_LREAD,
p_LOGOFF_PREAD,
p_LOGOFF_LWRITE,
v_logoff_dlock,
p_CLIENT_ID,
p_TERMINAL,
p_DBID,
p_DB_NAME,
p_INSTANCE_NUMBER,
p_STATEMENTID,
p_ENTRYID,
p_TRANSACTIONID,
p_SCN,
p_PROXY_SESSIONID,
p_GLOBAL_UID,
p_ECONTEXT_ID,
p_COMMENT_TEXT,
p_OS_PROCESS,
p_SESSIONCPU,
p_RETURNCODE,
v_return_message,
p_SQL_BIND,
p_SQL_TEXT,
p_OBJ_EDITION,
0, -- 0 = Issue_Id UNMARKED,
p_trail_eval         
);

end;  

-- ===========================================================

PROCEDURE P_AUD_TRAIL_PURGE
-- to be run by SYS only, for no Audit Trail generated  !!!
-- All Other Users then SYS audited by default in Oracle10g no matter what audit on aud$ !!!

AS

-- AUD$ cursor
cursor C_Sys_Aud is select * from aud$ 
FOR UPDATE;

v_db_open_mode         V$DATABASE.OPEN_MODE%TYPE;

v_aud_map              OMEGACA.sys_param.PARAM_VALUE%TYPE;
-- Parameter ID = 2 = AUDMAP
p_param_id_AUDMAP      integer :=2; 

POLICY_CACHE_REC_FOUND Boolean;
V_POLICY_RESULT        VARCHAR2(10);  -- OMEGACA.aud_pol_log.policy_result%TYPE;
v_policy_factor_str    OMEGACA.aud_pol_cache.policy_factor_str%TYPE;

-- Init and use variable - no hard parse
p_policy_status_id integer := 1; -- Active
-- Policy Cursor
cursor C_Policy is select * from OMEGACA.aud_pol
where status_id = p_policy_status_id
order by policy_id ;

v_S_F integer;

-- Init and use variable - no hard parse
p_aud_obj_status_id integer := 1; -- Active
-- Policy Audit Object Cursor
Cursor C_Policy_Obj (
p_policy_id in integer,
p_object_owner in varchar2,
p_object_name in varchar2,
p_success_failure in integer
) is
select * from OMEGACA.aud_pol_obj
where policy_id = p_policy_id
and object_owner = p_object_owner
and object_name = p_object_name
and success_failure in (1, p_success_failure)
and status_id = p_aud_obj_status_id
order by aud_obj_id;

cnt_obj_act integer;
v_Aud_Obj_Id integer;

-- Init and use variable - no hard parse
p_aud_stmt_status_id integer := 1; -- Active
p_aud_act_enabled integer := 1; -- Active
-- Audit Statement [Priv] Options Action Cursor
cursor C_Aud_Stmt_Act (p_Action_Id in integer) is
select * from OMEGACA.aud_sys_stmt_opt_act
where action_id = p_Action_Id
and act_enabled = p_aud_act_enabled;

v_Aud_Stmt_Id       integer;

v_stmt_aud_option_name    OMEGACA.aud_sys_stmt_opt.OPTION_NAME%TYPE;
v_stmt_audit_by_user      OMEGACA.aud_pol_stmt.AUDIT_BY_USER%TYPE;

v_priv_used_audit_opt     OMEGACA.aud_sys_stmt_opt.option_name%TYPE;

v_trail_pol_tmp           varchar2(1000);
v_trail_pol               varchar2(2000);

v_policy_log_detail       varchar2(2000);
v_rule_log_detail         varchar2(4000);

v_db_name                 varchar2(50);

begin

-- BEGIN CHECK DB OPEN MODE
-- Get Database Mode
select open_mode into v_db_open_mode
from sys.V$DATABASE;
-- Check Read-Write Status
if v_db_open_mode <> 'READ WRITE' then
RETURN;    -- Quit Further Processing - Return Proc
end if;
-- END CHECK DB OPEN MODE


-- BEGIN MAIN BEGIN-EXCEPTION-END
BEGIN

-- Make DB_NAME
v_db_name := SYS_CONTEXT('USERENV', 'DB_NAME');


-- Parameter_Id = 2 = AUDMAP = Standard Audit Trail Map
select param_value into v_aud_map
from OMEGACA.sys_param
where parameter_id = p_param_id_AUDMAP;


-- BEGIN PROCESS AUD$ Cursor
for rec_sys_aud in C_Sys_Aud loop


-- BEGIN AUD MAP PROCESS for aud$ record
if v_aud_map = 1 then

-- Reset Policies Found
v_trail_pol := '';


-- Make Success/Failure
if rec_sys_aud.returncode = 0 then
v_S_F := 2; -- 2 = Success
else
v_S_F := 3; -- 3 = Failure
end if;


-- BEGIN LOOP C_POLICY
for Rec_Policy in C_Policy loop


-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
'UNSET',
'Policy: evaluation...'
);
end if;


-- ============= BEGIN PROCESS CACHE ====================
if Rec_Policy.Use_Cache = 1 then

v_policy_factor_str :=
   rec_sys_aud.ACTION#       || '~'
|| rec_sys_aud.PRIV$USED     || '~'
|| rec_sys_aud.USERID        || '~'
|| rec_sys_aud.OBJ$CREATOR   || '~'
|| rec_sys_aud.OBJ$NAME      || '~'
|| -- ReturnCode 0/1
Case
when rec_sys_aud.RETURNCODE = 0
then 0 -- ORA-00000 = Success
else
1 -- ORA-xxxxx = Failure
End;


BEGIN
select policy_result into V_POLICY_RESULT
from OMEGACA.aud_pol_cache
where policy_id = Rec_Policy.Policy_Id
and policy_factor_str = v_policy_factor_str;
POLICY_CACHE_REC_FOUND := True;
EXCEPTION
WHEN NO_DATA_FOUND then
POLICY_CACHE_REC_FOUND := False;
END;

end if;
-- ============= END PROCESS CACHE ====================


-- BEGIN PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]
if Rec_Policy.Use_Cache = 0 or
(Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False ) then

-- BEGIN POLICY EVALUATION

-- Set FALSE Initial, can be changed in loop
V_POLICY_RESULT := 'FALSE';


-- Check Aud Policy Type - "If" separate processing for Obj and Stmt !
if Rec_Policy.Type_Id not in (1,2) then
raise_application_error(-20010, 'Wrong Standard Audit policy type id non 1/2 !');
end if;


-- BEGIN MAKE POL OBJ
If Rec_Policy.Type_Id = 1 then

v_Aud_Stmt_Id := null;

-- Begin Loop Policy Audit Object
for Rec_Policy_Obj in C_Policy_Obj (
Rec_Policy.Policy_Id,
rec_sys_aud.obj$creator,
rec_sys_aud.obj$name,
v_S_F
) loop

select count(*) into cnt_obj_act
from OMEGACA.aud_sys_obj_opt_act
where obj_type = Rec_Policy_Obj.Object_Type
and audit_option = Rec_Policy_Obj.Sql_Operation
and action_id = rec_sys_aud.ACTION#
and act_enabled = 1;

if cnt_obj_act > 0 then
V_POLICY_RESULT := 'TRUE';
else
V_POLICY_RESULT := 'FALSE';
end if;

v_rule_log_detail := 'Rule: ' || V_POLICY_RESULT;


-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
Rec_Policy_Obj.Aud_Obj_Id,
Lpad(Rec_Policy_Obj.Aud_Obj_Id, 7, '0'), -- RULE_CODE LENGTH = 7
NULL,
NULL,
V_POLICY_RESULT,
v_rule_log_detail
);
end if;


if V_POLICY_RESULT = 'TRUE' then
v_Aud_Obj_Id := Rec_Policy_Obj.Aud_Obj_Id;
EXIT; -- Exit Policy Audit Object loop if found
end if;

end loop;
-- End Loop Policy Audit Object

end if;
-- END MAKE POL OBJ


-- BEGIN MAKE POL STMT
if Rec_Policy.Type_Id = 2 then

v_Aud_Obj_Id := null;

-- Begin Make audit_by_user for 0 Oracle Default and Normal Policies
if Rec_Policy.Policy_Id = 0 then
v_stmt_audit_by_user := '<*>';
else
v_stmt_audit_by_user := rec_sys_aud.userid;
end if;
-- End Make audit_by_user for 0 Oracle Default and normal


-- BEGIN CHECK ALL STATEMENTS AUD OPTION for Non-Oracle Default Policy
-- <*> user not available in ALL STATEMENTS
if Rec_Policy.Policy_Id <> 0 then

BEGIN

select aud_stmt_id into v_Aud_Stmt_Id
from OMEGACA.aud_pol_stmt
where policy_id = Rec_Policy.Policy_Id
and audit_option = 'ALL STATEMENTS'
and audit_by_user = rec_sys_aud.userid
and success_failure in (1,v_S_F) -- 1 Success/Failure, 2-Success, 3-Failure
and status_id = p_aud_stmt_status_id;

V_POLICY_RESULT := 'TRUE';

EXCEPTION

WHEN NO_DATA_FOUND THEN
v_Aud_Stmt_Id := 0;
V_POLICY_RESULT := 'FALSE';

END;

-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
v_rule_log_detail := 'Rule: ' || V_POLICY_RESULT || ' - ALL STATEMENTS';

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
v_Aud_Stmt_Id,
Lpad(v_Aud_Stmt_Id, 7, '0'), -- RULE_CODE LENGTH = 7
NULL,
NULL,
V_POLICY_RESULT,
v_rule_log_detail
);
end if;

end if;
-- END CHECK ALL STATEMENTS AUD OPTION for Non-Oracle Default Policy


-- ---------------------------------------------------------------------
-- BEGIN PROCESS Priv Used if ALL STATEMENTS FALSE
If V_POLICY_RESULT = 'FALSE' then

-- Begin Priv Used if available
if rec_sys_aud.priv$used is not null then

BEGIN
select option_name into v_priv_used_audit_opt
from OMEGACA.aud_sys_stmt_opt
where option_id = rec_sys_aud.priv$used;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_priv_used_audit_opt := '<UNDECLARED>';
END;

BEGIN

select aud_stmt_id into v_Aud_Stmt_Id
from OMEGACA.aud_pol_stmt
where policy_id = Rec_Policy.Policy_Id
and audit_option = v_priv_used_audit_opt
and audit_by_user = v_stmt_audit_by_user
and success_failure in (1,v_S_F) -- 1 Success/Failure, 2-Success, 3-Failure
and status_id = p_aud_stmt_status_id;

V_POLICY_RESULT := 'TRUE';

EXCEPTION

WHEN NO_DATA_FOUND THEN
v_Aud_Stmt_Id := 0;
V_POLICY_RESULT := 'FALSE';

END;

-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
v_rule_log_detail := 'Rule: ' || V_POLICY_RESULT || ' - Privilege';

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
v_Aud_Stmt_Id,
Lpad(v_Aud_Stmt_Id, 7, '0'), -- RULE_CODE LENGTH = 7
NULL,
NULL,
V_POLICY_RESULT,
v_rule_log_detail
);
end if;

end if;
-- End Priv Used if available

end if;
-- END PROCESS Priv Used if ALL STATEMENTS FALSE


-- BEGIN PROCESS Action# if Priv_Used FALSE
If V_POLICY_RESULT = 'FALSE' then

-- Begin Loop Aud Stmt Act_Id-s
for Rec_Aud_Stmt_Act in C_Aud_Stmt_Act (rec_sys_aud.ACTION#) loop

-- get stmt aud option name
BEGIN
select option_name into v_stmt_aud_option_name
from OMEGACA.aud_sys_stmt_opt
where option_id = Rec_Aud_Stmt_Act.Option_Id;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_stmt_aud_option_name := '<UNDECLARED>';
END;

BEGIN

select aud_stmt_id into v_Aud_Stmt_Id
from OMEGACA.aud_pol_stmt
where policy_id = Rec_Policy.Policy_Id
and audit_option = v_stmt_aud_option_name
and audit_by_user = v_stmt_audit_by_user
and success_failure in (1,v_S_F) -- 1 Success/Failure, 2-Success, 3-Failure
and status_id = p_aud_stmt_status_id;

V_POLICY_RESULT := 'TRUE';
EXIT; -- Exit Aud Stmt Act_Id-s loop if found

EXCEPTION
WHEN NO_DATA_FOUND THEN
v_Aud_Stmt_Id := 0;
V_POLICY_RESULT := 'FALSE'; -- Continue Stmt Obj Act_Id-s loop if not found

END;

-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
v_rule_log_detail := 'Rule: ' || V_POLICY_RESULT || ' - Audit Action';

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
v_Aud_Stmt_Id,
Lpad(v_Aud_Stmt_Id, 7, '0'), -- RULE_CODE LENGTH = 7
Rec_Aud_Stmt_Act.Option_Id,
v_stmt_aud_option_name, -- RULE_CODE LENGTH = 7
V_POLICY_RESULT,
v_rule_log_detail
);
end if;

end loop;
-- End Loop Aud Obj Act_Id-s

end if;
-- END PROCESS if Priv_Used FALSE


-- Begin Check NOT EXISTS AUD OPTION for Non-Oracle Default Policy
if Rec_Policy.Policy_Id <> 0 then

-- Begin Still FALSE - Check NOT EXISTS
If V_POLICY_RESULT = 'FALSE' then

-- Begin Check Not Exists specific errors
if rec_sys_aud.returncode in (
   942, 943, 959, 1418, 1432, 1434, 1435, 1534, 1917, 1918, 1919, 2019,
   2024, 2289,
   4042, 4043, 4080, 1, 951, 955, 957, 1430, 1433, 1452, 1471, 1535, 1543,
   1758, 1920, 1921, 1922, 2239, 2264, 2266, 2273, 2292, 2297, 2378, 2379,
   2382, 4081, 12006, 12325
) then

BEGIN

-- Do not allow Not Exists on Success !
select aud_stmt_id into v_Aud_Stmt_Id
from OMEGACA.aud_pol_stmt
where policy_id = Rec_Policy.Policy_Id
and audit_option = 'NOT EXISTS'
and audit_by_user = rec_sys_aud.userid
and success_failure in (1,3) -- 1-Success/Failure, 3-Failure;
and status_id = p_aud_stmt_status_id;

V_POLICY_RESULT := 'TRUE';

EXCEPTION
WHEN NO_DATA_FOUND THEN
v_Aud_Stmt_Id := 0;
V_POLICY_RESULT := 'FALSE';

END;

-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
v_rule_log_detail := 'Rule: ' || V_POLICY_RESULT || ' - NOT EXISTS';

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
v_Aud_Stmt_Id,
Lpad(v_Aud_Stmt_Id, 7, '0'), -- RULE_CODE LENGTH = 7
NULL,
NULL,
V_POLICY_RESULT,
v_rule_log_detail
);
end if;

end if;
-- End Check Not Exists specific errors

end if;
-- End Still FALSE - Check NOT EXISTS

end if;
-- End Check NOT EXISTS AUD OPTION for Non-Oracle Default Policy


end if;
-- END MAKE POL STMT

-- END POLICY EVALUATION


-- BEGIN INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]
if Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False then

-- Insert Cache
P_AUD_POL_CACHE_INS(
Rec_Policy.Policy_Id,
v_policy_factor_str,
V_POLICY_RESULT
);

end if;
-- END INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]


end if;
-- END PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]


-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then

-- Make Detail if cache
If Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND then
v_policy_log_detail := 'CACHE - ' || V_POLICY_RESULT;
else
v_policy_log_detail := 'ANY TRUE - ' || V_POLICY_RESULT;
end if;


-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
rec_sys_aud.userid,
2, -- 2 = AUD
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
V_POLICY_RESULT,
'Policy: ' || '' || v_policy_log_detail
);

end if;


-- BEGIN Policy is TRUE
if V_POLICY_RESULT = 'TRUE' then

-- Null Obj/Stmt Ids when Cache !
If Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND then
v_Aud_Obj_Id := 0;
v_Aud_Stmt_Id := 0;
end if;

-- Begin Make Trail Policies
v_trail_pol_tmp :=
'<Policy>'
|| Chr(10)
|| '<Id>'       || Rec_Policy.Policy_Id     || '</Id>'
|| Chr(10)
|| '<Name>'     || Rec_Policy.Policy_Name   || '</Name>'
|| Chr(10)
|| '<Result>'   || 'TRUE'                   || '</Result>'
|| Chr(10)
|| '<Obj.Id>'   || v_Aud_Obj_Id             || '</Obj.Id>'
|| Chr(10)
|| '<Stmt.Id>'  || v_Aud_Stmt_Id            || '</Stmt.Id>'
|| Chr(10)
|| '</Policy>';

if v_trail_pol is null then
v_trail_pol := v_trail_pol_tmp;
else
v_trail_pol := v_trail_pol
               || Chr(10)
               || v_trail_pol_tmp;
end if;
-- End Make Trail Policies

end if;
-- END Policy is TRUE


end loop;
-- END LOOP C_POLICY


end if;
-- END AUD MAP PROCESS for aud$ record


-- Insert UNF Trail for AUD
P_AUD_UNF_TRAIL (
rec_sys_aud.NTIMESTAMP#,        -- p_TIMESTAMP_UTC
rec_sys_aud.USERID,             -- p_USERNAME
rec_sys_aud.SESSIONID,          -- p_SESSIONID
rec_sys_aud.spare1,             -- p_OS_USER
rec_sys_aud.userhost,            -- p_USERHOST
rec_sys_aud.action#,             -- p_ACTION_ID
rec_sys_aud.obj$creator,        -- p_OBJECT_OWNER
rec_sys_aud.obj$name,           -- p_OBJECT_NAME
rec_sys_aud.priv$used,          -- p_PRIVILEGE_ID
rec_sys_aud.new$owner,          -- p_NEW_OWNER
rec_sys_aud.new$name,           -- p_NEW_NAME
rec_sys_aud.auth$privileges,    -- p_AUTH_PRIVILEGES
rec_sys_aud.logoff$dead,        -- p_LOGOFF_DEAD
rec_sys_aud.auth$grantee,       -- p_GRANTEE_NAME
rec_sys_aud.ses$actions,        -- p_SES_ACTIONS
rec_sys_aud.logoff$time,        -- p_LOGOFF_TIME
rec_sys_aud.logoff$lread,       -- p_LOGOFF_LREAD
rec_sys_aud.logoff$pread,       -- p_LOGOFF_PREAD
rec_sys_aud.logoff$lwrite,      -- p_LOGOFF_LWRITE
rec_sys_aud.clientid,           -- p_CLIENT_ID
rec_sys_aud.terminal,           -- p_TERMINAL in varchar2,          
rec_sys_aud.dbid,               -- p_DBID in number,
v_db_name,                      -- p_DB_NAME in varchar2,
rec_sys_aud.instance#,          -- p_INSTANCE_NUMBER in number,          
rec_sys_aud.statement,          -- p_STATEMENTID in number,
rec_sys_aud.entryid,            -- p_ENTRYID in number,
rec_sys_aud.xid,                -- p_TRANSACTIONID in raw,
rec_sys_aud.scn,                -- p_SCN in number,
rec_sys_aud.proxy$sid,          -- p_PROXY_SESSIONID in number,
rec_sys_aud.user$guid ,         -- p_GLOBAL_UID in varchar2,
rec_sys_aud.auditid,            -- p_ECONTEXT_ID in varchar2,
rec_sys_aud.comment$text,       -- p_COMMENT_TEXT in varchar2,
rec_sys_aud.process#,           -- p_OS_PROCESS in varchar2,
rec_sys_aud.sessioncpu,         -- p_SESSIONCPU in varchar2,
rec_sys_aud.returncode,         -- p_RETURNCODE in number,
rec_sys_aud.sqlbind,            -- p_SQL_BIND in clob,
rec_sys_aud.sqltext,            -- p_SQL_TEXT in clob,
NULL,                           -- p_OBJ_EDITION in varchar2,
v_trail_pol                    -- p_trail_eval in varchar2
);

-- Make Delete
delete from aud$ where current of C_Sys_Aud;

end loop ;
-- END PROCESS AUD$ Cursor

-- Commit after close of FOR UPDATE cursor only !
COMMIT;


EXCEPTION -- MAIN EXCEPTION

WHEN OTHERS THEN

ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
RAISE;

END;
-- END MAIN BEGIN-EXCEPTION-END

end; -- end proc

-- ===========================================================
-- ===========================================================
-- END AUD


-- BEGIN RTP DDL
-- ================================================================
-- ================================================================

FUNCTION F_RTP_DDL_POL_COND_EVAL (
         p_cond_id in integer
         )

RETURN VARCHAR2 IS

v_rule_id                      OMEGACA.rtp_ddl_pol_cond.rule_id%TYPE;

v_cond_eval                    OMEGACA.rtp_ddl_pol_cond.cond_eval%TYPE;
v_min_trust_level_no           OMEGACA.rtp_ddl_pol_cond.min_trust_level_no%TYPE;
v_validate_expr_owner          OMEGACA.rtp_ddl_pol_cond.validate_expr_owner%TYPE;
v_validate_expr_object         OMEGACA.rtp_ddl_pol_cond.validate_expr_object%TYPE;
v_factor_id                    OMEGACA.rtp_ddl_pol_cond.factor_id%TYPE;

v_policy_id                    OMEGACA.rtp_ddl_pol_rule.policy_id%TYPE;
v_rule_name                    OMEGACA.rtp_ddl_pol_rule.rule_name%TYPE;

v_policy_name                  OMEGACA.rtp_ddl_pol.policy_name%TYPE;
v_policy_audit_option          OMEGACA.rtp_ddl_pol.audit_option%TYPE;
v_policy_debug_log             OMEGACA.rtp_ddl_pol.debug_log%TYPE;

V_COND_EVAL_OPR_CMD            Varchar2(4000);
v_cond_trust_level             integer;

v_expr_factor_code             OMEGACA.sys_factor.factor_code%TYPE;
v_expr_factor_value            Varchar2(4000);

V_SQL                          Varchar2(2000);
V_COND_LOG_DETAIL              Varchar2(4000);

V_COND_RESULT                  OMEGACA.sys_pol_debug.eval_result%TYPE;

BEGIN

-- get rule_id and cond details
select rule_id, cond_eval, min_trust_level_no,
validate_expr_owner, validate_expr_object, factor_id
into v_rule_id, v_cond_eval, v_min_trust_level_no,
v_validate_expr_owner, v_validate_expr_object, v_factor_id
from OMEGACA.rtp_ddl_pol_cond
where cond_id = p_cond_id;

-- get Rule Data
select policy_id, rule_name
into v_policy_id, v_rule_name
from OMEGACA.rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- get policy data
select policy_name, audit_option, debug_log
into v_policy_name, v_policy_audit_option, v_policy_debug_log
from OMEGACA.rtp_ddl_pol
where policy_id = v_policy_id;


-- Begin Condition is Operand evaluated
if v_cond_eval = 1 then -- 1 = Operand

V_COND_EVAL_OPR_CMD := F_SYS_FACTOR_OPERAND_CMD(
                       p_cond_id,
                       3 -- Pol Type = 3 = RTP DDL
                       );

V_SQL := 'DECLARE
          BEGIN
          if ' || V_COND_EVAL_OPR_CMD || ' then
          :p1 := ''TRUE'';
          else
          :p1 := ''FALSE'';
          end if;
          END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Operand: ' || V_COND_EVAL_OPR_CMD
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Operand evaluated


-- Begin Condition is Trust Level evaluated
elsif v_cond_eval = 2 then -- 2 = Trust Level
v_cond_trust_level := F_SYS_FACTOR_GET_TRUST_LEVEL(
                      v_factor_id,
                      3 -- Pol Type = 3 = RTP DDL
                      );

if v_cond_trust_level < v_min_trust_level_no then
V_COND_RESULT := 'FALSE';
else
V_COND_RESULT := 'TRUE';
end if;

V_COND_LOG_DETAIL := 'Trust Level Found: ' || to_char(v_cond_trust_level)
                  || ', Min. Trust Level required: ' || to_char(v_min_trust_level_no)
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Trust Level evaluated


-- Begin Condition is Validate Expression evaluated
elsif v_cond_eval = 3 then -- 3 = Validate Expression

-- Get Factor Code - First (1st) Val Expr Function Param
select factor_code into v_expr_factor_code
from OMEGACA.sys_factor
where factor_id = v_factor_id;

-- Make Factor Value - Second (2d) Val Expr Function Param
v_expr_factor_value := F_SYS_FACTOR_GET_VALUE(
                       v_factor_id,
                       3 -- Pol Type = 3 = RTP DDL
                       );

-- Prepare Validation Expression Exec Command
V_SQL := 'DECLARE
      res boolean;
      BEGIN
      res := '|| v_validate_expr_owner || '.' || v_validate_expr_object
      || '('
      || '''' || to_char(v_expr_factor_code) || '''' -- string (quoted)
      || ','
      || '''' || to_char(v_expr_factor_value) || '''' -- string (quoted)
      || ')'
      ||';
      if res then
      :p1 := ''TRUE'';
      else
      :p1 := ''FALSE'';
      end if;
      END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Validate Expression: ' || V_SQL
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Validate Expression evaluated


-- Begin Unknown Cond_Eval, Raise
else
raise_application_error(-20020, 'RTP DDL Condition Evaluation method not in 1-Operand, 2-Trust Level, 3-Validate Expression !');
end if;
-- End Unknown Cond_Eval, Raise


-- Insert Condition Log if policy_log = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
v_policy_id,
v_policy_name,
v_rule_id,
v_rule_name,
p_cond_id,
Lpad(p_cond_id, 7, '0'), -- COND_CODE LENGTH = 7
V_COND_RESULT,
v_cond_log_detail
);
End if;


RETURN V_COND_RESULT ;

END ;

-- ===========================================================

FUNCTION F_RTP_DDL_POL_RULE_EVAL (
         p_rule_id in integer
         )

RETURN VARCHAR2 IS

v_policy_id             OMEGACA.rtp_ddl_pol_rule.policy_id%TYPE;
v_cond_eval             OMEGACA.rtp_ddl_pol_rule.cond_eval%TYPE;

v_rule_name             OMEGACA.rtp_ddl_pol_rule.rule_name%TYPE;
v_rule_formula          OMEGACA.rtp_ddl_pol_rule.formula%TYPE;

S                       varchar2(1024);
I                       integer;
x                       integer;
y                       integer;
V_FORMULA               varchar2(1024);

v_cond_id               OMEGACA.rtp_ddl_pol_cond.cond_id%TYPE;
v_cond_status           OMEGACA.rtp_ddl_pol_cond.status_id%TYPE;
v_cond_result           OMEGACA.sys_pol_debug.eval_result%TYPE;
v_rule_log_detail       Varchar2(4000);

v_policy_audit_option   OMEGACA.rtp_ddl_pol.audit_option%TYPE;
v_policy_debug_log      OMEGACA.rtp_ddl_pol.debug_log%TYPE;
v_policy_name           OMEGACA.rtp_ddl_pol.policy_name%TYPE;

V_RULE_RESULT           OMEGACA.sys_pol_debug.eval_result%TYPE;

-- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
-- Cond Cursor
cursor C_Cond is
select * from OMEGACA.rtp_ddl_pol_cond
where rule_id = p_rule_id
and status_id = p_cond_status_id
order by cond_id ;

begin

-- get rule data
select policy_id, cond_eval, formula, rule_name
into v_policy_id, v_cond_eval, v_rule_formula, v_rule_name
from OMEGACA.rtp_ddl_pol_rule
where rule_id = p_rule_id;

-- Get Policy Data
select policy_name, audit_option, debug_log
into v_policy_name, v_policy_audit_option, v_policy_debug_log
from OMEGACA.rtp_ddl_pol
where policy_id = v_policy_id;


-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
v_policy_id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
'UNSET',
'Rule: evaluation...'
);

end if;


-- Initialize Rule Result default FALSE
V_RULE_RESULT := 'FALSE';


-- BEGIN ANY TRUE
if v_cond_eval = 1 then -- 1 = Any True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_RTP_DDL_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'TRUE' then
V_RULE_RESULT := 'TRUE';
Exit; -- Exit Condition Loop when TRUE on Any True found
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ANY TRUE - ' || V_RULE_RESULT;
-- END ANY TRUE


-- BEGIN ALL TRUE
elsif v_cond_eval = 2 then -- 2 = All True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_RTP_DDL_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'FALSE' then
V_RULE_RESULT := 'FALSE';
Exit; -- Exit Condition Loop when FALSE on All True found
else
V_RULE_RESULT := 'TRUE'; -- Continue Loop, remain last if no FALSE
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ALL TRUE - ' || V_RULE_RESULT;
-- END ALL TRUE


-- BEGIN FORMULA
elsif v_cond_eval = 3 then -- 3 = Formula

-- BEGIN LOOP FORMULA STRING SEARCHING For DATA INSIDE []
for I in 1..100 loop

x := INSTR(v_rule_formula, '[', 1, 1);

if X = 0 then
exit;
end if;

y := 9; -- COND_CODE LENGTH 7 + 2
S:= SUBSTR(v_rule_formula, x, y);
v_cond_id := To_Number( substr(S, 2, 7) ); -- COND_CODE LENGTH 7 !!!

-- Begin Check Inactive Condition status_id=0
select status_id into v_cond_status
from OMEGACA.rtp_ddl_pol_cond
where cond_id = v_cond_id;

if v_cond_status = 0 then
-- Raise Error
raise_application_error(-20020, 'RTP DDL Policy: ' || v_policy_name
                                || ', Rule: ' || v_rule_name
                                || ' - Inactive Condition ' || S || ' included in formula !');
end if;
-- End Check Inactive Condition status_id=0

v_cond_result := F_RTP_DDL_POL_COND_EVAL(
                 v_cond_id
                 );

v_rule_formula := REPLACE(v_rule_formula, S, v_cond_result);

end loop;
-- END LOOP FORMULA STRING SEARCHING For DATA INSIDE []

V_FORMULA := 'DECLARE
            res boolean;
            BEGIN
               res := '|| v_rule_formula ||';
               if res then
                  :p1 := ''TRUE'';
               else
                  :p1 := ''FALSE'';
               end if;
            END;';
v_rule_log_detail := 'FORMULA - ' || v_rule_formula;

EXECUTE IMMEDIATE V_FORMULA using out V_RULE_RESULT;
-- END FORMULA


else -- raise if none
raise_application_error(-20020, 'RTP DDL Rule Condition Evaluation not in 1-Any True, 2-All True, 3-Formula !');
end if;


-- Update Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
v_policy_id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
V_RULE_RESULT,
'Rule: ' || v_rule_log_detail
);
End if;


RETURN V_RULE_RESULT;

end; -- end proc

-- =================================================================

PROCEDURE P_RTP_DDL_POL_CACHE_INS (
          p_policy_id in integer,
          p_policy_factor_str in varchar2,
          p_policy_result in varchar2
          )

AS

begin

-- Insert rtp_ddl_pol_cache
insert into OMEGACA.rtp_ddl_pol_cache
(
policy_id,
policy_factor_str,
policy_result
)
values
(
p_policy_id,
p_policy_factor_str,
p_policy_result
);

end; -- end proc

-- =================================================================

PROCEDURE P_RTP_DDL_UNF_TRAIL (
          p_timestamp_sts in timestamp,
          p_timestamp_utc in timestamp,
          p_ora_owner in varchar2,
          p_ora_object_name in varchar2,
          p_ora_object_type in varchar2,
          p_ora_sys_event in varchar2,
          p_ddl_body in clob,
          p_ddl_cmd in clob,
          p_returncode in number,
          p_return_message in varchar2,
          p_trail_eval in varchar2,
          p_dbid in number
				  )

as

begin

-- Insert UNF Trail for RTP_DDL
insert into OMEGACA.sys_unf_trail
(
TIMESTAMP_STS,
TIMESTAMP_UTC,
POLICY_TYPE_ID,
USERNAME,
SESSIONID,
OS_USER,
USERHOST,
ACTION_NAME,
OBJECT_OWNER,
OBJECT_NAME,
OBJECT_TYPE,
CLIENT_ID,
TERMINAL,
IP_ADDRESS,
NETWORK_PROTOCOL,
DBID,
DB_NAME,
INSTANCE_NUMBER,
AUTHENTICATION_METHOD,
IDENTIFICATION_TYPE,
ISDBA,
MODULE,
BG_JOB_ID,
FG_JOB_ID,
RETURNCODE,
RETURN_MESSAGE,
SQL_TEXT,
DDL_BODY,
ISSUE_ID,
TRAIL_EVAL
)
VALUES
(
p_timestamp_sts,
p_timestamp_utc,
3, -- Default Pol Type 3=RTP_DDL
USER,
SYS_CONTEXT('USERENV', 'SESSIONID'),
SYS_CONTEXT('USERENV', 'OS_USER'),
SYS_CONTEXT('USERENV', 'HOST'),
p_ora_sys_event, -- ACTION_NAME
p_ora_owner,
p_ora_object_name,
p_ora_object_type,
SYS_CONTEXT('USERENV', 'CLIENT_IDENTIFIER'),
SYS_CONTEXT('USERENV', 'TERMINAL'),
SYS_CONTEXT('USERENV', 'IP_ADDRESS'),
SYS_CONTEXT('USERENV', 'NETWORK_PROTOCOL'),
p_dbid,
SYS_CONTEXT('USERENV', 'DB_NAME'),
SYS_CONTEXT('USERENV', 'INSTANCE'),
NULL, -- AUTHENTICATION_METHOD,
SYS_CONTEXT('USERENV', 'IDENTIFICATION_TYPE'),
SYS_CONTEXT('USERENV', 'ISDBA'),
SYS_CONTEXT('USERENV', 'MODULE'),
SYS_CONTEXT('USERENV', 'BG_JOB_ID'),
SYS_CONTEXT('USERENV', 'FG_JOB_ID'),
p_returncode,
p_return_message,
p_ddl_cmd,
p_ddl_body,
0, -- 0 = Issue_Id UNMARKED,
p_trail_eval
);

end; -- end proc

-- =================================================================

FUNCTION  F_RTP_DDL_TRAIL_DDL_BODY

RETURN CLOB IS

v_ddl_body_before        clob;
v_ora_dict_obj_type      varchar2(100);
v_ora_dict_obj_owner     varchar2(100);

begin

-- BEGIN MAKE V_DDL_BODY_BEFORE IF NOT DDL NON-AFFECTIONG SOURCE
If ora_sysevent not in (
'ANALYZE',
'ASSOCIATE STATISTICS',
'AUDIT',
'DISASSOCIATE STATISTICS',
'FLASHBACK',
'GRANT',
'NOAUDIT',
'REVOKE'
) then


-- Begin Make null ora_dict_obj_owner fix
if ora_dict_obj_type in ('DIRECTORY', 'DATABASE LINK') then

if ora_dict_obj_type = 'DIRECTORY' then
v_ora_dict_obj_owner := NULL;
end if;
if ora_dict_obj_type = 'DATABASE LINK' then
v_ora_dict_obj_owner := ora_login_user;
end if;

else
v_ora_dict_obj_owner := ora_dict_obj_owner;
end if;
-- End Make null ora_dict_obj_owner fix


-- Dbms_Metadata.get_ddl problem with spaced object type names, given '_' instead of Space
v_ora_dict_obj_type := Replace(ora_dict_obj_type, ' ', '_');

-- DB_LINK instead of DATABASE_LINK
if v_ora_dict_obj_type = 'DATABASE_LINK' then
v_ora_dict_obj_type := 'DB_LINK';
end if;


-- Begin get DDL from dbms_metadata
BEGIN
v_ddl_body_before := DBMS_METADATA.GET_DDL(
                     v_ora_dict_obj_type,  -- use fixed ora_dict_obj_type
                     ora_dict_obj_name,
                     v_ora_dict_obj_owner
                     );
EXCEPTION
WHEN OTHERS then
v_ddl_body_before := SQLERRM;
END;
-- End get DDL from dbms_metadata


end if;
-- END MAKE V_DDL_BODY_BEFORE IF NOT DDL NON-AFFECTIONG SOURCE


RETURN v_ddl_body_before;

end; -- end proc

-- =================================================================

FUNCTION  F_RTP_DDL_TRAIL_DDL_CMD

RETURN CLOB IS

sql_text           ora_name_list_t;
n                  number;

v_ddl_command      clob;

begin


BEGIN

-- Begin make DDL command
n := ora_sql_txt(sql_text);
-- Begin Fix Oracle Problem 550241.1
-- Doc Id 550241.1: User Can Not Change Expired Password With Auditing Trigger
-- Enabled With ORA-00604, ORA-06531 and ORA-06512
IF n >= 1 THEN
FOR i IN 1..n LOOP
 v_ddl_command := v_ddl_command || sql_text(i);
END LOOP;
end if;
-- End make DDL command

EXCEPTION
WHEN OTHERS then
v_ddl_command := SQLERRM;
END;


RETURN v_ddl_command;

end; -- end proc

-- =================================================================

PROCEDURE P_RTP_DB_BF_DDL
as

-- Area
POLICY_AREA_GO         Boolean;
POLICY_USER_GO         Boolean;
POLICY_CACHE_REC_FOUND Boolean;

V_POLICY_RESULT        OMEGACA.sys_pol_debug.eval_result%TYPE;

v_policy_formula       OMEGACA.rtp_ddl_pol.formula%TYPE;
v_policy_log_detail    Varchar2(4000);

  S                      varchar2(1024);
  I                      integer;
  x                      integer;
  y                      integer;
  V_FORMULA              varchar2(1024);

  v_rule_id              OMEGACA.rtp_ddl_pol_rule.rule_id%TYPE;
  v_rule_status          OMEGACA.rtp_ddl_pol_rule.status_id%TYPE;
  v_rule_result          OMEGACA.sys_pol_debug.eval_result%TYPE;

-- DDL Body and Cmd
v_ddl_body_exec         integer:=0;  -- Flag, Initialize to false
v_ddl_body              clob;
v_ddl_cmd_exec         integer:=0;  -- Flag, Initialize to false
v_ddl_cmd              clob;

  -- Init and use variable - no hard parse
  p_policy_status_id integer := 1; -- Active
  -- Policy Cursor
  cursor C_Policy is
  select * from OMEGACA.rtp_ddl_pol
  where status_id = p_policy_status_id
  order by policy_id ;

  -- Policy Area Cursor
  cursor C_Policy_Area (Pls_Id in integer) is
  select * from OMEGACA.rtp_ddl_pol_area
  where policy_id = Pls_Id;

v_area_item_factor_val     varchar2(1000);
v_area_item_operand_val    varchar2(2000);
v_area_item_cmd            varchar2(2000);
v_area_cmd                 varchar2(2000);
v_area_SQL                 varchar2(2000);
v_area_result              varchar2(5);

v_str                      varchar2(100);
v_str_DZ_Field             varchar2(100);
v_DZ_pos                   number;
v_start_pos                number;

  -- Init and use variable - no hard parse
  p_rule_status_id integer := 1; -- Active
  -- Rule Cursor
  cursor C_Rule (Pls_Id in integer) is
  select * from OMEGACA.rtp_ddl_pol_rule
  where policy_id = Pls_Id
  and status_id = p_rule_status_id
  order by rule_id ;

  v_factor_value          varchar2(4000);
  v_policy_factor_str     OMEGACA.rtp_ddl_pol_cache.policy_factor_str%TYPE;

  -- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
  p_rule_sts_id integer := 1; -- Active
  -- Distincted Factor_Id Conditions of Policy - Cursor
  cursor C_Cond_Cache (Pol_Id in integer) is
  select distinct factor_id from OMEGACA.v_rtp_ddl_pol_cond_ids
  where policy_id = Pol_Id
  and status_id = p_cond_status_id
  and rule_status_id = p_rule_sts_id
  order by factor_id;

v_db_open_mode            SYS.V$DATABASE.OPEN_MODE%TYPE;
v_dbid                    sys.V$DATABASE.DBID%TYPE;

v_ora_dict_obj_owner      varchar2(100);

v_trail_pol_tmp           varchar2(1000);
v_trail_pol               varchar2(2000);
TRAIL_INS                 Boolean;
v_return_message          varchar2(2000);

v_timestamp_sts           OMEGACA.sys_unf_trail.TIMESTAMP_STS%TYPE;
v_timestamp_utc           OMEGACA.sys_unf_trail.TIMESTAMP_UTC%TYPE;

-- Policy User Variables
cnt_policy_user_apply    integer;
cnt_policy_user_exclude  integer;
p_pol_user_apply         integer :=1 ; -- 1 = Apply
p_pol_user_exclude       integer :=2 ; -- 2 = Exclude

PRAGMA AUTONOMOUS_TRANSACTION;

begin

-- ACC TIMESTAMPS - FIRST ACTION
v_timestamp_sts := SYSTIMESTAMP;
v_timestamp_utc := SYS_EXTRACT_UTC(SYSTIMESTAMP);


-- BEGIN CHECK DB OPEN MODE
-- Get Database Data
select open_mode, dbid
into v_db_open_mode, v_dbid
from sys.V$DATABASE;
-- Check Read-Write Status
if v_db_open_mode <> 'READ WRITE' then
RETURN;    -- Quit Further Processing - Return Proc
end if;
-- END CHECK DB OPEN MODE


-- BEGIN MAIN BEGIN-EXCEPTION-END
BEGIN

-- Begin Make null ora_dict_obj_owner fix
if ora_dict_obj_type in ('DIRECTORY', 'DATABASE LINK') then

if ora_dict_obj_type = 'DIRECTORY' then
v_ora_dict_obj_owner := 'SYS';
end if;
if ora_dict_obj_type = 'DATABASE LINK' then
v_ora_dict_obj_owner := ora_login_user;
end if;

else
v_ora_dict_obj_owner := ora_dict_obj_owner;
end if;
-- End Make null ora_dict_obj_owner fix


-- Set default TRAIL_INS to False
TRAIL_INS := False;


-- BEGIN LOOP C_POLICY
for Rec_Policy in C_Policy loop

-- BEGIN EVALUATE AREA

-- Reset v_area_cmd
v_area_cmd := '';

-- BEGIN LOOP POLICY AREA
for Rec_Policy_Area in C_Policy_Area(Rec_Policy.Policy_Id) loop

-- Reset Area Item Operand Value
v_area_item_operand_val:= '';

-- Begin Make Area Item Factor Value
if Rec_Policy_Area.Area_Factor = 'OBJ_OWNER' then
v_area_item_factor_val:=  v_ora_dict_obj_owner;
elsif Rec_Policy_Area.Area_Factor = 'OBJ_TYPE' then
v_area_item_factor_val:=  ora_dict_obj_type;
elsif Rec_Policy_Area.Area_Factor = 'OBJ_NAME' then
v_area_item_factor_val:=  ora_dict_obj_name;
elsif Rec_Policy_Area.Area_Factor = 'DDL_EVENT' then
v_area_item_factor_val:=  ora_sysevent;
else
raise_application_error(-20020, 'Unknown DDL Policy Area Factor !');
end if;
-- End Make Area Item Factor Value


-- Begin Make Operand value by Operator
if Rec_Policy_Area.Opr_Code in ('IN', 'NOT IN') then

-- Reset Loop IN Variables
v_str := Rec_Policy_Area.Operand;
v_str_DZ_Field := '';
v_DZ_pos := 0;
v_start_pos := 1;

-- Begin Loop [NOT] IN Operands
loop
v_DZ_pos := INSTR(v_str, '#', v_start_pos);

  -- Begin Make # not found
  if v_DZ_pos = 0 then
  v_str_DZ_Field := substr(v_str, v_start_pos);

  if v_area_item_operand_val is null then
  v_area_item_operand_val := '''' || v_str_DZ_Field || '''';
  else
  v_area_item_operand_val :=
  v_area_item_operand_val || ', ' || '''' || v_str_DZ_Field || '''';
  end if;

  -- Exit Loop
  exit;
  end if;
  -- End Make # not found

-- Begin Make # found
v_str_DZ_Field := substr(v_str, v_start_pos, (v_DZ_pos - v_start_pos));

if v_area_item_operand_val is null then
v_area_item_operand_val := '''' || v_str_DZ_Field || '''';
else
v_area_item_operand_val :=
v_area_item_operand_val || ', ' || '''' || v_str_DZ_Field || '''';
end if;

-- Incr Start Position
v_start_pos := v_DZ_pos + 1;
-- End Make # found

end loop;
-- End Loop [NOT] IN Operands

-- Make Area Item CMD
v_area_item_cmd := '''' || v_area_item_factor_val || ''''
                || ' ' ||  Rec_Policy_Area.Opr_Code || ' '
                || '(' || v_area_item_operand_val || ')' ;

-- Make for IS [NOT] NULL
elsif Rec_Policy_Area.Opr_Code in ('IS NULL', 'IS NOT NULL') then
-- Make Area Item CMD
v_area_item_cmd := '''' || v_area_item_factor_val || ''''
                || ' ' ||  Rec_Policy_Area.Opr_Code;

else -- Make for non ( IS [NOT] NULL/[NOT] IN )
v_area_item_operand_val := '''' || Rec_Policy_Area.Operand || '''' ;
-- Make Area Item CMD
v_area_item_cmd := '''' || v_area_item_factor_val || ''''
                || ' ' ||  Rec_Policy_Area.Opr_Code || ' '
                || v_area_item_operand_val ;

end if;
-- End Make Operand value by Operator


-- Make Area CMD
if v_area_cmd is null then
v_area_cmd := v_area_item_cmd;
else
v_area_cmd := v_area_cmd || ' AND ' || v_area_item_cmd;
end if;

end loop;
-- END LOOP POLICY AREA


-- Insert Area CMD Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
'UNSET',
'Area CMD: ' || v_area_cmd
);
end if;


-- Begin Make Area Result
if v_area_cmd is null then

-- Area do not go for empty Policy Area cursor
POLICY_AREA_GO := False;

-- Area Eval on non-empty Policy Area cursor
else
-- Make Area CMD
v_area_SQL := 'DECLARE
          BEGIN
          if ' || v_area_cmd || ' then
          :p1 := ''TRUE'';
          else
          :p1 := ''FALSE'';
          end if;
          END;';
-- Eval Area Result
EXECUTE IMMEDIATE v_area_SQL using out v_area_result;

-- Pol Area GO by Area Result
if v_area_result = 'TRUE' then
POLICY_AREA_GO := True;
elsif v_area_result = 'FALSE' then
POLICY_AREA_GO := False;
else
raise_application_error(-20020, 'DDL Policy Area Factor Result non TRUE/FALSE !');
end if;

end if;
-- End Make Area Result

-- END EVALUATE AREA


-- Begin Evaluate POLICY_USER_GO
if Rec_Policy.User_Apply = 0 then -- 0 Policy goes to all users

POLICY_USER_GO := True;

elsif Rec_Policy.User_Apply = 1 then -- 1 Policy goes only for apply users

select count(*) into cnt_policy_user_apply
from OMEGACA.rtp_ddl_pol_user
where policy_id = Rec_Policy.Policy_Id
and user_id = USER
and user_apply = p_pol_user_apply; -- 1=Apply

if cnt_policy_user_apply = 1 then
POLICY_USER_GO := True;
else
POLICY_USER_GO := False;
end if;


elsif Rec_Policy.User_Apply = 2 then -- 2 Policy goes not for exlude users

select count(*) into cnt_policy_user_exclude
from OMEGACA.rtp_ddl_pol_user
where policy_id = Rec_Policy.Policy_Id
and user_id = USER
and user_apply = p_pol_user_exclude; -- 2=Exclude

if cnt_policy_user_exclude = 1 then
POLICY_USER_GO := False;
else
POLICY_USER_GO := True;
end if;


else
raise_application_error(-20020, 'RTP DDL Policy User Appliance option not in 0-All Users, 1-Users Apply, 2-Users Exclude !');
end if;
-- End Evaluate POLICY_USER_GO



-- BEGIN PROCESS POLICY ONLY IF POLICY_USER_GO and POLICY_AREA_GO are TRUE
if POLICY_USER_GO and POLICY_AREA_GO then


-- Insert Log if POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
'UNSET',
'Policy: evaluation...'
);
end if;


-- ============= BEGIN PROCESS CACHE ====================
if Rec_Policy.Use_Cache = 1 then
 -- Initialize Factor String to NULL
v_policy_factor_str := '';
-- Begin Loop Distincted factor for Cache
for rec1 in C_Cond_Cache(Rec_Policy.Policy_Id) loop
v_factor_value := F_SYS_FACTOR_GET_VALUE(
                  rec1.factor_id,
                  3 -- Pol Type = 3 = RTP DDL
                  );
v_policy_factor_str := v_policy_factor_str || '~' || v_factor_value;
end loop;
-- End Loop Distincted factor for Cache

-- Begin Check and raise Empty Factor String = No Active Rule-Condition
if v_policy_factor_str is null then
raise_application_error(-20020, 'RTP DDL Policy: ' || Rec_Policy.Policy_Name
                                || ' - no Active Condition[s] found !');
end if;
-- End Check and raise Empty Factor String = No Active Rule-Condition

BEGIN
select policy_result into V_POLICY_RESULT
from OMEGACA.rtp_ddl_pol_cache
where policy_id = Rec_Policy.Policy_Id
and policy_factor_str = v_policy_factor_str;
POLICY_CACHE_REC_FOUND := True;
EXCEPTION
WHEN NO_DATA_FOUND then
POLICY_CACHE_REC_FOUND := False;
END;

end if;
-- ============= END PROCESS CACHE ====================



-- BEGIN PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]
if Rec_Policy.Use_Cache = 0 or
(Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False ) then


-- BEGIN POLICY EVALUATION

-- Initialize Policy Result default FALSE
V_POLICY_RESULT := 'FALSE';


-- BEGIN ANY TRUE
if Rec_Policy.Rule_Eval = 1 then -- 1 = Any True

-- Begin Loop Rules
for rec_rule in C_Rule(Rec_Policy.Policy_Id) loop

v_rule_result := F_RTP_DDL_POL_RULE_EVAL(
                 rec_rule.rule_id
                 );

if v_rule_result = 'TRUE' then
V_POLICY_RESULT := 'TRUE';
Exit; -- Exit Rule Loop when TRUE on Any True found
end if;

end loop;
-- End Loop Rules

v_policy_log_detail := 'ANY TRUE - ' || V_POLICY_RESULT;
-- END ANY TRUE


-- BEGIN ALL TRUE
elsif Rec_Policy.Rule_Eval = 2 then -- 2 = All True

-- Begin Loop Rules
for rec_rule in C_Rule(Rec_Policy.Policy_Id) loop

v_rule_result := F_RTP_DDL_POL_RULE_EVAL(
                 rec_rule.rule_id
                 );
if v_rule_result = 'FALSE' then
V_POLICY_RESULT := 'FALSE';
Exit; -- Exit Rule Loop when FALSE on All True found
else
V_POLICY_RESULT := 'TRUE'; -- Continue Loop, remain last if no FALSE
end if;

end loop;
-- End Loop Rules

v_policy_log_detail := 'ALL TRUE - ' || V_POLICY_RESULT;
-- END ALL TRUE


-- BEGIN FORMULA
elsif Rec_Policy.Rule_Eval = 3 then -- 3 = Formula

v_policy_formula := Rec_Policy.Formula;

-- BEGIN LOOP FORMULA STRING SEARCHING For DATA INSIDE []
for I in 1..100 loop

x := INSTR(v_policy_formula, '[', 1, 1);

if X = 0 then
exit;
end if;

y := 9; -- COND_CODE LENGTH 7 + 2
S:= SUBSTR(v_policy_formula, x, y);
v_rule_id := To_Number( substr(S, 2, 7) ); -- COND_CODE LENGTH 7


-- Begin Check Inactive Rule status_id=0
select status_id into v_rule_status
from OMEGACA.rtp_ddl_pol_rule
where rule_id = v_rule_id;

if v_rule_status = 0 then
-- Raise Error
raise_application_error(-20020, 'RTP DDL Policy: ' || Rec_Policy.Policy_Name
                                || ' - Inactive Rule ' || S || ' included in formula !');
end if;
-- End Check Inactive Rule status_id=0

v_rule_result := F_RTP_DDL_POL_RULE_EVAL(
                 v_rule_id
                 );

v_policy_formula := REPLACE(v_policy_formula, S, v_rule_result);

end loop;
-- END LOOP FORMULA STRING SEARCHING For DATA INSIDE []

V_FORMULA := 'DECLARE
            res boolean;
            BEGIN
               res := '|| v_policy_formula ||';
               if res then
                  :p1 := ''TRUE'';
               else
                  :p1 := ''FALSE'';
               end if;
            END;';

v_policy_log_detail := 'FORMULA - ' || v_policy_formula;

EXECUTE IMMEDIATE V_FORMULA using out V_POLICY_RESULT;
-- END FORMULA


else -- raise if none
raise_application_error(-20020, 'RTP DDL Policy Rule Evaluation not in 1-Any True, 2-All True, 3-Formula !');
end if;

-- END POLICY EVALUATION


-- BEGIN INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]
if Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND = False then

-- Insert Cache
P_RTP_DDL_POL_CACHE_INS(
Rec_Policy.Policy_Id,
v_policy_factor_str,
V_POLICY_RESULT
);

end if;
-- END INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]

end if;
-- END PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]



-- BEGIN UPDATE LOG IF POLICY_LOG = 1
if Rec_Policy.Debug_Log = 1 then

-- Make Detail if cache
If Rec_Policy.Use_Cache = 1 and POLICY_CACHE_REC_FOUND then
v_policy_log_detail := 'CACHE - ' || V_POLICY_RESULT;
end if;

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
3, -- 3 = RTP DDL
Rec_Policy.Policy_Id,
Rec_Policy.Policy_Name,
NULL,
NULL,
NULL,
NULL,
V_POLICY_RESULT,
'Policy: ' || v_policy_log_detail
);

end if;
-- END UPDATE LOG IF POLICY_LOG = 1


-- BEGIN DO RTP DDL TRAIL

-- Begin 1 - Audit On Failure.
if Rec_Policy.Audit_Option = 1 then
if V_POLICY_RESULT = 'FALSE'  then
TRAIL_INS := True;
end if;
end if;
-- End 1 - Audit On Failure.

-- Begin 2 - Audit On Success/Failure.
if Rec_Policy.Audit_Option = 2 then
TRAIL_INS := True;
end if;
-- End 2 - Audit On Success/Failure.


-- Begin Make Trail Policies
v_trail_pol_tmp :=
'<Policy>'
|| Chr(10)
|| '<Id>'       || Rec_Policy.Policy_Id     || '</Id>'
|| Chr(10)
|| '<Name>'     || Rec_Policy.Policy_Name   || '</Name>'
|| Chr(10)
|| '<Result>'   || V_POLICY_RESULT          || '</Result>'
|| Chr(10)
|| '</Policy>';

if v_trail_pol is null then
v_trail_pol := v_trail_pol_tmp;
else
v_trail_pol := v_trail_pol
               || Chr(10)
               || v_trail_pol_tmp;
end if;
-- End Make Trail Policies



-- BEGIN MAKE LOG_DDL_BODY
if Rec_Policy.Log_Ddl_Body = 1 then

-- Begin Update DDL Body if Trail Insert
if TRAIL_INS then
-- Begin Exec DDL Body Proc if not run before
if v_ddl_body_exec = 0 then
-- Exec DDL Body Proc
v_ddl_body := F_RTP_DDL_TRAIL_DDL_BODY;
v_ddl_body_exec := 1; -- Set DDL Body proc executed
end if;
-- End Exec DDL Body Proc if not run before
end if;
-- End Update DDL Body if Trail Insert

end if;
-- END MAKE LOG_DDL_BODY


-- BEGIN MAKE LOG_DDL_CMD
if Rec_Policy.Log_Cmd = 1 then

-- Begin Update DDL Cmd if Trail Insert
if TRAIL_INS then
-- Begin Exec DDL Cmd Proc if not run before
if v_ddl_cmd_exec = 0 then
-- Exec DDL Cmd Proc
v_ddl_cmd := F_RTP_DDL_TRAIL_DDL_CMD;
v_ddl_cmd_exec := 1; -- Set DDL Cmd proc executed
end if;
-- End Exec DDL Cmd Proc if not run before
end if;
-- End Update DDL Cmd if Trail Insert

end if;
-- END MAKE LOG_DDL_CMD


-- END DO RTP DDL TRAIL


-- Begin Evaluate Raise Error (Protection) Policy operation
if V_POLICY_RESULT = 'FALSE' and Rec_Policy.Silent_Deny = 0 then -- 0 = No Silent Deny

-- Begin Insert Trail if Param Set TRUE
-- ... and FALSE non-Silent Policy !
if TRAIL_INS then

-- Make return message
v_return_message := 'RTP DDL Policy: ' || Rec_Policy.Policy_Name || ' violation!';
-- Insert UNF Trail for Error for RTP_DDL
P_RTP_DDL_UNF_TRAIL (
v_timestamp_sts,
v_timestamp_utc,
v_ora_dict_obj_owner,
ora_dict_obj_name,
ora_dict_obj_type,          
ora_sysevent,
v_ddl_body,
v_ddl_cmd,
-20010,  -- ReturnCode to Error
v_return_message,
v_trail_pol,
v_dbid
);

end if;
-- End Insert Trail if Param Set TRUE

raise_application_error(-20010, 'RTP DDL Policy: ' || Rec_Policy.Policy_Name || ' violation !');
end if;
-- End Evaluate Raise Error (Protection) Policy operation


end if;
-- END PROCESS POLICY ONLY IF POLICY_USER_GO and POLICY_AREA_GO are TRUE


end loop;
-- END LOOP C_POLICY


-- Begin Insert Trail if Param Set TRUE
-- ... and not Raising on FALSE non-Silent Policy above !
if TRAIL_INS then

-- Insert UNF Trail for 0 for RTP_DDL
P_RTP_DDL_UNF_TRAIL (
v_timestamp_sts,
v_timestamp_utc,
v_ora_dict_obj_owner,
ora_dict_obj_name,
ora_dict_obj_type,          
ora_sysevent,
v_ddl_body,
v_ddl_cmd,
0,  -- 0 - No Error,
'ORA-00000: normal, successful completion',
v_trail_pol,
v_dbid
);

end if;
-- End Insert Trail if Param Set TRUE


COMMIT;  -- MAIN COMMIT, last before MAIN EXCEPTION

EXCEPTION -- MAIN EXCEPTION

WHEN OTHERS THEN

If SQLCODE = -20010 then
COMMIT;
RAISE;
elsif SQLCODE = -20020 then
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
RAISE;
else -- non Omegaca 20010,20020
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
end if;

END;
-- END MAIN BEGIN-EXCEPTION-END

end; -- end proc

-- ===========================================================
-- ===========================================================
-- END RTP DDL


-- BEGIN RTP DML
-- ===========================================================
-- ===========================================================

FUNCTION F_RTP_DML_POL_COND_EVAL (
         p_cond_id in integer
         )

RETURN VARCHAR2 IS

v_rule_id                      OMEGACA.rtp_dml_pol_cond.rule_id%TYPE;

v_cond_eval                    OMEGACA.rtp_dml_pol_cond.cond_eval%TYPE;
v_min_trust_level_no           OMEGACA.rtp_dml_pol_cond.min_trust_level_no%TYPE;
v_validate_expr_owner          OMEGACA.rtp_dml_pol_cond.validate_expr_owner%TYPE;
v_validate_expr_object         OMEGACA.rtp_dml_pol_cond.validate_expr_object%TYPE;
v_factor_id                    OMEGACA.rtp_dml_pol_cond.factor_id%TYPE;

v_policy_id                    OMEGACA.rtp_dml_pol_rule.policy_id%TYPE;
v_rule_name                    OMEGACA.rtp_dml_pol_rule.rule_name%TYPE;

v_policy_name                  OMEGACA.rtp_dml_pol.policy_name%TYPE;
v_policy_debug_log             OMEGACA.rtp_dml_pol.debug_log%TYPE;

V_COND_EVAL_OPR_CMD            Varchar2(4000);
v_cond_trust_level             integer;

v_expr_factor_code             OMEGACA.sys_factor.factor_code%TYPE;
v_expr_factor_value            Varchar2(4000);

V_SQL                          Varchar2(2000);

V_COND_LOG_DETAIL              Varchar2(4000);

V_COND_RESULT                  OMEGACA.sys_pol_debug.eval_result%TYPE;

BEGIN

-- get rule_id and cond details
select rule_id, cond_eval, min_trust_level_no,
validate_expr_owner, validate_expr_object, factor_id
into v_rule_id, v_cond_eval, v_min_trust_level_no,
v_validate_expr_owner, v_validate_expr_object, v_factor_id
from OMEGACA.rtp_dml_pol_cond
where cond_id = p_cond_id;

-- get policy_id
select policy_id, rule_name
into v_policy_id, v_rule_name
from OMEGACA.rtp_dml_pol_rule
where rule_id = v_rule_id;

-- get policy data
select policy_name, debug_log
into v_policy_name, v_policy_debug_log
from OMEGACA.rtp_dml_pol
where policy_id = v_policy_id;


-- Begin Condition is Operand evaluated
if v_cond_eval = 1 then -- 1 = Operand

V_COND_EVAL_OPR_CMD := F_SYS_FACTOR_OPERAND_CMD(
                       p_cond_id,
                       4 -- Pol Type = 4 = RTP DML
                       );

V_SQL := 'DECLARE
          BEGIN
          if ' || V_COND_EVAL_OPR_CMD || ' then
          :p1 := ''TRUE'';
          else
          :p1 := ''FALSE'';
          end if;
          END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Operand: ' || V_COND_EVAL_OPR_CMD
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Operand evaluated


-- Begin Condition is Trust Level evaluated
elsif v_cond_eval = 2 then -- 2 = Trust Level
v_cond_trust_level := F_SYS_FACTOR_GET_TRUST_LEVEL(
                      v_factor_id,
                      4 -- Pol Type = 4 = RTP DML
                      );

if v_cond_trust_level < v_min_trust_level_no then
V_COND_RESULT := 'FALSE';
else
V_COND_RESULT := 'TRUE';
end if;

V_COND_LOG_DETAIL := 'Trust Level Found: ' || to_char(v_cond_trust_level)
                  || ', Min. Trust Level required: ' || to_char(v_min_trust_level_no)
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Trust Level evaluated


-- Begin Condition is Validate Expression evaluated
elsif v_cond_eval = 3 then -- 3 = Validate Expression

-- Get Factor Code - First (1st) Val Expr Function Param
select factor_code into v_expr_factor_code
from OMEGACA.sys_factor
where factor_id = v_factor_id;

-- Make Factor Value - Second (2d) Val Expr Function Param
v_expr_factor_value := F_SYS_FACTOR_GET_VALUE(
                       v_factor_id,
                       4 -- Pol Type = 4 = RTP DML
                       );

-- Prepare Validation Expression Exec Command
V_SQL := 'DECLARE
      res boolean;
      BEGIN
      res := '|| v_validate_expr_owner || '.' || v_validate_expr_object
      || '('
      || '''' || to_char(v_expr_factor_code) || '''' -- string (quoted)
      || ','
      || '''' || to_char(v_expr_factor_value) || '''' -- string (quoted)
      || ')'
      ||';
      if res then
      :p1 := ''TRUE'';
      else
      :p1 := ''FALSE'';
      end if;
      END;';

EXECUTE IMMEDIATE V_SQL using out V_COND_RESULT;

V_COND_LOG_DETAIL := 'Validate Expression: ' || V_SQL
                  || ', FACTOR_ID=' || v_factor_id;
-- End Condition is Validate Expression evaluated


-- Begin Unknown Cond_Eval, Raise
else
raise_application_error(-20020, 'RTP DML Condition Evaluation method not in 1-Operand, 2-Trust Level, 3-Validate Expression !');
end if;
-- End Unknown Cond_Eval, Raise


-- Insert Condition Log if policy_log = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
v_rule_id,
v_rule_name,
p_cond_id,
Lpad(p_cond_id, 7, '0'), -- COND_CODE LENGTH = 7
V_COND_RESULT,
v_cond_log_detail
);
End if;


RETURN V_COND_RESULT ;

END ;

-- =================================================================

FUNCTION F_RTP_DML_POL_RULE_EVAL (
         p_rule_id in integer
         )

RETURN VARCHAR2 IS

v_policy_id             OMEGACA.rtp_dml_pol_rule.policy_id%TYPE;
v_cond_eval             OMEGACA.rtp_dml_pol_rule.cond_eval%TYPE;

v_rule_name             OMEGACA.rtp_dml_pol_rule.rule_name%TYPE;
v_rule_formula          OMEGACA.rtp_dml_pol_rule.formula%TYPE;

S                       varchar2(1024);
I                       integer;
x                       integer;
y                       integer;
V_FORMULA               varchar2(1024);

v_cond_id               OMEGACA.rtp_dml_pol_cond.cond_id%TYPE;
v_cond_status           OMEGACA.rtp_dml_pol_cond.status_id%TYPE;
v_cond_result           OMEGACA.sys_pol_debug.eval_result%TYPE;
v_rule_log_detail       Varchar2(4000);

v_policy_name           OMEGACA.rtp_dml_pol.policy_name%TYPE;
v_policy_debug_log      OMEGACA.rtp_dml_pol.debug_log%TYPE;

V_RULE_RESULT           OMEGACA.sys_pol_debug.eval_result%TYPE;

-- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
-- Cond Cursor
cursor C_Cond is
select * from OMEGACA.rtp_dml_pol_cond
where rule_id = p_rule_id
and status_id = p_cond_status_id
order by cond_id;

begin

-- get rule data
select policy_id, cond_eval, formula, rule_name
into v_policy_id, v_cond_eval, v_rule_formula, v_rule_name
from OMEGACA.rtp_dml_pol_rule
where rule_id = p_rule_id;

-- Get Policy Data
select policy_name, debug_log
into v_policy_name, v_policy_debug_log
from OMEGACA.rtp_dml_pol
where policy_id = v_policy_id;


-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
'UNSET',
'Rule: evaluation...'
);
end if;


-- Initialize Rule Result default FALSE
V_RULE_RESULT := 'FALSE';


-- BEGIN ANY TRUE
if v_cond_eval = 1 then -- 1 = Any True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_RTP_DML_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'TRUE' then
V_RULE_RESULT := 'TRUE';
Exit; -- Exit Condition Loop when TRUE on Any True found
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ANY TRUE - ' || V_RULE_RESULT;
-- END ANY TRUE


-- BEGIN ALL TRUE
elsif v_cond_eval = 2 then -- 2 = All True

-- Begin Loop Conditions
for rec_cond in C_Cond loop

v_cond_result := F_RTP_DML_POL_COND_EVAL(
                 rec_cond.cond_id
                 );

if v_cond_result = 'FALSE' then
V_RULE_RESULT := 'FALSE';
Exit; -- Exit Condition Loop when FALSE on All True found
else
V_RULE_RESULT := 'TRUE'; -- Continue Loop, remain last if no FALSE
end if;

end loop;
-- End Loop Conditions

v_rule_log_detail := 'ALL TRUE - ' || V_RULE_RESULT;
-- END ALL TRUE


-- BEGIN FORMULA
elsif v_cond_eval = 3 then -- 3 = Formula

-- BEGIN LOOP FORMULA STRING SEARCHING For DATA INSIDE []
for I in 1..100 loop

x := INSTR(v_rule_formula, '[', 1, 1);

if X = 0 then
exit;
end if;

y := 9; -- COND_CODE LENGTH 7 + 2
S:= SUBSTR(v_rule_formula, x, y);
v_cond_id := To_Number( substr(S, 2, 7) ); -- COND_CODE LENGTH 7 !!!

-- Begin Check Inactive Condition status_id=0
select status_id into v_cond_status
from OMEGACA.rtp_dml_pol_cond
where cond_id = v_cond_id;

if v_cond_status = 0 then
-- Raise Error
raise_application_error(-20020, 'RTP DML Policy: ' || v_policy_name
                                || ', Rule: ' || v_rule_name
                                || ' - Inactive Condition ' || S || ' included in formula !');
end if;
-- End Check Inactive Condition status_id=0


v_cond_result := F_RTP_DML_POL_COND_EVAL(
                 v_cond_id
                 );

v_rule_formula := REPLACE(v_rule_formula, S, v_cond_result);

end loop;
-- END LOOP FORMULA STRING SEARCHING For DATA INSIDEE []

V_FORMULA := 'DECLARE
            res boolean;
            BEGIN
               res := '|| v_rule_formula ||';
               if res then
                  :p1 := ''TRUE'';
               else
                  :p1 := ''FALSE'';
               end if;
            END;';
v_rule_log_detail := 'FORMULA - ' || v_rule_formula;

EXECUTE IMMEDIATE V_FORMULA using out V_RULE_RESULT;
-- END FORMULA

else -- raise if none
raise_application_error(-20020, 'RTP DML Rule Condition Evaluation not in 0-None, 1-Any True, 2-All True, 3-Formula !');
end if;


-- Update Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
p_rule_id,
v_rule_name,
NULL,
NULL,
V_RULE_RESULT,
'Rule: ' || v_rule_log_detail
);
End if;


RETURN V_RULE_RESULT;

end; -- end proc

-- =================================================================

PROCEDURE P_RTP_DML_POL_CACHE_INS (
          p_rule_id in integer,
          p_rule_factor_str in varchar2,
          p_policy_result in varchar2
          )

AS

begin

-- Insert rtp_dml_pol_cache
insert into OMEGACA.rtp_dml_pol_cache
(
rule_id,
rule_factor_str,
policy_result
)
values
(
p_rule_id,
p_rule_factor_str,
p_policy_result
);

end; -- end proc

-- ================================================================

FUNCTION F_RTP_DML_POL_RULE_AUD_POL_CND (
         p_rule_id in integer
         )
-- Set by P_RTP_DML_POL_RULE_GEN  as fga policy's
--  audit_condition dbms_fga.add_policy param !!!!!!!!
-- RTP DML's analogue with Trigger RTP_DB_DDL_BF of RTP DDL !!!
-- Audit Condition TRUE means Audit event (FGA Log) is triggered
-- Audit Condition set
-- (OMEGACA.CORE_AUDIT.)F_RTP_DML_POL_RULE_AUD_POL_CND(x) = 'TRUE'
-- HARDCODE set on every RTP-DML FGA policy as audit_condition by _GEN Proc !!!

RETURN VARCHAR2 IS

POLICY_USER_GO         Boolean;
POLICY_CACHE_REC_FOUND Boolean;

v_policy_id             OMEGACA.rtp_dml_pol_rule.policy_id%TYPE;
v_audit_condition_type  OMEGACA.rtp_dml_pol_rule.audit_condition_type%TYPE;
v_rule_name             OMEGACA.rtp_dml_pol_rule.rule_name%TYPE;

v_policy_name           OMEGACA.rtp_dml_pol.policy_name%TYPE;
v_policy_debug_log      OMEGACA.rtp_dml_pol.debug_log%TYPE;
v_user_apply            OMEGACA.rtp_dml_pol.user_apply%TYPE;

v_use_cache             OMEGACA.rtp_dml_pol.use_cache%TYPE;

  v_factor_value        varchar2(4000);
  v_rule_factor_str     OMEGACA.rtp_dml_pol_cache.rule_factor_str%TYPE;

v_policy_log_detail     varchar2(4000);

  -- Init and use variable - no hard parse
  p_cond_status_id integer := 1; -- Active
  -- Distincted Factor_Id Conditions of Policy - Cursor
  cursor C_Cond_Cache  is
  select distinct factor_id from OMEGACA.v_rtp_dml_pol_cond_ids
  where rule_id = p_rule_id
  and status_id = p_cond_status_id
  order by factor_id;

V_RULE_RESULT           OMEGACA.sys_pol_debug.eval_result%TYPE;

v_db_open_mode          sys.V$DATABASE.OPEN_MODE%TYPE;

-- Policy User Variables
cnt_policy_user_apply    integer;
cnt_policy_user_exclude  integer;
p_pol_user_apply         integer :=1 ; -- 1 = Apply
p_pol_user_exclude       integer :=2 ; -- 2 = Exclude

PRAGMA AUTONOMOUS_TRANSACTION;

begin

-- BEGIN CHECK DB OPEN MODE
-- Get Database Mode
select open_mode into v_db_open_mode
from sys.V$DATABASE;
-- Check Read-Write Status
if v_db_open_mode <> 'READ WRITE' then
V_RULE_RESULT := 'FALSE'; -- Do not trigger FGA audit event on READ ONLY Db
RETURN V_RULE_RESULT;    -- Quit Further Processing - Return Proc
end if;
-- END CHECK DB OPEN MODE


-- BEGIN MAIN BEGIN-EXCEPTION-END
BEGIN


-- get rtp_dml_pol_rule data
select policy_id, rule_name, audit_condition_type
into v_policy_id, v_rule_name, v_audit_condition_type
from OMEGACA.rtp_dml_pol_rule
where rule_id = p_rule_id;

-- Get Policy Data
select policy_name, user_apply, debug_log, use_cache
into v_policy_name, v_user_apply, v_policy_debug_log, v_use_cache
from OMEGACA.rtp_dml_pol
where policy_id = v_policy_id;


-- Begin Evaluate POLICY_USER_GO
if v_user_apply = 0 then -- 0 Policy goes to all users

POLICY_USER_GO := True;

elsif v_user_apply = 1 then -- 1 Policy goes only for apply users

select count(*) into cnt_policy_user_apply
from OMEGACA.rtp_dml_pol_user
where policy_id = v_policy_id
and user_id = USER
and user_apply = p_pol_user_apply; -- 1=Apply

if cnt_policy_user_apply = 1 then
POLICY_USER_GO := True;
else
POLICY_USER_GO := False;
end if;


elsif v_user_apply = 2 then -- 2 Policy goes not for exlude users

select count(*) into cnt_policy_user_exclude
from OMEGACA.rtp_dml_pol_user
where policy_id = v_policy_id
and user_id = USER
and user_apply = p_pol_user_exclude; -- 2=Exclude

if cnt_policy_user_exclude = 1 then
POLICY_USER_GO := False;
else
POLICY_USER_GO := True;
end if;


else
raise_application_error(-20020, 'RTP DML Policy User Appliance option not in 0-All Users, 1-Users Apply, 2-Users Exclude !');
end if;
-- End Evaluate POLICY_USER_GO



-- BEGIN PROCESS POLICY ONLY IF POLICY_USER_GO is TRUE
if POLICY_USER_GO then


-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
NULL,
NULL,
NULL,
NULL,
'UNSET',
'Policy: evaluation...'
);
end if;


-- BEGIN MAKE 3 = NO CONDITION
if v_audit_condition_type = 3 then -- 3 = No Condition

V_RULE_RESULT := 'TRUE';  -- Trigger FGA

-- Insert Log if POLICY_LOG = 1
if v_policy_debug_log = 1 then
-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
NULL,
NULL,
NULL,
NULL,
V_RULE_RESULT,
'Policy: Rule Eval - No Condition'
);
end if;

RETURN V_RULE_RESULT;    -- Quit Further Processing - Return Proc

end if;
-- END MAKE 3 = NO CONDITION



-- ============= BEGIN PROCESS CACHE ====================
if v_use_cache = 1 then
-- Initialize Factor String to NULL
v_rule_factor_str := '';
-- Begin Loop Distincted factor for Cache
for rec1 in C_Cond_Cache loop
v_factor_value := F_SYS_FACTOR_GET_VALUE(
                  rec1.factor_id,
                  4 -- Pol Type = 4 = RTP DML
                  );
v_rule_factor_str := v_rule_factor_str || '~' || v_factor_value;
end loop;
-- End Loop Distincted factor for Cache

-- Begin Check and raise Empty Factor String = No Active Condition
if v_rule_factor_str is null then
raise_application_error(-20020, 'RTP DML Policy: ' || v_policy_name
                                || ', Rule: ' || v_rule_name
                                || ' - no Active Condition[s] found !');
end if;
-- End Check and raise Empty Factor String = No Active Condition

BEGIN
select policy_result into V_RULE_RESULT
from OMEGACA.rtp_dml_pol_cache
where rule_id = p_rule_id
and rule_factor_str = v_rule_factor_str;
POLICY_CACHE_REC_FOUND := True;
EXCEPTION
WHEN NO_DATA_FOUND then
POLICY_CACHE_REC_FOUND := False;
END;

end if;
-- ============= END PROCESS CACHE ======================


-- BEGIN PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]
if v_use_cache = 0 or
(v_use_cache = 1 and POLICY_CACHE_REC_FOUND = False ) then

-- BEGIN RULE/POLICY EVALUATION
-- get rule result from conditions combination only
V_RULE_RESULT := F_RTP_DML_POL_RULE_EVAL(
                 p_rule_id
                 );

-- check rule result
if V_RULE_RESULT not in ('TRUE','FALSE') then
raise_application_error(-20020, 'RTP DML Policy: ' || v_policy_name
                      || ', Rule: ' || v_rule_name
                      || ' - wrong Rule result, not in TRUE, FALSE !');
end if;
-- END RULE/POLICY EVALUATION

-- BEGIN INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]
if v_use_cache = 1 and POLICY_CACHE_REC_FOUND = False then

-- Insert Cache
P_RTP_DML_POL_CACHE_INS(
p_rule_id,
v_rule_factor_str,
V_RULE_RESULT
);

end if;
-- END INSERT CACHE IF [POLICY.USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE]


end if;
-- END PROCESS POLICY IF [USE_CACHE=0 OR (USE_CACHE=1 AND POLICY_CACHE_REC_FOUND=FALSE)]


-- BEGIN UPDATE LOG IF POLICY_LOG = 1
if v_policy_debug_log = 1 then

-- Make Detail if cache
If v_use_cache = 1 and POLICY_CACHE_REC_FOUND then
v_policy_log_detail := 'CACHE - ' || V_RULE_RESULT;
else
v_policy_log_detail := 'ANY TRUE - ' || V_RULE_RESULT;
end if;

-- Debug Policy Evaluation
P_SYS_POL_DEBUG(
USER,
4, -- 4 = RTP DML
v_policy_id,
v_policy_name,
NULL,
NULL,
NULL,
NULL,
V_RULE_RESULT,
'Policy: ' || v_policy_log_detail
);

end if;
-- END UPDATE LOG IF POLICY_LOG = 1


-- POLICY_USER_GO is FALSE
else
-- Set Audit_Condition to FALSE, Audit event (FGA Log) is not triggered
V_RULE_RESULT := 'FALSE';

end if;
-- END PROCESS POLICY ONLY IF POLICY_USER_GO is TRUE


COMMIT;  -- MAIN COMMIT, last before MAIN EXCEPTION

EXCEPTION -- MAIN EXCEPTION

WHEN OTHERS THEN

If SQLCODE = -20010 then
COMMIT;
RAISE;
elsif SQLCODE = -20020 then
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
RAISE;
else -- non Omegaca 20010,20020
-- Set Audit_Condition to FALSE, Audit event (FGA Log) is not triggered
V_RULE_RESULT := 'FALSE';
ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
end if;

END;
-- END MAIN BEGIN-EXCEPTION-END


-- Return last - after Main Exception
RETURN V_RULE_RESULT;

end; -- end proc

-- ================================================================

PROCEDURE P_RTP_DML_AUD_POL_ADD(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2,
          p_audit_condition in varchar2,
          p_audit_column in varchar2,
          p_handler_schema in varchar2,
          p_handler_module in varchar2,
          p_enable in boolean,
          p_statement_types in varchar2,
          p_audit_trail in integer,
          p_audit_col_opt in integer,
          p_audit_condition_priv_run in integer -- 0 - do not run, 1 - run
          )

AS

-- P_RTP_DML_POL_RULE_GEN calls this within PRAGMA AUTONOMOUS_TRANSACTION
-- does not see changes in rtp_dml_rule set !

cnt_audit_condition_owner_priv    integer;

v_audit_trail integer;
v_audit_col_opt integer;

begin

-- Only Omega CA Administrators can add RTP DML Policies on Omega CA Objects
if p_object_schema = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrators can add RTP DML Policies on Omega CA Objects !' );
end if;
end if;


-- set v_audit_trail
if p_audit_trail = 1 then
v_audit_trail := DBMS_FGA.DB_EXTENDED;
elsif p_audit_trail = 2 then
v_audit_trail := DBMS_FGA.DB;
else
raise_application_error(-20010, 'Wrong p_audit_trail Integer !' );
end if;

-- set v_audit_col_opt
if p_audit_col_opt = 1 then
v_audit_col_opt := DBMS_FGA.ANY_COLUMNS;
elsif p_audit_col_opt = 2 then
v_audit_col_opt := DBMS_FGA.ALL_COLUMNS;
else
raise_application_error(-20010, 'Wrong p_audit_col_opt Integer !' );
end if;


-- Add FGA Policy
SYS.DBMS_FGA.ADD_POLICY(
    p_object_schema,
    p_object_name,
    p_policy_name,
    p_audit_condition,
    p_audit_column,
    p_handler_schema,
    p_handler_module,
    p_enable,
    p_statement_types,
    v_audit_trail,
    v_audit_col_opt
    );


-- Run After SYS.DBMS_FGA.ADD_POLICY exec to have dictionary commited 1
-- BEGIN RUN EXECUTION OF AUDIT CONDITION PRIVILEGE - BEFORE 11GR2
if p_audit_condition_priv_run = 1 then

-- Get number of fga policies with owner (schema for <11gR2)
select count(*) into cnt_audit_condition_owner_priv
from dba_tab_privs
where owner = 'OMEGACA'
and table_name = 'F_RTP_DML_POL_RULE_AUD_POL_CND'
and grantee = p_object_schema;

-- Begin execute Grant if Grantee = 0 - priv needed
if cnt_audit_condition_owner_priv = 0 then
-- Make Audit Condition Grant
EXECUTE IMMEDIATE 'grant EXECUTE on OMEGACA.F_RTP_DML_POL_RULE_AUD_POL_CND'
                  || ' to ' || p_object_schema;
end if;
-- End execute revoke if Grant if Grantee = 0 - priv needed

end if;
-- END RUN EXECUTION OF AUDIT CONDITION PRIVILEGE - BEFORE 11GR2

end; -- end proc

-- ============================================================

PROCEDURE P_RTP_DML_AUD_POL_DROP(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2,
          p_audit_condition_priv_run in integer -- 0 - do not run, 1 - run
          )

AS

-- P_RTP_DML_POL_RULE_GEN calls this within PRAGMA AUTONOMOUS_TRANSACTION
-- does not see changes in rtp_dml_rule set !

cnt_audit_condition_owner integer;

begin


-- Only Omega CA Administrators can drop RTP DML Policies on Omega CA Objects
if p_object_schema = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrators can drop RTP DML Policies on Omega CA Objects !' );
end if;
end if;


-- Drop FGA Policy
SYS.DBMS_FGA.DROP_POLICY(
p_object_schema,
p_object_name,
p_policy_name
);


-- Run After SYS.DBMS_FGA.DROP_POLICY exec to have dictionary commited 1
-- BEGIN RUN EXECUTION OF AUDIT CONDITION PRIVILEGE - BEFORE 11GR2
if p_audit_condition_priv_run = 1 then

-- Get number of fga policies with owner (schema for <11gR2)
select count(*) into cnt_audit_condition_owner
from dba_audit_policies
where object_schema = p_object_schema;

-- Begin execute Revoke if Owner = 0 - priv not needed
if cnt_audit_condition_owner = 0 then
-- Make Audit Condition Revoke
EXECUTE IMMEDIATE 'revoke EXECUTE on OMEGACA.F_RTP_DML_POL_RULE_AUD_POL_CND'
                  || ' from ' || p_object_schema;
end if;
-- End execute Revoke if Owner = 0 - priv not needed

end if;
-- END RUN EXECUTION OF AUDIT CONDITION PRIVILEGE - BEFORE 11GR2

end; -- end proc

-- ============================================================

PROCEDURE P_RTP_DML_AUD_POL_ENABLE(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2
          )

AS

begin

-- Only Omega CA Administrators can enable RTP DML Policies on Omega CA Objects
if p_object_schema = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrators can enable RTP DML Policies on Omega CA Objects !' );
end if;
end if;

-- Enable FGA Policy
SYS.DBMS_FGA.ENABLE_POLICY(
    p_object_schema,
    p_object_name,
    p_policy_name,
    TRUE
    );

end; -- end proc

-- ============================================================

PROCEDURE P_RTP_DML_AUD_POL_DISABLE(
          p_object_schema in varchar2,
          p_object_name in varchar2,
          p_policy_name in varchar2
          )

AS

begin

-- Only Omega CA Administrators can disable RTP DML Policies on Omega CA Objects
if p_object_schema = 'OMEGACA' then
if F_SYS_USER_IS_OMEGACA_ADMIN = 0 then
raise_application_error(-20010, 'Only Omega CA Administrators can disable RTP DML Policies on Omega CA Objects !' );
end if;
end if;

-- Disable FGA Policy
SYS.DBMS_FGA.DISABLE_POLICY(
    p_object_schema,
    p_object_name,
    p_policy_name
    );

end; -- end proc

-- ============================================================

PROCEDURE P_RTP_DML_POL_RULE_GEN (
          p_rule_id in integer,
          p_rule_status_id in integer,
          -- FGA options
          p_object_owner in varchar2,
          p_object_name in varchar2,
          p_fga_policy_name in varchar2,
          p_audit_condition_type in integer,
          p_audit_condition in varchar2,
          p_audit_column in varchar2,
          p_statement_SEL in integer,
          p_statement_INS in integer,
          p_statement_UPD in integer,
          p_statement_DEL in integer,
          p_audit_trail in integer,
          p_audit_col_opt in integer,
          p_action_code in integer -- 1-INS,2-UPD,3-DEL
          )

as

-- No ddl auto-commit in the DML of the calling proc
PRAGMA AUTONOMOUS_TRANSACTION;

-- Oracle Version Variables
v_oracle_version_no       integer;
v_oracle_mntn_release_no  integer;
v_oracle_patchset_no      integer;

v_audit_condition         varchar2(4000); -- FGA policy Condition

v_audit_condition_priv_run integer;

-- FGA Policy Cursor (Existing Policy Name = DML Rule FGA Policy Name).
-- Should be 0 in Rule Ins and 1 in Rule Upd.
-- Will erase all in case more (accumulated errors) exist
Cursor C_FGA_Pol (c_fga_policy_name in varchar2)
is
select * from dba_audit_policies
where policy_name = c_fga_policy_name;

v_fga_status              Boolean;
v_statement_types         varchar2(100);

begin

-- check Action Code
if p_action_code not in (1,2,3) then
raise_application_error(-20010, 'Wrong INS/UPD/DEL Action Code not in 1/2/3 !');
end if;

-- Get DML Rule Data - Old data only, Pragma cannot se changes !

-- check rule status
if p_rule_status_id = 0 then
v_fga_status := false;
elsif p_rule_status_id = 1 then
v_fga_status := true;
else
raise_application_error(-20010, 'Wrong Rule status value, not in 0/1 !');
end if;

-- Check Audit Condition Type
if p_audit_condition_type not in (1,2,3) then
raise_application_error(-20010, 'Unknown Rule Authorization Type !');
end if;


-- BEGIN Make FGA's Permission if Oracle Version  < 11gR2

--The FGA policy enforcement runs in the scope of the policy owner.
--Until 11gR2 the owner of the FGA policy is the owner of the protected table.
--Starting with 11gR2 the owner is the user who creates the FGA policy.

-- Get Version info
P_SYS_ORACLE_VERSION_INFO(
v_oracle_version_no,
v_oracle_mntn_release_no,
v_oracle_patchset_no
);

-- Check Ora Version for Feature Compatibility
-- < 11g R2
if v_oracle_mntn_release_no < 1102 then
v_audit_condition_priv_run := 1;
v_audit_condition
:= 'OMEGACA.F_RTP_DML_POL_RULE_AUD_POL_CND(' || p_rule_id || ') = ''TRUE''';
-- >= 11g R2
else
v_audit_condition_priv_run := 0;
v_audit_condition
:= 'OMEGA_CORE_AUDIT.F_RTP_DML_POL_RULE_AUD_POL_CND(' || p_rule_id || ') = ''TRUE''';
end if;

-- END Make FGA's Permission if Oracle Version  < 11gR2


-- Begin Drop Existing FGA with Policy Name = DML Rule FGA Policy Name - if any
for Rec_Fga in C_FGA_Pol (p_fga_policy_name) loop

-- Drop FGA Policy
P_RTP_DML_AUD_POL_DROP(
Rec_Fga.Object_Schema,
Rec_Fga.Object_Name,
Rec_Fga.Policy_Name,
v_audit_condition_priv_run
);

end loop;
-- End Drop Existing FGA with Policy Name = DML Rule FGA Policy Name - if any


-- Begin Add FGA if Action Code in 1-INS, 2-UPD
if p_action_code in (1,2) then

-- Begin Keep Inputed Condition if Column Condition
-- audit_condition_type	= 2 = column condition
if p_audit_condition_type = 2 then
v_audit_condition := p_audit_condition;
end if;
-- End Keep Inputed Condition if Column Condition


-- Begin Make Statements Types
v_statement_types :=
                  Case p_statement_SEL
                  when 1 then 'SELECT,'
                  else ''
                  End
                  ||
                  Case p_statement_INS
                  when 1 then 'INSERT,'
                  else ''
                  End
                  ||
                  Case p_statement_UPD
                  when 1 then 'UPDATE,'
                  else ''
                  End
                  ||
                  Case p_statement_DEL
                  when 1 then 'DELETE' -- no comma (,) on Last (DEL)
                  else ''
                  End ;
-- End Make Statements Types

-- Add FGA
P_RTP_DML_AUD_POL_ADD(
p_object_owner,
p_object_name,
p_fga_policy_name,
v_audit_condition,
p_audit_column,
'SYS', -- v_handler_schema,
'OMEGA_CORE_AUDIT.P_RTP_DML_POL_RULE_AUD_POL_HND', -- fga handler module,
v_fga_status,
v_statement_types,
p_audit_trail,
p_audit_col_opt,
v_audit_condition_priv_run
);

end if;
-- End Add FGA if Action Code in 1-INS, 2-UPD

end;

-- ================================================================

PROCEDURE P_RTP_DML_POL_RULE_STAT (
          p_object_owner in varchar2,
          p_object_name in varchar2,
          p_fga_policy_name in varchar2,
          p_status_id in integer
          )

as

-- No ddl auto-commit in the DML of the calling proc
PRAGMA AUTONOMOUS_TRANSACTION;

begin

-- check Status status
if p_status_id not in (0,1) then
raise_application_error(-20010, 'Wrong Status Id not in 0/1 !');
end if;

-- Get DML Rule Data - Old data only, Pragma cannot se changes !

-- Begin Make Policy Enable/Disable
if p_status_id = 0 then
P_RTP_DML_AUD_POL_DISABLE(
p_object_owner,
p_object_name,
p_fga_policy_name
);
else -- p_status_id = 1 then
P_RTP_DML_AUD_POL_ENABLE(
p_object_owner,
p_object_name,
p_fga_policy_name
);
end if;
-- End Make Policy Enable/Disable

end;

-- ================================================================

PROCEDURE P_RTP_DML_POL_RULE_AUD_POL_HND (
          p_object_owner VARCHAR2,
          p_object_name VARCHAR2,
          p_fga_policy_name VARCHAR2
				  )

as

v_rule_id            OMEGACA.rtp_dml_pol_rule.rule_id%TYPE;
v_rule_name          OMEGACA.rtp_dml_pol_rule.rule_name%TYPE;
v_silent_deny        OMEGACA.rtp_dml_pol_rule.silent_deny%TYPE;

v_dml_err_msg         Varchar2(1000);

begin

-- get Rule Data by Tripple UN Owner, Object and Policy Name of FGA Handler
select rule_id, rule_name, silent_deny
into v_rule_id, v_rule_name, v_silent_deny
from OMEGACA.rtp_dml_pol_rule
where obj_owner = p_object_owner
and obj_name = p_object_name
and fga_policy_name = p_fga_policy_name;

-- Raise  if non Silent deny
if v_silent_deny = 0 then -- IS Non-Silent
v_dml_err_msg := 'RTP DML Rule violation Id: ' || v_rule_id || ' Rule Name: ' || v_rule_name || '!';
raise_application_error(-20010, v_dml_err_msg);
end if;

end; -- end proc

-- ================================================================

PROCEDURE P_RTP_DML_UNF_TRAIL (
          p_TIMESTAMP_UTC in TIMESTAMP,
          p_USERNAME in varchar2,
          p_SESSIONID in number,
          p_OS_USER in varchar2,
          p_USERHOST in varchar2,
          p_ACTION_ID in number,
          p_OBJECT_OWNER in varchar2,
          p_OBJECT_NAME in varchar2,
          p_CLIENT_ID in varchar2,
          p_DBID in number,
          p_DB_NAME in varchar2,
          p_INSTANCE_NUMBER in number,
          p_STATEMENTID in number,
          p_ENTRYID in number,
          p_TRANSACTIONID in raw,
          p_SCN in number,
          p_PROXY_SESSIONID in number,
          p_GLOBAL_UID in varchar2,
          p_ECONTEXT_ID in varchar2,
          p_COMMENT_TEXT in varchar2,
          p_OS_PROCESS in varchar2,
          p_RETURNCODE in number,
          p_RETURN_MESSAGE in varchar2,
          p_SQL_BIND in clob,
          p_SQL_TEXT in clob,
          p_FGA_POLICY_NAME in varchar2,
          p_EXT_NAME in varchar2,
          p_OBJ_EDITION in varchar2,
          p_trail_eval in varchar2
				  )
          
AS   

v_timestamp_sts      OMEGACA.sys_unf_trail.timestamp_sts%type;
v_action_name        OMEGACA.sys_unf_trail.action_name%type;

begin

-- Make Local SysTimeStamp
v_timestamp_sts := from_tz(p_TIMESTAMP_UTC,'00:00') at local;

-- Make Action_Name
if      p_ACTION_ID = 1 then v_action_name := 'SELECT'; 
elsif   p_ACTION_ID = 2 then v_action_name := 'INSERT';
elsif   p_ACTION_ID = 4 then v_action_name := 'UPDATE';
elsif   p_ACTION_ID = 8 then v_action_name := 'DELETE';
else    v_action_name := 'INVALID';
end if;

-- Insert UNF Trail for RTP_DML
insert into OMEGACA.Sys_Unf_Trail (
TIMESTAMP_STS,
TIMESTAMP_UTC,
POLICY_TYPE_ID,
USERNAME,
SESSIONID,
OS_USER,
USERHOST,
ACTION_ID,
ACTION_NAME,
OBJECT_OWNER,
OBJECT_NAME,
CLIENT_ID,
DBID,
DB_NAME,
INSTANCE_NUMBER,
STATEMENTID,
ENTRYID,
TRANSACTIONID,
SCN,
PROXY_SESSIONID,
GLOBAL_UID,
ECONTEXT_ID,
COMMENT_TEXT,
OS_PROCESS,
RETURNCODE,
RETURN_MESSAGE,
SQL_BIND,
SQL_TEXT,
FGA_POLICY_NAME,
EXT_NAME,
OBJ_EDITION,
ISSUE_ID,
TRAIL_EVAL
)
values
(
v_timestamp_sts,
p_TIMESTAMP_UTC,
4, -- Default Pol Type 3=RTP_DML
p_USERNAME,
p_SESSIONID,
p_OS_USER,
p_USERHOST,
p_ACTION_ID,
v_action_name,
p_OBJECT_OWNER,
p_OBJECT_NAME,
p_CLIENT_ID,
p_DBID,
p_DB_NAME,
p_INSTANCE_NUMBER,
p_STATEMENTID,
p_ENTRYID,
p_TRANSACTIONID,
p_SCN,
p_PROXY_SESSIONID,
p_GLOBAL_UID,
p_ECONTEXT_ID,
p_COMMENT_TEXT,
p_OS_PROCESS,
p_RETURNCODE,
p_RETURN_MESSAGE,
p_SQL_BIND,
p_SQL_TEXT,
p_FGA_POLICY_NAME,
p_EXT_NAME,
p_OBJ_EDITION,
0, -- 0 = Issue_Id UNMARKED,
p_trail_eval         
);

end;  

-- ===========================================================

PROCEDURE P_RTP_DML_TRAIL_PURGE
-- to be run by SYS only, for no Audit Trail generated  !!!
-- All Other Users then SYS audited by default in Oracle10g no matter what audit on aud$ !!!

AS

-- FGA_LOG$ cursor
cursor C_Fga_Log is select * from fga_log$ 
FOR UPDATE;

v_db_open_mode    sys.V$DATABASE.OPEN_MODE%TYPE;

v_rule_id         OMEGACA.rtp_dml_pol_rule.rule_id%TYPE;
v_rule_name       OMEGACA.rtp_dml_pol_rule.rule_name%TYPE;
v_policy_id       OMEGACA.rtp_dml_pol_rule.policy_id%TYPE;
v_policy_name     OMEGACA.rtp_dml_pol.policy_name%TYPE;
v_silent_deny     OMEGACA.rtp_dml_pol_rule.silent_deny%TYPE;

v_returncode      NUMBER := 0; -- Initialize to 0 - ORA-00000
v_return_message  OMEGACA.sys_unf_trail.return_message%type; 

v_db_name         varchar2(50);


v_dml_rtc         OMEGACA.sys_param.PARAM_VALUE%TYPE;
-- Parameter ID = 3 = DMLRTC
p_param_id_DMLRTC integer := 3; 

v_dml_map         OMEGACA.sys_param.PARAM_VALUE%TYPE;
-- Parameter ID = 3 = DMLMAP
p_param_id_DMLMAP integer := 4; 


v_trail_pol       varchar2(2000);
v_ext_name        OMEGACA.sys_unf_trail.EXT_NAME%TYPE;

begin

-- BEGIN CHECK DB OPEN MODE
-- Get Database Mode
select open_mode into v_db_open_mode
from sys.V$DATABASE;
-- Check Read-Write Status
if v_db_open_mode <> 'READ WRITE' then
RETURN;    -- Quit Further Processing - Return Proc
end if;
-- END CHECK DB OPEN MODE


-- BEGIN MAIN BEGIN-EXCEPTION-END
BEGIN

-- Make DB_NAME
v_db_name := SYS_CONTEXT('USERENV', 'DB_NAME');

-- Reset Policies Found
v_trail_pol := '';


-- Parameter_Id = 3 = DMLRTC = RTP DML Return Code
select param_value into v_dml_rtc
from OMEGACA.sys_param
where parameter_id = p_param_id_DMLRTC;
-- Parameter_Id = 4 = DMLMAP = RTP DML Trail Map
select param_value into v_dml_map
from OMEGACA.sys_param
where parameter_id = p_param_id_DMLMAP;


-- BEGIN PROCESS FGA_LOG$ Cursor
for rec_sys_fga in C_Fga_Log loop


-- BEGIN MAKE MAP if sys_param-s
if v_dml_map = 1 or v_dml_rtc = 1 then

-- Begin make rule_id, if not found set UNDEFINED-DML
-- by Tripple Object_Owner(Schema)/Object_Name/FGA Policy Name
BEGIN
select rule_id, rule_name, policy_id, silent_deny
into v_rule_id, v_rule_name, v_policy_id, v_silent_deny
from OMEGACA.rtp_dml_pol_rule
where obj_owner = rec_sys_fga.obj$schema
and obj_name = rec_sys_fga.obj$name
and fga_policy_name = rec_sys_fga.policyname;
EXCEPTION
WHEN NO_DATA_FOUND THEN
v_rule_id := 0;        -- 0 = Rule Id UNDEFINED-DML
v_policy_id := 0;      -- 0 = Policy Id UNDEFINED-DML
v_silent_deny := 1;    -- Silent Deny UNDEFINED-DML
v_returncode := 0;     -- 0 on UNDEFINED-DML
v_return_message := ''; -- Empty on UNDEFINED-DML
END;
-- End make rule_id, if not found set UNDEFINED-DML

end if;
-- END MAKE MAP if sys_param-s


-- BEGIN DML RETURN CODE/MSG for fga_log$ record
if v_dml_rtc = 1 then
             
   if v_silent_deny = 0 then
   v_returncode := -20010;
   v_return_message := 'RTP DML Policy Rule: ' || v_rule_name || ' violation!';
   else
   v_returncode := 0;
   v_return_message := 'ORA-00000: normal, successful completion';
   end if;

else -- DMLRTC = 0

v_returncode := 0;
v_return_message := 'ORA-00000: normal, successful completion';  

end if;
-- END DML RETURN CODE/MSG for fga_log$ record


-- BEGIN DML MAP PROCESS for fga_log$ record
if v_dml_map = 1 then

-- Begin Make by DML Rule Found/Not found
if v_rule_id <> 0 then

select policy_name into v_policy_name
from OMEGACA.rtp_dml_pol 
where policy_id = v_policy_id;

v_trail_pol :=
'<Policy>'
|| Chr(10)
|| '<Id>'       || v_policy_id     || '</Id>'
|| Chr(10)
|| '<Name>'     || v_policy_name   || '</Name>'
|| Chr(10)
|| '<Result>'   || 'TRUE'          || '</Result>'
|| Chr(10)
|| '<RuleId>'   || v_rule_id       || '</RuleId>'
|| Chr(10)
|| '<Rulename>' || v_rule_name     || '</Rulename>'
|| Chr(10)
|| '</Policy>';

else

v_trail_pol :=
'<Policy>'
|| Chr(10)
|| '<Id>'       || 0               || '</Id>'
|| Chr(10)
|| '<Name>'     || 'UNDEFINED>'    || '</Name>'
|| Chr(10)
|| '<Result>'   || 'TRUE'          || '</Result>'
|| Chr(10)
|| '<RuleId>'   || 0               || '</RuleId>'
|| Chr(10)
|| '<Rulename>' || 'UNDEFINED'     || '</Rulename>'
|| Chr(10)
|| '</Policy>';

end if;
-- End Make by DML Rule Found/Not found

end if;
--END DML MAP PROCESS for fga_log$ record


-- Truncate Ext_Name
v_ext_name := substr(rec_sys_fga.extid, 1, 200);

-- Insert UNF Trail for RTP_DML
P_RTP_DML_UNF_TRAIL (
rec_sys_fga.NTIMESTAMP#,   -- p_TIMESTAMP_UTC
rec_sys_fga.DBUID,         -- p_USERNAME
rec_sys_fga.SESSIONID,     -- p_SESSIONID
rec_sys_fga.OSUID,         -- p_OS_USER
rec_sys_fga.OSHST,         -- p_USERHOST
rec_sys_fga.STMT_TYPE,     -- p_ACTION_ID
rec_sys_fga.OBJ$SCHEMA,    -- p_OBJECT_OWNER
rec_sys_fga.OBJ$NAME,      -- p_OBJECT_NAME
rec_sys_fga.CLIENTID,      -- p_CLIENT_ID
rec_sys_fga.DBID,          -- p_DBID
v_db_name,                 -- p_DB_NAME
rec_sys_fga.INSTANCE#,     -- p_INSTANCE_NUMBER
rec_sys_fga.STATEMENT,     -- p_STATEMENTID
rec_sys_fga.ENTRYID,       -- p_ENTRYID
rec_sys_fga.XID,           -- p_TRANSACTIONID
rec_sys_fga.SCN,           -- p_SCN
rec_sys_fga.PROXY$SID,     -- p_PROXY_SESSIONID
rec_sys_fga.USER$GUID,     -- p_GLOBAL_UID
rec_sys_fga.AUDITID,       -- p_ECONTEXT_ID
rec_sys_fga.COMMENT$TEXT,  -- p_COMMENT_TEXT
rec_sys_fga.PROCESS#,      -- p_OS_PROCESS
v_returncode,              -- p_RETURNCODE
v_return_message,          -- p_RETURN_MESSAGE
rec_sys_fga.LSQLBIND,      -- p_SQL_BIND in clob,
rec_sys_fga.LSQLTEXT,      -- p_SQL_TEXT in clob,
rec_sys_fga.POLICYNAME,    -- p_FGA_POLICY_NAME
v_ext_name,                -- p_EXT_NAME
NULL,                      -- p_OBJ_EDITION
v_trail_pol                -- p_trail_eval
);

-- Make Delete
delete from fga_log$ where current of C_Fga_Log;

end loop ;
-- END PROCESS FGA_LOG$ Cursor

-- Commit after close of FOR UPDATE cursor only !
COMMIT;


EXCEPTION -- MAIN EXCEPTION

WHEN OTHERS THEN

ROLLBACK;
P_SYS_ERROR_LOG(SQLERRM || Chr(10) || DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
RAISE;

END;
-- END MAIN BEGIN-EXCEPTION-END

end; -- end proc

-- ===========================================================
-- ===========================================================
-- END RTP DML


-- BEGIN SYS_MANAGE
-- ===========================================================
-- ===========================================================

PROCEDURE P_SYS_UNF_TRAIL_MARK_SNG (
p_row_id in varchar2,
p_issue_id in integer
)
-- To Be stored in SYS Schema for no further Audit Logs !!!
as

begin

update OMEGACA.sys_unf_trail set
issue_id = p_issue_id
where rowid = CHARTOROWID(p_row_id);

end; -- end proc

-- ===========================================================

PROCEDURE P_SYS_UNF_TRAIL_MARK_MLT (
p_trail_condition in varchar2,
p_issue_id in integer
)
-- To Be stored in SYS Schema for no further Audit Logs !!!

as

v_trail_condition   varchar2(4000);
v_trail_issue_cmd   varchar2(4000);

begin

-- Trim trail Condition
v_trail_condition := TRIM(p_trail_condition);

-- CHECK Non-Null WHERE (with right-side Space) Condition
if Upper(SubStr(v_trail_condition, 1, 5)) <> 'WHERE' then
raise_application_error(-20010, 'WHERE Clause missing in condition !');
end if;

v_trail_issue_cmd := 'update OMEGACA.V_SYS_UNF_TRAIL '
                  || ' set issue_id = ' || p_issue_id 
                  || ' ' 
                  || v_trail_condition;

EXECUTE IMMEDIATE v_trail_issue_cmd;
COMMIT;

end; -- end proc

-- ===========================================================

FUNCTION F_SYS_USER_IS_OMEGACA_ADMIN

return integer is

cnt_user_omegaca_admin integer;

begin

select count(*) into cnt_user_omegaca_admin
from OMEGACA.v_omegaca_user_role
where grantee = USER
and granted_role = 'OMEGACA_ADMIN';

-- 0 no OMEGACA
-- 1 is OMEGACA

  return cnt_user_omegaca_admin;

end; -- end func

-- ===========================================================

PROCEDURE P_SYS_POL_DEBUG (
          p_username in varchar2,
          p_policy_type_id in integer,
          p_policy_id in integer,
          p_policy_name in varchar2,
          p_rule_id in integer,
          p_rule_name in varchar2,
          p_cond_id in integer,
          p_cond_code in varchar2,
          p_eval_result in varchar2,
          p_debug_log in varchar2
          )

as

PRAGMA AUTONOMOUS_TRANSACTION;

begin

insert into OMEGACA.sys_pol_debug
(
username,
policy_type_id,
policy_id,
policy_name,
rule_id,
rule_name,
cond_id,
cond_code,
eval_result,
debug_log,
timestamp_sts
)
values
(
p_username,
p_policy_type_id,
p_policy_id,
p_policy_name,
p_rule_id,
p_rule_name,
p_cond_id,
p_cond_code,
p_eval_result,
p_debug_log,
SYSTIMESTAMP
);

-- commit explicitely (AUTONOMOUS_TRANSACTION)
COMMIT;

end; -- end proc

-- ===========================================================

PROCEDURE P_SYS_ERROR_LOG (
          p_error_data in varchar2
          )

as

v_userhost             OMEGACA.sys_error_log.userhost%TYPE;
v_ip_address           OMEGACA.sys_error_log.IP_ADDRESS%TYPE;
v_os_user              OMEGACA.sys_error_log.OS_USER%TYPE;
v_bg_job_id            OMEGACA.sys_error_log.BG_JOB_ID%TYPE;

PRAGMA AUTONOMOUS_TRANSACTION;

begin

-- Begin Make Userhost
BEGIN
v_userhost := SYS_CONTEXT('USERENV', 'HOST');
EXCEPTION
WHEN OTHERS THEN
v_userhost := SubStr(SQLERRM, 1, 200); -- Field Length
END;
-- End Make Userhost

-- Begin Make IP Address
BEGIN
v_ip_address := SYS_CONTEXT('USERENV', 'IP_ADDRESS');
EXCEPTION
WHEN OTHERS THEN
v_ip_address := SubStr(SQLERRM, 1, 30); -- Field Length
END;
-- End Make IP Address

-- Begin Make OS User
BEGIN
v_os_user := SYS_CONTEXT('USERENV', 'OS_USER');
EXCEPTION
WHEN OTHERS THEN
v_os_user := SubStr(SQLERRM, 1, 200); -- Field Length
END;
-- End Make OS User

-- Begin Make bg job id
BEGIN
v_bg_job_id := SYS_CONTEXT('USERENV', 'BG_JOB_ID'); -- Field Length
EXCEPTION
WHEN OTHERS THEN
v_bg_job_id := SubStr(SQLERRM, 1, 20);
END;
-- End Make bg job id


-- Insert Error Log
insert into OMEGACA.sys_error_log
(
userhost,
ip_address,
os_user,
bg_job_id,
error_data,
timestamp_sts
)
values
(
v_userhost,
v_ip_address,
v_os_user,
v_bg_job_id,
p_error_data,
SYSTIMESTAMP
);

-- commit explicitely (AUTONOMOUS_TRANSACTION)
COMMIT;

end; -- end proc

-- ===========================================================

PROCEDURE P_SYS_TRAIL_TRANS

AS

begin

-- call standart audit trans proc
P_AUD_TRAIL_PURGE;
-- call fga audit trans proc
P_RTP_DML_TRAIL_PURGE;

end ;

-- ============================================================

PROCEDURE P_SYS_MANAGE_ACC (
          p_trigger_status in integer
          )
          is

v_trigger_status  varchar2(10);

begin

-- Check Status
if p_trigger_status = 0 then
v_trigger_status := 'DISABLE';
elsif p_trigger_status = 1 then
v_trigger_status := 'ENABLE';
else
raise_application_error(-20010, 'Wrong Status 1/0 value !');
end if;

-- Change Trigger status
EXECUTE IMMEDIATE 'alter trigger '
                  || 'OMEGACA_ACC_DB_AF_LOGON ' -- HARDCODE !
                  || v_trigger_status ;

-- Begin e-mail notification
-- End e-mail notification

end;

-- ===========================================================

PROCEDURE P_SYS_MANAGE_AUD (
          p_audit_trail_param_value in varchar2
          )
          is

begin

-- Check audit_trail parameter value
if p_audit_trail_param_value not in ('NONE', 'DB', 'DB_EXTENDED') then
raise_application_error(-20010, 'Wrong audit_trail parameter value not in NONE/DB/DB_EXTENDED !');
end if;

-- Change audit_trail parameter value
EXECUTE IMMEDIATE 'alter system set audit_trail = '
                  || p_audit_trail_param_value -- HARDCODE !
                  || ' scope=spfile' ;
                  
-- Begin e-mail notification
-- End e-mail notification

end;

-- ===========================================================

PROCEDURE P_SYS_MANAGE_AUD_SCHED_JOB (
          p_scheduler_job_status in integer
          )
          is

begin

-- Check Status
if p_scheduler_job_status = 0 then

dbms_scheduler.disable('SYS.OMEGACA_TRANS', true);

elsif p_scheduler_job_status = 1 then

dbms_scheduler.enable('SYS.OMEGACA_TRANS');

else
raise_application_error(-20010, 'Wrong Status 1/0 value !');
end if;

-- Begin e-mail notification
-- End e-mail notification

end;

-- ===========================================================

PROCEDURE P_SYS_MANAGE_RTP_DDL (
          p_trigger_status in integer
          )
          is

v_trigger_status  varchar2(10);

begin

-- Check Status
if p_trigger_status = 0 then
v_trigger_status := 'DISABLE';
elsif p_trigger_status = 1 then
v_trigger_status := 'ENABLE';
else
raise_application_error(-20010, 'Wrong Status 1/0 value !');
end if;

-- Change Trigger status
EXECUTE IMMEDIATE 'alter trigger '
                  || 'OMEGACA_RTP_DB_BF_DDL ' -- HARDCODE !
                  || v_trigger_status ;

-- Begin e-mail notification
-- End e-mail notification

end;

-- ===========================================================

PROCEDURE P_SYS_ORACLE_VERSION_INFO(
          p_oracle_version_no       out integer,
          p_oracle_mntn_release_no  out integer,
          p_oracle_patchset_no      out integer
          )
          is

v_oracle_version      v$instance.version%TYPE;

begin

-- VRS.REL.IAS.PTCHS.PS
-- 10.1.0.4.0 - Ora 10, Release 1, PatchSet 4
-- 11.2.0.1.0 - Ora 11, Release 2, PatchSet 1

-- get Oracle Version from single-row v$instance !
select version into v_oracle_version
from v$instance;

-- Test Oracle 11.2.0.1.0

-- Make Oracle Version - Start to First Colon 1 (.)
p_oracle_version_no := to_number(
SubStr(
v_oracle_version,
1,
InStr(v_oracle_version, '.', 1, 1) - 1
)
);

-- Make Oracle Mntn Release Simple
-- First Colon 1 (.) to Second Colon  2 (.)
p_oracle_mntn_release_no := to_number(
SubStr(
v_oracle_version,
InStr(v_oracle_version, '.', 1, 1) + 1,
InStr(v_oracle_version, '.', 1, 2) - InStr(v_oracle_version, '.', 1, 1) -1
)
);
-- Make Oracle Mntn Release Full number 4 digits
p_oracle_mntn_release_no :=
   to_char(p_oracle_version_no)
|| Lpad(to_char(p_oracle_mntn_release_no), 2, 0) ;


-- Make Oracle Patchset - Third Colon 3 (.) to Fourth Colon 4 (.)
p_oracle_patchset_no := to_number(
SubStr(
v_oracle_version,
InStr(v_oracle_version, '.', 1, 3) + 1,
InStr(v_oracle_version, '.', 1, 4) - InStr(v_oracle_version, '.', 1, 3) -1
)
);
-- Make Oracle Patchset Full number 6 digits
p_oracle_patchset_no :=
   to_char(p_oracle_mntn_release_no)
|| Lpad(to_char(p_oracle_patchset_no), 2, 0) ;

end;

-- ===========================================================
-- ===========================================================
-- END SYS_MANAGE

END;
-- END PACKAGE BODY
/
   
   
-- 07. Omega CA - Engine Triggers
prompt 07. Omega CA - Engine Triggers
prompt ==================================================
prompt
   

  CREATE OR REPLACE TRIGGER "SYS"."OMEGACA_ACC_DB_AF_LOGON" 
AFTER LOGON ON DATABASE
--  ------------------------------------------------------------------------------------------
-- This source is part of the Omega Core Audit Software System and is copyrighted by DATAPLUS.
-- All rights reserved.  
-- DATAPLUS.
-- Tirana, Albania.
-- Street Address: Bul. Zog I, P. Edicom, 8F.
-- Web: www.dataplus-al.com
-- Copyright  2015 by DATAPLUS.
--  ------------------------------------------------------------------------------------------
BEGIN
OMEGA_CORE_AUDIT.P_ACC_DB_AF_LOGON;
END;
-- END TRIGGER
/
   
ALTER TRIGGER "SYS"."OMEGACA_ACC_DB_AF_LOGON" DISABLE
/

  CREATE OR REPLACE TRIGGER "SYS"."OMEGACA_RTP_DB_BF_DDL" 
BEFORE DDL ON DATABASE
--  ------------------------------------------------------------------------------------------
-- This source is part of the Omega Core Audit Software System and is copyrighted by DATAPLUS.
-- All rights reserved.  
-- DATAPLUS.
-- Tirana, Albania.
-- Street Address: Bul. Zog I, P. Edicom, 8F.
-- Web: www.dataplus-al.com
-- Copyright  2015 by DATAPLUS.
--  ------------------------------------------------------------------------------------------
BEGIN
OMEGA_CORE_AUDIT.P_RTP_DB_BF_DDL;
END;
-- END TRIGGER
/
   
ALTER TRIGGER "SYS"."OMEGACA_RTP_DB_BF_DDL" DISABLE
/
   
-- 08. Omega CA - Engine Jobs
prompt 08. Omega CA - Engine Jobs
prompt ==================================================
prompt
   
begin
     dbms_scheduler.create_job(
     job_name => 'OMEGACA_TRANS',
     job_type => 'PLSQL_BLOCK',
     job_action => 'begin OMEGA_CORE_AUDIT.P_SYS_TRAIL_TRANS; end; ',
     start_date => SYSTIMESTAMP + 1/(24*60), -- set 1 min later
     repeat_interval => 'FREQ=MINUTELY',
     enabled => FALSE,
     comments => 'OMEGA Core Audit Trans Job'
     );
end;
/
   
-- 09. Omega CA - Repository Schema Engine Privileges
prompt 09. Omega CA - Repository Schema Engine Privileges
prompt ==================================================
prompt
   
grant execute on OMEGA_CORE_AUDIT to OMEGACA;
grant alter on OMEGACA_TRANS to OMEGACA;

   
-- 10. Omega CA - Set Current Schema to Repository Schema
prompt 10. Omega CA - Set Current Schema to Repository Schema
prompt ==================================================
prompt
   
alter session set current_schema = OMEGACA;
   
-- 11. Omega CA - Repository Install
prompt 11. Omega CA - Repository Install
prompt ==================================================
prompt
   

prompt
prompt Creating table ACC_POL
prompt ======================
prompt
create table ACC_POL
(
  policy_id    NUMBER(9) not null,
  policy_name  VARCHAR2(200) not null,
  policy_desc  VARCHAR2(1000),
  status_id    NUMBER(1) default 0 not null,
  rule_eval    NUMBER(1) not null,
  audit_option NUMBER not null,
  formula      VARCHAR2(1024),
  debug_log    NUMBER(1) not null,
  user_apply   NUMBER(1) not null,
  use_cache    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column ACC_POL.status_id
  is '0 Inactive, 1 Active';
comment on column ACC_POL.rule_eval
  is '1 Any True, 2 All True, 3 Formula';
comment on column ACC_POL.audit_option
  is '0 - Disabled, 1 - On Failure, 2 - On Success/Failure';
comment on column ACC_POL.debug_log
  is '0 - No, 1 - Yes';
comment on column ACC_POL.user_apply
  is '0 - All Users, 1 Users Apply, 2 Users Exclude';
comment on column ACC_POL.use_cache
  is '0 - No, 1 - Yes';
alter table ACC_POL
  add constraint ACC_POL_PK primary key (POLICY_ID);
alter table ACC_POL
  add constraint ACC_POL_UN unique (POLICY_NAME);
alter table ACC_POL
  add constraint ACC_POL_AUDIT_OPTION_CHECK
  check (AUDIT_OPTION in (0,1,2));
alter table ACC_POL
  add constraint ACC_POL_DEBUG_LOG_CHECK
  check (DEBUG_LOG in (0,1));
alter table ACC_POL
  add constraint ACC_POL_RULE_EVAL_CHECK
  check (RULE_EVAL in (1,2,3));
alter table ACC_POL
  add constraint ACC_POL_STATUS_ID_CHECK
  check (STATUS_ID in (0,1));
alter table ACC_POL
  add constraint ACC_POL_USER_APPLY_CHECK
  check (USER_APPLY in (0,1,2));
alter table ACC_POL
  add constraint ACC_POL_USE_CACHE_CHECK
  check (USE_CACHE in (0,1));

prompt
prompt Creating table ACC_POL_CACHE
prompt ============================
prompt
create table ACC_POL_CACHE
(
  policy_id         NUMBER(9) not null,
  policy_factor_str VARCHAR2(1000) not null,
  policy_result     VARCHAR2(5) not null,
  date_created      DATE default SYSDATE not null,
  user_created      VARCHAR2(30) default USER not null
)
;
alter table ACC_POL_CACHE
  add constraint ACC_POL_CACHE_UN unique (POLICY_ID, POLICY_FACTOR_STR);
alter table ACC_POL_CACHE
  add constraint ACC_POL_CACHE_POLICY_FK foreign key (POLICY_ID)
  references ACC_POL (POLICY_ID);

prompt
prompt Creating table ACC_POL_RULE
prompt ===========================
prompt
create table ACC_POL_RULE
(
  rule_id      NUMBER(9) not null,
  policy_id    NUMBER(9) not null,
  rule_name    VARCHAR2(200) not null,
  rule_desc    VARCHAR2(1000),
  status_id    NUMBER(1) not null,
  cond_eval    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null,
  formula      VARCHAR2(1024)
)
;
comment on column ACC_POL_RULE.status_id
  is '0 Inactive, 1 Active';
comment on column ACC_POL_RULE.cond_eval
  is '1 Any True, 2 All True, 3 Formula';
alter table ACC_POL_RULE
  add constraint ACC_POL_RULE_PK primary key (RULE_ID);
alter table ACC_POL_RULE
  add constraint ACC_POL_RULE_UN unique (POLICY_ID, RULE_NAME);
alter table ACC_POL_RULE
  add constraint ACC_POL_RULE_POL_FK foreign key (POLICY_ID)
  references ACC_POL (POLICY_ID);
alter table ACC_POL_RULE
  add constraint ACC_POL_RULE_COND_EVAL_CHCK
  check (COND_EVAL in (1,2,3));
alter table ACC_POL_RULE
  add constraint ACC_POL_RULE_ST_ID_CHCK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table SYS_FACTOR_CATEGORY
prompt ==================================
prompt
create table SYS_FACTOR_CATEGORY
(
  category_id   NUMBER(3) not null,
  category_name VARCHAR2(30) not null,
  date_created  DATE default SYSDATE not null,
  user_created  VARCHAR2(30) default USER not null
)
;
alter table SYS_FACTOR_CATEGORY
  add constraint SYS_FACTOR_CATEGORY_PK primary key (CATEGORY_ID);
alter table SYS_FACTOR_CATEGORY
  add constraint SYS_FACTOR_CATEGORY_UN unique (CATEGORY_NAME);

prompt
prompt Creating table SYS_FACTOR
prompt =========================
prompt
create table SYS_FACTOR
(
  factor_id         NUMBER(9) not null,
  factor_code       VARCHAR2(50) not null,
  factor_name       VARCHAR2(50) not null,
  description       VARCHAR2(1024),
  category_id       NUMBER(9) not null,
  validate_expr     VARCHAR2(1024),
  identification_id NUMBER(3) default 1 not null,
  evaluation_id     NUMBER(3) default 1 not null,
  audit_option_id   NUMBER(3) default 1 not null,
  fail_option_id    NUMBER(3) default 1 not null,
  ret_data_type     VARCHAR2(10) not null,
  date_upd          DATE,
  user_upd          VARCHAR2(30),
  date_created      DATE default SYSDATE not null,
  user_created      VARCHAR2(30) default USER not null
)
;
comment on column SYS_FACTOR.identification_id
  is '1 By Method, 2 By Constant';
comment on column SYS_FACTOR.evaluation_id
  is '1 By Session, 2 By Access - Not In Use';
comment on column SYS_FACTOR.audit_option_id
  is 'Not in Use';
comment on column SYS_FACTOR.fail_option_id
  is 'Not in Use';
alter table SYS_FACTOR
  add constraint SYS_FACTOR_PK primary key (FACTOR_ID);
alter table SYS_FACTOR
  add constraint SYS_FACTOR_UN unique (FACTOR_CODE);
alter table SYS_FACTOR
  add constraint SYS_FACTOR_CATEGORY_FK foreign key (CATEGORY_ID)
  references SYS_FACTOR_CATEGORY (CATEGORY_ID);
alter table SYS_FACTOR
  add constraint SYS_FACTOR_RET_DATA_TYPE_CHECK
  check (RET_DATA_TYPE in ('VARCHAR2', 'NUMBER', 'DATE'));

prompt
prompt Creating table SYS_FACTOR_TRUST_LEVEL
prompt =====================================
prompt
create table SYS_FACTOR_TRUST_LEVEL
(
  trust_level_no   NUMBER(3) not null,
  trust_level_name VARCHAR2(30) not null
)
;
alter table SYS_FACTOR_TRUST_LEVEL
  add constraint SYS_FACTOR_TRUST_LEVEL_PK primary key (TRUST_LEVEL_NO);
alter table SYS_FACTOR_TRUST_LEVEL
  add constraint SYS_FACTOR_TRUST_LEVEL_UN unique (TRUST_LEVEL_NAME);

prompt
prompt Creating table SYS_OPERATION_CODE
prompt =================================
prompt
create table SYS_OPERATION_CODE
(
  code_id      NUMBER(9) not null,
  code_group   VARCHAR2(30) not null,
  code_symbol  VARCHAR2(30) not null,
  code_value   VARCHAR2(255) not null,
  code_desc    VARCHAR2(1024),
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
alter table SYS_OPERATION_CODE
  add constraint SYS_OPERATION_CODE_PK primary key (CODE_ID);
alter table SYS_OPERATION_CODE
  add constraint SYS_OPERATION_CODE_CS_UN unique (CODE_SYMBOL);

prompt
prompt Creating table ACC_POL_COND
prompt ===========================
prompt
create table ACC_POL_COND
(
  cond_id              NUMBER(9) not null,
  rule_id              NUMBER(9) not null,
  cond_eval            NUMBER(1) not null,
  factor_id            NUMBER(9) not null,
  opr_code_id          NUMBER(9),
  operand_1            VARCHAR2(1024),
  operand_2            VARCHAR2(1024),
  min_trust_level_no   NUMBER(3) not null,
  validate_expr_owner  VARCHAR2(30),
  validate_expr_object VARCHAR2(30),
  status_id            NUMBER(1) not null,
  date_upd             DATE,
  user_upd             VARCHAR2(30),
  date_created         DATE default SYSDATE not null,
  user_created         VARCHAR2(30) default USER not null
)
;
comment on column ACC_POL_COND.cond_eval
  is '1 Operand, 2 Trust Level, 3 Validate_Expr';
comment on column ACC_POL_COND.status_id
  is '0 Inactive, 1 Active';
create index ACC_POL_COND_FACTOR_IDX on ACC_POL_COND (FACTOR_ID);
create index ACC_POL_COND_OPR_CODE_IDX on ACC_POL_COND (OPR_CODE_ID);
create index ACC_POL_COND_RULE_IDX on ACC_POL_COND (RULE_ID);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_PK primary key (COND_ID);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_FACTOR_FK foreign key (FACTOR_ID)
  references SYS_FACTOR (FACTOR_ID);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_MIN_TR_LV_FK foreign key (MIN_TRUST_LEVEL_NO)
  references SYS_FACTOR_TRUST_LEVEL (TRUST_LEVEL_NO);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_OPR_CODE_FK foreign key (OPR_CODE_ID)
  references SYS_OPERATION_CODE (CODE_ID);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_RULE_FK foreign key (RULE_ID)
  references ACC_POL_RULE (RULE_ID);
alter table ACC_POL_COND
  add constraint ACC_POL_COND_COND_EVAL_CHCK
  check (COND_EVAL in (1,2,3));
alter table ACC_POL_COND
  add constraint ACC_POL_COND_STATUS_CHCK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table ACC_POL_COND_LIST
prompt ================================
prompt
create table ACC_POL_COND_LIST
(
  list_id      NUMBER(9) not null,
  cond_id      NUMBER(9) not null,
  operand_1    VARCHAR2(1024) not null,
  status_id    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column ACC_POL_COND_LIST.status_id
  is '0 Inactive, 1 Active';
create index ACC_POL_COND_LIST_OPR1_IDX on ACC_POL_COND_LIST (OPERAND_1);
alter table ACC_POL_COND_LIST
  add constraint ACC_POL_COND_LIST_PK primary key (LIST_ID);
alter table ACC_POL_COND_LIST
  add constraint ACC_POL_COND_LIST_UN unique (COND_ID, OPERAND_1);
alter table ACC_POL_COND_LIST
  add constraint ACC_POL_COND_LIST_COND_FK foreign key (COND_ID)
  references ACC_POL_COND (COND_ID);
alter table ACC_POL_COND_LIST
  add constraint ACC_POL_COND_LIST_STAT_CHCK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table ACC_POL_USER
prompt ===========================
prompt
create table ACC_POL_USER
(
  policy_id    NUMBER(9) not null,
  user_id      VARCHAR2(30) not null,
  user_apply   NUMBER(1) not null,
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column ACC_POL_USER.user_apply
  is '1 Users Apply, 2 Users Exclude';
alter table ACC_POL_USER
  add constraint ACC_POL_USER_PK unique (POLICY_ID, USER_ID, USER_APPLY);
alter table ACC_POL_USER
  add constraint ACC_POL_USER_POLICY_FK foreign key (POLICY_ID)
  references ACC_POL (POLICY_ID);
alter table ACC_POL_USER
  add constraint ACC_POL_USER_APPLY_CHK
  check (USER_APPLY in (1,2));

prompt
prompt Creating table ACM_SYS_TABLE_PRIVILEGE_MAP
prompt ==========================================
prompt
create table ACM_SYS_TABLE_PRIVILEGE_MAP
(
  privilege NUMBER not null,
  name      VARCHAR2(100) not null
)
;
comment on table ACM_SYS_TABLE_PRIVILEGE_MAP
  is 'GRANT, Table 18-1,2, priv only, table_privilege_map';
alter table ACM_SYS_TABLE_PRIVILEGE_MAP
  add constraint ACM_SYS_TABLE_PRIVILEGE_MAP_PK primary key (PRIVILEGE);
alter table ACM_SYS_TABLE_PRIVILEGE_MAP
  add constraint ACM_SYS_TABLE_PRIVILEGE_MAP_UN unique (NAME);

prompt
prompt Creating table SYS_OBJ_TYPE
prompt ===========================
prompt
create table SYS_OBJ_TYPE
(
  obj_type VARCHAR2(100) not null,
  obj_cat  VARCHAR2(20)
)
;
alter table SYS_OBJ_TYPE
  add constraint SYS_OBJ_TYPE_PK primary key (OBJ_TYPE);

prompt
prompt Creating table ACM_SYS_TABLE_PRIVILEGE
prompt ======================================
prompt
create table ACM_SYS_TABLE_PRIVILEGE
(
  object_type VARCHAR2(100) not null,
  priv_name   VARCHAR2(100) not null
)
;
comment on table ACM_SYS_TABLE_PRIVILEGE
  is 'GRANT command, Table 18-1,2 ';
alter table ACM_SYS_TABLE_PRIVILEGE
  add constraint ACM_SYS_TABLE_PRIVILEGE_PK primary key (OBJECT_TYPE, PRIV_NAME);
alter table ACM_SYS_TABLE_PRIVILEGE
  add constraint ACM_SYS_TABLE_PRIVILEGE_OBT_FK foreign key (OBJECT_TYPE)
  references SYS_OBJ_TYPE (OBJ_TYPE);
alter table ACM_SYS_TABLE_PRIVILEGE
  add constraint ACM_SYS_TABLE_PRIVILEGE_PRV_FK foreign key (PRIV_NAME)
  references ACM_SYS_TABLE_PRIVILEGE_MAP (NAME);

prompt
prompt Creating table AUD_POL
prompt ======================
prompt
create table AUD_POL
(
  policy_id    NUMBER(9) not null,
  policy_name  VARCHAR2(200) not null,
  policy_desc  VARCHAR2(1000),
  status_id    NUMBER(1) default 0 not null,
  use_cache    NUMBER(1) not null,
  type_id      NUMBER(1) not null,
  debug_log    NUMBER(1),
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column AUD_POL.status_id
  is '0 Inactive, 1 Active';
comment on column AUD_POL.use_cache
  is '0 - No, 1 - Yes';
comment on column AUD_POL.type_id
  is '1 - Obj, 2 - Stmt [Priv]';
comment on column AUD_POL.debug_log
  is '0 - No, 1 - Yes';
alter table AUD_POL
  add constraint AUD_POL_PK primary key (POLICY_ID);
alter table AUD_POL
  add constraint AUD_POL_UN unique (POLICY_NAME);
alter table AUD_POL
  add constraint AUD_POL_DEBUG_LOG_CHECK
  check (DEBUG_LOG in (0,1));
alter table AUD_POL
  add constraint AUD_POL_STATUS_ID_CHK
  check (STATUS_ID in (0,1));
alter table AUD_POL
  add constraint AUD_POL_TYPE_ID_CHECK
  check (TYPE_ID in (1,2));
alter table AUD_POL
  add constraint AUD_POL_USE_CACHE_CHCK
  check (USE_CACHE in (0,1));

prompt
prompt Creating table AUD_POL_CACHE
prompt ============================
prompt
create table AUD_POL_CACHE
(
  policy_id         NUMBER(9) not null,
  policy_factor_str VARCHAR2(1000) not null,
  policy_result     VARCHAR2(5) not null,
  date_created      DATE default SYSDATE not null,
  user_created      VARCHAR2(30) default USER not null
)
;
alter table AUD_POL_CACHE
  add constraint AUD_POL_CACHE_UN unique (POLICY_ID, POLICY_FACTOR_STR);
alter table AUD_POL_CACHE
  add constraint AUD_POL_CACHE_POLICY_FK foreign key (POLICY_ID)
  references AUD_POL (POLICY_ID);

prompt
prompt Creating table AUD_SYS_OBJ_OPT
prompt ==============================
prompt
create table AUD_SYS_OBJ_OPT
(
  obj_type     VARCHAR2(100) not null,
  audit_option VARCHAR2(100) not null
)
;
comment on table AUD_SYS_OBJ_OPT
  is 'Audit 13-3 Level 1';
alter table AUD_SYS_OBJ_OPT
  add constraint AUD_SYS_OBJ_OPT_PK primary key (OBJ_TYPE, AUDIT_OPTION);
alter table AUD_SYS_OBJ_OPT
  add constraint AUD_SYS_OBJ_OPT_OBJ_TYPE_FK foreign key (OBJ_TYPE)
  references SYS_OBJ_TYPE (OBJ_TYPE);

prompt
prompt Creating table AUD_POL_OBJ
prompt ==========================
prompt
create table AUD_POL_OBJ
(
  aud_obj_id      NUMBER(9) not null,
  policy_id       NUMBER(9) not null,
  status_id       NUMBER(1) not null,
  sql_operation   VARCHAR2(200) not null,
  object_owner    VARCHAR2(30) not null,
  object_type     VARCHAR2(30) not null,
  object_name     VARCHAR2(30) not null,
  success_failure NUMBER(1) not null,
  date_upd        DATE,
  user_upd        VARCHAR2(30),
  date_created    DATE default SYSDATE not null,
  user_created    VARCHAR2(30) default USER not null
)
;
comment on column AUD_POL_OBJ.status_id
  is '0 Inactive, 1 Active';
comment on column AUD_POL_OBJ.success_failure
  is '1 Both, 2 Success, 3 Failure';
create index AUD_POL_OBJ_IDX on AUD_POL_OBJ (OBJECT_OWNER, OBJECT_TYPE, OBJECT_NAME, SQL_OPERATION);
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_PK primary key (AUD_OBJ_ID);
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_UN unique (POLICY_ID, OBJECT_OWNER, OBJECT_TYPE, OBJECT_NAME, SQL_OPERATION);
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_POLICY_FK foreign key (POLICY_ID)
  references AUD_POL (POLICY_ID);
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_SQL_OPERATION_FK foreign key (OBJECT_TYPE, SQL_OPERATION)
  references AUD_SYS_OBJ_OPT (OBJ_TYPE, AUDIT_OPTION);
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_STATUS_ID_CHK
  check (STATUS_ID in (0,1));
alter table AUD_POL_OBJ
  add constraint AUD_POL_OBJ_SUCCS_FLR_CHK
  check (SUCCESS_FAILURE in (1,2,3));

prompt
prompt Creating table AUD_SYS_STMT_OPT
prompt ===============================
prompt
create table AUD_SYS_STMT_OPT
(
  option_id   NUMBER not null,
  option_name VARCHAR2(40) not null,
  property    NUMBER not null,
  is_shortcut NUMBER(1) not null,
  is_sys_priv NUMBER(1) not null
)
;
comment on table AUD_SYS_STMT_OPT
  is 'sys.stmt_audit_option_map - Level 1';
comment on column AUD_SYS_STMT_OPT.property
  is 'Sys Privilege Property';
alter table AUD_SYS_STMT_OPT
  add constraint AUD_SYS_STMT_OPT_PK primary key (OPTION_ID);
alter table AUD_SYS_STMT_OPT
  add constraint AUD_SYS_STMT_OPT_UN unique (OPTION_NAME);
alter table AUD_SYS_STMT_OPT
  add constraint AUD_SYS_STMT_OPT_IS_SHTC_CH
  check (IS_SHORTCUT in (0,1));
alter table AUD_SYS_STMT_OPT
  add constraint AUD_SYS_STMT_OPT_IS_SYS_PV_CH
  check (IS_SYS_PRIV in (0,1));

prompt
prompt Creating table AUD_POL_STMT
prompt ===========================
prompt
create table AUD_POL_STMT
(
  aud_stmt_id     NUMBER(9) not null,
  policy_id       NUMBER(9) not null,
  status_id       NUMBER(1) not null,
  audit_option    VARCHAR2(200) not null,
  audit_by_user   VARCHAR2(30) not null,
  success_failure NUMBER(1) not null,
  date_upd        DATE,
  user_upd        VARCHAR2(30),
  date_created    DATE default SYSDATE not null,
  user_created    VARCHAR2(30) default USER not null
)
;
comment on column AUD_POL_STMT.status_id
  is '0 Inactive, 1 Active';
comment on column AUD_POL_STMT.success_failure
  is '1 Both, 2 Success, 3 Failure';
create index AUD_POL_STMT_IDX on AUD_POL_STMT (AUDIT_OPTION, AUDIT_BY_USER);
create index AUD_POL_STMT_IDX_POL_USER on AUD_POL_STMT (POLICY_ID, AUDIT_BY_USER, SUCCESS_FAILURE);
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_PK primary key (AUD_STMT_ID);
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_UN unique (POLICY_ID, AUDIT_OPTION, AUDIT_BY_USER);
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_AUDIT_OPTION_FK foreign key (AUDIT_OPTION)
  references AUD_SYS_STMT_OPT (OPTION_NAME);
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_POLICY_FK foreign key (POLICY_ID)
  references AUD_POL (POLICY_ID);
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_STATUS_ID_CHK
  check (STATUS_ID in (0,1));
alter table AUD_POL_STMT
  add constraint AUD_POL_STMT_SUCCS_FLR_CHK
  check (SUCCESS_FAILURE in (1,2,3));

prompt
prompt Creating table SYS_STMT
prompt =======================
prompt
create table SYS_STMT
(
  stmt_name VARCHAR2(100) not null,
  stmt_type VARCHAR2(20) not null
)
;
alter table SYS_STMT
  add constraint SYS_STMT_PK primary key (STMT_NAME);

prompt
prompt Creating table AUD_SYS_ACTION
prompt =============================
prompt
create table AUD_SYS_ACTION
(
  action_id   NUMBER not null,
  action_name VARCHAR2(100) not null,
  stmt_name   VARCHAR2(100) not null,
  obj_type    VARCHAR2(100) not null
)
;
comment on table AUD_SYS_ACTION
  is 'sys.audit_actions';
alter table AUD_SYS_ACTION
  add constraint AUD_SYS_ACTION_PK primary key (ACTION_ID);
alter table AUD_SYS_ACTION
  add constraint AUD_SYS_ACTION_UN unique (ACTION_NAME);
alter table AUD_SYS_ACTION
  add constraint AUD_SYS_ACTION_OBJ_TYPE_FK foreign key (OBJ_TYPE)
  references SYS_OBJ_TYPE (OBJ_TYPE);
alter table AUD_SYS_ACTION
  add constraint AUD_SYS_ACTION_STMT_FK foreign key (STMT_NAME)
  references SYS_STMT (STMT_NAME);

prompt
prompt Creating table AUD_SYS_OBJ_OPT_ACT
prompt ==================================
prompt
create table AUD_SYS_OBJ_OPT_ACT
(
  obj_type     VARCHAR2(100) not null,
  audit_option VARCHAR2(100) not null,
  stmt_name    VARCHAR2(100) not null,
  action_id    NUMBER not null,
  act_enabled  NUMBER not null
)
;
comment on table AUD_SYS_OBJ_OPT_ACT
  is 'Audit 13-3 Level 2';
create index AUD_SYS_OBJ_OPT_ACT_ACT_IDX on AUD_SYS_OBJ_OPT_ACT (ACTION_ID);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_PK primary key (OBJ_TYPE, AUDIT_OPTION, ACTION_ID);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_ACTION_FK foreign key (ACTION_ID)
  references AUD_SYS_ACTION (ACTION_ID);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_OT_AUD_FK foreign key (OBJ_TYPE, AUDIT_OPTION)
  references AUD_SYS_OBJ_OPT (OBJ_TYPE, AUDIT_OPTION);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_OT_FK foreign key (OBJ_TYPE)
  references SYS_OBJ_TYPE (OBJ_TYPE);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_STMT_FK foreign key (STMT_NAME)
  references SYS_STMT (STMT_NAME);
alter table AUD_SYS_OBJ_OPT_ACT
  add constraint AUD_SYS_OBJ_OPT_ACT_EN_CHK
  check (ACT_ENABLED in (0,1));

prompt
prompt Creating table AUD_SYS_STMT_OPT_ACT
prompt ===================================
prompt
create table AUD_SYS_STMT_OPT_ACT
(
  option_id   NUMBER not null,
  stmt_name   VARCHAR2(100) not null,
  obj_type    VARCHAR2(100) not null,
  action_id   NUMBER not null,
  act_enabled NUMBER not null
)
;
comment on table AUD_SYS_STMT_OPT_ACT
  is 'sys.stmt_audit_option_map - Level 2';
create index AUD_SYS_STMT_OPT_ACT_ACT_IDX on AUD_SYS_STMT_OPT_ACT (ACTION_ID);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_PK primary key (OPTION_ID, ACTION_ID);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_ACTION_FK foreign key (ACTION_ID)
  references AUD_SYS_ACTION (ACTION_ID);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_OBJ_TP_FK foreign key (OBJ_TYPE)
  references SYS_OBJ_TYPE (OBJ_TYPE);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_OPTION_FK foreign key (OPTION_ID)
  references AUD_SYS_STMT_OPT (OPTION_ID);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_STMT_FK foreign key (STMT_NAME)
  references SYS_STMT (STMT_NAME);
alter table AUD_SYS_STMT_OPT_ACT
  add constraint AUD_SYS_STMT_OPT_ACT_EN_CHK
  check (ACT_ENABLED in (0,1));

prompt
prompt Creating table ITS_CLASS
prompt ========================
prompt
create table ITS_CLASS
(
  class_id     NUMBER(20) not null,
  class_name   VARCHAR2(100) not null,
  class_desc   VARCHAR2(250),
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
alter table ITS_CLASS
  add constraint ITS_CLASS_PK primary key (CLASS_ID);
alter table ITS_CLASS
  add constraint ITS_CLASS_UN unique (CLASS_NAME);

prompt
prompt Creating table ITS_GROUP
prompt ========================
prompt
create table ITS_GROUP
(
  group_id     NUMBER(20) not null,
  group_name   VARCHAR2(100) not null,
  group_desc   VARCHAR2(250),
  class_id     NUMBER(20) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
create index ITS_GROUP_CLASS_IDX on ITS_GROUP (CLASS_ID);
alter table ITS_GROUP
  add constraint ITS_GROUP_PK primary key (GROUP_ID);
alter table ITS_GROUP
  add constraint ITS_GROUP_UN unique (GROUP_NAME);
alter table ITS_GROUP
  add constraint ITS_GROUP_CLASS_FK foreign key (CLASS_ID)
  references ITS_CLASS (CLASS_ID);

prompt
prompt Creating table ITS_ISSUE
prompt ========================
prompt
create table ITS_ISSUE
(
  issue_id     NUMBER(20) not null,
  issue_name   VARCHAR2(100) not null,
  issue_desc   VARCHAR2(250),
  group_id     NUMBER(20) not null,
  perpetual    NUMBER(1) default 0 not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
create index ITS_ISSUE_GROUP_IDX on ITS_ISSUE (GROUP_ID);
alter table ITS_ISSUE
  add constraint ITS_ISSUE_PK primary key (ISSUE_ID);
alter table ITS_ISSUE
  add constraint ITS_ISSUE_UN unique (ISSUE_NAME);
alter table ITS_ISSUE
  add constraint ITS_ISSUE_GROUP_FK foreign key (GROUP_ID)
  references ITS_GROUP (GROUP_ID);

prompt
prompt Creating table RPT_REP
prompt ======================
prompt
create table RPT_REP
(
  report_id        NUMBER(9) not null,
  profile_id       NUMBER(9) not null,
  report_name      VARCHAR2(100) not null,
  report_desc      VARCHAR2(250),
  report_base_sql  VARCHAR2(4000) not null,
  report_component CLOB,
  report_link      CLOB,
  rep_native       NUMBER(1) not null,
  date_upd         DATE,
  user_upd         VARCHAR2(30),
  date_created     DATE default SYSDATE not null,
  user_created     VARCHAR2(30) default USER not null
)
;
comment on column RPT_REP.rep_native
  is '0 non-Native-Client, 1 Predefined-Deploy';
alter table RPT_REP
  add constraint RTP_REP_PK primary key (REPORT_ID);
alter table RPT_REP
  add constraint RPT_REP_UN unique (REPORT_NAME, REP_NATIVE);
alter table RPT_REP
  add constraint RPT_REP_PROFILE_CHCK
  check (PROFILE_ID in (1,2,3,4,5));
alter table RPT_REP
  add constraint RPT_REP_REP_NATIVE_CHCK
  check (REP_NATIVE in (0,1));

prompt
prompt Creating table RPT_REP_COL
prompt ==========================
prompt
create table RPT_REP_COL
(
  column_id      NUMBER(9) not null,
  report_id      NUMBER(9) not null,
  column_name    VARCHAR2(30) not null,
  col_data_type  VARCHAR2(50) not null,
  column_caption VARCHAR2(30) not null,
  search_field   NUMBER(1) not null,
  search_order   NUMBER(3) not null,
  search_active  NUMBER(1) not null,
  opr_code_id    NUMBER(9),
  operand_1      VARCHAR2(1024),
  operand_2      VARCHAR2(1024),
  date_upd       DATE,
  user_upd       VARCHAR2(30),
  date_created   DATE default SYSDATE not null,
  user_created   VARCHAR2(30) default USER not null
)
;
alter table RPT_REP_COL
  add constraint RPT_REP_COL_PK primary key (COLUMN_ID);
alter table RPT_REP_COL
  add constraint RPT_REP_COL_UN unique (REPORT_ID, COLUMN_NAME);
alter table RPT_REP_COL
  add constraint RPT_REP_COL_OPR_CODE_FK foreign key (OPR_CODE_ID)
  references SYS_OPERATION_CODE (CODE_ID);
alter table RPT_REP_COL
  add constraint RPT_REP_COL_REPORT_FK foreign key (REPORT_ID)
  references RPT_REP (REPORT_ID);
alter table RPT_REP_COL
  add constraint RPT_REP_COL_SEARCH_ACTIVE_CHK
  check (SEARCH_ACTIVE in (0,1));
alter table RPT_REP_COL
  add constraint RPT_REP_COL_SEARCH_FIELD_CHK
  check (SEARCH_FIELD in (0,1));

prompt
prompt Creating table RPT_REP_PRM
prompt ==========================
prompt
create table RPT_REP_PRM
(
  param_id           NUMBER(9) not null,
  report_id          NUMBER(9) not null,
  param_name         VARCHAR2(30) not null,
  param_data_type    VARCHAR2(50) not null,
  param_display_type VARCHAR2(50) not null,
  param_caption      VARCHAR2(30) not null,
  time_end           NUMBER(1) not null,
  date_upd           DATE,
  user_upd           VARCHAR2(30),
  date_created       DATE default SYSDATE not null,
  user_created       VARCHAR2(30) default USER not null
)
;
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_PK primary key (PARAM_ID);
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_UN unique (REPORT_ID, PARAM_NAME);
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_REPORT_FK foreign key (REPORT_ID)
  references RPT_REP (REPORT_ID);
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_DSP_DATA_TYPE_CHK
  check (PARAM_DISPLAY_TYPE in ('ftString','ftFloat','ftInteger','ftDateTime'));
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_PRM_DATA_TYPE_CHK
  check (PARAM_DATA_TYPE in ('ftString','ftFloat','ftInteger'));
alter table RPT_REP_PRM
  add constraint RPT_REP_PRM_TIME_END_CHK
  check (TIME_END in (0,1));

prompt
prompt Creating table RPT_REP_PRV
prompt ==========================
prompt
create table RPT_REP_PRV
(
  rep_priv_id  NUMBER(9) not null,
  report_id    NUMBER(9) not null,
  priv_role    VARCHAR2(30) not null,
  priv_id      NUMBER(9) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RPT_REP_PRV.priv_id
  is '1 - R, 2 - RW';
alter table RPT_REP_PRV
  add constraint RPT_REP_PRV_UN primary key (REPORT_ID, PRIV_ROLE);
alter table RPT_REP_PRV
  add constraint RPT_REP_PRV_PK unique (REP_PRIV_ID);
alter table RPT_REP_PRV
  add constraint RPT_REP_PRV_REPORT_FK foreign key (REPORT_ID)
  references RPT_REP (REPORT_ID);
alter table RPT_REP_PRV
  add constraint RPT_REP_PRV_PRIV_ID_CHK
  check (PRIV_ID in (1,2));
alter table RPT_REP_PRV
  add constraint RPT_REP_PRV_PRIV_ROLE_CHK
  check (PRIV_ROLE in ('OMEGACA_ACCTMGR','OMEGACA_ADMIN','OMEGACA_AUDIT', 'OMEGACA_SECANALYST'));

prompt
prompt Creating table RTP_DDL_POL
prompt ==========================
prompt
create table RTP_DDL_POL
(
  policy_id    NUMBER(9) not null,
  policy_name  VARCHAR2(200) not null,
  policy_desc  VARCHAR2(1000),
  status_id    NUMBER(1) default 0 not null,
  rule_eval    NUMBER(1) not null,
  audit_option NUMBER(1) not null,
  formula      VARCHAR2(1024),
  debug_log    NUMBER(1) not null,
  user_apply   NUMBER(1) not null,
  use_cache    NUMBER(1) not null,
  silent_deny  NUMBER(1) not null,
  log_ddl_body NUMBER(1) not null,
  log_cmd      NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DDL_POL.status_id
  is '0 Inactive, 1 Active';
comment on column RTP_DDL_POL.rule_eval
  is '1 Any True, 2 All True, 3 Formula';
comment on column RTP_DDL_POL.audit_option
  is '0 - Disabled, 1 - On Failure, 2 - On Success/Failure';
comment on column RTP_DDL_POL.debug_log
  is '0 - No, 1 - Yes';
comment on column RTP_DDL_POL.user_apply
  is '0 - All Users, 1 Users Apply, 2 Users Exclude';
comment on column RTP_DDL_POL.use_cache
  is '0 - No, 1 - Yes';
comment on column RTP_DDL_POL.silent_deny
  is '0 - No, 1 - Yes';
comment on column RTP_DDL_POL.log_ddl_body
  is '0 - No Log, 1 Log';
comment on column RTP_DDL_POL.log_cmd
  is '0 - No Log, 1 Log';
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_PK primary key (POLICY_ID);
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_UN unique (POLICY_NAME);
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_AUDIT_OPTION
  check (AUDIT_OPTION in (0,1,2));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_DEBUG_LOG_CHK
  check (DEBUG_LOG in (0,1));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_LOG_CMD_CHK
  check (LOG_CMD in (0,1));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_LOG_DDL_BODY_CHK
  check (LOG_DDL_BODY in (0,1));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_RULE_EVAL_CHECK
  check (RULE_EVAL in (1,2,3));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_SILENT_DENY_CHCK
  check (SILENT_DENY in (0,1));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_STATUS_ID_CHK
  check (STATUS_ID in (0,1));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_USER_APPLY_CHCK
  check (USER_APPLY in (0,1,2));
alter table RTP_DDL_POL
  add constraint RTP_DDL_POL_USE_CACHE_CHCK
  check (USE_CACHE in (0,1));

prompt
prompt Creating table RTP_DDL_POL_AREA
prompt ===============================
prompt
create table RTP_DDL_POL_AREA
(
  policy_id    NUMBER(9) not null,
  area_factor  VARCHAR2(20) not null,
  opr_code     VARCHAR2(20) not null,
  operand      VARCHAR2(1024),
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
alter table RTP_DDL_POL_AREA
  add constraint RTP_DDL_POL_AREA_UN unique (POLICY_ID, AREA_FACTOR);
alter table RTP_DDL_POL_AREA
  add constraint RTP_DDL_POL_AREA_POLICY_FK foreign key (POLICY_ID)
  references RTP_DDL_POL (POLICY_ID);
alter table RTP_DDL_POL_AREA
  add constraint RTP_DDL_POL_AREA_FACTOR_CHK
  check (AREA_FACTOR in ('OBJ_OWNER','OBJ_NAME','OBJ_TYPE','DDL_EVENT'));
alter table RTP_DDL_POL_AREA
  add constraint RTP_DDL_POL_AREA_OPR_CODE_CHK
  check (OPR_CODE in ('=','<>','LIKE','NOT LIKE','IS NULL','IS NOT NULL','IN','NOT IN'));

prompt
prompt Creating table RTP_DDL_POL_CACHE
prompt ================================
prompt
create table RTP_DDL_POL_CACHE
(
  policy_id         NUMBER(9) not null,
  policy_factor_str VARCHAR2(1000) not null,
  policy_result     VARCHAR2(5) not null,
  date_created      DATE default SYSDATE not null,
  user_created      VARCHAR2(30) default USER not null
)
;
alter table RTP_DDL_POL_CACHE
  add constraint RTP_DDL_POL_CACHE_UN unique (POLICY_ID, POLICY_FACTOR_STR);
alter table RTP_DDL_POL_CACHE
  add constraint RTP_DDL_POL_CACHE_POLICY_FK foreign key (POLICY_ID)
  references RTP_DDL_POL (POLICY_ID);

prompt
prompt Creating table RTP_DDL_POL_RULE
prompt ===============================
prompt
create table RTP_DDL_POL_RULE
(
  rule_id      NUMBER(9) not null,
  policy_id    NUMBER(9) not null,
  rule_name    VARCHAR2(200) not null,
  rule_desc    VARCHAR2(1000),
  status_id    NUMBER(1) not null,
  cond_eval    NUMBER(1) not null,
  formula      VARCHAR2(1024),
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DDL_POL_RULE.status_id
  is '0 Inactive, 1 Active';
comment on column RTP_DDL_POL_RULE.cond_eval
  is '1 Any True, 2 All True, 3 Formula';
create index RTP_DDL_POL_RULE_POLICY_IDX on RTP_DDL_POL_RULE (POLICY_ID);
alter table RTP_DDL_POL_RULE
  add constraint RTP_DDL_POL_RULE_PK primary key (RULE_ID);
alter table RTP_DDL_POL_RULE
  add constraint RTP_DDL_POL_RULE_UN unique (POLICY_ID, RULE_NAME);
alter table RTP_DDL_POL_RULE
  add constraint RTP_DDL_POL_RULE_POL_FK foreign key (POLICY_ID)
  references RTP_DDL_POL (POLICY_ID);
alter table RTP_DDL_POL_RULE
  add constraint RTP_DDL_POL_RULE_COND_EVAL_CHK
  check (COND_EVAL in (1,2,3));
alter table RTP_DDL_POL_RULE
  add constraint RTP_DDL_POL_RULE_STATUS_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DDL_POL_COND
prompt ===============================
prompt
create table RTP_DDL_POL_COND
(
  cond_id              NUMBER(9) not null,
  rule_id              NUMBER(9) not null,
  cond_eval            NUMBER(1) not null,
  factor_id            NUMBER(9) not null,
  opr_code_id          NUMBER(9),
  operand_1            VARCHAR2(1024),
  operand_2            VARCHAR2(1024),
  min_trust_level_no   NUMBER(3) not null,
  validate_expr_owner  VARCHAR2(30),
  validate_expr_object VARCHAR2(30),
  status_id            NUMBER(1) not null,
  date_upd             DATE,
  user_upd             VARCHAR2(30),
  date_created         DATE default SYSDATE not null,
  user_created         VARCHAR2(30) default USER not null
)
;
comment on column RTP_DDL_POL_COND.cond_eval
  is '1 Operand, 2 Trust Level, 3 Validate_Expr';
comment on column RTP_DDL_POL_COND.status_id
  is '0 Inactive, 1 Active';
create index RTP_DDL_POL_COND_FACTOR_IDX on RTP_DDL_POL_COND (FACTOR_ID);
create index RTP_DDL_POL_COND_OPR_CODE_IDX on RTP_DDL_POL_COND (OPR_CODE_ID);
create index RTP_DDL_POL_COND_RULE_IDX on RTP_DDL_POL_COND (RULE_ID);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_PK primary key (COND_ID);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_FACTOR_FK foreign key (FACTOR_ID)
  references SYS_FACTOR (FACTOR_ID);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_MIN_TR_LV_FK foreign key (MIN_TRUST_LEVEL_NO)
  references SYS_FACTOR_TRUST_LEVEL (TRUST_LEVEL_NO);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_OPR_CODE_FK foreign key (OPR_CODE_ID)
  references SYS_OPERATION_CODE (CODE_ID);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_RULE_FK foreign key (RULE_ID)
  references RTP_DDL_POL_RULE (RULE_ID);
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_COND_EVAL_CHK
  check (COND_EVAL in (1,2,3));
alter table RTP_DDL_POL_COND
  add constraint RTP_DDL_POL_COND_STATUS_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DDL_POL_COND_LIST
prompt ====================================
prompt
create table RTP_DDL_POL_COND_LIST
(
  list_id      NUMBER(9) not null,
  cond_id      NUMBER(9) not null,
  operand_1    VARCHAR2(1024) not null,
  status_id    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DDL_POL_COND_LIST.status_id
  is '0 Inactive, 1 Active';
create index RTP_DDL_POL_COND_LIST_OPR1_IDX on RTP_DDL_POL_COND_LIST (OPERAND_1);
alter table RTP_DDL_POL_COND_LIST
  add constraint RTP_DDL_POL_COND_LIST_PK primary key (LIST_ID);
alter table RTP_DDL_POL_COND_LIST
  add constraint RTP_DDL_POL_COND_LIST_UN unique (COND_ID, OPERAND_1);
alter table RTP_DDL_POL_COND_LIST
  add constraint RTP_DDL_POL_COND_LIST_COND_FK foreign key (COND_ID)
  references RTP_DDL_POL_COND (COND_ID);
alter table RTP_DDL_POL_COND_LIST
  add constraint RTP_DDL_POL_COND_LIST_STAT_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DDL_POL_USER
prompt ===============================
prompt
create table RTP_DDL_POL_USER
(
  policy_id    NUMBER(9) not null,
  user_id      VARCHAR2(30) not null,
  user_apply   NUMBER(1) not null,
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DDL_POL_USER.user_apply
  is '1 Users Apply, 2 Users Exclude';
alter table RTP_DDL_POL_USER
  add constraint RTP_DDL_POL_USER_PK unique (POLICY_ID, USER_ID, USER_APPLY);
alter table RTP_DDL_POL_USER
  add constraint RTP_DDL_POL_USER_POLICY_FK foreign key (POLICY_ID)
  references RTP_DDL_POL (POLICY_ID);
alter table RTP_DDL_POL_USER
  add constraint RTP_DDL_POL_USER_APPLY_CH
  check (USER_APPLY in (1,2));

prompt
prompt Creating table RTP_DML_POL
prompt ==========================
prompt
create table RTP_DML_POL
(
  policy_id    NUMBER(9) not null,
  policy_name  VARCHAR2(200) not null,
  policy_desc  VARCHAR2(1000),
  status_id    NUMBER(1) default 0 not null,
  debug_log    NUMBER(1) not null,
  user_apply   NUMBER(1) not null,
  use_cache    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DML_POL.status_id
  is '0 Inactive, 1 Active';
comment on column RTP_DML_POL.debug_log
  is '0 - No, 1 - Yes';
comment on column RTP_DML_POL.user_apply
  is '0 - All Users, 1 Users Apply, 2 Users Exclude';
comment on column RTP_DML_POL.use_cache
  is '0 - No, 1 - Yes';
alter table RTP_DML_POL
  add constraint RTP_DML_POL_PK primary key (POLICY_ID);
alter table RTP_DML_POL
  add constraint RTP_DML_POL_UN unique (POLICY_NAME);
alter table RTP_DML_POL
  add constraint RTP_DML_POL_DEBUG_LOG_CHK
  check (DEBUG_LOG in (0,1));
alter table RTP_DML_POL
  add constraint RTP_DML_POL_STATUS_ID_CHK
  check (STATUS_ID in (0,1));
alter table RTP_DML_POL
  add constraint RTP_DML_POL_USER_APPLY_CHCK
  check (USER_APPLY in (0,1,2));
alter table RTP_DML_POL
  add constraint RTP_DML_POL_USE_CACHE_CHCK
  check (USE_CACHE in (0,1));

prompt
prompt Creating table RTP_DML_POL_RULE
prompt ===============================
prompt
create table RTP_DML_POL_RULE
(
  rule_id              NUMBER(9) not null,
  policy_id            NUMBER(9) not null,
  rule_name            VARCHAR2(200) not null,
  rule_desc            VARCHAR2(1000),
  status_id            NUMBER(1) not null,
  cond_eval            NUMBER(1) not null,
  obj_owner            VARCHAR2(30) not null,
  obj_name             VARCHAR2(30) not null,
  fga_policy_name      VARCHAR2(30) not null,
  audit_condition_type NUMBER(1) not null,
  formula              VARCHAR2(1024),
  silent_deny          NUMBER(1) not null,
  date_upd             DATE,
  user_upd             VARCHAR2(30),
  date_created         DATE default SYSDATE not null,
  user_created         VARCHAR2(30) default USER not null
)
;
comment on column RTP_DML_POL_RULE.status_id
  is '0 Inactive, 1 Active';
comment on column RTP_DML_POL_RULE.cond_eval
  is '0 None, 1 Any True, 2 All True, 3 Formula';
comment on column RTP_DML_POL_RULE.audit_condition_type
  is '1 = rule conditions, 2 = column condition, 3 = no condition';
comment on column RTP_DML_POL_RULE.silent_deny
  is '0 - No, 1 - Yes';
create index RTP_DML_POL_RULE_POLICY_IDX on RTP_DML_POL_RULE (POLICY_ID);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_PK primary key (RULE_ID);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_UN unique (POLICY_ID, RULE_NAME);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_UN_AUD_POL unique (OBJ_OWNER, OBJ_NAME, FGA_POLICY_NAME);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_UN_AUD_POL_NM unique (FGA_POLICY_NAME);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_POL_FK foreign key (POLICY_ID)
  references RTP_DML_POL (POLICY_ID);
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_COND_EVAL_CHK
  check (COND_EVAL in (0,1,2,3));
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_DML_AUD_CT_CH
  check (AUDIT_CONDITION_TYPE in (1,2, 3));
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_SILENT_DN_CHK
  check (SILENT_DENY in (0,1));
alter table RTP_DML_POL_RULE
  add constraint RTP_DML_POL_RULE_STATUS_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DML_POL_CACHE
prompt ================================
prompt
create table RTP_DML_POL_CACHE
(
  rule_id         NUMBER(9) not null,
  rule_factor_str VARCHAR2(1000) not null,
  policy_result   VARCHAR2(5) not null,
  date_created    DATE default SYSDATE not null,
  user_created    VARCHAR2(30) default USER not null
)
;
alter table RTP_DML_POL_CACHE
  add constraint RTP_DML_POL_CACHE_UN unique (RULE_ID, RULE_FACTOR_STR);
alter table RTP_DML_POL_CACHE
  add constraint RTP_DML_POL_CACHE_RULE_FK foreign key (RULE_ID)
  references RTP_DML_POL_RULE (RULE_ID);

prompt
prompt Creating table RTP_DML_POL_COND
prompt ===============================
prompt
create table RTP_DML_POL_COND
(
  cond_id              NUMBER(9) not null,
  rule_id              NUMBER(9) not null,
  cond_eval            NUMBER(1) not null,
  factor_id            NUMBER(9) not null,
  opr_code_id          NUMBER(9),
  operand_1            VARCHAR2(1024),
  operand_2            VARCHAR2(1024),
  min_trust_level_no   NUMBER(3) not null,
  validate_expr_owner  VARCHAR2(30),
  validate_expr_object VARCHAR2(30),
  status_id            NUMBER(1) not null,
  date_upd             DATE,
  user_upd             VARCHAR2(30),
  date_created         DATE default SYSDATE not null,
  user_created         VARCHAR2(30) default USER not null
)
;
comment on column RTP_DML_POL_COND.cond_eval
  is '1 Operand, 2 Trust Level, 3 Validate_Expr';
comment on column RTP_DML_POL_COND.status_id
  is '0 Inactive, 1 Active';
create index RTP_DML_POL_COND_FACTOR_IDX on RTP_DML_POL_COND (FACTOR_ID);
create index RTP_DML_POL_COND_OPR_CODE_IDX on RTP_DML_POL_COND (OPR_CODE_ID);
create index RTP_DML_POL_COND_RULE_IDX on RTP_DML_POL_COND (RULE_ID);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_PK primary key (COND_ID);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_FACTOR_FK foreign key (FACTOR_ID)
  references SYS_FACTOR (FACTOR_ID);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_MIN_TR_LV_FK foreign key (MIN_TRUST_LEVEL_NO)
  references SYS_FACTOR_TRUST_LEVEL (TRUST_LEVEL_NO);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_OPR_CODE_FK foreign key (OPR_CODE_ID)
  references SYS_OPERATION_CODE (CODE_ID);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_RULE_FK foreign key (RULE_ID)
  references RTP_DML_POL_RULE (RULE_ID);
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_COND_EVAL_CHK
  check (COND_EVAL in (1,2,3));
alter table RTP_DML_POL_COND
  add constraint RTP_DML_POL_COND_STATUS_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DML_POL_COND_LIST
prompt ====================================
prompt
create table RTP_DML_POL_COND_LIST
(
  list_id      NUMBER(9) not null,
  cond_id      NUMBER(9) not null,
  operand_1    VARCHAR2(1024) not null,
  status_id    NUMBER(1) not null,
  date_upd     DATE,
  user_upd     VARCHAR2(30),
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DML_POL_COND_LIST.status_id
  is '0 Inactive, 1 Active';
create index RTP_DML_POL_COND_LIST_OPR1_IDX on RTP_DML_POL_COND_LIST (OPERAND_1);
alter table RTP_DML_POL_COND_LIST
  add constraint RTP_DML_POL_COND_LIST_PK primary key (LIST_ID);
alter table RTP_DML_POL_COND_LIST
  add constraint RTP_DML_POL_COND_LIST_UN unique (COND_ID, OPERAND_1);
alter table RTP_DML_POL_COND_LIST
  add constraint RTP_DML_POL_COND_LIST_COND_FK foreign key (COND_ID)
  references RTP_DML_POL_COND (COND_ID);
alter table RTP_DML_POL_COND_LIST
  add constraint RTP_DML_POL_COND_LIST_STAT_CHK
  check (STATUS_ID in (0,1));

prompt
prompt Creating table RTP_DML_POL_USER
prompt ===============================
prompt
create table RTP_DML_POL_USER
(
  policy_id    NUMBER(9) not null,
  user_id      VARCHAR2(30) not null,
  user_apply   NUMBER(1) not null,
  date_created DATE default SYSDATE not null,
  user_created VARCHAR2(30) default USER not null
)
;
comment on column RTP_DML_POL_USER.user_apply
  is '1 Users Apply, 2 Users Exclude';
alter table RTP_DML_POL_USER
  add constraint RTP_DML_POL_USER_PK unique (POLICY_ID, USER_ID, USER_APPLY);
alter table RTP_DML_POL_USER
  add constraint RTP_DML_POL_USER_POLICY_FK foreign key (POLICY_ID)
  references RTP_DML_POL (POLICY_ID);
alter table RTP_DML_POL_USER
  add constraint RTP_DML_POL_USER_APPLY_CH
  check (USER_APPLY in (1,2));

prompt
prompt Creating table SYS_ERROR_LOG
prompt ============================
prompt
create table SYS_ERROR_LOG
(
  username      VARCHAR2(30) default USER not null,
  userhost      VARCHAR2(200),
  ip_address    VARCHAR2(30),
  os_user       VARCHAR2(200),
  bg_job_id     VARCHAR2(20),
  error_data    VARCHAR2(3000),
  timestamp_sts TIMESTAMP(6) not null
)
;
create index SYS_ERROR_LOG_TMST_STS_IDX on SYS_ERROR_LOG (TIMESTAMP_STS);

prompt
prompt Creating table SYS_FACTOR_IDENTITY
prompt ==================================
prompt
create table SYS_FACTOR_IDENTITY
(
  identity_id    NUMBER(9) not null,
  factor_id      NUMBER(9) not null,
  factor_value   VARCHAR2(1024) not null,
  trust_level_no NUMBER(3) not null,
  date_upd       DATE,
  user_upd       VARCHAR2(30),
  date_created   DATE default SYSDATE not null,
  user_created   VARCHAR2(30) default USER not null
)
;
alter table SYS_FACTOR_IDENTITY
  add constraint SYS_FACTOR_IDENTITY_PK primary key (IDENTITY_ID);
alter table SYS_FACTOR_IDENTITY
  add constraint SYS_FACTOR_IDENTITY_UN unique (FACTOR_ID, FACTOR_VALUE);
alter table SYS_FACTOR_IDENTITY
  add constraint SYS_FACTOR_IDENTITY_FACTOR_FK foreign key (FACTOR_ID)
  references SYS_FACTOR (FACTOR_ID);
alter table SYS_FACTOR_IDENTITY
  add constraint SYS_FACTOR_IDENTITY_TRS_LVL_FK foreign key (TRUST_LEVEL_NO)
  references SYS_FACTOR_TRUST_LEVEL (TRUST_LEVEL_NO);
alter table SYS_FACTOR_IDENTITY
  add constraint SYS_FACTOR_IDENTITY_TR_LVL_CHK
  check (TRUST_LEVEL_NO in (-1, 0, 1, 2, 3));

prompt
prompt Creating table SYS_POL_TYPE
prompt ===========================
prompt
create table SYS_POL_TYPE
(
  policy_type_id   NUMBER(9) not null,
  policy_type_code VARCHAR2(10) not null,
  policy_type_name VARCHAR2(30) not null,
  date_created     DATE default SYSDATE not null,
  user_created     VARCHAR2(30) default USER not null
)
;
alter table SYS_POL_TYPE
  add constraint SYS_POL_TYPE_PK primary key (POLICY_TYPE_ID);
alter table SYS_POL_TYPE
  add constraint SYS_POL_TYPE_UN unique (POLICY_TYPE_CODE);
alter table SYS_POL_TYPE
  add constraint SYS_POL_TYPE_UN_NAME unique (POLICY_TYPE_NAME);

prompt
prompt Creating table SYS_FACTOR_POL_TYPE
prompt ==================================
prompt
create table SYS_FACTOR_POL_TYPE
(
  factor_policy_type_id NUMBER(9) not null,
  factor_id             NUMBER(9) not null,
  policy_type_id        NUMBER(9) not null,
  retrieval_expr        VARCHAR2(1024) not null,
  validate_expr         VARCHAR2(1024),
  date_upd              DATE,
  user_upd              VARCHAR2(30),
  date_created          DATE default SYSDATE not null,
  user_created          VARCHAR2(30) default USER not null
)
;
alter table SYS_FACTOR_POL_TYPE
  add constraint SYS_FACTOR_POLICY_TYPE_PK primary key (FACTOR_POLICY_TYPE_ID);
alter table SYS_FACTOR_POL_TYPE
  add constraint SYS_FACTOR_POLICY_TYPE_UN unique (FACTOR_ID, POLICY_TYPE_ID);
alter table SYS_FACTOR_POL_TYPE
  add constraint SYS_FACTOR_POLICY_TYPE_FCT_FK foreign key (FACTOR_ID)
  references SYS_FACTOR (FACTOR_ID);
alter table SYS_FACTOR_POL_TYPE
  add constraint SYS_FACTOR_POLICY_TYPE_P_T_FK foreign key (POLICY_TYPE_ID)
  references SYS_POL_TYPE (POLICY_TYPE_ID);

prompt
prompt Creating table SYS_PARAM
prompt ========================
prompt
create table SYS_PARAM
(
  parameter_id   NUMBER(9) not null,
  parameter_name VARCHAR2(30) not null,
  parameter_desc VARCHAR2(250) not null,
  param_value    VARCHAR2(100) not null,
  param_type     NUMBER(2) not null,
  date_upd       DATE,
  user_upd       VARCHAR2(30),
  date_created   DATE default SYSDATE not null,
  user_created   VARCHAR2(30) default USER not null
)
;
comment on column SYS_PARAM.param_type
  is '1 String, 2 Integer, 3 Number, 4 Date, 5 Boolean (0,1)';
alter table SYS_PARAM
  add constraint SYS_PARAM_PK primary key (PARAMETER_ID);
alter table SYS_PARAM
  add constraint SYS_PARAM_UN unique (PARAMETER_NAME);
alter table SYS_PARAM
  add constraint SYS_PARAM_TYPE_CHCK
  check (PARAM_TYPE in (1,2,3,4,5));

prompt
prompt Creating table SYS_POL_DEBUG
prompt ============================
prompt
create table SYS_POL_DEBUG
(
  policy_type_id NUMBER(9) not null,
  policy_id      NUMBER(9) not null,
  policy_name    VARCHAR2(200) not null,
  rule_id        NUMBER(9),
  rule_name      VARCHAR2(200),
  cond_id        NUMBER(9),
  cond_code      VARCHAR2(200),
  eval_result    VARCHAR2(5) not null,
  debug_log      VARCHAR2(4000) not null,
  username       VARCHAR2(30),
  timestamp_sts  TIMESTAMP(6) not null
)
;
create index SYS_POL_DEBUG_TMST_STS_IDX on SYS_POL_DEBUG (TIMESTAMP_STS);
alter table SYS_POL_DEBUG
  add constraint SYS_POL_DEBUG_POL_TYPE_FK foreign key (POLICY_TYPE_ID)
  references SYS_POL_TYPE (POLICY_TYPE_ID);
alter table SYS_POL_DEBUG
  add constraint SYS_POLICY_DEBUG_EVAL_RES_CH
  check (EVAL_RESULT in ('TRUE','FALSE','UNSET'));

prompt
prompt Creating table SYS_SYSTEM_PRIVILEGE_MAP
prompt =======================================
prompt
create table SYS_SYSTEM_PRIVILEGE_MAP
(
  privilege NUMBER not null,
  name      VARCHAR2(100) not null,
  property  NUMBER not null
)
;
alter table SYS_SYSTEM_PRIVILEGE_MAP
  add constraint SYS_SYSTEM_PRIVILEGE_MAP_PK primary key (PRIVILEGE);
alter table SYS_SYSTEM_PRIVILEGE_MAP
  add constraint SYS_SYSTEM_PRIVILEGE_MAP_UN unique (NAME);

prompt
prompt Creating table SYS_UNF_TRAIL
prompt ============================
prompt
create table SYS_UNF_TRAIL
(
  timestamp_sts         TIMESTAMP(6) not null,
  timestamp_utc         TIMESTAMP(6) not null,
  policy_type_id        NUMBER(9) not null,
  username              VARCHAR2(100),
  sessionid             NUMBER,
  os_user               VARCHAR2(255),
  userhost              VARCHAR2(200),
  action_id             NUMBER,
  action_name           VARCHAR2(200),
  object_owner          VARCHAR2(100),
  object_name           VARCHAR2(100),
  object_type           VARCHAR2(100),
  privilege_id          NUMBER,
  system_privilege      VARCHAR2(200),
  new_owner             VARCHAR2(100),
  new_name              VARCHAR2(100),
  auth_privileges       VARCHAR2(100),
  obj_privilege         VARCHAR2(100),
  logoff_dead           NUMBER,
  sys_privilege         VARCHAR2(100),
  admin_option          VARCHAR2(100),
  grantee               VARCHAR2(100),
  audit_option          VARCHAR2(200),
  ses_actions           VARCHAR2(100),
  logoff_time           DATE,
  logoff_lread          NUMBER,
  logoff_pread          NUMBER,
  logoff_lwrite         NUMBER,
  logoff_dlock          VARCHAR2(100),
  client_id             VARCHAR2(100),
  terminal              VARCHAR2(255),
  ip_address            VARCHAR2(100),
  network_protocol      VARCHAR2(100),
  dbid                  NUMBER,
  db_name               VARCHAR2(100),
  instance_number       NUMBER,
  statementid           NUMBER,
  entryid               NUMBER,
  transactionid         RAW(8),
  scn                   NUMBER,
  proxy_sessionid       NUMBER,
  global_uid            VARCHAR2(100),
  econtext_id           VARCHAR2(100),
  comment_text          VARCHAR2(4000),
  os_process            VARCHAR2(100),
  sessioncpu            NUMBER,
  authentication_method VARCHAR2(100),
  identification_type   VARCHAR2(100),
  isdba                 VARCHAR2(50),
  module                VARCHAR2(200),
  bg_job_id             VARCHAR2(20),
  fg_job_id             VARCHAR2(20),
  returncode            NUMBER,
  return_message        VARCHAR2(2000),
  sql_bind              CLOB,
  sql_text              CLOB,
  ddl_body              CLOB,
  fga_policy_name       VARCHAR2(100),
  ext_name              VARCHAR2(200),
  obj_edition           VARCHAR2(100),
  issue_id              NUMBER(20) not null,
  trail_eval            VARCHAR2(2000)
)
;
create index SYS_UNF_TRAIL_TMST_STS_IDX on SYS_UNF_TRAIL (TIMESTAMP_STS);

prompt
prompt Creating table SYS_VERSION
prompt ==========================
prompt
create table SYS_VERSION
(
  version_id    NUMBER(9) not null,
  major_version NUMBER(2) not null,
  mntn_release  NUMBER(2) not null,
  patch_no      NUMBER(4) not null,
  script_name   VARCHAR2(200) not null,
  date_applied  DATE default SYSDATE not null,
  user_applied  VARCHAR2(30) default USER not null
)
;
alter table SYS_VERSION
  add constraint SYS_VERSION_PK primary key (VERSION_ID);
alter table SYS_VERSION
  add constraint SYS_VERSION_UN unique (MAJOR_VERSION, MNTN_RELEASE, PATCH_NO);
alter table SYS_VERSION
  add constraint SYS_VERSION_UN_SCRIPT unique (SCRIPT_NAME);


prompt
prompt Creating sequence SEQ_ACC_POL
prompt ======================================
prompt
create sequence SEQ_ACC_POL start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ACC_POL_COND
prompt ======================================
prompt
create sequence SEQ_ACC_POL_COND start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ACC_POL_COND_LIST
prompt ======================================
prompt
create sequence SEQ_ACC_POL_COND_LIST start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ACC_POL_RULE
prompt ======================================
prompt
create sequence SEQ_ACC_POL_RULE start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_AUD_POL
prompt ======================================
prompt
create sequence SEQ_AUD_POL start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_AUD_POL_OBJ
prompt ======================================
prompt
create sequence SEQ_AUD_POL_OBJ start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_AUD_POL_STMT
prompt ======================================
prompt
create sequence SEQ_AUD_POL_STMT start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ITS_CLASS
prompt ======================================
prompt
create sequence SEQ_ITS_CLASS start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ITS_GROUP
prompt ======================================
prompt
create sequence SEQ_ITS_GROUP start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_ITS_ISSUE
prompt ======================================
prompt
create sequence SEQ_ITS_ISSUE start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RPT_REP
prompt ======================================
prompt
create sequence SEQ_RPT_REP start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RPT_REP_COL
prompt ======================================
prompt
create sequence SEQ_RPT_REP_COL start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RPT_REP_PRM
prompt ======================================
prompt
create sequence SEQ_RPT_REP_PRM start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RPT_REP_PRV
prompt ======================================
prompt
create sequence SEQ_RPT_REP_PRV start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DDL_POL
prompt ======================================
prompt
create sequence SEQ_RTP_DDL_POL start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DDL_POL_COND
prompt ======================================
prompt
create sequence SEQ_RTP_DDL_POL_COND start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DDL_POL_COND_LIST
prompt ======================================
prompt
create sequence SEQ_RTP_DDL_POL_COND_LIST start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DDL_POL_RULE
prompt ======================================
prompt
create sequence SEQ_RTP_DDL_POL_RULE start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DML_POL
prompt ======================================
prompt
create sequence SEQ_RTP_DML_POL start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DML_POL_COND
prompt ======================================
prompt
create sequence SEQ_RTP_DML_POL_COND start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DML_POL_COND_LIST
prompt ======================================
prompt
create sequence SEQ_RTP_DML_POL_COND_LIST start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_RTP_DML_POL_RULE
prompt ======================================
prompt
create sequence SEQ_RTP_DML_POL_RULE start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_SYS_FACTOR_IDENTITY
prompt ======================================
prompt
create sequence SEQ_SYS_FACTOR_IDENTITY start with 1 increment by 1 nocache;
prompt
prompt Creating sequence SEQ_SYS_VERSION
prompt ======================================
prompt
create sequence SEQ_SYS_VERSION start with 1 increment by 1 nocache;

prompt
prompt Creating view V_ACC_POL
prompt =======================
prompt
create or replace force view v_acc_pol as
select

  a.policy_id,
  a.policy_name, a.policy_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.audit_option,
  decode(a.audit_option, 0, 'Disabled', 1, 'On Failure', 2, 'On Success/Failure') as Audit_Option_Code,

  a.user_apply,
  decode(a.user_apply, 0, 'All Users', 1, 'Users Apply', 2, 'Users Exclude') as User_Apply_Code,

  a.rule_eval,
  decode(a.rule_eval, 1, 'Any True', 2, 'All True', 3, 'Formula') as Rule_Eval_Code,

  a.use_cache,
  decode(a.use_cache, 0, 'NO', 1, 'YES') as Use_Cache_Code,

  a.debug_log,
  decode(a.debug_log, 0, 'NO', 1, 'YES') as Debug_Log_Code,

  a.formula,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ACC_POL a;

prompt
prompt Creating view V_ACC_POL_CACHE
prompt =============================
prompt
create or replace force view v_acc_pol_cache as
select

  a.policy_id,

  a.policy_factor_str, b.policy_name, b.policy_desc,

  a.policy_result,

  a.date_created, a.user_created

  from ACC_POL_CACHE a, acc_pol b

  where a.policy_id = b.policy_id;

prompt
prompt Creating view V_ACC_POL_COND
prompt ============================
prompt
create or replace force view v_acc_pol_cond as
select

  a.cond_id,

  Lpad(a.cond_id, 7, '0') as Cond_Code,
  -- COND_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.rule_id,

  a.factor_id, b.factor_code, b.factor_name,

  a.cond_eval,
  decode(a.cond_eval, 1, 'Operand', 2, 'Trust Level', 3, 'Validate Expr.') as Cond_Eval_Code,

  a.opr_code_id,  d.code_symbol as opr_code_symbol,

  a.operand_1, a.operand_2,

  a.min_trust_level_no, c.trust_level_name,

  a.validate_expr_owner, a.validate_expr_object,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ACC_POL_COND a, sys_factor b, sys_factor_trust_level c,
  sys_operation_code d

  where a.factor_id = b.factor_id
  and   a.min_trust_level_no = c.trust_level_no
  and   a.opr_code_id = d.code_id(+) -- opr_code null for Trust_Level and Validate_Expression
;

prompt
prompt Creating view V_ACC_POL_COND_IDS
prompt ================================
prompt
create or replace force view v_acc_pol_cond_ids as
select

  a.cond_id,

  a.rule_id, b.policy_id,
  b.status_id as Rule_Status_Id,

  a.factor_id,

  a.status_id

  from ACC_POL_COND a, acc_pol_rule b

  where a.rule_id = b.rule_id;

prompt
prompt Creating view V_ACC_POL_COND_LIST
prompt =================================
prompt
create or replace force view v_acc_pol_cond_list as
select

  a.list_id,

  a.cond_id,

  a.operand_1,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ACC_POL_COND_LIST a;

prompt
prompt Creating view V_ACC_POL_RULE
prompt ============================
prompt
create or replace force view v_acc_pol_rule as
select

  a.rule_id,

  Lpad(a.rule_id, 7, '0') as Rule_Code,
  -- RULE_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.policy_id, b.policy_name, b.audit_option,

  a.rule_name, a.rule_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.cond_eval,
  decode(a.cond_eval, 1, 'Any True', 2, 'All True', 3, 'Formula') as Cond_Eval_Code,

  a.formula,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ACC_POL_RULE a, acc_pol b

  where a.policy_id = b.policy_id
;

prompt
prompt Creating view V_ACC_POL_USER
prompt ============================
prompt
create or replace force view v_acc_pol_user as
select

  a.policy_id, a.user_id,

  a.user_apply,
  Decode(
  a.user_apply,
  1, 'Users Apply',
  2, 'Users Exclude'
  ) as User_Apply_Code,

  a.date_created, a.user_created

  from ACC_POL_USER a;

prompt
prompt Creating view V_ACM_GRANTEE
prompt ===========================
prompt
create or replace force view v_acm_grantee as
select

  'PUBLIC' as Grantee, 'Public' as Grantee_Type
  from sys.dual

  union all

  select

  a.username as Grantee, 'User' as Grantee_Type

  from sys.dba_users a

  union all

  select

  b.role as Grantee, 'Role' as Grantee_Type

  from sys.dba_roles b;

prompt
prompt Creating view V_ACM_PRIV_OBJ
prompt ============================
prompt
create or replace force view v_acm_priv_obj as
select

  a.grantee, b.Grantee_Type,

  a.owner, a.table_name,

  a.grantor, a.privilege, a.grantable, a.hierarchy

    from sys.dba_tab_privs a, v_acm_grantee b

    where a.grantee = b.Grantee;

prompt
prompt Creating view V_ACM_PRIV_SYS
prompt ============================
prompt
create or replace force view v_acm_priv_sys as
select

  a.grantee, b.Grantee_Type,

  a.privilege, a.admin_option

  from sys.dba_sys_privs a, v_acm_grantee b

  where a.grantee = b.Grantee;

prompt
prompt Creating view V_ACM_ROLE
prompt ========================
prompt
create or replace force view v_acm_role as
select

  a.role, a.password_required
  -- a.authentication_type

  from sys.DBA_ROLES a
;

prompt
prompt Creating view V_ACM_SYS_DBA_PROFILES
prompt ====================================
prompt
create or replace force view v_acm_sys_dba_profiles as
select

  a.profile, a.resource_name, a.resource_type, a.limit

  from sys.dba_profiles a;

prompt
prompt Creating view V_ACM_SYS_DBA_ROLE_PRIVS
prompt ======================================
prompt
create or replace force view v_acm_sys_dba_role_privs as
select

   a.grantee, a.granted_role, a.admin_option, a.default_role

    from sys.DBA_ROLE_PRIVS  a;

prompt
prompt Creating view V_ACM_SYS_DBA_TS_QUOTAS
prompt =====================================
prompt
create or replace force view v_acm_sys_dba_ts_quotas as
select

  a.username,

  a.tablespace_name,

  a.bytes, a.max_bytes,

  a.blocks, a.max_blocks

  from sys.DBA_TS_QUOTAS a;

prompt
prompt Creating view V_ACM_SYS_PROFNAME
prompt ================================
prompt
create or replace force view v_acm_sys_profname as
select

-- No Sys DBA VIEW, Direct Access to table

  a.PROFILE#, a.NAME

  from sys.profname$ a
;

prompt
prompt Creating view V_ACM_SYS_TABLE_PRIVILEGE
prompt =======================================
prompt
create or replace force view v_acm_sys_table_privilege as
select

  a.object_type, a.priv_name

  from ACM_SYS_TABLE_PRIVILEGE a;

prompt
prompt Creating view V_ACM_SYS_TABLE_PRIVILEGE_MAP
prompt ===========================================
prompt
create or replace force view v_acm_sys_table_privilege_map as
select

  a.privilege, a.name

  from ACM_SYS_TABLE_PRIVILEGE_MAP a;

prompt
prompt Creating view V_ACM_SYS_TABLE_PRIV_OBJ_TYPE
prompt ===========================================
prompt
create or replace force view v_acm_sys_table_priv_obj_type as
select

  distinct a.object_type

  from ACM_SYS_TABLE_PRIVILEGE a;

prompt
prompt Creating view V_ACM_USER
prompt ========================
prompt
create or replace force view v_acm_user as
select

  a.username,

  a.user_id,

  a.account_status, a.lock_date, a.expiry_date,

  decode(a.password,
         'EXTERNAL', 'EXTERNAL',
         'anonymous', 'ANONYMOUS',
         'GLOBAL', 'GLOBAL',
         'PASSWORD') as Pass_Mode,

  a.default_tablespace, a.temporary_tablespace,

  a.created, a.profile, a.initial_rsrc_consumer_group, a.external_name

  from sys.dba_users a;

prompt
prompt Creating view V_AUD_DBA_OBJ_AUDIT_OPTS
prompt ======================================
prompt
create or replace force view v_aud_dba_obj_audit_opts as
select

  a.owner, a.object_name, a.object_type,

  a.alt, a.aud, a.com, a.del, a.gra, a.ind, a.ins, a.loc,

  a.ren, a.sel, a.upd,
  -- a.ref,  backward compatibility only !
  a.exe, a.cre, a.rea, a.wri, a.fbk

    from sys.DBA_OBJ_AUDIT_OPTS a
;

prompt
prompt Creating type TY_SYS_AUD_OBJ
prompt ============================
prompt
CREATE OR REPLACE TYPE "TY_SYS_AUD_OBJ"                                                                          AS OBJECT
-- Datatypes must be the same as those of sys.dba_obj_audit_opts
       (
       OWNER           VARCHAR2(30),
       OBJECT_NAME     VARCHAR2(30),
       OBJECT_TYPE     VARCHAR2(23),
       AUDIT_OPTION    VARCHAR2(100),
       AUDIT_OPT       VARCHAR2(3),
       SUCCESS         VARCHAR2(20),
       FAILURE         VARCHAR2(20)
       )
/

prompt
prompt Creating type TY_SYS_AUD_OBJ_TAB
prompt ================================
prompt
CREATE OR REPLACE TYPE "TY_SYS_AUD_OBJ_TAB" AS TABLE OF TY_SYS_AUD_OBJ
/

prompt
prompt Creating function F_AUD_SYS_OBJECT
prompt ==================================
prompt
CREATE OR REPLACE FUNCTION F_AUD_SYS_OBJECT

         RETURN TY_SYS_AUD_OBJ_TAB PIPELINED IS

out_rec   TY_SYS_AUD_OBJ
          := TY_SYS_AUD_OBJ(NULL,NULL,NULL,NULL,NULL,NULL,NULL);

cursor C1 is SELECT * from sys.dba_obj_audit_opts;

BEGIN

for rec in C1   LOOP

    -- Begin Make ALTER
    if rec.ALT <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'ALTER';
    out_rec.AUDIT_OPT       := rec.ALT;

    Case Substr(rec.ALT,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.ALT,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make ALTER

    -- Begin Make AUDIT
    if rec.AUD <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'AUDIT';
    out_rec.AUDIT_OPT       := rec.AUD;

    Case Substr(rec.AUD,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.AUD,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make AUDIT

    -- Begin Make COMMENT
    if rec.COM <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'COMMENT';
    out_rec.AUDIT_OPT       := rec.COM;

    Case Substr(rec.COM,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.COM,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make COMMENT

    -- Begin Make DELETE
    if rec.DEL <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'DELETE';
    out_rec.AUDIT_OPT       := rec.DEL;

    Case Substr(rec.DEL,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.DEL,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make DELETE

    -- Begin Make GRANT
    if rec.GRA <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'GRANT';
    out_rec.AUDIT_OPT       := rec.GRA;

    Case Substr(rec.GRA,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.GRA,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make GRANT

    -- Begin Make INDEX
    if rec.IND <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'INDEX';
    out_rec.AUDIT_OPT       := rec.IND;

    Case Substr(rec.IND,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.IND,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make INDEX

    -- Begin Make INSERT
    if rec.INS <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'INSERT';
    out_rec.AUDIT_OPT       := rec.INS;

    Case Substr(rec.INS,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.INS,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make INSERT

    -- Begin Make LOCK
    if rec.LOC <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'LOCK';
    out_rec.AUDIT_OPT       := rec.LOC;

    Case Substr(rec.LOC,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.LOC,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make LOCK

    -- Begin Make RENAME
    if rec.REN <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'RENAME';
    out_rec.AUDIT_OPT       := rec.REN;

    Case Substr(rec.REN,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.REN,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make RENAME

    -- Begin Make SELECT
    if rec.SEL <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'SELECT';
    out_rec.AUDIT_OPT       := rec.SEL;

    Case Substr(rec.SEL,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.SEL,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make SELECT

    -- Begin Make UPDATE
    if rec.UPD <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'UPDATE';
    out_rec.AUDIT_OPT       := rec.UPD;

    Case Substr(rec.UPD,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.UPD,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make UPDATE

    -- a.ref,  backward compatibility only !

    -- Begin Make EXECUTE
    if rec.EXE <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'EXECUTE';
    out_rec.AUDIT_OPT       := rec.EXE;

    Case Substr(rec.EXE,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.EXE,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make EXECUTE

    -- Begin Make CREATE
    if rec.CRE <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'CREATE';
    out_rec.AUDIT_OPT       := rec.CRE;

    Case Substr(rec.CRE,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.CRE,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make CREATE

    -- Begin Make READ
    if rec.REA <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'READ';
    out_rec.AUDIT_OPT       := rec.REA;

    Case Substr(rec.REA,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.REA,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make READ

    -- Begin Make WRITE
    if rec.WRI <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'WRITE';
    out_rec.AUDIT_OPT       := rec.WRI;

    Case Substr(rec.WRI,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.WRI,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make WRITE

    -- Begin Make FLASHBACK
    if rec.FBK <> '-/-' then
    out_rec.OWNER           := rec.owner;
    out_rec.OBJECT_NAME     := rec.object_name;
    out_rec.OBJECT_TYPE     := rec.object_type;
    out_rec.AUDIT_OPTION    := 'FLASHBACK';
    out_rec.AUDIT_OPT       := rec.FBK;

    Case Substr(rec.FBK,1,1)
    WHEN '-' THEN out_rec.SUCCESS := 'NOT SET';
    WHEN 'A' THEN out_rec.SUCCESS := 'BY ACCESS';
    WHEN 'S' THEN out_rec.SUCCESS := 'BY SESSION';
    Else
    out_rec.SUCCESS := 'ERROR';
    end case;

    Case Substr(rec.FBK,3,1)
    WHEN '-' THEN out_rec.FAILURE := 'NOT SET';
    WHEN 'A' THEN out_rec.FAILURE := 'BY ACCESS';
    WHEN 'S' THEN out_rec.FAILURE := 'BY SESSION';
    Else
    out_rec.FAILURE := 'ERROR';
    end case;

    PIPE ROW(out_rec);  -- output out_rec row
    end if;
    -- End Make FLASHBACK

  END LOOP;

RETURN; -- give cursor output

END ;
/

prompt
prompt Creating view V_AUD_DBA_OBJ_AUDIT_OPTS_TAB
prompt ==========================================
prompt
create or replace force view v_aud_dba_obj_audit_opts_tab as
select

owner, object_name, object_type,

audit_option, audit_opt,

success, failure

from TABLE(F_AUD_SYS_OBJECT);

prompt
prompt Creating view V_AUD_POL
prompt =======================
prompt
create or replace force view v_aud_pol as
select

  a.policy_id,
  a.policy_name, a.policy_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.type_id,
  decode(a.type_id, 1, 'Object', 2, 'Statement [Priv.]') as Type_Code,

  a.use_cache,
  decode(a.use_cache, 0, 'NO', 1, 'YES') as Use_Cache_Code,

  a.debug_log,
  decode(a.debug_log, 0, 'NO', 1, 'YES') as Debug_Log_Code,

  a.date_created, a.user_created,
  a.date_upd, a.user_upd

  from AUD_POL a;

prompt
prompt Creating view V_AUD_POL_CACHE
prompt =============================
prompt
create or replace force view v_aud_pol_cache as
select

  a.policy_id,

  a.policy_factor_str, b.policy_name, b.policy_desc,

  a.policy_result,

  a.date_created, a.user_created

  from AUD_POL_CACHE a, aud_pol b

  where a.policy_id = b.policy_id;

prompt
prompt Creating view V_AUD_POL_OBJ
prompt ===========================
prompt
create or replace force view v_aud_pol_obj as
select

  a.aud_obj_id,
  Lpad(a.aud_obj_id, 7, '0') as Aud_Obj_Code,
  -- RULE_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.policy_id, b.policy_name,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.sql_operation,

  a.object_type, a.object_owner, a.object_name,

  a.success_failure,
  decode(a.success_failure,
         1, 'Success/Failure',
         2, 'Success',
         3, 'Failure'
         ) as Success_Failure_Code,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from AUD_POL_OBJ a, aud_pol b

  where a.policy_id = b.policy_id
;

prompt
prompt Creating view V_AUD_POL_STMT
prompt ============================
prompt
create or replace force view v_aud_pol_stmt as
select

  a.aud_stmt_id,
  Lpad(a.aud_stmt_id, 7, '0') as Aud_Stmt_Code,
  -- RULE_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.policy_id, b.policy_name,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.audit_option,

  a.audit_by_user,

  a.success_failure,
  decode(a.success_failure,
         1, 'Success/Failure',
         2, 'Success',
         3, 'Failure'
         ) as Success_Failure_Code,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from AUD_POL_STMT a, aud_pol b

  where a.policy_id = b.policy_id
;

prompt
prompt Creating view V_AUD_SYS_ACTION
prompt ==============================
prompt
create or replace force view v_aud_sys_action as
select

  a.action_id,

  a.action_name,

  a.stmt_name,
  a.obj_type


    from AUD_SYS_ACTION a;

prompt
prompt Creating view V_AUD_SYS_DBA_STMT_AUDIT_OPTS
prompt ===========================================
prompt
create or replace force view v_aud_sys_dba_stmt_audit_opts as
select
-- plus system_privilege_map
 a.user_name, a.proxy_name, a.audit_option, a.success, a.failure,

 Case -- AUDIT SYSTEM system_privilege_map - only diff
 when a.audit_option = 'SYSTEM AUDIT' then 1
 else
      Case
      when b.name is null then 0
      else 1 -- found system_privilege_map
      End
 End as Is_System_Privilege


 from sys.DBA_STMT_AUDIT_OPTS a, sys.SYSTEM_PRIVILEGE_MAP b

where a.audit_option = b.name(+)
;

prompt
prompt Creating view V_AUD_SYS_OBJ_OPT
prompt ===============================
prompt
create or replace force view v_aud_sys_obj_opt as
select

  a.obj_type, a.audit_option

  from AUD_SYS_OBJ_OPT a;

prompt
prompt Creating view V_AUD_SYS_OBJ_OPT_ACT
prompt ===================================
prompt
create or replace force view v_aud_sys_obj_opt_act as
select

  a.obj_type, a.audit_option,

  a.stmt_name, c.stmt_type,

  a.action_id, b.action_name,
  a.act_enabled,
  b.stmt_name as act_stmt_name,
  b.obj_type  as act_obj_type

  from AUD_SYS_OBJ_OPT_ACT a, aud_sys_action b, sys_stmt c

  where a.action_id = b.action_id
  and   a.stmt_name = c.stmt_name;

prompt
prompt Creating view V_AUD_SYS_OBJ_OPT_OBJ_TYPE
prompt ========================================
prompt
create or replace force view v_aud_sys_obj_opt_obj_type as
select

  distinct a.obj_type

  from AUD_SYS_OBJ_OPT a;

prompt
prompt Creating view V_AUD_SYS_STMT_AUDIT_OPTS_MAP
prompt ===========================================
prompt
create or replace force view v_aud_sys_stmt_audit_opts_map as
select
 -- Mixes OMEGACA-s declared SYS.STMT_AUDIT_OPTION_MAP and SYS.SYSTEM_PRIVILEGE_MAP

 a.option# as Audit_Option_Id,
 a.name as Audit_Option_Name,
 --a.property
 Case
 when b.privilege is null then 0
 else 1
 End as Is_System_Privilege

 from SYS.STMT_AUDIT_OPTION_MAP a, SYS.SYSTEM_PRIVILEGE_MAP b

where a.option# = b.privilege(+)
;

prompt
prompt Creating view V_AUD_SYS_STMT_OPT
prompt ================================
prompt
create or replace force view v_aud_sys_stmt_opt as
select

  a.option_id,

  a.option_name,

  a.property,

  a.is_shortcut, a.is_sys_priv

  from AUD_SYS_STMT_OPT a;

prompt
prompt Creating view V_AUD_SYS_STMT_OPT_ACT
prompt ====================================
prompt
create or replace force view v_aud_sys_stmt_opt_act as
select

  a.option_id,

  b.option_name,
  b.property, b.is_shortcut,
  b.is_sys_priv,

  a.stmt_name, a.obj_type,

  a.action_id, c.action_name,
  a.act_enabled,
  c.stmt_name as act_stmt_name,
  c.obj_type  as act_obj_type

  from AUD_SYS_STMT_OPT_ACT a, aud_sys_stmt_opt b,  aud_sys_action c

  where a.option_id = b.option_id
  and   a.action_id = c.action_id;

prompt
prompt Creating view V_ITS_CLASS
prompt =========================
prompt
create or replace force view v_its_class as
select

  a.class_id,

  a.class_name, a.class_desc,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ITS_CLASS a;

prompt
prompt Creating view V_ITS_GROUP
prompt =========================
prompt
create or replace force view v_its_group as
select

  a.group_id,

  a.group_name, a.group_desc,

  a.class_id, b.class_name, b.class_desc,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ITS_GROUP a, its_class b

  where a.class_id = b.class_id;

prompt
prompt Creating view V_ITS_ISSUE
prompt =========================
prompt
create or replace force view v_its_issue as
select

  a.issue_id,

  a.issue_name, a.issue_desc,

  a.group_id, b.group_name, b.group_desc,
  b.class_id, b.class_name, b.class_desc,

  a.perpetual,
  decode(a.perpetual, 1, 'X', 0, '') as Perpetual_Status,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from ITS_ISSUE a, v_its_group b

  where a.group_id = b.group_id;

prompt
prompt Creating view V_OMEGACA_ROLE
prompt ============================
prompt
create or replace force view v_omegaca_role as
select

  a.role, a.password_required,

  decode(a.role,
  'OMEGACA_ADMIN',      'Administrator',
  'OMEGACA_ACCTMGR',    'Account Manager',
  'OMEGACA_AUDIT',      'Auditor',
  'OMEGACA_SECANALYST', 'Security Analyst' ) as Role_Desc

  from sys.dba_roles a

  where a.role in ('OMEGACA_ADMIN', 'OMEGACA_ACCTMGR', 'OMEGACA_AUDIT', 'OMEGACA_SECANALYST' );

prompt
prompt Creating view V_OMEGACA_USER_ROLE
prompt =================================
prompt
create or replace force view v_omegaca_user_role as
select

   a.grantee, a.granted_role, b.Role_Desc,

   a.admin_option, a.default_role

   from sys.DBA_ROLE_PRIVS a, v_omegaca_role b

   where a.granted_role = b.role;

prompt
prompt Creating view V_RPT_REP
prompt =======================
prompt
create or replace force view v_rpt_rep as
select

  a.report_id,

  a.profile_id,
  decode(a.profile_id,
  1, 'Access Control',
  2, 'Account Manager',
  3, 'Auditor',
  4, 'Administrator',
  5, 'Others')
  as Profile_Name,

  a.report_name, a.report_desc,

  a.report_base_sql, a.report_component, a.report_link,

  a.rep_native,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from RPT_REP a;

prompt
prompt Creating function F_RPT_REP_MOD_ACCESS
prompt ======================================
prompt
CREATE OR REPLACE FUNCTION F_RPT_REP_MOD_ACCESS(
                           p_report_id in integer,
                           p_priv_id in varchar2
                           )
-- User Report Access By Omega CA Role
RETURN Integer IS  -- 0 - FALSE, 1 - TRUE

cnt_rep_prv        integer;
F_Result           integer;

BEGIN

-- Check Priv ID only 1-R-Read, 2-RW-Read-Write
if p_priv_id not in (1, 2) then
raise_application_error(-20010, 'Report Permission Type not in R - Read, RW - Read-Write !' );
end if;


-- Begin Make Report Access
if p_priv_id = 1 then -- 1-R-Read

select count(*) into cnt_rep_prv
from omegaca.v_omegaca_user_role t
where t.grantee = USER
and exists (
select priv_role from omegaca.rpt_rep_prv a
where report_id = p_report_id
and a.priv_role = t.granted_role
);

else -- 2-RW-Read-Write

select count(*) into cnt_rep_prv
from omegaca.v_omegaca_user_role t
where t.grantee = USER
and exists (
select priv_role from omegaca.rpt_rep_prv a
where report_id = p_report_id
and a.priv_role = t.granted_role
and a.priv_id = 2  -- 2-RW-Read-Write
);

end if;
-- End Make Report Access


-- Make Integer/Boolean Result
if cnt_rep_prv = 0 then
F_Result := 0; -- FALSE
else -- > 0
F_Result := 1; -- TRUE
end if;


-- return result
RETURN F_Result;

END ;
/

prompt
prompt Creating view V_RPT_REP_ACCESS
prompt ==============================
prompt
create or replace force view v_rpt_rep_access as
select

  a.report_id,

  a.profile_id, a.profile_name,

  a.report_name, a.report_desc,

  a.rep_native,
  -- Priv ID 1-R-Read
  F_RPT_REP_MOD_ACCESS(a.report_id, 1) as Report_Access,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from V_RPT_REP a
;

prompt
prompt Creating view V_RPT_REP_COL
prompt ===========================
prompt
create or replace force view v_rpt_rep_col as
select

  a.column_id,
  a.report_id, b.report_name, b.report_desc,
  b.profile_id, b.Profile_Name,
  b.rep_native,

  a.column_name, a.col_data_type, a.column_caption,

  a.search_field, a.search_order, a.search_active,

  a.opr_code_id, c.code_symbol, c.code_value,
  a.operand_1, a.operand_2,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from RPT_REP_COL a, v_rpt_rep b, sys_operation_code c

  where a.report_id = b.report_id
  and a.opr_code_id = c.code_id(+) -- opr_code null
;

prompt
prompt Creating view V_RPT_REP_PRM
prompt ===========================
prompt
create or replace force view v_rpt_rep_prm as
select

  a.param_id,

  a.report_id, b.report_name, b.report_desc,
  b.profile_id, b.Profile_Name,
  b.rep_native,

  a.param_name,
  a.param_data_type, a.param_display_type,

  a.param_caption, a.time_end,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from RPT_REP_PRM a, v_rpt_rep b

  where a.report_id = b.report_id;

prompt
prompt Creating view V_RPT_REP_PRV
prompt ===========================
prompt
create or replace force view v_rpt_rep_prv as
select

  a.rep_priv_id,

  a.report_id, b.report_name, b.report_desc,
  b.profile_id, b.Profile_Name,
  b.rep_native,

  a.priv_role,
  decode(a.priv_role,
  'OMEGACA_ADMIN',      'Administrator',
  'OMEGACA_ACCTMGR',    'Account Manager',
  'OMEGACA_AUDIT',      'Auditor',
  'OMEGACA_SECANALYST', 'Security Analyst' ) as Role_Desc,

  a.priv_id,
  Decode(
  a.priv_id,
  1, 'Read',
  2, 'Read-Write'
  )
  as Privilege_Name,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from RPT_REP_PRV a, v_rpt_rep b

  where a.report_id = b.report_id;

prompt
prompt Creating view V_RTP_DDL_POL
prompt ===========================
prompt
create or replace force view v_rtp_ddl_pol as
select

  a.policy_id,
  a.policy_name, a.policy_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.audit_option,
  decode(a.audit_option, 0, 'Disabled', 1, 'On Failure', 2, 'On Success/Failure') as Audit_Option_Code,

  a.user_apply,
  decode(a.user_apply, 0, 'All Users', 1, 'Users Apply', 2, 'Users Exclude') as User_Apply_Code,

  a.rule_eval,
  decode(a.rule_eval, 1, 'Any True', 2, 'All True', 3, 'Formula') as Rule_Eval_Code,

  a.silent_deny,
  decode(a.silent_deny, 0, 'NO', 1, 'YES') as Silent_Deny_Code,

  a.use_cache,
  decode(a.use_cache, 0, 'NO', 1, 'YES') as Use_Cache_Code,

  a.debug_log,
  decode(a.debug_log, 0, 'NO', 1, 'YES') as Debug_Log_Code,

  a.formula,

  a.log_ddl_body, a.log_cmd,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DDL_POL a;

prompt
prompt Creating view V_RTP_DDL_POL_AREA
prompt ================================
prompt
create or replace force view v_rtp_ddl_pol_area as
select

a.policy_id, b.policy_name, b.policy_desc,

a.area_factor,

Decode(a.area_factor,
       'OBJ_OWNER', 'Object Owner',
       'OBJ_TYPE', 'Object Type',
       'OBJ_NAME', 'Object Name',
       'DDL_EVENT', 'Action',
       a.area_factor
       ) as Area_Factor_Name,

a.opr_code, a.operand,

a.date_upd, a.user_upd,

a.date_created, a.user_created

from RTP_DDL_POL_AREA a, rtp_ddl_pol b

where a.policy_id = b.policy_id;

prompt
prompt Creating view V_RTP_DDL_POL_CACHE
prompt =================================
prompt
create or replace force view v_rtp_ddl_pol_cache as
select

  a.policy_id,

  a.policy_factor_str, b.policy_name, b.policy_desc,

  a.policy_result,

  a.date_created, a.user_created

  from RTP_DDL_POL_CACHE a, rtp_ddl_pol b

  where a.policy_id = b.policy_id;

prompt
prompt Creating view V_RTP_DDL_POL_COND
prompt ================================
prompt
create or replace force view v_rtp_ddl_pol_cond as
select

  a.cond_id,

  Lpad(a.cond_id, 7, '0') as Cond_Code,
  -- COND_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.rule_id,

  a.factor_id, b.factor_code, b.factor_name,

  a.cond_eval,
  decode(a.cond_eval, 1, 'Operand', 2, 'Trust Level', 3, 'Validate Expr.') as Cond_Eval_Code,

  a.opr_code_id, d.code_symbol as opr_code_symbol,

  a.operand_1, a.operand_2,

  a.min_trust_level_no, c.trust_level_name,

  a.validate_expr_owner, a.validate_expr_object,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DDL_POL_COND a, sys_factor b, sys_factor_trust_level c,
  sys_operation_code d

  where a.factor_id = b.factor_id
  and   a.min_trust_level_no = c.trust_level_no
  and   a.opr_code_id = d.code_id(+) -- opr_code null for Trust_Level and Validate_Expression
;

prompt
prompt Creating view V_RTP_DDL_POL_COND_IDS
prompt ====================================
prompt
create or replace force view v_rtp_ddl_pol_cond_ids as
select

  a.cond_id,

  a.rule_id, b.policy_id,
  b.status_id as Rule_Status_Id,

  a.factor_id,

  a.status_id

  from RTP_DDL_POL_COND a, rtp_ddl_pol_rule b

  where a.rule_id = b.rule_id;

prompt
prompt Creating view V_RTP_DDL_POL_COND_LIST
prompt =====================================
prompt
create or replace force view v_rtp_ddl_pol_cond_list as
select

  a.list_id,

  a.cond_id,

  a.operand_1,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DDL_POL_COND_LIST a;

prompt
prompt Creating view V_RTP_DDL_POL_RULE
prompt ================================
prompt
create or replace force view v_rtp_ddl_pol_rule as
select

  a.rule_id,

  Lpad(a.rule_id, 7, '0') as Rule_Code,
  -- RULE_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.policy_id, b.policy_name, b.audit_option,

  a.rule_name, a.rule_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.cond_eval,
  decode(a.cond_eval, 1, 'Any True', 2, 'All True', 3, 'Formula') as Cond_Eval_Code,

  a.formula,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DDL_POL_RULE a, rtp_ddl_pol b

  where a.policy_id = b.policy_id
;

prompt
prompt Creating view V_RTP_DDL_POL_USER
prompt ================================
prompt
create or replace force view v_rtp_ddl_pol_user as
select

  a.policy_id, a.user_id,

  a.user_apply,
  Decode(
  a.user_apply,
  1, 'Users Apply',
  2, 'Users Exclude'
  ) as User_Apply_Code,

  a.date_created, a.user_created

  from RTP_DDL_POL_USER a;

prompt
prompt Creating view V_RTP_DML_POL
prompt ===========================
prompt
create or replace force view v_rtp_dml_pol as
select

  a.policy_id,
  a.policy_name, a.policy_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.user_apply,
  decode(a.user_apply, 0, 'All Users', 1, 'Users Apply', 2, 'Users Exclude') as User_Apply_Code,

  a.use_cache,
  decode(a.use_cache, 0, 'NO', 1, 'YES') as Use_Cache_Code,

  a.debug_log,
  decode(a.debug_log, 0, 'NO', 1, 'YES') as Debug_Log_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DML_POL a;

prompt
prompt Creating view V_RTP_DML_POL_CACHE
prompt =================================
prompt
create or replace force view v_rtp_dml_pol_cache as
select

  a.rule_id,

  a.rule_factor_str, b.rule_name, b.rule_desc,

  b.policy_id, c.policy_name, c.policy_desc,
  a.policy_result,

  a.date_created, a.user_created

  from RTP_DML_POL_CACHE a, rtp_dml_pol_rule b, rtp_dml_pol c

  where a.rule_id = b.rule_id
  and   b.policy_id = c.policy_id;

prompt
prompt Creating view V_RTP_DML_POL_COND
prompt ================================
prompt
create or replace force view v_rtp_dml_pol_cond as
select

  a.cond_id,

  Lpad(a.cond_id, 7, '0') as Cond_Code,
  -- COND_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.rule_id,

  a.factor_id, b.factor_code, b.factor_name,

  a.cond_eval,
  decode(a.cond_eval, 1, 'Operand', 2, 'Trust Level', 3, 'Validate Expr.') as Cond_Eval_Code,

  a.opr_code_id, d.code_symbol as opr_code_symbol,

  a.operand_1, a.operand_2,

  a.min_trust_level_no, c.trust_level_name,

  a.validate_expr_owner, a.validate_expr_object,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DML_POL_COND a, sys_factor b, sys_factor_trust_level c,
  sys_operation_code d

  where a.factor_id = b.factor_id
  and   a.min_trust_level_no = c.trust_level_no
  and   a.opr_code_id = d.code_id(+) -- opr_code null for Trust_Level and Validate_Expression
;

prompt
prompt Creating view V_RTP_DML_POL_COND_IDS
prompt ====================================
prompt
create or replace force view v_rtp_dml_pol_cond_ids as
select

  a.cond_id,

  a.rule_id,

  a.factor_id,

  b.policy_id,

  a.status_id

  from RTP_DML_POL_COND a, rtp_dml_pol_rule b

  where a.rule_id = b.rule_id;

prompt
prompt Creating view V_RTP_DML_POL_COND_LIST
prompt =====================================
prompt
create or replace force view v_rtp_dml_pol_cond_list as
select

  a.list_id,

  a.cond_id,

  a.operand_1,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DML_POL_COND_LIST a;

prompt
prompt Creating view V_RTP_DML_POL_RULE
prompt ================================
prompt
create or replace force view v_rtp_dml_pol_rule as
select

  a.rule_id,

  Lpad(a.rule_id, 7, '0') as Rule_Code,
  -- RULE_CODE LENGTH = 7
  -- fix referenced on formula evaluation procedures

  a.policy_id, b.policy_name,

  a.rule_name, a.rule_desc,

  a.status_id,
  decode(a.status_id, 0, 'Inactive', 1, 'Active') as Status_Code,

  a.cond_eval,
  decode(a.cond_eval, 0, 'None', 1, 'Any True', 2, 'All True', 3, 'Formula') as Cond_Eval_Code,

  a.formula,

  a.silent_deny,
  decode(a.silent_deny, 0, 'NO', 1, 'YES') as Silent_Deny_Code,

  -- FGA Options
  a.obj_owner,
  a.obj_name,
  a.fga_policy_name,
  a.audit_condition_type,
  decode(a.audit_condition_type,
         1, 'Rule Condition',
         2, 'Column Condition',
         3, 'No Condition'
         ) as Audit_Condition_Type_Code,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from RTP_DML_POL_RULE a, rtp_dml_pol b

  where a.policy_id = b.policy_id
;

prompt
prompt Creating view V_RTP_DML_SYS_DBA_AUDIT_POL
prompt =========================================
prompt
create or replace force view v_rtp_dml_sys_dba_audit_pol as
select

 a.object_schema, a.object_name,
 --a.policy_owner,
 a.policy_name,

 a.policy_text, a.policy_column,

 a.pf_schema, a.pf_package, a.pf_function,

 a.enabled,

 a.sel, a.ins, a.upd, a.del,

 Decode(a.audit_trail, 'DB+EXTENDED', 'DB_EXTENDED', a.audit_trail) as audit_trail,

 a.policy_column_options

 from SYS.DBA_AUDIT_POLICIES a
;

prompt
prompt Creating view V_RTP_DML_POL_RULE_DBA_AUD_POL
prompt ============================================
prompt
create or replace force view v_rtp_dml_pol_rule_dba_aud_pol as
select

  a.rule_id,

  a.obj_owner, a.obj_name,

  a.fga_policy_name, b.policy_name,
  a.audit_condition_type, a.Audit_Condition_Type_Code,

  b.policy_text, b.policy_column, b.enabled,
  b.sel, b.ins, b.upd, b.del,
  b.audit_trail, b.policy_column_options,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from v_rtp_dml_pol_rule a, v_rtp_dml_sys_dba_audit_pol b

  -- By Tripple Key
  where a.obj_owner = b.object_schema
  and   a.obj_name = b.object_name
  and   a.fga_policy_name = b.policy_name
;

prompt
prompt Creating view V_RTP_DML_POL_USER
prompt ================================
prompt
create or replace force view v_rtp_dml_pol_user as
select

  a.policy_id, a.user_id,

  a.user_apply,
  Decode(
  a.user_apply,
  1, 'Users Apply',
  2, 'Users Exclude'
  ) as User_Apply_Code,

  a.date_created, a.user_created

  from RTP_DML_POL_USER a;

prompt
prompt Creating view V_RTP_DML_SYS_DBA_AUDIT_POL_CL
prompt ============================================
prompt
create or replace force view v_rtp_dml_sys_dba_audit_pol_cl as
select

  a.object_schema, a.object_name,

  a.policy_name, a.policy_column

    from sys.DBA_AUDIT_POLICY_COLUMNS a;

prompt
prompt Creating view V_SYS_DBA_TAB_COLS
prompt ================================
prompt
create or replace force view v_sys_dba_tab_cols as
select

  a.OWNER, a.TABLE_NAME, a.COLUMN_NAME, a.DATA_TYPE, a.DATA_TYPE_MOD,
  a.DATA_TYPE_OWNER, a.DATA_LENGTH, a.DATA_PRECISION, a.DATA_SCALE,
  a.NULLABLE, a.COLUMN_ID, a.DEFAULT_LENGTH,
  --a.DATA_DEFAULT,
  a.NUM_DISTINCT,
  a.LOW_VALUE, a.HIGH_VALUE, a.DENSITY, a.NUM_NULLS, a.NUM_BUCKETS, a.LAST_ANALYZED,
  a.SAMPLE_SIZE, a.CHARACTER_SET_NAME, a.CHAR_COL_DECL_LENGTH, a.GLOBAL_STATS,
  a.USER_STATS, a.AVG_COL_LEN, a.CHAR_LENGTH, a.CHAR_USED, a.V80_FMT_IMAGE,
  a.DATA_UPGRADED, a.HIDDEN_COLUMN, a.VIRTUAL_COLUMN, a.SEGMENT_COLUMN_ID,
  a.INTERNAL_COLUMN_ID, a.HISTOGRAM, a.QUALIFIED_COL_NAME

    from sys.DBA_TAB_COLS a
;

prompt
prompt Creating view V_SYS_ERROR_LOG
prompt =============================
prompt
create or replace force view v_sys_error_log as
select

  a.timestamp_sts, a.username,

  a.userhost, a.ip_address,
  a.os_user, a.bg_job_id,

  a.error_data

  from SYS_ERROR_LOG a;

prompt
prompt Creating view V_SYS_FACTOR
prompt ==========================
prompt
create or replace force view v_sys_factor as
select

  a.factor_id,

  a.factor_code, a.factor_name, a.description,

  a.category_id, b.category_name,

  a.validate_expr,

  a.ret_data_type,

  a.identification_id, a.evaluation_id, a.audit_option_id, a.fail_option_id,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from SYS_FACTOR a, sys_factor_category b

  where a.category_id = b.category_id
  -- Next Vers Bug
  and a.factor_code <> 'AUTHENTICATION_METHOD'
;

prompt
prompt Creating view V_SYS_FACTOR_IDENTITY
prompt ===================================
prompt
create or replace force view v_sys_factor_identity as
select

  a.identity_id,

  a.factor_id, b.factor_code, b.factor_name, b.description,
  a.factor_value,

  a.trust_level_no, c.trust_level_name,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from SYS_FACTOR_IDENTITY a, sys_factor b, sys_factor_trust_level c

  where a.factor_id = b.factor_id
  and   a.trust_level_no = c.trust_level_no;

prompt
prompt Creating view V_SYS_FACTOR_POL_TYPE
prompt ===================================
prompt
create or replace force view v_sys_factor_pol_type as
select

  a.factor_policy_type_id,

  a.factor_id, b.factor_code, b.factor_name, b.category_id,
  b.ret_data_type,

  a.policy_type_id, c.policy_type_code, c.policy_type_name,

  a.retrieval_expr, a.validate_expr,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from SYS_FACTOR_POL_TYPE a, sys_factor b, sys_pol_type c

  where a.factor_id      = b.factor_id
  and   a.policy_type_id = c.policy_type_id;

prompt
prompt Creating view V_SYS_FACTOR_TRUST_LEVEL
prompt ======================================
prompt
create or replace force view v_sys_factor_trust_level as
select

  a.trust_level_no, a.trust_level_name

  from SYS_FACTOR_TRUST_LEVEL a;

prompt
prompt Creating view V_SYS_JOB_CLASSIC
prompt ===============================
prompt
create or replace force view v_sys_job_classic as
select

a.JOB, a.LOG_USER, a.PRIV_USER, a.SCHEMA_USER,

a.LAST_DATE, a.LAST_SEC, a.THIS_DATE, a.THIS_SEC,
a.NEXT_DATE, a.NEXT_SEC,
a.TOTAL_TIME, a.BROKEN, a.interval, a.FAILURES,
a.WHAT, a.NLS_ENV, a.MISC_ENV, a.INSTANCE

from sys.dba_jobs a;

prompt
prompt Creating view V_SYS_JOB_SCHEDULER
prompt =================================
prompt
create or replace force view v_sys_job_scheduler as
select

"OWNER","JOB_NAME","JOB_SUBNAME",--"JOB_STYLE",
"JOB_CREATOR",
"CLIENT_ID","GLOBAL_UID","PROGRAM_OWNER","PROGRAM_NAME",
"JOB_TYPE","JOB_ACTION","NUMBER_OF_ARGUMENTS",
"SCHEDULE_OWNER","SCHEDULE_NAME","SCHEDULE_TYPE", "START_DATE","REPEAT_INTERVAL",
"EVENT_QUEUE_OWNER","EVENT_QUEUE_NAME","EVENT_QUEUE_AGENT","EVENT_CONDITION","EVENT_RULE",
--"FILE_WATCHER_OWNER", "FILE_WATCHER_NAME",
"END_DATE","JOB_CLASS","ENABLED",
"AUTO_DROP","RESTARTABLE","STATE","JOB_PRIORITY",
"RUN_COUNT","MAX_RUNS","FAILURE_COUNT","MAX_FAILURES","RETRY_COUNT",
"LAST_START_DATE","LAST_RUN_DURATION","NEXT_RUN_DATE",
"SCHEDULE_LIMIT","MAX_RUN_DURATION","LOGGING_LEVEL","STOP_ON_WINDOW_CLOSE",
"INSTANCE_STICKINESS","RAISE_EVENTS","SYSTEM","JOB_WEIGHT","NLS_ENV","SOURCE",
--"NUMBER_OF_DESTINATIONS", "DESTINATION_OWNER",
"DESTINATION",
--"CREDENTIAL_OWNER", "CREDENTIAL_NAME",
--"INSTANCE_ID",
--"DEFERRED_DROP",
--"ALLOW_RUNS_IN_RESTRICTED_MODE",
"COMMENTS","FLAGS"

from sys.DBA_SCHEDULER_JOBS a
;

prompt
prompt Creating view V_SYS_MANAGE_ACC
prompt ==============================
prompt
create or replace force view v_sys_manage_acc as
select
t.OWNER,
t.TRIGGER_NAME,
a.status as prog_Status,
t.TRIGGER_TYPE,
t.TRIGGERING_EVENT,
t.TABLE_OWNER,
t.BASE_OBJECT_TYPE,
t.STATUS,
t.ACTION_TYPE

from sys.dba_triggers t, sys.dba_objects a

where t.owner = a.owner
and   t.trigger_name = a.object_name
and   t.owner = 'SYS'
and   t.trigger_name = 'OMEGACA_ACC_DB_AF_LOGON' -- HARDCODE
;

prompt
prompt Creating view V_SYS_MANAGE_AUD
prompt ==============================
prompt
create or replace force view v_sys_manage_aud as
select
t.NUM,
t.NAME,
t.TYPE,

Decode(t.value,
'DB, EXTENDED', 'DB_EXTENDED',
t.value) as Param_Value,

t.DISPLAY_VALUE,
t.ISDEFAULT,
t.ISSES_MODIFIABLE,
t.ISSYS_MODIFIABLE,
t.ISINSTANCE_MODIFIABLE,
t.ISMODIFIED,
t.ISADJUSTED,
t.DESCRIPTION

from SYS.v_$parameter t

where Upper(t.name) = Upper('audit_trail') -- HARDCODE
;

prompt
prompt Creating view V_SYS_MANAGE_AUD_SCHED_JOB
prompt ========================================
prompt
create or replace force view v_sys_manage_aud_sched_job as
select

a.Owner, a.Job_name, a.Job_creator,
a.Client_id, a.Global_uid, a.Program_owner, a.Program_name,

a.Job_type, a.Job_action, a.Number_of_arguments,
a.Schedule_owner, a.Schedule_name,
a.Start_date, a.Repeat_interval, a.End_date,

a.Job_class, a.Enabled, a.Auto_drop, a.Restartable, a.State, a.Job_priority,
a.Run_count, a.Max_runs, a.Failure_count, a.Max_failures, a.Retry_count,

a.Last_start_date,
--from_tz(cast(a.Last_start_date as Timestamp), '00:00') at local as Last_start_date,
a.Last_run_duration,
cast(a.Next_run_date as Date) as Next_run_date,

a.Schedule_limit, a.Max_run_duration, a.Logging_level,
a.Stop_on_window_close, a.Instance_stickiness, a.System,
a.Job_weight, a.Nls_env, a.Source, a.Destination, a.Comments, a.Flags

    from sys.dba_scheduler_jobs a

    where a.owner = 'SYS'
    and a.job_name = 'OMEGACA_TRANS' -- Hardcoded Job Name
;

prompt
prompt Creating view V_SYS_MANAGE_AUD_SCHED_JOB_LOG
prompt ============================================
prompt
create or replace force view v_sys_manage_aud_sched_job_log as
select

a.LOG_ID,

a.LOG_DATE,

a.OWNER, a.job_name, a.STATUS,
a.ERROR#, a.REQ_START_DATE, a.actual_start_date,
a.RUN_DURATION, a.INSTANCE_ID, a.SESSION_ID, a.SLAVE_PID,
a.CPU_USED, a.ADDITIONAL_INFO

from sys.DBA_SCHEDULER_JOB_RUN_DETAILS a

where owner = 'SYS'
and job_name = 'OMEGACA_TRANS' -- Hardcoded Job Name
;

prompt
prompt Creating view V_SYS_MANAGE_RTP_DDL
prompt ==================================
prompt
create or replace force view v_sys_manage_rtp_ddl as
select
t.OWNER,
t.TRIGGER_NAME,
a.status as prog_Status,
t.TRIGGER_TYPE,
t.TRIGGERING_EVENT,
t.TABLE_OWNER,
t.BASE_OBJECT_TYPE,
t.STATUS,
t.ACTION_TYPE

from sys.dba_triggers t, sys.dba_objects a

where t.owner = a.owner
and   t.trigger_name = a.object_name
and   t.owner = 'SYS'
and   t.trigger_name = 'OMEGACA_RTP_DB_BF_DDL' -- HARDCODE
;

prompt
prompt Creating view V_SYS_MANAGE_RTP_DML
prompt ==================================
prompt
create or replace force view v_sys_manage_rtp_dml as
select

to_char(nvl(count(*), 0)) as Cnt_RTP_DML_ACTIVE

from sys.dba_audit_policies t

where Upper(t.enabled) = Upper('YES');

prompt
prompt Creating view V_SYS_OBJECTS
prompt ===========================
prompt
create or replace force view v_sys_objects as
select

  a.owner, a.object_name, a.subobject_name,

  a.object_id, a.data_object_id, a.object_type,

  a.last_ddl_time, a.timestamp, a.status,

  a.temporary, a.generated, a.secondary

  -- Multi-Version Columns !!!!!!!!!!!!!!!!!!!!
  -- a.namespace, a.edition_name

    from sys.dba_objects a
;

prompt
prompt Creating view V_SYS_OBJ_TYPE
prompt ============================
prompt
create or replace force view v_sys_obj_type as
select

  a.obj_type, a.obj_cat

  from SYS_OBJ_TYPE a;

prompt
prompt Creating view V_SYS_OPERATION_CODE
prompt ==================================
prompt
create or replace force view v_sys_operation_code as
select

  a.code_id,

  a.code_group,

  a.code_symbol,

  a.code_value,

  a.code_desc,

  a.date_upd, a.user_upd,

  a.date_created, a.user_created

  from SYS_OPERATION_CODE a;

prompt
prompt Creating view V_SYS_PARAM
prompt =========================
prompt
create or replace force view v_sys_param as
select

  a.parameter_id,

  a.parameter_name, a.parameter_desc,

  a.param_value, a.param_type,

  a.date_upd, a.user_upd,
  a.date_created, a.user_created

  from SYS_PARAM a;

prompt
prompt Creating view V_SYS_POL_DEBUG
prompt =============================
prompt
create or replace force view v_sys_pol_debug as
select

  a.timestamp_sts,
  a.username,

  a.policy_type_id, b.policy_type_code,

  a.policy_id, a.policy_name,

  a.rule_id, a.rule_name,

  a.cond_id, a.cond_code,

  a.eval_result,

  a.debug_log

  from SYS_POL_DEBUG a, sys_pol_type b

  where a.policy_type_id = b.policy_type_id;

prompt
prompt Creating view V_SYS_POL_TYPE
prompt ============================
prompt
create or replace force view v_sys_pol_type as
select

  a.policy_type_id,

  a.policy_type_code, a.policy_type_name,

  a.date_created, a.user_created

  from SYS_POL_TYPE a;

prompt
prompt Creating view V_SYS_STMT
prompt ========================
prompt
create or replace force view v_sys_stmt as
select

  a.stmt_name, a.stmt_type

  from SYS_STMT a;

prompt
prompt Creating view V_SYS_STMT_DDL
prompt ============================
prompt
create or replace force view v_sys_stmt_ddl as
select

  a.stmt_name, a.stmt_type

  from SYS_STMT a

   where a.stmt_type = 'DDL';

prompt
prompt Creating view V_SYS_SYSTEM_PRIVILEGE_MAP
prompt ========================================
prompt
create or replace force view v_sys_system_privilege_map as
select


  a.privilege,

  a.name,

  a.property

  from SYS_SYSTEM_PRIVILEGE_MAP a;

prompt
prompt Creating view V_SYS_TABLESPACE
prompt ==============================
prompt
create or replace force view v_sys_tablespace as
select

  a.TABLESPACE_NAME, a.BLOCK_SIZE, a.INITIAL_EXTENT,
  a.NEXT_EXTENT, a.MIN_EXTENTS, a.MAX_EXTENTS, a.PCT_INCREASE,
  a.MIN_EXTLEN, a.STATUS, a.CONTENTS, a.LOGGING, a.FORCE_LOGGING,
  a.EXTENT_MANAGEMENT ,a.ALLOCATION_TYPE, a.PLUGGED_IN, a.SEGMENT_SPACE_MANAGEMENT,
  a.DEF_TAB_COMPRESSION, a.RETENTION, a.BIGFILE

  from sys.dba_tablespaces a;

prompt
prompt Creating view V_SYS_UNF_TRAIL
prompt =============================
prompt
create or replace force view v_sys_unf_trail as
select 

 a.TIMESTAMP_STS, a.TIMESTAMP_UTC, 
 
 a.POLICY_TYPE_ID, b.policy_type_code, b.policy_type_name,
 
 a.USERNAME, a.SESSIONID, a.OS_USER, a.USERHOST, 
 a.ACTION_ID, a.ACTION_NAME, 

 a.OBJECT_OWNER, a.OBJECT_NAME, a.OBJECT_TYPE, 
 
 a.PRIVILEGE_ID, a.SYSTEM_PRIVILEGE, 
 
 a.NEW_OWNER, a.NEW_NAME, a.AUTH_PRIVILEGES, a.OBJ_PRIVILEGE, 
 
 a.LOGOFF_DEAD, a.SYS_PRIVILEGE, a.ADMIN_OPTION, a.GRANTEE, a.AUDIT_OPTION, 
 
 a.SES_ACTIONS, a.LOGOFF_TIME, a.LOGOFF_LREAD, a.LOGOFF_PREAD, a.LOGOFF_LWRITE, a.LOGOFF_DLOCK, 

 a.CLIENT_ID, a.TERMINAL, a.IP_ADDRESS, a.NETWORK_PROTOCOL, 
 
 a.DBID, a.DB_NAME, a.INSTANCE_NUMBER, 
 
 a.STATEMENTID, a.ENTRYID, a.TRANSACTIONID, a.SCN, 
 
 a.PROXY_SESSIONID, a.GLOBAL_UID, a.ECONTEXT_ID, a.COMMENT_TEXT, 
 
 a.OS_PROCESS, a.SESSIONCPU, 
 
 a.AUTHENTICATION_METHOD, a.IDENTIFICATION_TYPE, a.ISDBA, a.MODULE, 
 
 a.BG_JOB_ID, a.FG_JOB_ID, 
 
 a.RETURNCODE, a.RETURN_MESSAGE, 
 
 a.SQL_BIND, a.SQL_TEXT, a.DDL_BODY, a.FGA_POLICY_NAME, 
 
 a.EXT_NAME, a.OBJ_EDITION, 
 
 a.ISSUE_ID, c.issue_name,
 
 a.TRAIL_EVAL

from SYS_UNF_TRAIL a, sys_pol_type b, its_issue c

where a.policy_type_id = b.policy_type_id
and   a.issue_id       = c.issue_id;

prompt
prompt Creating view V_SYS_VERSION
prompt ===========================
prompt
create or replace force view v_sys_version as
select

  a.version_id,

  a.major_version, a.mntn_release, a.patch_no,
  LPad(a.major_version, 2, '0') || '.' ||
  LPad(a.mntn_release, 2, '0') || '.'  ||
  LPad(a.patch_no, 2, '0')
  as Full_Version,

  a.script_name,

  a.date_applied, a.user_applied

  from SYS_VERSION a;

prompt
prompt Creating view V_SYS_VERSION_CRRNT
prompt =================================
prompt
create or replace force view v_sys_version_crrnt as
select
t.version_id,
t.major_version, t.mntn_release, t.patch_no,
t.full_version,

t.script_name,

t.date_applied, t.user_applied
from v_sys_version t

where t.version_id = (
select Max(a.version_id) from
v_sys_version a
);

prompt
prompt Creating function F_RTP_DML_POL_RULE_AUD_POL_CND
prompt ================================================
prompt
CREATE OR REPLACE FUNCTION F_RTP_DML_POL_RULE_AUD_POL_CND (
                           p_rule_id in integer
                           )
return varchar2 is

-- Calling SYS Function for ORA-00904 Invalid identifier on FGA
-- ID 561319.1 ORA-904 when referencing a function in dbms_fga.add_policy audit_condition

v_FGA_AUDIT_IS_TRUE     varchar2(5);

begin

v_FGA_AUDIT_IS_TRUE := SYS.OMEGA_CORE_AUDIT.F_RTP_DML_POL_RULE_AUD_POL_CND(
                                            p_rule_id
                                            );
RETURN v_FGA_AUDIT_IS_TRUE;

end ;
/

prompt
prompt Creating function F_VAL_EXPR_TEST
prompt =================================
prompt
create or replace function F_VAL_EXPR_TEST (
                           p_factor_id in integer
                           )
return boolean is

begin

--return TRUE;
return FALSE;

end;
/

prompt
prompt Creating procedure P_ACC_POL_CACHE_DEL
prompt ======================================
prompt
create or replace procedure P_ACC_POL_CACHE_DEL (
                            p_row_id in varchar2
                            )

as

begin

-- Delete acc_pol_cache
delete from acc_pol_cache
where rowid = CHARTOROWID(p_row_id);

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_CACHE_POL_DEL
prompt ==========================================
prompt
create or replace procedure P_ACC_POL_CACHE_POL_DEL (
                            p_policy_id in integer
                            )

as


begin

-- Delete acc_pol_cache
delete from acc_pol_cache
where policy_id = p_policy_id;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_DEL
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_DEL (
                            p_cond_id in integer
                            )

AS

v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

-- delete acc_pol_cond_list
delete from acc_pol_cond_list
where cond_id = p_cond_id;

-- Get Rule Id before Condition delete
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = p_cond_id;

-- delete acc_policy_cond
delete from acc_pol_cond
where cond_id = p_cond_id;

-- get policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_INS
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_INS (
                            p_rule_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;
v_policy_id                 acc_pol_rule.policy_id%TYPE;

begin

-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Set Inactive only for Operand - IN, NOT IN
--v_status_id := 0;

-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR


-- Insert acc_pol_cond
insert into acc_pol_cond
(
cond_id,
rule_id,
factor_id,
opr_code_id,
operand_1,
operand_2,
cond_eval,
min_trust_level_no,
validate_expr_owner,
validate_expr_object,
status_id
)
values
(
seq_acc_pol_cond.nextval,
p_rule_id,
p_factor_id,
p_opr_code_id,
p_operand_1,
p_operand_2,
p_cond_eval,
p_min_trust_level_no,
p_validate_expr_owner,
p_validate_expr_object,
p_status_id
);


-- get policy for cache
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = p_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_LIST_DEL
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_LIST_DEL (
                            p_list_id in integer
                            )

AS

v_cond_id      acc_pol_cond_list.cond_id%TYPE;
v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin


-- Get Condition
select cond_id into v_cond_id
from acc_pol_cond_list
where list_id = p_list_id;
-- Get Rule
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = v_cond_id;
-- Get Policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


-- Delete acc_pol_cond_list
delete from acc_pol_cond_list
where list_id = p_list_id;

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_LIST_INS
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_LIST_INS (
                            p_cond_id in integer,
                            p_operand_1 in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_id          acc_pol_cond.opr_code_id%TYPE;

v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

select opr_code_id into v_opr_code_id
from acc_pol_cond where cond_id = p_cond_id;

if v_opr_code_id not in (12, 13) then
raise_application_error(-20010, 'Operation Code must be only IN/NOT IN !');
end if;


-- Insert acc_pol_cond_list
insert into acc_pol_cond_list
(
list_id,
cond_id,
operand_1,
status_id
)
values
(
seq_acc_pol_cond_list.nextval,
p_cond_id,
p_operand_1,
p_status_id
);


-- Get Rule
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = p_cond_id;
-- Get Policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_LIST_STAT
prompt ===========================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_LIST_STAT (
                            p_list_id in integer
                            )

AS

v_curr_status_id      acc_pol_cond_list.status_id%TYPE;
v_new_status_id       acc_pol_cond_list.status_id%TYPE;

v_cond_id      acc_pol_cond_list.cond_id%TYPE;
v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

-- get curr status
select status_id into v_curr_status_id
from acc_pol_cond_list where list_id = p_list_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Update acc_pol_cond_list status
update acc_pol_cond_list set
status_id = v_new_status_id,
date_upd = SYSDATE,
user_upd = USER
where list_id = p_list_id;


-- Get Condition
select cond_id into v_cond_id
from acc_pol_cond_list
where list_id = p_list_id;
-- Get Rule
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = v_cond_id;
-- Get Policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_LIST_UPD
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_LIST_UPD (
                            p_list_id in integer,
                            p_operand_1 in varchar2
                            )

AS

v_cond_id      acc_pol_cond_list.cond_id%TYPE;
v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin


-- Update acc_pol_cond_list
update acc_pol_cond_list set

operand_1 = p_operand_1,

date_upd = SYSDATE,
user_upd = USER

where list_id = p_list_id;


-- Get Condition
select cond_id into v_cond_id
from acc_pol_cond_list
where list_id = p_list_id;
-- Get Rule
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = v_cond_id;
-- Get Policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_STAT
prompt ======================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_STAT (
                            p_cond_id in integer
                            )

AS

v_curr_status_id      acc_pol_cond.status_id%TYPE;
v_new_status_id       acc_pol_cond.status_id%TYPE;

v_cond_eval           acc_pol_cond.cond_eval%TYPE;
v_opr_code_id         acc_pol_cond.opr_code_id%TYPE;
v_opr_code_symbol     sys_operation_code.code_group%TYPE;
cnt_in_list           integer;

v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

-- get condition data
select status_id, opr_code_id, cond_eval
into v_curr_status_id, v_opr_code_id, v_cond_eval
from acc_pol_cond where cond_id = p_cond_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;



-- BEGIN CHECK IN (NOT IN) list
if v_cond_eval = 1 then -- 1 = Operand

-- get opr_code symbol
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = v_opr_code_id;

if v_opr_code_symbol in ('IN', 'NOT IN') then

if v_new_status_id = 1 then
select count(*) into cnt_in_list
from acc_pol_cond_list
where cond_id = p_cond_id and status_id = 1;
if cnt_in_list = 0 then
raise_application_error(-20010, 'At least one active operand must be active in the IN (NOT IN) list for this condition to be active !');
end if;
end if;

end if;

end if;
-- END CHECK IN (NOT IN) list



-- Update acc_pol_cond status
update acc_pol_cond set
status_id = v_new_status_id,
date_upd = SYSDATE,
user_upd = USER
where cond_id = p_cond_id;


-- get rule
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = p_cond_id;
-- get policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COND_UPD
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COND_UPD (
                            p_cond_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;

v_rule_id      acc_pol_cond.rule_id%TYPE;
v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR



-- update acc_pol_cond
update acc_pol_cond set

factor_id = p_factor_id,
opr_code_id = p_opr_code_id,
operand_1 = p_operand_1,
operand_2 = p_operand_2,
cond_eval = p_cond_eval,
min_trust_level_no = p_min_trust_level_no,
validate_expr_owner = p_validate_expr_owner,
validate_expr_object = p_validate_expr_object,

date_upd = SYSDATE,
user_upd = USER

where cond_id = p_cond_id;



-- Get Rule Id
select rule_id into v_rule_id
from acc_pol_cond
where cond_id = p_cond_id;
-- Get Policy Id
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = v_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_INS
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_INS (
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_audit_option in integer,
                            p_user_apply in integer,
                            p_rule_eval in integer,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

begin

-- Insert acc_pol
BEGIN

insert into acc_pol
(
policy_id,
policy_name,
policy_desc,
audit_option,
user_apply,
rule_eval,
use_cache,
debug_log
)
values
(
seq_acc_pol.nextval,
p_policy_name,
p_policy_desc,
p_audit_option,
p_user_apply,
p_rule_eval,
p_use_cache,
p_debug_log
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_RULE_INS
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_RULE_INS (
                            p_policy_id in number,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_status_id in integer
                            )

AS

begin


-- Insert acc_pol_rule
BEGIN

insert into acc_pol_rule
(
rule_id,
policy_id,
rule_name,
rule_desc,
cond_eval,
status_id
)
values
(
seq_acc_pol_rule.nextval,
p_policy_id,
p_rule_name,
p_rule_desc,
p_cond_eval,
p_status_id
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Rule name already in this Policy !');
END;


-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
p_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_COPY
prompt =================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_COPY (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2
                            )

AS

v_rule_eval        acc_pol.rule_eval%TYPE;
v_audit_option     acc_pol.audit_option%TYPE;
v_debug_log        acc_pol.debug_log%TYPE;
v_user_apply       acc_pol.user_apply%TYPE;
v_use_cache        acc_pol.use_cache%TYPE;

v_policy_id        acc_pol.policy_id%TYPE;
v_rule_id          acc_pol_rule.rule_id%TYPE;
v_cond_id          acc_pol_cond.cond_id%TYPE;

cursor C_Rule is select * from acc_pol_rule t
where policy_id = p_policy_id
order by t.rule_id;

cursor C_Cond (Rul_Id in integer) is select * from acc_pol_cond t
where rule_id = Rul_Id
order by t.cond_id;

cursor C_Cond_List (Cnd_Id in integer) is select * from acc_pol_cond_list t
where cond_id = Cnd_Id
order by t.list_id;

begin

-- Get Original policy data
select rule_eval, audit_option,
debug_log, user_apply, use_cache
into v_rule_eval, v_audit_option,
v_debug_log, v_user_apply, v_use_cache
from acc_pol
where policy_id = p_policy_id;


-- Insert New Policy
P_ACC_POL_INS(
p_policy_name,
p_policy_desc,
v_audit_option,
v_user_apply,
v_rule_eval,
v_use_cache,
v_debug_log
);

-- Get New inserted Policy_Id
select seq_acc_pol.currval into v_policy_id from sys.dual;

-- Begin Loop Rule
for Rec1 in C_Rule loop

-- Insert Rule
P_ACC_POL_RULE_INS(
v_policy_id,
Rec1.Rule_Name,
Rec1.Rule_Desc,
Rec1.Cond_Eval,
Rec1.Status_Id
);

-- Get New inserted Rule_Id
select seq_acc_pol_rule.currval into v_rule_id from sys.dual;

    -- Begin Loop Condition
    for Rec2 in C_Cond(Rec1.Rule_Id) loop

    -- Insert Condition
    P_ACC_POL_COND_INS(
    v_rule_id,
    Rec2.Factor_Id,
    Rec2.Cond_Eval,
    Rec2.Opr_Code_Id,
    Rec2.Operand_1,
    Rec2.Operand_2,
    Rec2.Min_Trust_Level_No,
    Rec2.Validate_Expr_Owner,
    Rec2.Validate_Expr_Object,
    Rec2.Status_Id
    );

    -- Get New inserted Cond_Id
    select seq_acc_pol_cond.currval into v_cond_id from sys.dual;

              -- Begin Loop Condition List
              for Rec3 in C_Cond_List(Rec2.Cond_Id) loop

              -- Insert Condition List
              P_ACC_POL_COND_LIST_INS(
              v_cond_id,
              Rec3.Operand_1,
              Rec3.Status_Id
              );

              end loop;
              -- End Loop Condition List

    end loop;
    -- End Loop Condition

end loop;
-- End Loop Rule


-- insert user_apply
insert into acc_pol_user
(policy_id, user_id, user_apply)
select v_policy_id, user_id, user_apply
from acc_pol_user
where policy_id = p_policy_id;

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_RULE_DEL
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_RULE_DEL (
                            p_rule_id in integer
                            )

AS

-- Condition Cursor
cursor C_Cond is select * from acc_pol_cond
where rule_id = p_rule_id;

v_policy_id    acc_pol_rule.policy_id%TYPE;

begin

-- Begin loop Conditions
for Rec in C_Cond loop

    P_ACC_POL_COND_DEL(
    Rec.Cond_Id
    );

end loop;
-- End loop Conditions


-- Get Policy
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = p_rule_id;
-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);

-- delete acc_policy_rule
delete from acc_pol_rule
where rule_id = p_rule_id;

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_DEL
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_DEL (
                            p_policy_id in integer
                            )

AS

-- Rule Cursor
cursor C_Rule is select * from acc_pol_rule
where policy_id = p_policy_id;

begin


-- Begin Loop Policy Rules
for Rec_Rule in C_Rule loop

-- Delete Rule
P_ACC_POL_RULE_DEL(
Rec_Rule.Rule_Id
);

end loop;
-- End Loop Policy Rules


-- delete acc_pol_user
delete from acc_pol_user
where policy_id = p_policy_id;


-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
p_policy_id
);


-- delete acc_pol
delete from acc_pol
where policy_id = p_policy_id;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_RULE_STAT
prompt ======================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_RULE_STAT (
                            p_rule_id in integer
                            )

AS

v_curr_status_id      acc_pol_rule.status_id%TYPE;
v_new_status_id       acc_pol_rule.status_id%TYPE;

cnt_active_cond      integer;

v_policy_id          acc_pol_rule.policy_id%TYPE;

begin


-- get rule data
select status_id, policy_id
into v_curr_status_id, v_policy_id
from acc_pol_rule
where rule_id = p_rule_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- begin check active Conditions when new status Active
if v_new_status_id = 1 then

-- make condition count
select count(*) into cnt_active_cond
from acc_pol_cond
where rule_id = p_rule_id
and status_id = 1; -- 1=Active

-- evaluate and raise
if cnt_active_cond = 0 then
raise_application_error(-20010, 'Rule with no Active Conditions cannot be set as Active !');
end if;

end if;
-- end check active Conditions when new status Active



-- update acc_pol_rule status
update acc_pol_rule set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;


-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_RULE_UPD
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_RULE_UPD (
                            p_rule_id in integer,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_formula in varchar2
                            )

AS


v_policy_id    acc_pol_rule.policy_id%TYPE;


begin

-- get policy_id for cache !!!!
select policy_id into v_policy_id
from acc_pol_rule
where rule_id = p_rule_id;


-- update acc_policy_rule
BEGIN

update acc_pol_rule set

rule_name = p_rule_name,
rule_desc = p_rule_desc,
cond_eval = p_cond_eval,
formula = p_formula,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Rule name already in this Policy !');
END;



-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_STAT
prompt =================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_STAT (
                            p_policy_id in integer
                            )

AS

v_curr_status_id      acc_pol.status_id%TYPE;
v_new_status_id       acc_pol.status_id%TYPE;

cnt_active_rule       integer;

v_user_apply          acc_pol.user_apply%TYPE;
cnt_pol_user          integer;

begin

-- get acc_pol data
select status_id, user_apply
into v_curr_status_id, v_user_apply
from acc_pol where policy_id = p_policy_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- BEGIN CHECK FOR NEW STATUS ACTIVE
if v_new_status_id = 1 then

-- make count Active Rules
select count(*) into cnt_active_rule
from acc_pol_rule
where policy_id = p_policy_id and status_id = 1; -- 1=Active
-- Raise if no Active Rule
if cnt_active_rule = 0 then
raise_application_error(-20010, 'Policy with no Active Rules cannot be set as Active !');
end if;

-- Begin check Users Apply
if v_user_apply = 1 then
-- Count Users Apply
select count(*) into cnt_pol_user
from acc_pol_user
where policy_id = p_policy_id and user_apply = 1; -- 1 Users Apply
-- Raise if no Users Apply
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Apply with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Apply

-- Begin check Users Exclude
if v_user_apply = 2 then
-- Count Users Exclude
select count(*) into cnt_pol_user
from acc_pol_user
where policy_id = p_policy_id and user_apply = 2; -- 2 Users Exclude
-- Raise if no Users Exclude
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Exclude with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Exclude

end if;
-- END CHECK FOR NEW STATUS ACTIVE


-- update acc_pol status
update acc_pol set
status_id = v_new_status_id,
date_upd = SYSDATE,
user_upd = USER
where policy_id = p_policy_id ;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_UPD
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_UPD (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_audit_option in integer,
                            p_user_apply in integer,
                            p_rule_eval in integer,
                            p_formula in varchar2,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

begin

-- update acc_pol
BEGIN

update acc_pol set

policy_name = p_policy_name,
policy_desc = p_policy_desc,
audit_option = p_audit_option,
user_apply = p_user_apply,
rule_eval = p_rule_eval,
formula = p_formula,
use_cache = p_use_cache,
debug_log = p_debug_log,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


-- Clear Policy from Cache
P_ACC_POL_CACHE_POL_DEL(
p_policy_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_USER_DEL
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_USER_DEL (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Delete acc_pol_user
delete acc_pol_user
where policy_id = p_policy_id
and user_id = p_user_id
and user_apply = p_user_apply;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_POL_USER_INS
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_POL_USER_INS (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Insert acc_pol_user
BEGIN

insert into acc_pol_user
(
policy_id,
user_id,
user_apply
)
values
(
p_policy_id,
p_user_id,
p_user_apply
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'User appliance already declared for this Policy !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ACC_SILENT
prompt ===============================
prompt
CREATE OR REPLACE PROCEDURE P_ACC_SILENT (
                            p_silent_value in varchar2
                            )

AS

begin

-- Check ACCSLNT Value
if p_silent_value not in ('0','1') then
raise_application_error(-20010, 'Unknown Silent Access Control parameter not in 0/1 !');
end if;

-- update sys_param ACCSLNT value
-- Parameter_Id = 1 = ACCSLNT = Silent Access Control
update sys_param set
param_value = p_silent_value,
date_upd = SYSDATE,
user_upd = USER
where parameter_id = 1 ;

end; -- end proc
/

prompt
prompt Creating procedure P_ACM_PRIV_OBJ_GRANT
prompt =======================================
prompt
create or replace procedure P_ACM_PRIV_OBJ_GRANT (
                  p_grantee in varchar2,
                  p_obj_owner in varchar2,
                  p_obj_name in varchar2,
                  p_obj_priv in varchar2,
                  p_grant_option in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_OBJ_GRANT(
               p_grantee,
               p_obj_owner,
               p_obj_name,
               p_obj_priv,
               p_grant_option
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_OBJ_REVOKE
prompt ========================================
prompt
create or replace procedure P_ACM_PRIV_OBJ_REVOKE (
                  p_grantee in varchar2,
                  p_obj_owner in varchar2,
                  p_obj_name in varchar2,
                  p_obj_priv in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_OBJ_REVOKE(
               p_grantee,
               p_obj_owner,
               p_obj_name,
               p_obj_priv
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_ROLE_DEFAULT
prompt ==========================================
prompt
create or replace procedure P_ACM_PRIV_ROLE_DEFAULT (
                  p_user in varchar2,
                  p_role in varchar2,
                  p_def_role in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_ROLE_DEFAULT (
               p_user,
               p_role,
               p_def_role
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_ROLE_GRANT
prompt ========================================
prompt
create or replace procedure P_ACM_PRIV_ROLE_GRANT (
                  p_grantee in varchar2,
                  p_granted_role in varchar2,
                  p_admin_option in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_ROLE_GRANT (
               p_grantee,
               p_granted_role,
               p_admin_option
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_ROLE_REVOKE
prompt =========================================
prompt
create or replace procedure P_ACM_PRIV_ROLE_REVOKE (
                  p_grantee in varchar2,
                  p_granted_role in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_ROLE_REVOKE (
               p_grantee,
               p_granted_role
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_SYS_GRANT
prompt =======================================
prompt
create or replace procedure P_ACM_PRIV_SYS_GRANT (
                  p_grantee in varchar2,
                  p_sys_priv in varchar2,
                  p_admin_option in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_SYS_GRANT (
               p_grantee,
               p_sys_priv,
               p_admin_option
               );

end ;
/

prompt
prompt Creating procedure P_ACM_PRIV_SYS_REVOKE
prompt ========================================
prompt
create or replace procedure P_ACM_PRIV_SYS_REVOKE (
                  p_grantee in varchar2,
                  p_sys_priv in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_PRIV_SYS_REVOKE (
               p_grantee,
               p_sys_priv
               );

end ;
/

prompt
prompt Creating procedure P_ACM_ROLE_ALTER
prompt ===================================
prompt
create or replace procedure P_ACM_ROLE_ALTER (
                  p_role in varchar2,
                  p_identification in integer,
                  p_password in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_ROLE_ALTER (
               p_role,
               p_identification,
               p_password
               );

end ;
/

prompt
prompt Creating procedure P_ACM_ROLE_CREATE
prompt ====================================
prompt
create or replace procedure P_ACM_ROLE_CREATE (
                  p_role in varchar2,
                  p_identification in integer,
                  p_password in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_ROLE_CREATE (
               p_role,
               p_identification,
               p_password
               );

end ;
/

prompt
prompt Creating procedure P_ACM_ROLE_DROP
prompt ==================================
prompt
create or replace procedure P_ACM_ROLE_DROP (
                  p_role in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_ROLE_DROP (
               p_role
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_ALTER
prompt ===================================
prompt
create or replace procedure P_ACM_USER_ALTER (
                  p_user in varchar2,
                  p_profile in varchar2,
                  p_acc_locked in integer,
                  p_default_tbs in varchar2,
                  p_temp_tbs in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_ALTER (
               p_user,
               p_profile,
               p_acc_locked,
               p_default_tbs,
               p_temp_tbs
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_CREATE
prompt ====================================
prompt
create or replace procedure P_ACM_USER_CREATE (
                  p_user in varchar2,
                  p_profile in varchar2,
                  p_identified_mode in varchar2,
                  p_password in varchar2,
                  p_global_external_name in varchar2,
                  p_pass_expire in integer,
                  p_acc_locked in integer,
                  p_default_tbs in varchar2,
                  p_temp_tbs in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_CREATE (
               p_user,
               p_profile,
               p_identified_mode,
               p_password,
               p_global_external_name,
               p_pass_expire,
               p_acc_locked,
               p_default_tbs,
               p_temp_tbs
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_DROP
prompt ==================================
prompt
create or replace procedure P_ACM_USER_DROP (
                  p_user in varchar2,
                  p_cascade in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_DROP (
               p_user,
               p_cascade
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_PASS_EXPIRE
prompt =========================================
prompt
create or replace procedure P_ACM_USER_PASS_EXPIRE (
                  p_user in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_PASS_EXPIRE (
               p_user
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_PASS_OWN
prompt ======================================
prompt
create or replace procedure P_ACM_USER_PASS_OWN (
                  p_password in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_PASS_OWN (
               p_password
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_PASS_SET
prompt ======================================
prompt
create or replace procedure P_ACM_USER_PASS_SET (
                  p_user in varchar2,
                  p_password in varchar2
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_PASS_SET (
               p_user,
               p_password
               );

end ;
/

prompt
prompt Creating procedure P_ACM_USER_QUOTA
prompt ===================================
prompt
create or replace procedure P_ACM_USER_QUOTA (
                  p_user in varchar2,
                  p_tablespace in varchar2,
                  p_unlimited in integer,
                  p_quota in number
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_ACM_USER_QUOTA (
               p_user,
               p_tablespace,
               p_unlimited,
               p_quota
               );

end ;
/

prompt
prompt Creating procedure P_AUD_MAP
prompt ============================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_MAP (
                            p_aud_map in varchar2
                            )

AS

begin

-- Check AUDMAP Value
if p_aud_map not in ('0','1') then
raise_application_error(-20010, 'Unknown Standard Audit Trail Map parameter not in 0/1 !');
end if;

-- update sys_param AUDMAP value
-- Parameter_Id = 2 = AUDMAP = Standard Audit Trail Map
update sys_param set
param_value = p_aud_map,
date_upd = SYSDATE,
user_upd = USER
where parameter_id = 2 ;

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_CACHE_DEL
prompt ======================================
prompt
create or replace procedure P_AUD_POL_CACHE_DEL (
                            p_row_id in varchar2
                            )

as

begin

-- Delete aud_pol_cache
delete from aud_pol_cache
where rowid = CHARTOROWID(p_row_id);

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_CACHE_POL_DEL
prompt ==========================================
prompt
create or replace procedure P_AUD_POL_CACHE_POL_DEL (
                            p_policy_id in integer
                            )

as

begin

-- Delete aud_pol_cache
delete from aud_pol_cache
where policy_id = p_policy_id;

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_INS
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_INS (
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_type_id in integer,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

begin

-- Insert aud_pol
BEGIN

insert into aud_pol
(
policy_id,
policy_name,
policy_desc,
type_id,
use_cache,
debug_log
)
values
(
seq_aud_pol.nextval,
p_policy_name,
p_policy_desc,
p_type_id,
p_use_cache,
p_debug_log
);

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_UN') <> 0 then
raise_application_error(-20010, 'Policy name already in use !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;



end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_OBJ_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_OBJ_INS (
                            p_policy_id in number,
                            p_sql_operation in varchar2,
                            p_object_owner in varchar2,
                            p_object_type in varchar2,
                            p_object_name in varchar2,
                            p_success_failure in integer,
                            p_status_id in integer
                            )

AS

v_policy_type_id     aud_pol.type_id%TYPE;

cnt_aud_option_act_enb integer;

begin

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if p_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;

-- get policy type
select type_id into v_policy_type_id
from aud_pol where policy_id = p_policy_id;

-- Raise if type <> 1=Object
if v_policy_type_id <> 1 then
raise_application_error(-20010, 'Policy is not of type Object !');
end if;

-- Get Active Mapped Audit Action Count
select count(*) into cnt_aud_option_act_enb
from v_aud_sys_obj_opt_act
where obj_type = p_object_type
and audit_option = p_sql_operation
and act_enabled = 1;
-- Raise Active Mapped Audit Action Count=0
if cnt_aud_option_act_enb = 0 then
raise_application_error(-20010, 'No Audit Action enabled for this Audit Option !');
end if;


-- Insert aud_pol_obj
BEGIN

insert into aud_pol_obj
(
aud_obj_id,
policy_id,
status_id ,
sql_operation,
object_type,
object_owner,
object_name,
success_failure
)
values
(
seq_aud_pol_obj.nextval,
p_policy_id,
p_status_id,
p_sql_operation,
p_object_type,
p_object_owner,
p_object_name,
p_success_failure
);

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_OBJ_UN') <> 0 then
raise_application_error(-20010, 'Object Audit already in use for this Owner, Type, Object and Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
p_policy_id
);


-- Begin Call Audit GEN if Status Active
if p_status_id = 1 then
-- Generate AUDIT - Call for Insert Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_OBJ_GEN (
                     NULL,
                     -- Object (obj, dir, mining) Current
                     NULL,
                     NULL,
                     NULL,
                     NULL,
                     NULL,
                     -- Object (obj, dir, mining) New
                     p_sql_operation,
                     p_object_owner,
                     p_object_type,
                     p_object_name,
                     p_success_failure,
                     -- Action
                     1 -- Action INS
                     );
end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_STMT_INS
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_STMT_INS (
                            p_policy_id in number,
                            p_audit_option in varchar2,
                            p_audit_by_user in varchar2,
                            p_success_failure in integer,
                            p_status_id in integer
                            )

AS

v_policy_type_id     aud_pol.type_id%TYPE;

cnt_aud_option_act_enb integer;

cnt_all_stmt         integer;
cnt_all_stmt_other   integer;

begin

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if p_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;

-- get policy type
select type_id into v_policy_type_id
from aud_pol where policy_id = p_policy_id;

-- Raise if type <> 2=Statement[Privilege]
if v_policy_type_id <> 2 then
raise_application_error(-20010, 'Policy is not of type Statement [privilege] !');
end if;


-- Get Active Mapped Audit Action Count
select count(*) into cnt_aud_option_act_enb
from v_aud_sys_stmt_opt_act
where option_name = p_audit_option
and act_enabled = 1;
-- Raise Active Mapped Audit Action Count=0
if cnt_aud_option_act_enb = 0 then
raise_application_error(-20010, 'No Audit Action enabled for this Audit Option !');
end if;


-- Begin Check NOT EXISTS not on Success !!!
if p_audit_option = 'NOT EXISTS' then
if p_success_failure = 2 then  -- 2=Success
raise_application_error(-20010, 'NOT EXISTS cannot be audited for Success !');
end if;
end if;
-- End Check NOT EXISTS not on Success !!!


-- Insert aud_pol_stmt
BEGIN

insert into aud_pol_stmt
(
aud_stmt_id,
policy_id,
status_id,
audit_option,
audit_by_user,
success_failure
)
values
(
seq_aud_pol_stmt.nextval,
p_policy_id,
p_status_id,
p_audit_option,
p_audit_by_user,
p_success_failure
);

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_STMT_UN') <> 0 then
raise_application_error(-20010, 'Statement Audit already in use for this User and Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Begin Handle ALL STATEMENTS vs Others
-- Handle AFTER Action (INS/UPD)
select count(*) into cnt_all_stmt
from aud_pol_stmt
where policy_id = p_policy_id
and audit_by_user = p_audit_by_user
and audit_option = 'ALL STATEMENTS';

if cnt_all_stmt > 0 then -- if ALL STATEMENTS, then check Others

   select count(*) into cnt_all_stmt_other
   from aud_pol_stmt
   where policy_id = p_policy_id
   and audit_by_user = p_audit_by_user
   and audit_option <> 'ALL STATEMENTS'
   and audit_option not in ('CREATE SESSION');

   if cnt_all_stmt_other > 0 then
   raise_application_error(-20010, 'ALL STATEMENTS can coexist only with CREATE SESSION !');
   end if;

end if;
-- End Handle ALL STATEMENTS


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
p_policy_id
);


-- Begin Call Audit GEN if Status Active
if p_status_id = 1 then
-- Generate AUDIT - Call for Insert Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_STMT_GEN (
                     NULL,
                     -- Statement[Privilege] Current
                     NULL,
                     NULL,
                     NULL,
                     -- Statement[Privilege] New
                     p_audit_option,
                     p_audit_by_user,
                     p_success_failure,
                     -- Action
                     1 -- Action INS
                     );
end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_COPY
prompt =================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_COPY (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2
                            )

AS

v_policy_id        aud_pol.policy_id%TYPE;

v_type_id          aud_pol.type_id%TYPE;
v_debug_log        aud_pol.debug_log%TYPE;
v_use_cache        aud_pol.use_cache%TYPE;

cursor C_Aud_Obj is select * from aud_pol_obj t
where policy_id = p_policy_id
order by t.aud_obj_id;

cursor C_Aud_Stmt is select * from aud_pol_stmt t
where policy_id = p_policy_id
order by t.aud_stmt_id;

begin

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if p_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;


-- Get Original policy data
select type_id, debug_log, use_cache
into  v_type_id, v_debug_log, v_use_cache
from aud_pol
where policy_id = p_policy_id;

-- Insert New Policy
P_AUD_POL_INS(
p_policy_name,
p_policy_desc,
v_type_id,
v_use_cache,
v_debug_log
);

-- Get New inserted Policy_Id
select seq_aud_pol.currval into v_policy_id from sys.dual;


-- Begin Loop Aud_Pol_Obj
for Rec_Aud_Obj in C_Aud_Obj loop

-- Insert Aud_Pol_Obj
P_AUD_POL_OBJ_INS(
v_policy_id,
Rec_Aud_Obj.Sql_Operation,
Rec_Aud_Obj.Object_Owner,
Rec_Aud_Obj.Object_Type,
Rec_Aud_Obj.Object_Name,
Rec_Aud_Obj.Success_Failure,
0 -- New Aud_Pol_Obj Status Disabled on Copy
);

end loop;
-- End Loop Aud_Pol_Obj

-- Begin Loop Aud_Pol_Stmt
for Rec_Aud_Stmt in C_Aud_Stmt loop

-- Insert Aud_Pol_Stmt
P_AUD_POL_STMT_INS(
v_policy_id,
Rec_Aud_Stmt.Audit_Option,
Rec_Aud_Stmt.Audit_By_User,
Rec_Aud_Stmt.Success_Failure,
0 -- New Aud_Pol_Stmt Status Disabled on Copy
);

end loop;
-- End Loop Aud_Pol_Stmt


end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_OBJ_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_OBJ_DEL (
                            p_aud_obj_id in integer
                            )

AS

v_policy_id                      aud_pol.policy_id%TYPE;

v_status_id                      aud_pol_obj.status_id%TYPE;
v_sql_operation                  aud_pol_obj.sql_operation%TYPE;
v_object_type                    aud_pol_obj.object_type%TYPE;
v_object_owner                   aud_pol_obj.object_owner%TYPE;
v_object_name                    aud_pol_obj.object_name%TYPE;
v_success_failure                aud_pol_obj.success_failure%TYPE;

begin

-- Get AUD Details
select
policy_id,
status_id,
sql_operation,
object_type,
object_owner,
object_name,
success_failure
into
v_policy_id,
v_status_id,
v_sql_operation,
v_object_type,
v_object_owner,
v_object_name,
v_success_failure
from aud_pol_obj
where aud_obj_id = p_aud_obj_id;


-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if v_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- delete aud_pol_obj
delete from aud_pol_obj
where aud_obj_id = p_aud_obj_id;


-- Begin Call Audit GEN if Status Active
if v_status_id = 1 then

BEGIN

-- Generate AUDIT - Call for Delete Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_OBJ_GEN (
                     p_aud_obj_id,
                     -- Object (obj, dir, mining) Current
                     v_sql_operation,
                     v_object_owner,
                     v_object_type,
                     v_object_name,
                     v_success_failure,
                     -- Object (obj, dir, mining) New
                     NULL,
                     NULL,
                     NULL,
                     NULL,
                     NULL,
                     -- Action
                     3 -- Action DEL
                     );

EXCEPTION
WHEN OTHERS THEN

-- ORA-00942 table or view does not exist
if sqlcode = -942 then
null; -- Continue Delete when Object not found
else
--re-raise Error if no defined found
RAISE;
end if;

END;

end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_STMT_DEL
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_STMT_DEL (
                            p_aud_stmt_id in integer
                            )

AS

v_policy_id                      aud_pol.policy_id%TYPE;

v_status_id                      aud_pol_stmt.status_id%TYPE;
v_audit_option                   aud_pol_stmt.audit_option%TYPE;
v_audit_by_user                  aud_pol_stmt.audit_by_user%TYPE;
v_success_failure                aud_pol_stmt.success_failure%TYPE;

begin


-- Get AUD Details
select
policy_id,
status_id,
audit_option,
audit_by_user,
success_failure
into
v_policy_id,
v_status_id,
v_audit_option,
v_audit_by_user,
v_success_failure
from aud_pol_stmt
where aud_stmt_id = p_aud_stmt_id;


-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if v_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- delete aud_pol_stmt
delete from aud_pol_stmt
where aud_stmt_id = p_aud_stmt_id;


-- Begin Call Audit GEN if Status Active
if v_status_id = 1 then

BEGIN

-- Generate AUDIT - Call for Delete Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_STMT_GEN (
                     p_aud_stmt_id,
                     -- Statement[Privilege] Current
                     v_audit_option,
                     v_audit_by_user,
                     v_success_failure,
                     -- Statement[Privilege] New
                     NULL,
                     NULL,
                     NULL,
                     -- Action
                     3 -- Action DEL
                     );
                     
EXCEPTION
WHEN OTHERS THEN

-- ORA-01435 user does not exist
if sqlcode = -1435 then
null; -- Continue Delete when User not found
else
--re-raise Error if no defined found
RAISE;
end if;

END;
                     
end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_DEL
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_DEL (
                            p_policy_id in integer
                            )

AS

-- Aud Obj cursor
cursor C_Aud_Obj is select * from aud_pol_obj
where policy_id = p_policy_id;

-- Aud Stmt cursor
cursor C_Aud_Stmt is select * from aud_pol_stmt
where policy_id = p_policy_id;

begin


-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if p_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;


-- Begin Loop Audit Objects
for Rec_Aud_Obj in C_Aud_Obj loop

-- Delete Audit Object
P_AUD_POL_OBJ_DEL(
Rec_Aud_Obj.Aud_Obj_Id
);

end loop;
-- End Loop Audit Objects


-- Begin Loop Audit Statements
for Rec_Aud_Stmt in C_Aud_Stmt loop

-- Delete Audit Statement
P_AUD_POL_STMT_DEL(
Rec_Aud_Stmt.Aud_Stmt_Id
);

end loop;
-- End Loop Audit Statements


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
p_policy_id
);


-- delete aud_pol
delete from aud_pol
where policy_id = p_policy_id;


end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_OBJ_STAT
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_OBJ_STAT (
                            p_aud_obj_id in integer
                            )

AS

v_curr_status_id     aud_pol_obj.status_id%TYPE;
v_new_status_id      aud_pol_obj.status_id%TYPE;

v_policy_id          aud_pol_obj.policy_id%TYPE;
v_sql_operation      aud_pol_obj.sql_operation%TYPE;
v_object_owner       aud_pol_obj.object_owner%TYPE;
v_object_type        aud_pol_obj.object_type%TYPE;
v_object_name        aud_pol_obj.object_name%TYPE;

v_success_failure    aud_pol_obj.success_failure%TYPE;
v_aud_obj_gen_act    integer;

begin

-- get aud_pol_stmt data
select status_id, policy_id,
sql_operation, object_owner, object_type, object_name,
success_failure
into v_curr_status_id, v_policy_id,
v_sql_operation, v_object_owner, v_object_type, v_object_name,
v_success_failure
from aud_pol_obj
where aud_obj_id = p_aud_obj_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
v_aud_obj_gen_act := 1; -- Action INS
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
v_aud_obj_gen_act := 3; -- Action DEL
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- update aud_pol_obj status
update aud_pol_obj set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where aud_obj_id = p_aud_obj_id ;


-- Generate AUDIT - Call for INS or DEL - depending on Status
SYS.OMEGA_CORE_AUDIT.P_AUD_OBJ_GEN (
p_aud_obj_id,
-- Object (obj, dir, mining) Current
v_sql_operation,
v_object_owner,
v_object_type,
v_object_name,
v_success_failure,
-- Object (obj, dir, mining) New
v_sql_operation,
v_object_owner,
v_object_type,
v_object_name,
v_success_failure,
-- Action
v_aud_obj_gen_act -- -- Action INS/DEL
);

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_OBJ_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_OBJ_UPD (
                            p_aud_obj_id in integer,
                            p_sql_operation in varchar2,
                            p_object_owner in varchar2,
                            p_object_type in varchar2,
                            p_object_name in varchar2,
                            p_success_failure in integer
                            )

AS

v_policy_id                      aud_pol.policy_id%TYPE;

v_status_id                      aud_pol_obj.status_id%TYPE;
v_sql_operation                  aud_pol_obj.sql_operation%TYPE;
v_object_type                    aud_pol_obj.object_type%TYPE;
v_object_owner                   aud_pol_obj.object_owner%TYPE;
v_object_name                    aud_pol_obj.object_name%TYPE;
v_success_failure                aud_pol_obj.success_failure%TYPE;

cnt_aud_option_act_enb integer;

begin

-- Get Active Mapped Audit Action Count
select count(*) into cnt_aud_option_act_enb
from v_aud_sys_obj_opt_act
where obj_type = p_object_type
and audit_option = p_sql_operation
and act_enabled = 1;
-- Raise Active Mapped Audit Action Count=0
if cnt_aud_option_act_enb = 0 then
raise_application_error(-20010, 'No Audit Action enabled for this Audit Option !');
end if;

-- Get AUD Details
select
policy_id,
status_id,
sql_operation,
object_type,
object_owner,
object_name,
success_failure
into
v_policy_id,
v_status_id,
v_sql_operation,
v_object_type,
v_object_owner,
v_object_name,
v_success_failure
from aud_pol_obj
where aud_obj_id = p_aud_obj_id;

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if v_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;

-- Update aud_pol_obj
BEGIN

update aud_pol_obj set

sql_operation = p_sql_operation,
object_type = p_object_type,
object_owner = p_object_owner,
object_name = p_object_name,
success_failure = p_success_failure,

user_upd = USER,
date_upd = SYSDATE

where aud_obj_id = p_aud_obj_id ;

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_OBJ_UN') <> 0 then
raise_application_error(-20010, 'Object Audit already in use for this Owner, Type, Object and Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- Begin Call Audit GEN if Status Active
if v_status_id = 1 then
-- Generate DEL NoAudit - Call for Update Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_OBJ_GEN (
                     p_aud_obj_id,
                     -- Object (obj, dir, mining) Current
                     v_sql_operation,
                     v_object_owner,
                     v_object_type,
                     v_object_name,
                     v_success_failure,
                     -- Object (obj, dir, mining) Current
                     p_sql_operation,
                     p_object_owner,
                     p_object_type,
                     p_object_name,
                     p_success_failure,
                     -- Action
                     2 -- Action UPD
                     );
end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_ORA_DF_SYNC
prompt ========================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_ORA_DF_SYNC

AS

-- Policy_Id = 0 = 'Oracle Default Audits'
cursor c_ora_def_aud is select * from aud_pol_stmt
where policy_id = 0; 

cnt_aud           integer;
cnt_rule_active   integer;

begin

-- Begin loop 'Oracle Default Audits' stmt aud
for rec_ora_def_aud in c_ora_def_aud loop

-- Get Ora Def Audit (user-wide) count for rec
select count(*) into cnt_aud
from dba_stmt_audit_opts t
where t.audit_option = rec_ora_def_aud.audit_option
and t.user_name is null; 

-- Begin Make 'Oracle Default Audits' Rule status
if cnt_aud > 0 then
-- Set Status Active
update aud_pol_stmt set
status_id = 1,
date_upd = SYSDATE,
user_upd = USER
where aud_stmt_id = rec_ora_def_aud.aud_stmt_id;
else -- = 0
-- Set Status InActive
update aud_pol_stmt set
status_id = 0,
date_upd = SYSDATE,
user_upd = USER
where aud_stmt_id = rec_ora_def_aud.aud_stmt_id;
end if;
-- End Make 'Oracle Default Audits' Rule status

end loop;
-- End loop 'Oracle Default Audits' stmt aud


-- Begin Make Policy Status
-- Active Rules for Policy_id = 0
select count(*) into cnt_rule_active 
from aud_pol_stmt
where policy_id = 0 
and status_id = 1;

-- Begin Make 'Oracle Default Audits' Policy status
if cnt_rule_active > 0 then
-- Set Status Active - Direct Status Set
update aud_pol set 
status_id = 1,
date_upd = SYSDATE,
user_upd = USER
where policy_id = 0;
else
-- Set Status InActive
update aud_pol set 
status_id = 0,
date_upd = SYSDATE,
user_upd = USER
where policy_id = 0;
end if;
-- End Make 'Oracle Default Audits' Policy status 
-- End Make Policy Status


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
0  -- 0 = 'Oracle Default Audits'
);

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_STMT_STAT
prompt ======================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_STMT_STAT (
                            p_aud_stmt_id in integer
                            )

AS

v_curr_status_id     aud_pol_stmt.status_id%TYPE;
v_new_status_id      aud_pol_stmt.status_id%TYPE;

v_policy_id          aud_pol_stmt.policy_id%TYPE;
v_audit_option       aud_pol_stmt.audit_option%TYPE;
v_audit_by_user      aud_pol_stmt.audit_by_user%TYPE;
v_success_failure    aud_pol_stmt.success_failure%TYPE;
v_aud_stmt_gen_act   integer;

begin

-- get aud_pol_stmt data
select status_id, policy_id,
audit_option, audit_by_user, success_failure
into v_curr_status_id, v_policy_id,
v_audit_option, v_audit_by_user, v_success_failure
from aud_pol_stmt
where aud_stmt_id = p_aud_stmt_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
v_aud_stmt_gen_act := 1; -- Action INS
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
v_aud_stmt_gen_act := 3; -- Action DEL
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- update aud_pol_stmt status
update aud_pol_stmt set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where aud_stmt_id = p_aud_stmt_id ;


-- begin check active Conditions when new status Active
if v_policy_id = 0 then

SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_SYS_DEF_AUDIT(
v_audit_option,
v_new_status_id
);

else -- policy_id <> 0

-- Generate Audit - Call for INS or DEL - depending on Status
SYS.OMEGA_CORE_AUDIT.P_AUD_STMT_GEN (
p_aud_stmt_id,
-- Statement[Privilege] Current
v_audit_option,
v_audit_by_user,
v_success_failure,
-- Statement[Privilege] New
v_audit_option,
v_audit_by_user,
v_success_failure,
v_aud_stmt_gen_act -- Action INS/DEL
);

end if;

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_STAT
prompt =================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_STAT (
                            p_policy_id in integer
                            )

AS

v_curr_status_id      aud_pol.status_id%TYPE;
v_new_status_id       aud_pol.status_id%TYPE;

v_type_id             aud_pol.type_id%TYPE;
cnt_active_aud        integer;

-- Active Policy Obj Audits Cursor
cursor c_pol_obj_active is
select * from aud_pol_obj
where policy_id = p_policy_id
and status_id = 1; -- 1 = Active only - for Deactivating

-- Active Policy Stmt Audits Cursor
cursor c_pol_stmt_active is
select * from aud_pol_stmt
where policy_id = p_policy_id
and status_id = 1; -- 1 = Active only - for Deactivating

begin

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
-- Not Checked - Status manipulation allowed for POLICY_ID = 0

-- get aud_pol data
select status_id, type_id
into v_curr_status_id, v_type_id
from aud_pol
where policy_id = p_policy_id;

-- Check Type_Id
if v_type_id not in (1,2) then
raise_application_error(-20010, 'Unknown Type Id not in 1-Obj/2-Stmt !');
end if;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- BEGIN CHECK FOR NEW STATUS ACTIVE
if v_new_status_id = 1 then

-- Begin Check Active Obj/Stmt by Status
if v_type_id = 1 then
-- make count Pol Obj Audit
select count(*) into cnt_active_aud
from aud_pol_obj
where policy_id = p_policy_id and status_id = 1; -- 1=Active
else -- v_type_id = 2 Stmt
-- make count Pol Stmt Audit
select count(*) into cnt_active_aud
from aud_pol_stmt
where policy_id = p_policy_id and status_id = 1; -- 1=Active
end if;
-- End Check Active Obj/Stmt by Status

-- Raise if no Active Obj/Stmt Audit
if cnt_active_aud = 0 then
raise_application_error(-20010, 'Policy with no Active Object or Statement Audits cannot be set as Active !');
end if;

-- END CHECK FOR NEW STATUS ACTIVE
else  -- v_new_status_id = 0
-- Begin CHECK FOR NEW STATUS INACTIVE

-- Loop Active Obj Audits and Deactivate (Active->Inactive)
for rec_pol_obj_active in c_pol_obj_active loop
P_AUD_POL_OBJ_STAT(rec_pol_obj_active.aud_obj_id);
end loop;

-- Loop Active Stmt Audits and Deactivate (Active->Inactive)
for rec_pol_stmt_active in c_pol_stmt_active loop
P_AUD_POL_STMT_STAT(rec_pol_stmt_active.aud_stmt_id);
end loop;

end if;
-- END CHECK FOR NEW STATUS INACTIVE


-- update aud_pol status
update aud_pol set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;


end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_STMT_UPD
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_STMT_UPD (
                            p_aud_stmt_id in integer,
                            -- Statement[Privilege]
                            p_audit_option in varchar2,
                            p_audit_by_user in varchar2,
                            -- General
                            p_success_failure in integer
                            )

AS

v_policy_id                      aud_pol.policy_id%TYPE;

v_status_id                      aud_pol_stmt.status_id%TYPE;
v_audit_option                   aud_pol_stmt.audit_option%TYPE;
v_audit_by_user                  aud_pol_stmt.audit_by_user%TYPE;
v_success_failure                aud_pol_stmt.success_failure%TYPE;

cnt_aud_option_act_enb integer;

cnt_all_stmt         integer;
cnt_all_stmt_other   integer;

begin

-- Get Active Mapped Audit Action Count
select count(*) into cnt_aud_option_act_enb
from v_aud_sys_stmt_opt_act
where option_name = p_audit_option
and act_enabled = 1;
-- Raise Active Mapped Audit Action Count=0
if cnt_aud_option_act_enb = 0 then
raise_application_error(-20010, 'No Audit Action enabled for this Audit Option !');
end if;

-- Begin Check NOT EXISTS not on Success !!!
if p_audit_option = 'NOT EXISTS' then
if p_success_failure = 2 then  -- 2=Success
raise_application_error(-20010, 'NOT EXISTS cannot be audited for Success !');
end if;
end if;
-- End Check NOT EXISTS not on Success !!!


-- Get AUD Details
select
policy_id,
status_id,
audit_option,
audit_by_user,
success_failure
into
v_policy_id,
v_status_id,
v_audit_option,
v_audit_by_user,
v_success_failure
from aud_pol_stmt
where aud_stmt_id = p_aud_stmt_id;

-- No Operations on Oracle Default Audit Policy POLICY_ID = 0
if v_policy_id = 0 then
raise_application_error(-20010, 'Oracle Default Audit Policy cannot be manipulated !');
end if;

-- Update aud_pol_stmt
BEGIN

update aud_pol_stmt set

audit_option = p_audit_option,
audit_by_user = p_audit_by_user,
success_failure = p_success_failure,

user_upd = USER,
date_upd = SYSDATE

where aud_stmt_id = p_aud_stmt_id ;

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_STMT_UN') <> 0 then
raise_application_error(-20010, 'Statement Audit already in use for this User and Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Begin Handle ALL STATEMENTS vs Others
-- Handle AFTER Action (INS/UPD)
select count(*) into cnt_all_stmt
from aud_pol_stmt
where policy_id = v_policy_id
and audit_by_user = p_audit_by_user
and audit_option = 'ALL STATEMENTS';

if cnt_all_stmt > 0 then -- if ALL STATEMENTS, then check Others

   select count(*) into cnt_all_stmt_other
   from aud_pol_stmt
   where policy_id = v_policy_id
   and audit_by_user = p_audit_by_user
   and audit_option <> 'ALL STATEMENTS'
   and audit_option not in ('CREATE SESSION');

   if cnt_all_stmt_other > 0 then
   raise_application_error(-20010, 'ALL STATEMENTS can coexist only with CREATE SESSION !');
   end if;

end if;
-- End Handle ALL STATEMENTS


-- Clear Policy from Cache
P_AUD_POL_CACHE_POL_DEL(
v_policy_id
);


-- Begin Call Audit GEN if Status Active
if v_status_id = 1 then
-- Generate Audit - Call for Update Only !!!
SYS.OMEGA_CORE_AUDIT.P_AUD_STMT_GEN (
                     p_aud_stmt_id,
                     -- Statement[Privilege] Current
                     v_audit_option,
                     v_audit_by_user,
                     v_success_failure,
                     -- Statement[Privilege] New
                     p_audit_option,
                     p_audit_by_user,
                     p_success_failure,
                     2 -- Action UPD
                     );
end if;
-- End Call Audit GEN if Status Active

end; -- end proc
/

prompt
prompt Creating procedure P_AUD_POL_UPD
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_AUD_POL_UPD (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

v_policy_name     aud_pol.policy_name%TYPE;
v_policy_desc     aud_pol.policy_desc%TYPE;

begin


-- Begin Change Elements on Oracle Default Audit Policy POLICY_ID = 0
if p_policy_id = 0 then

-- get unchanging elements
select policy_name, policy_desc
into v_policy_name, v_policy_desc
from aud_pol
where policy_id = p_policy_id;

-- Raise if Policy Name changed
if p_policy_name <> v_policy_name then
raise_application_error(-20010, 'Name of the Oracle Default Audit Policy cannot be manipulated !');
end if;
-- Raise if Policy Decription changed
if p_policy_desc <> v_policy_desc then
raise_application_error(-20010, 'Decription of the Oracle Default Audit Policy cannot be manipulated !');
end if;

end if;
-- End Change Elements on Oracle Default Audit Policy POLICY_ID = 0


-- Clear Policy from Cache
--P_AUD_POLICY_CACHE_POL_DEL(--p_policy_id);

-- Update aud_pol
BEGIN

update aud_pol set

policy_name = p_policy_name,
policy_desc = p_policy_desc,
use_cache = p_use_cache,
debug_log = p_debug_log,

user_upd = USER,
date_upd = SYSDATE

where policy_id = p_policy_id ;

EXCEPTION

WHEN DUP_VAL_ON_INDEX then
-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'AUD_POL_UN') <> 0 then
raise_application_error(-20010, 'Policy Name already in use !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


end; -- end proc
/

prompt
prompt Creating procedure P_AUD_PRIV_OBJ_NOAUDIT
prompt =========================================
prompt
create or replace procedure P_AUD_PRIV_OBJ_NOAUDIT (
                  p_obj_owner in varchar2,
                  p_obj_name in varchar2,
                  p_obj_type in varchar2,
                  p_audit_option in varchar2,
                  p_force_drop in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

v_success              varchar2(100);
v_failure              varchar2(100);

cursor c_aud_rem is select * from aud_pol_obj
where object_owner = p_obj_owner
and object_type = p_obj_type
and object_name = p_obj_name
and sql_operation = p_audit_option
and status_id = 1; -- Active;

begin

-- Check p_force_drop
if p_force_drop not in (0,1) then
raise_application_error(-20010, 'Parameter Force Delete not in 0/1 !');
end if;


-- Begin get success/failure
select success, failure
into v_success, v_failure
from v_aud_dba_obj_audit_opts_tab
where owner = p_obj_owner
and object_name = p_obj_name
and object_type = p_obj_type
and audit_option = p_audit_option;
-- End get success/failure


-- Begin Load Audit Settings
for rec_aud_rem in c_aud_rem loop

if v_success = 'BY ACCESS' and v_failure = 'BY ACCESS' then
   -- All 1-2-3 Success/Failure
   if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_OBJ_NOAUDIT (
               p_obj_owner,
               p_obj_name,
               p_obj_type,
               p_audit_option
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Object '
    || to_char(rec_aud_rem.aud_obj_id) || ' !');
    end if;

elsif v_success = 'BY ACCESS' then
    -- Success/Failure and Success
    if rec_aud_rem.success_failure in (1,2) then
    if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_OBJ_NOAUDIT (
               p_obj_owner,
               p_obj_name,
               p_obj_type,
               p_audit_option
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Object '
    || to_char(rec_aud_rem.aud_obj_id) || ' !');
    end if;
    end if;

elsif v_failure = 'BY ACCESS' then
    -- Success/Failure and Failure
    if rec_aud_rem.success_failure in (1,3) then
    if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_OBJ_NOAUDIT (
               p_obj_owner,
               p_obj_name,
               p_obj_type,
               p_audit_option
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Object '
    || to_char(rec_aud_rem.aud_obj_id) || ' !');
    end if;
    end if;

else
null; -- continue to drop
end if;

end loop;
-- End Load Audit Settings to cnt_%


-- Drop if no error/return so far
SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_OBJ_NOAUDIT (
               p_obj_owner,
               p_obj_name,
               p_obj_type,
               p_audit_option
               );

end ;
/

prompt
prompt Creating procedure P_AUD_PRIV_SYS_NOAUDIT
prompt =========================================
prompt
create or replace procedure P_AUD_PRIV_SYS_NOAUDIT (
                  p_priv in varchar2,
                  p_user in varchar2,
                  p_force_drop in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

v_username             varchar2(100);

v_success              varchar2(100);
v_failure              varchar2(100);

cursor c_aud_rem (p_aud_option in varchar2, p_aud_user in varchar2)
is select * from aud_pol_stmt
where audit_option = p_aud_option
and audit_by_user = p_aud_user
and status_id = 1; -- Active

begin

-- Check p_force_drop
if p_force_drop not in (0,1) then
raise_application_error(-20010, 'Parameter Force Delete not in 0/1 !');
end if;


-- Begin get success/failure by user (<*>)
if p_user is not null then
select success, failure
into v_success, v_failure
from v_aud_sys_dba_stmt_audit_opts
where user_name = p_user
and audit_option = p_priv;
-- Set User to Input
v_username := p_user;
else -- user is null - Oracle Default Audit Setting
select success, failure
into v_success, v_failure
from v_aud_sys_dba_stmt_audit_opts
where user_name is null
and audit_option = p_priv;
-- Set User to Oracle Default - All
v_username := '<*>';
end if;
-- End get success/failure by user (<*>)


-- Begin Load Audit Settings
for rec_aud_rem in c_aud_rem(p_priv, v_username) loop

if v_success = 'BY ACCESS' and v_failure = 'BY ACCESS' then
   -- All 1-2-3 Success/Failure
   if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_SYS_NOAUDIT (
               p_priv,
               p_user
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Statement '
    || to_char(rec_aud_rem.aud_stmt_id) || ' !');
    end if;

elsif v_success = 'BY ACCESS' then
    -- Success/Failure and Success
    if rec_aud_rem.success_failure in (1,2) then
    if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_SYS_NOAUDIT (
               p_priv,
               p_user
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Statement '
    || to_char(rec_aud_rem.aud_stmt_id) || ' !');
    end if;
    end if;

elsif v_failure = 'BY ACCESS' then
    -- Success/Failure and Failure
    if rec_aud_rem.success_failure in (1,3) then
    if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_SYS_NOAUDIT (
               p_priv,
               p_user
               );
               Return; -- return and finish proc !
    else -- p_force_drop = 0
    raise_application_error(-20010, 'Oracle audit setting bound to AUD Statement '
    || to_char(rec_aud_rem.aud_stmt_id) || ' !');
    end if;
    end if;

else
null; -- continue to drop
end if;

end loop;
-- End Load Audit Settings to cnt_%


-- Drop if no error/return so far
SYS.OMEGA_CORE_AUDIT.P_AUD_PRIV_SYS_NOAUDIT (
               p_priv,
               p_user
               );

end ;
/

prompt
prompt Creating procedure P_ITS_CLASS_DEL
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_CLASS_DEL(
                            p_class_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Class CLASS_ID = 0
if p_class_id = 0 then
raise_application_error(-20010, 'UNMARKED Class cannot be manipulated !');
end if;


-- Make Delete
delete from its_class
where class_id = p_class_id ;

end; -- end proc
/

prompt
prompt Creating procedure P_ITS_CLASS_INS
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_CLASS_INS(
                            p_class_name in varchar2,
                            p_class_desc in varchar2
                            )

AS

begin

-- Make Insert
BEGIN
insert into its_class (
class_id, class_name, class_desc )
values (
seq_its_class.nextval, p_class_name, p_class_desc );
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Class already declared !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ITS_CLASS_UPD
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_CLASS_UPD(
                            p_class_id in integer,
                            p_class_name in varchar2,
                            p_class_desc in varchar2
                            )

AS

begin

-- No Operations on UNMARKED Class CLASS_ID = 0
if p_class_id = 0 then
raise_application_error(-20010, 'UNMARKED Class cannot be manipulated !');
end if;


-- Make Update
BEGIN
update its_class set

class_name = p_class_name,
class_desc = p_class_desc,

date_upd = SYSDATE,
user_upd = USER

where class_id = p_class_id ;
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Class already declared !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ITS_GROUP_DEL
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_GROUP_DEL(
                            p_group_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Group GROUP_ID = 0
if p_group_id = 0 then
raise_application_error(-20010, 'UNMARKED Group cannot be manipulated !');
end if;


-- Make Delete
delete from its_group
where group_id = p_group_id ;

end; -- end proc
/

prompt
prompt Creating procedure P_ITS_GROUP_INS
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_GROUP_INS(
                            p_group_name in varchar2,
                            p_group_desc in varchar2,
                            p_class_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Class CLASS_ID = 0
if p_class_id = 0 then
raise_application_error(-20010, 'UNMARKED Class cannot be manipulated !');
end if;


-- Make Insert
BEGIN
insert into its_group (
group_id, group_name, group_desc, class_id )
values (
seq_its_group.nextval, p_group_name, p_group_desc, p_class_id );
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Group already declared !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ITS_GROUP_UPD
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_GROUP_UPD(
                            p_group_id in integer,
                            p_group_name in varchar2,
                            p_group_desc in varchar2,
                            p_class_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Group GROUP_ID = 0
if p_group_id = 0 then
raise_application_error(-20010, 'UNMARKED Group cannot be manipulated !');
end if;

-- No Operations on UNMARKED Class CLASS_ID = 0
if p_class_id = 0 then
raise_application_error(-20010, 'UNMARKED Class cannot be manipulated !');
end if;


-- Make Update
BEGIN
update its_group set

group_name = p_group_name,
group_desc = p_group_desc,
class_id = p_class_id,

date_upd = SYSDATE,
user_upd = USER

where group_id = p_group_id ;
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Group already declared !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ITS_ISSUE_DEL
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_ISSUE_DEL(
                            p_issue_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Issue ISSUE_ID = 0
if p_issue_id = 0 then
raise_application_error(-20010, 'UNMARKED Issue cannot be manipulated !');
end if;


-- Make Delete
delete from its_issue
where issue_id = p_issue_id ;

end; -- end proc
/

prompt
prompt Creating procedure P_ITS_ISSUE_INS
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_ISSUE_INS(
                            p_issue_name in varchar2,
                            p_issue_desc in varchar2,
                            p_group_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Group GROUP_ID = 0
if p_group_id = 0 then
raise_application_error(-20010, 'UNMARKED Group cannot be manipulated !');
end if;


-- Make Insert
BEGIN
insert into its_issue (
issue_id, issue_name, issue_desc, group_id )
values (
seq_its_issue.nextval, p_issue_name, p_issue_desc, p_group_id );
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Issue already declared !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_ITS_ISSUE_UPD
prompt ==================================
prompt
CREATE OR REPLACE PROCEDURE P_ITS_ISSUE_UPD(
                            p_issue_id in integer,
                            p_issue_name in varchar2,
                            p_issue_desc in varchar2,
                            p_group_id in integer
                            )

AS

begin

-- No Operations on UNMARKED Issue ISSUE_ID = 0
if p_issue_id = 0 then
raise_application_error(-20010, 'UNMARKED Issue cannot be manipulated !');
end if;

-- No Operations on UNMARKED Group GROUP_ID = 0
if p_group_id = 0 then
raise_application_error(-20010, 'UNMARKED Group cannot be manipulated !');
end if;


-- Make Update
BEGIN
update its_issue set

issue_name = p_issue_name,
issue_desc = p_issue_desc,
group_id = p_group_id,

date_upd = SYSDATE,
user_upd = USER

where issue_id = p_issue_id ;
EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Issue already declared !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_COL_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_COL_DEL (
                            p_column_id in integer
				                    )

as

v_report_id         rpt_rep_col.report_id%TYPE;
v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Get Report ID
select report_id into v_report_id
from rpt_rep_col
where column_id = p_column_id;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot delete column, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = v_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Native reports columns cannot be deleted !' );
end if;
-- End Check Report Native


-- delete rpt_rep_col
delete rpt_rep_col
where column_id = p_column_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_COL_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_COL_INS (
                            p_report_id in integer,
                            p_column_name in varchar2,
                            p_col_data_type in varchar2,
                            p_column_caption in varchar2,
                            p_search_field in integer,
                            p_search_order in integer,
                            p_search_active in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2
				                    )

as

v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(p_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot insert column, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = p_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Cannot insert column on Native reports !' );
end if;
-- End Check Report Native


-- insert rpt_rep_col
BEGIN

insert into rpt_rep_col
(
column_id,
report_id,
column_name,
col_data_type,
column_caption,
search_field,
search_order,
search_active,
opr_code_id,
operand_1,
operand_2
)
values
(
SEQ_RPT_REP_COL.nextval,
p_report_id,
p_column_name,
p_col_data_type,
p_column_caption,
p_search_field,
p_search_order,
p_search_active,
p_opr_code_id,
p_operand_1,
p_operand_2
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Column Name already exists for this report !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_COL_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_COL_UPD (
                            p_column_id in integer,
                            p_column_name in varchar2,
                            p_col_data_type in varchar2,
                            p_column_caption in varchar2,
                            p_search_field in integer,
                            p_search_order in integer,
                            p_search_active in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2
				                    )

as

v_report_id         rpt_rep_col.report_id%TYPE;
v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Get Report ID
select report_id into v_report_id
from rpt_rep_col where column_id = p_column_id;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot update column, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = v_report_id;


-- update rpt_rep_col
BEGIN

-- Begin Make Report [non] Native
if v_rep_native = 0 then -- 0 = Report non-Native

update rpt_rep_col set

column_name = p_column_name,
col_data_type = p_col_data_type,
column_caption = p_column_caption,
search_field = p_search_field,
search_order = p_search_order,
search_active = p_search_active,
opr_code_id = p_opr_code_id,
operand_1 = p_operand_1,
operand_2 = p_operand_2,

date_upd = SYSDATE,
user_upd = USER

where column_id = p_column_id;

else -- 1 = Report Native

update rpt_rep_col set

search_field = p_search_field,
search_order = p_search_order,
search_active = p_search_active,
opr_code_id = p_opr_code_id,
operand_1 = p_operand_1,
operand_2 = p_operand_2,

date_upd = SYSDATE,
user_upd = USER

where column_id = p_column_id;

end if;
-- End Make Report [non] Native

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Column Name already exists for this report !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_CURRVAL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_CURRVAL (
                            p_report_id OUT integer
                            )

AS
-- Called Only after inserting into rpt_rep
-- to avoid
-- ORA-08002 - sequence <SEQ_NAME> not yet defined in this session

-- for reference by table only
v_ref_only   rpt_rep.report_id%TYPE;

BEGIN

  -- get data
  select SEQ_RPT_REP.currval into p_report_id from dual;

END ;
/

prompt
prompt Creating procedure P_RPT_REP_DEL
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_DEL (
                            p_report_id in integer
				                    )

as

v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(p_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot delete report, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = p_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Native reports cannot be deleted !' );
end if;
-- End Check Report Native


-- delete report privileges
delete from rpt_rep_prv
where report_id = p_report_id;

-- delete rpt_rep_col
delete from rpt_rep_col
where report_id = p_report_id;

-- delete rpt_rep_prm
delete from rpt_rep_prm
where report_id = p_report_id;

-- delete rpt_rep
delete from rpt_rep
where report_id = p_report_id;


end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_INS
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_INS (
                            p_profile_id in integer,
                            p_report_name in varchar2,
                            p_report_desc in varchar2,
                            p_report_base_sql in clob,
                            p_report_component in clob,
                            p_report_link in clob
				                    )

as

-- Omega CA User Roles cursor
cursor C_Omega_User_Role is select * from v_omegaca_user_role t
where t.grantee = USER
and t.granted_role <> 'OMEGACA_ADMIN';

v_rpt_rep_id  rpt_rep.report_id%TYPE;

begin


-- insert rpt_rep
BEGIN

insert into rpt_rep
(
report_id,
profile_id,
report_name,
report_desc,
report_base_sql,
report_component,
report_link,
rep_native
)
values
(
SEQ_RPT_REP.nextval,
p_profile_id,
p_report_name,
p_report_desc,
p_report_base_sql,
p_report_component,
p_report_link,
0 -- 0 non-Native (Client) Report
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Report Name already exists !' );
END;


-- Get Newly inserted Rep ID
select seq_rpt_rep.currval into v_rpt_rep_id from dual;


-- Begin Make Privileges

-- Insert OMEGACA_ADMIN - 2-RW
insert into rpt_rep_prv
(rep_priv_id, report_id, priv_role, priv_id)
values
(SEQ_RPT_REP_PRV.Nextval, v_rpt_rep_id, 'OMEGACA_ADMIN', 2);

-- Insert 2-RW for User's Omega CA Roles other then OMEGACA_ADMIN
for rec_omega_user_roles in C_Omega_User_Role loop
insert into rpt_rep_prv
(rep_priv_id, report_id, priv_role, priv_id)
values
(SEQ_RPT_REP_PRV.Nextval, v_rpt_rep_id, rec_omega_user_roles.granted_role, 2);
end loop;

-- End Make Privileges


end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRM_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRM_DEL (
                            p_param_id in integer
				                    )

as

v_report_id         rpt_rep_prm.report_id%TYPE;
v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Get Report ID
select report_id into v_report_id
from rpt_rep_prm where param_id = p_param_id;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot delete parameter, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = v_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Native reports parameters cannot be deleted !' );
end if;
-- End Check Report Native


-- delete rpt_rep_prm
delete rpt_rep_prm
where param_id = p_param_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRM_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRM_INS (
                            p_report_id in integer,
                            p_param_name in varchar2,
                            p_param_data_type in varchar2,
                            p_param_display_type in varchar2,
                            p_param_caption in varchar2,
                            p_time_end in integer
				                    )

as

v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(p_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot insert parameter, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = p_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Cannot insert parameter in Native reports !' );
end if;
-- End Check Report Native


-- insert rpt_rep_prm
BEGIN

insert into rpt_rep_prm
(
param_id,
report_id,
param_name,
param_data_type,
param_display_type,
param_caption,
time_end
)
values
(
seq_rpt_rep_prm.nextval,
p_report_id,
p_param_name,
p_param_data_type,
p_param_display_type,
p_param_caption,
p_time_end
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Parameter Name already exists for this report !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRM_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRM_UPD (
                            p_param_id in integer,
                            p_param_name in varchar2,
                            p_param_data_type in varchar2,
                            p_param_display_type in varchar2,
                            p_param_caption in varchar2,
                            p_time_end in integer
				                    )

as

v_report_id         rpt_rep_prm.report_id%TYPE;
v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Get Report ID
select report_id into v_report_id
from rpt_rep_prm where param_id = p_param_id;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot update parameter, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission


-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = v_report_id;

-- Begin Check Report Native
if v_rep_native = 1 then
raise_application_error(-20010, 'Native reports parameters cannot be modified !' );
end if;
-- End Check Report Native


-- update rpt_rep_prm
BEGIN

update rpt_rep_prm set

param_name = p_param_name,
param_data_type = p_param_data_type,
param_display_type = p_param_display_type,
param_caption = p_param_caption,
time_end = p_time_end,

date_upd = SYSDATE,
user_upd = USER

where param_id = p_param_id;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Parameter Name already exists for this report !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRV_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRV_DEL (
                            p_rep_priv_id in integer
				                    )

as

v_report_id         rpt_rep_prv.report_id%TYPE;
v_priv_role         rpt_rep_prv.priv_role%TYPE;

begin

-- Get Report Data
select report_id, priv_role
into v_report_id, v_priv_role
from rpt_rep_prv
where rep_priv_id = p_rep_priv_id;

-- No Change of OMEGACA_ADMIN
if v_priv_role = 'OMEGACA_ADMIN' then
raise_application_error(-20010, 'No operations allowed on built-in role Administrator !' );
end if;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot delete privilege, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission


-- Delete Report Privilege
delete from rpt_rep_prv
where rep_priv_id = p_rep_priv_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRV_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRV_INS (
                            p_report_id in integer,
                            p_priv_role in varchar2,
                            p_priv_id in integer
				                    )

as

begin

-- No Change of OMEGACA_ADMIN
if p_priv_role = 'OMEGACA_ADMIN' then
raise_application_error(-20010, 'No operations allowed on built-in role Administrator !' );
end if;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(p_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot insert privilege, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission


-- Insert Report Privilege
BEGIN

insert into rpt_rep_prv
(
rep_priv_id,
report_id,
priv_role,
priv_id
)
values
(
SEQ_RPT_REP_PRV.Nextval,
p_report_id,
p_priv_role,
p_priv_id
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Role privilege already exists for this report !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_PRV_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_PRV_UPD (
                            p_rep_priv_id in integer,
                            p_priv_role in varchar2,
                            p_priv_id in integer
				                    )

as

v_report_id         rpt_rep_prv.report_id%TYPE;
v_priv_role         rpt_rep_prv.priv_role%TYPE;

begin

-- Get Report Data
select report_id, priv_role
into v_report_id, v_priv_role
from rpt_rep_prv
where rep_priv_id = p_rep_priv_id;


-- No Change of OMEGACA_ADMIN
if p_priv_role = 'OMEGACA_ADMIN'
or v_priv_role = 'OMEGACA_ADMIN' then
raise_application_error(-20010, 'No operations allowed on built-in role Administrator !' );
end if;

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(v_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot update privilege, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission


-- Update Report Privilege
BEGIN

update rpt_rep_prv set

priv_role = p_priv_role,
priv_id = p_priv_id,

date_upd = SYSDATE,
user_upd = USER

where rep_priv_id = p_rep_priv_id;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Role privilege already exists for this report !' );
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RPT_REP_UPD
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_RPT_REP_UPD (
                            p_report_id in integer,
                            p_profile_id in integer,
                            p_report_name in varchar2,
                            p_report_desc in varchar2,
                            p_report_base_sql in clob,
                            p_report_component in clob,
                            p_report_link in clob
				                    )

as

v_rep_native        rpt_rep.rep_native%TYPE;

begin

-- Begin Check Report Write Permission
-- 2 - RW - Read-Write Privilege
if F_RPT_REP_MOD_ACCESS(p_report_id, 2) <> 1 then
raise_application_error(-20010, 'Cannot update report, no Write Permission on this report !' );
end if;
-- End Check Report Write Permission

-- Get Report Data
select rep_native into v_rep_native
from rpt_rep
where report_id = p_report_id;


-- update rpt_rep
BEGIN

-- Begin Make Report [non] Native
if v_rep_native = 0 then -- 0 = Report non-Native

update rpt_rep set

profile_id = p_profile_id,
report_name = p_report_name,
report_desc = p_report_desc,
report_base_sql = p_report_base_sql,
report_component = p_report_component,
report_link = p_report_link,

date_upd = SYSDATE,
user_upd = USER

where report_id = p_report_id;

else -- 1 = Report Native

update rpt_rep set

report_component = p_report_component,
report_link = p_report_link,

date_upd = SYSDATE,
user_upd = USER

where report_id = p_report_id;

end if;
-- End Make Report [non] Native

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Report Name already exists !' );
when OTHERS then
RAISE;
END;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_AREA_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_AREA_DEL (
                            p_policy_id in integer,
                            p_area_factor in varchar2
                            )

AS

begin

-- delete rtp_ddl_pol_area
delete from rtp_ddl_pol_area
where policy_id = p_policy_id
and area_factor = p_area_factor;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_AREA_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_AREA_INS (
                            p_pol_mode in integer,
                            p_policy_id in integer,
                            p_area_factor in varchar2,
                            p_opr_code in varchar2,
                            p_operand in varchar2
                            )

AS

v_policy_id   rtp_ddl_pol.policy_id%TYPE;

begin

-- Check Pol Mode
if p_pol_mode not in (1,2) then
raise_application_error(-20010, 'Unknown DDL Policy Mode, not in 1-New, 2-Existing !');
end if;

-- Make Policy ID by Pol Mode
if p_pol_mode = 1 then -- New
select seq_rtp_ddl_pol.currval
into v_policy_id
from dual;
else -- Existing
v_policy_id := p_policy_id;
end if;

-- Check Area Factor
if  p_area_factor not in ('OBJ_OWNER','OBJ_NAME','OBJ_TYPE','DDL_EVENT') then
raise_application_error(-20010, 'Unknown DDL Policy Area Factor !');
end if;

-- Check Opr Code
if p_opr_code not in ('=','<>','LIKE','NOT LIKE','IS NULL','IS NOT NULL','IN','NOT IN') then
raise_application_error(-20010, 'Unknown DDL Policy Area Operand !');
end if;

-- Check NULL Operand for non IS [NOT] NULL
if p_opr_code not in ('IS NULL', 'IS NOT NULL') then
-- Raise if null on non IS [NOT] NULL
if p_operand is null then
raise_application_error(-20010, 'Operand must be completed !');
end if;
end if;


-- Insert rtp_ddl_pol_area
BEGIN

insert into rtp_ddl_pol_area
(
policy_id,
area_factor,
opr_code,
operand

)
values
(
v_policy_id,
p_area_factor,
p_opr_code,
p_operand
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Area Factor already in use for the Policy !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_AREA_UPD
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_AREA_UPD (
                            p_policy_id in integer,
                            p_area_factor in varchar2,
                            p_opr_code in varchar2,
                            p_operand in varchar2
                            )

AS

begin

-- Check Area Factor
if  p_area_factor not in ('OBJ_OWNER','OBJ_NAME','OBJ_TYPE','DDL_EVENT') then
raise_application_error(-20010, 'Unknown DDL Policy Area Factor !');
end if;

-- Check Opr Code
if p_opr_code not in ('=','<>','LIKE','NOT LIKE','IS NULL','IS NOT NULL','IN','NOT IN') then
raise_application_error(-20010, 'Unknown DDL Policy Area Operand !');
end if;

-- Check NULL Operand for non IS [NOT] NULL
if p_opr_code not in ('IS NULL', 'IS NOT NULL') then
-- Raise if null on non IS [NOT] NULL
if p_operand is null then
raise_application_error(-20010, 'Operand must be completed !');
end if;
end if;


-- Update rtp_ddl_pol_area
update rtp_ddl_pol_area set

opr_code = p_opr_code,
operand = p_operand,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id
and area_factor = p_area_factor;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_CACHE_DEL
prompt ==========================================
prompt
create or replace procedure P_RTP_DDL_POL_CACHE_DEL (
                            p_row_id in varchar2
                            )

as


begin

-- Delete rtp_ddl_pol_cache
delete from rtp_ddl_pol_cache
where rowid = CHARTOROWID(p_row_id);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_CACHE_POL_DEL
prompt ==============================================
prompt
create or replace procedure P_RTP_DDL_POL_CACHE_POL_DEL (
                            p_policy_id in integer
                            )

as


begin

-- Delete rtp_ddl_pol_cache
delete from rtp_ddl_pol_cache
where policy_id = p_policy_id;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_DEL (
                            p_cond_id in integer
                            )

AS

v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin

-- delete rtp_ddl_pol_cond_list
delete from rtp_ddl_pol_cond_list
where cond_id = p_cond_id;

-- Get Rule Id before Condition delete
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = p_cond_id;

-- delete rtp_ddl_pol_cond
delete from rtp_ddl_pol_cond
where cond_id = p_cond_id;

-- get policy
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;
-- Clear Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_INS (
                            p_rule_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;

v_policy_id                 rtp_ddl_pol_rule.policy_id%TYPE;

begin

-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Set Inactive only for Operand - IN, NOT IN
--v_status_id := 0;

-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR


-- Insert rtp_ddl_pol_cond
insert into rtp_ddl_pol_cond
(
cond_id,
rule_id,
factor_id,
opr_code_id,
operand_1,
operand_2,
cond_eval,
min_trust_level_no,
validate_expr_owner,
validate_expr_object,
status_id
)
values
(
seq_rtp_ddl_pol_cond.nextval,
p_rule_id,
p_factor_id,
p_opr_code_id,
p_operand_1,
p_operand_2,
p_cond_eval,
p_min_trust_level_no,
p_validate_expr_owner,
p_validate_expr_object,
p_status_id
);


-- get policy for cache
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = p_rule_id;
-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);



end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_LIST_DEL
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_LIST_DEL (
                            p_list_id in integer
                            )

AS

v_cond_id      rtp_ddl_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin



-- Get Cond ID
select cond_id into v_cond_id
from rtp_ddl_pol_cond_list
where list_id = p_list_id;
-- Get Rule ID
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = v_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


-- Delete rtp_ddl_pol_cond_list
delete from rtp_ddl_pol_cond_list
where list_id = p_list_id;



end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_LIST_INS
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_LIST_INS (
                            p_cond_id in integer,
                            p_operand_1 in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_id          rtp_ddl_pol_cond.opr_code_id%TYPE;

v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin

select opr_code_id into v_opr_code_id
from rtp_ddl_pol_cond where cond_id = p_cond_id;

if v_opr_code_id not in (12, 13) then
raise_application_error(-20010, 'Operation Code must be only IN/NOT IN !');
end if;


-- Insert rtp_ddl_pol_cond_list
insert into rtp_ddl_pol_cond_list
(
list_id,
cond_id,
operand_1,
status_id
)
values
(
seq_rtp_ddl_pol_cond_list.nextval,
p_cond_id,
p_operand_1,
p_status_id
);



-- Get Rule ID
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = p_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);



end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_LIST_STAT
prompt ===============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_LIST_STAT (
                            p_list_id in integer
                            )

AS

v_curr_status_id      rtp_ddl_pol_cond_list.status_id%TYPE;
v_new_status_id       rtp_ddl_pol_cond_list.status_id%TYPE;

v_cond_id      rtp_ddl_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin

-- get List Condition data
select cond_id, status_id into v_cond_id, v_curr_status_id
from rtp_ddl_pol_cond_list
where list_id = p_list_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Update rtp_ddl_pol_cond_list status
update rtp_ddl_pol_cond_list set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where list_id = p_list_id;



-- Get Rule ID
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = v_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_LIST_UPD
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_LIST_UPD (
                            p_list_id in integer,
                            p_operand_1 in varchar2
                            )

AS

v_cond_id      rtp_ddl_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin


-- Update rtp_ddl_pol_cond_list
update rtp_ddl_pol_cond_list set

operand_1 = p_operand_1,

date_upd = SYSDATE,
user_upd = USER

where list_id = p_list_id;



-- Get Cond ID
select cond_id into v_cond_id
from rtp_ddl_pol_cond_list
where list_id = p_list_id;
-- Get Rule ID
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = v_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);



end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_STAT
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_STAT (
                            p_cond_id in integer
                            )

AS

v_curr_status_id      rtp_ddl_pol_cond.status_id%TYPE;
v_new_status_id       rtp_ddl_pol_cond.status_id%TYPE;

v_cond_eval           rtp_ddl_pol_cond.cond_eval%TYPE;
v_opr_code_id         rtp_ddl_pol_cond.opr_code_id%TYPE;
v_opr_code_symbol     sys_operation_code.code_group%TYPE;
cnt_in_list           integer;

v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin

-- get condition data
select status_id, opr_code_id, cond_eval
into v_curr_status_id, v_opr_code_id, v_cond_eval
from rtp_ddl_pol_cond
where cond_id = p_cond_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;



-- BEGIN CHECK IN (NOT IN) list
if v_cond_eval = 1 then -- 1 = Operand

-- get opr_code symbol
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = v_opr_code_id;

if v_opr_code_symbol in ('IN', 'NOT IN') then

if v_new_status_id = 1 then
select count(*) into cnt_in_list from rtp_ddl_pol_cond_list
where cond_id = p_cond_id and status_id = 1;
if cnt_in_list = 0 then
raise_application_error(-20010, 'At least one active operand must be active in the IN (NOT IN) list for this condition to be active !');
end if;
end if;

end if;

end if;
-- END CHECK IN (NOT IN) list



-- Update rtp_ddl_pol_cond status
update rtp_ddl_pol_cond set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where cond_id = p_cond_id;


-- Get Rule ID
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = p_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COND_UPD
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COND_UPD (
                            p_cond_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;

v_rule_id      rtp_ddl_pol_cond.rule_id%TYPE;
v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;

begin


-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR



-- update rtp_ddl_pol_cond
update rtp_ddl_pol_cond set

factor_id = p_factor_id,
opr_code_id = p_opr_code_id,
operand_1 = p_operand_1,
operand_2 = p_operand_2,
cond_eval = p_cond_eval,
min_trust_level_no = p_min_trust_level_no,
validate_expr_owner = p_validate_expr_owner,
validate_expr_object = p_validate_expr_object,

date_upd = SYSDATE,
user_upd = USER

where cond_id = p_cond_id;


-- Get Rule Id
select rule_id into v_rule_id
from rtp_ddl_pol_cond
where cond_id = p_cond_id;
-- Get Policy Id
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_INS (
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_audit_option in integer,
                            p_user_apply in integer,
                            p_rule_eval in integer,
                            p_silent_deny in integer,
                            p_use_cache in integer,
                            p_debug_log in integer,
                            p_log_ddl_body in integer,
                            p_log_cmd in integer
                            )

AS

begin

-- Insert rtp_ddl_pol
BEGIN

insert into rtp_ddl_pol
(
policy_id,
policy_name,
policy_desc,
audit_option,
user_apply,
rule_eval,
silent_deny,
use_cache,
debug_log,
log_ddl_body,
log_cmd

)
values
(
seq_rtp_ddl_pol.nextval,
p_policy_name,
p_policy_desc,
p_audit_option,
p_user_apply,
p_rule_eval,
p_silent_deny,
p_use_cache,
p_debug_log,
p_log_ddl_body,
p_log_cmd
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_RULE_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_RULE_INS (
                            p_policy_id in number,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_status_id in integer
                            )

AS

begin


-- Insert rtp_ddl_pol_rule
BEGIN

insert into rtp_ddl_pol_rule
(
rule_id,
policy_id,
rule_name,
rule_desc,
cond_eval,
status_id
)
values
(
seq_rtp_ddl_pol_rule.nextval,
p_policy_id,
p_rule_name,
p_rule_desc,
p_cond_eval,
p_status_id
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Rule name already in this Policy !');
END;


-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
p_policy_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_COPY
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_COPY (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2
                            )

AS

v_rule_eval        rtp_ddl_pol.rule_eval%TYPE;
v_audit_option     rtp_ddl_pol.audit_option%TYPE;
v_debug_log        rtp_ddl_pol.debug_log%TYPE;
v_user_apply       rtp_ddl_pol.user_apply%TYPE;
v_use_cache        rtp_ddl_pol.use_cache%TYPE;
v_silent_deny      rtp_ddl_pol.silent_deny%TYPE;
v_log_ddl_body     rtp_ddl_pol.log_ddl_body%TYPE;
v_log_cmd          rtp_ddl_pol.log_cmd%TYPE;

/*
-- Area
v_obj_owner        rtp_ddl_pol.obj_owner%TYPE;
v_obj_name         rtp_ddl_pol.obj_name%TYPE;
v_obj_type         rtp_ddl_pol.obj_type%TYPE;
v_ddl_event        rtp_ddl_pol.ddl_event%TYPE;
*/

v_policy_id        rtp_ddl_pol.policy_id%TYPE;
v_rule_id          rtp_ddl_pol_rule.rule_id%TYPE;
v_cond_id          rtp_ddl_pol_cond.cond_id%TYPE;


cursor C_Rule is select * from rtp_ddl_pol_rule t
where policy_id = p_policy_id
order by t.rule_id;

cursor C_Cond (Rul_Id in integer) is select * from rtp_ddl_pol_cond t
where rule_id = Rul_Id
order by t.cond_id;

cursor C_Cond_List (Cnd_Id in integer) is select * from rtp_ddl_pol_cond_list t
where cond_id = Cnd_Id
order by t.list_id;

begin

-- Get Original policy data
select
rule_eval, audit_option,
debug_log, user_apply, use_cache,
silent_deny, log_ddl_body, log_cmd
-- Area
--obj_owner, obj_name, obj_type, ddl_event
into
v_rule_eval, v_audit_option,
v_debug_log, v_user_apply, v_use_cache,
v_silent_deny, v_log_ddl_body, v_log_cmd
-- Area
--v_obj_owner, v_obj_name, v_obj_type, v_ddl_event
from rtp_ddl_pol
where policy_id = p_policy_id;


-- Insert New Policy
P_RTP_DDL_POL_INS(
p_policy_name,
p_policy_desc,
v_audit_option,
v_user_apply,
v_rule_eval,
v_silent_deny,
v_use_cache,
v_debug_log,
v_log_ddl_body,
v_log_cmd
);

-- Get New inserted Policy_Id
select seq_rtp_ddl_pol.currval into v_policy_id from sys.dual;

-- Begin Loop Rule
for Rec_Rule in C_Rule loop


-- Insert Rule
P_RTP_DDL_POL_RULE_INS(
v_policy_id,
Rec_Rule.Rule_Name,
Rec_Rule.Rule_Desc,
Rec_Rule.Cond_Eval,
Rec_Rule.Status_Id
);


-- Get New inserted Rule_Id, needed for cond insert
select seq_rtp_ddl_pol_rule.currval into v_rule_id from sys.dual;

    -- Begin Loop Condition
    for Rec_Cond in C_Cond(Rec_Rule.Rule_Id) loop

    -- Insert Condition
    P_RTP_DDL_POL_COND_INS(
    v_rule_id,
    Rec_Cond.Factor_Id,
    Rec_Cond.Cond_Eval,
    Rec_Cond.Opr_Code_Id,
    Rec_Cond.Operand_1,
    Rec_Cond.Operand_2,
    Rec_Cond.Min_Trust_Level_No,
    Rec_Cond.Validate_Expr_Owner,
    Rec_Cond.Validate_Expr_Object,
    Rec_Cond.Status_Id
    );

    -- Get New inserted Cond_Id
    select seq_rtp_ddl_pol_cond.currval into v_cond_id from sys.dual;

              -- Begin Loop Condition List
              for Rec_Cond_List in C_Cond_List(Rec_Cond.Cond_Id) loop

              -- Insert Condition List
              P_RTP_DDL_POL_COND_LIST_INS(
              v_cond_id,
              Rec_Cond_List.Operand_1,
              Rec_Cond_List.Status_Id
              );

              end loop;
              -- End Loop Condition List

    end loop;
    -- End Loop Condition

end loop;
-- End Loop Rule


-- insert user_apply
insert into rtp_ddl_pol_user
(policy_id, user_id, user_apply)
select v_policy_id, user_id, user_apply
from rtp_ddl_pol_user
where policy_id = p_policy_id;

-- insert rtp_ddl_pol_area
insert into rtp_ddl_pol_area
(policy_id, area_factor, opr_code, operand)
select v_policy_id, area_factor, opr_code, operand
from rtp_ddl_pol_area
where policy_id = p_policy_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_RULE_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_RULE_DEL (
                            p_rule_id in integer
                            )

AS

-- Condition Cursor
cursor C_Cond is select * from rtp_ddl_pol_cond
where rule_id = p_rule_id;

v_policy_id           rtp_ddl_pol_rule.policy_id%TYPE;

begin

-- Begin loop Conditions
for Rec in C_Cond loop

    P_RTP_DDL_POL_COND_DEL(
    Rec.Cond_Id
    );

end loop;
-- End loop Conditions


-- Get Policy ID
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = p_rule_id;
-- Clear Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);

-- delete rtp_ddl_pol_rule
delete from rtp_ddl_pol_rule
where rule_id = p_rule_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_DEL (
                            p_policy_id in integer
                            )

AS

-- Rule Cursor
cursor C_Rule is select * from rtp_ddl_pol_rule
where policy_id = p_policy_id;

begin

-- Begin Loop Policy Rules
for Rec_Rule in C_Rule loop

-- Delete rtp_ddl_pol_rule
P_RTP_DDL_POL_RULE_DEL(
Rec_Rule.Rule_Id
);

end loop;
-- End Loop Policy Rules


-- delete rtp_ddl_pol_user
delete from rtp_ddl_pol_user
where policy_id = p_policy_id;

-- delete rtp_ddl_pol_area
delete from rtp_ddl_pol_area
where policy_id = p_policy_id;

-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
p_policy_id
);

-- delete rtp_ddl_pol
delete from rtp_ddl_pol
where policy_id = p_policy_id;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_RULE_STAT
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_RULE_STAT (
                            p_rule_id in integer
                            )

AS

v_curr_status_id          rtp_ddl_pol_rule.status_id%TYPE;
v_new_status_id           rtp_ddl_pol_rule.status_id%TYPE;

cnt_active_cond           integer;

v_policy_id               rtp_ddl_pol_rule.policy_id%TYPE;


begin


-- get rule data
select policy_id, status_id
into v_policy_id, v_curr_status_id
from rtp_ddl_pol_rule
where rule_id = p_rule_id;


-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- begin check active Conditions when new status Active
if v_new_status_id = 1 then

-- make condition count
select count(*) into cnt_active_cond
from rtp_ddl_pol_cond
where rule_id = p_rule_id
and status_id = 1; -- 1=Active

-- evaluate and raise
if cnt_active_cond = 0 then
raise_application_error(-20010, 'Rule with no Active Conditions cannot be set as Active !');
end if;

end if;
-- end check active Conditions when new status Active



-- update rtp_ddl_pol_rule status
update rtp_ddl_pol_rule set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;


-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);



end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_RULE_UPD
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_RULE_UPD (
                            p_rule_id in integer,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_formula in varchar2
                            )

AS


v_policy_id    rtp_ddl_pol_rule.policy_id%TYPE;


begin

-- get policy_id for cache !!!!
select policy_id into v_policy_id
from rtp_ddl_pol_rule
where rule_id = p_rule_id;


-- update rtp_ddl_pol_rule
BEGIN

update rtp_ddl_pol_rule set

rule_name = p_rule_name,
rule_desc = p_rule_desc,
cond_eval = p_cond_eval,
formula = p_formula,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Rule name already in this Policy !');
END;



-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
v_policy_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_STAT
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_STAT (
                            p_policy_id in integer
                            )

AS

v_curr_status_id      rtp_ddl_pol.status_id%TYPE;
v_new_status_id       rtp_ddl_pol.status_id%TYPE;

cnt_active_rule       integer;

v_user_apply          rtp_ddl_pol.user_apply%TYPE;
cnt_pol_user          integer;

begin

-- get rtp_ddl_pol data
select status_id, user_apply
into v_curr_status_id, v_user_apply
from rtp_ddl_pol where policy_id = p_policy_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- BEGIN CHECK FOR NEW STATUS ACTIVE
if v_new_status_id = 1 then

-- make count Active Rules
select count(*) into cnt_active_rule from rtp_ddl_pol_rule
where policy_id = p_policy_id and status_id = 1; -- 1=Active
-- Raise if no Active Rule
if cnt_active_rule = 0 then
raise_application_error(-20010, 'Policy with no Active Rules cannot be set as Active !');
end if;

-- Begin check Users Apply
if v_user_apply = 1 then
-- Count Users Apply
select count(*) into cnt_pol_user
from rtp_ddl_pol_user
where policy_id = p_policy_id and user_apply = 1; -- 1 Users Apply
-- Raise if no Users Apply
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Apply with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Apply

-- Begin check Users Exclude
if v_user_apply = 2 then
-- Count Users Exclude
select count(*) into cnt_pol_user
from rtp_ddl_pol_user
where policy_id = p_policy_id and user_apply = 2; -- 2 Users Exclude
-- Raise if no Users Exclude
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Exclude with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Exclude

end if;
-- END CHECK FOR NEW STATUS ACTIVE


-- update rtp_ddl_pol status
update rtp_ddl_pol set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_UPD (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_audit_option in integer,
                            p_user_apply in integer,
                            p_rule_eval in integer,
                            p_formula in varchar2,
                            p_silent_deny in integer,
                            p_use_cache in integer,
                            p_debug_log in integer,
                            p_log_ddl_body in integer,
                            p_log_cmd in integer
                            )

AS

begin


-- Update rtp_ddl_pol
BEGIN

update rtp_ddl_pol set

policy_name = p_policy_name,
policy_desc = p_policy_desc,
audit_option = p_audit_option,
user_apply = p_user_apply,
rule_eval = p_rule_eval,
formula = p_formula,
silent_deny = p_silent_deny,
use_cache = p_use_cache,
debug_log = p_debug_log,
log_ddl_body = p_log_ddl_body,
log_cmd = p_log_cmd,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


-- Clear Policy from Cache
P_RTP_DDL_POL_CACHE_POL_DEL(
p_policy_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_USER_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_USER_DEL (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Delete rtp_ddl_pol_user
delete rtp_ddl_pol_user
where policy_id = p_policy_id
and user_id = p_user_id
and user_apply = p_user_apply;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DDL_POL_USER_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DDL_POL_USER_INS (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Insert rtp_ddl_pol_user
BEGIN

insert into rtp_ddl_pol_user
(
policy_id,
user_id,
user_apply
)
values
(
p_policy_id,
p_user_id,
p_user_apply
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'User appliance already declared for this Policy !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_AUD_POLICY_DROP
prompt ============================================
prompt
create or replace procedure P_RTP_DML_AUD_POLICY_DROP (
                  p_object_schema in varchar2,
                  p_object_name in varchar2,
                  p_fga_policy_name in varchar2,
                  p_force_drop in integer
                  ) is

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!
v_rule_id          rtp_dml_pol_rule.rule_id%TYPE;

begin

-- Check p_force_drop
if p_force_drop not in (0,1) then
raise_application_error(-20010, 'Parameter Force Delete not in 0/1 !');
end if;


-- Begin check rule existence
BEGIN
select rule_id into v_rule_id
from rtp_dml_pol_rule
where obj_owner = p_object_schema
and obj_name = p_object_name
and fga_policy_name = p_fga_policy_name;
EXCEPTION
WHEN NO_DATA_FOUND THEN
     SYS.OMEGA_CORE_AUDIT.P_RTP_DML_AUD_POL_DROP(
          p_object_schema,
          p_object_name,
          p_fga_policy_name,
          0 -- p_audit_condition_priv_run- 0-do not run, 1-run
          );
WHEN OTHERS THEN
RAISE;
END;
-- End check rule existence


-- Begin DML Rule Found
if v_rule_id is not null then

    -- p_force_drop = 1
    if p_force_drop = 1 then
    SYS.OMEGA_CORE_AUDIT.P_RTP_DML_AUD_POL_DROP(
          p_object_schema,
          p_object_name,
          p_fga_policy_name,
          0 -- p_audit_condition_priv_run- 0-do not run, 1-run
          );
    else -- p_force_drop <> 1
    raise_application_error(-20010, 'Oracle audit policy bound to RTP DML rule '
    || to_char(v_rule_id) || ' !');
    end if;

end if;
-- End DML Rule Found

end ;
/

prompt
prompt Creating procedure P_RTP_DML_MAP
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_MAP (
                            p_rtp_dml_map in varchar2
                            )

AS

begin

-- Check DMLMAP Value
if p_rtp_dml_map not in ('0','1') then
raise_application_error(-20010, 'Unknown RTP DML Trail Map parameter not in 0/1 !');
end if;

-- update sys_param DMLMAP value
-- Parameter_Id = 4 = DMLMAP = RTP DML Trail Map
update sys_param set
param_value = p_rtp_dml_map,
date_upd = SYSDATE,
user_upd = USER
where parameter_id = 4 ;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_CACHE_DEL
prompt ==========================================
prompt
create or replace procedure P_RTP_DML_POL_CACHE_DEL (
                            p_row_id in varchar2
                            )

as


begin

-- Delete rtp_dml_pol_cache
delete from rtp_dml_pol_cache
where rowid = CHARTOROWID(p_row_id);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_CACHE_RULE_DEL
prompt ===============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_CACHE_RULE_DEL (
                            p_rule_id in integer
                            )

as


begin

-- Delete rtp_dml_pol_cache
delete from rtp_dml_pol_cache
where rule_id = p_rule_id;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_DEL (
                            p_cond_id in integer
                            )

AS

v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;

begin

-- delete rtp_dml_pol_cond_list
delete from rtp_dml_pol_cond_list
where cond_id = p_cond_id;

-- Get Rule Id before Condition delete
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = p_cond_id;

-- delete rtp_dml_pol_cond
delete from rtp_dml_pol_cond
where cond_id = p_cond_id;


-- get policy
--select policy_id into v_policy_id
--from rtp_dml_pol_rule
--where rule_id = v_rule_id;
-- delete cache
P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_INS (
                            p_rule_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;

v_policy_id                 rtp_dml_pol_rule.policy_id%TYPE;
v_audit_condition_type      rtp_dml_pol_rule.audit_condition_type%TYPE;

begin

-- get policy data
select policy_id  into v_policy_id
from rtp_dml_pol_rule
where rule_id = p_rule_id;


-- BEGIN CHECK CONDITIONS
-- get audit_condition_type
select audit_condition_type
into v_audit_condition_type
from rtp_dml_pol_rule
where rule_id = p_rule_id;

-- Begin Check when audit_condition_type <> 1 = Rule Condition
if v_audit_condition_type <> 1 then
raise_application_error(-20010, 'Conditions can be added only to a Rule with Authorization Type of Rule Condition !');
end if;
-- End Check when audit_condition_type <> 1 = Rule Condition
-- END CHECK CONDITIONS


-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;


-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR


-- Insert rtp_dml_pol_cond
insert into rtp_dml_pol_cond
(
cond_id,
rule_id,
factor_id,
opr_code_id,
operand_1,
operand_2,
cond_eval,
min_trust_level_no,
validate_expr_owner,
validate_expr_object,
status_id
)
values
(
seq_rtp_dml_pol_cond.nextval,
p_rule_id,
p_factor_id,
p_opr_code_id,
p_operand_1,
p_operand_2,
p_cond_eval,
p_min_trust_level_no,
p_validate_expr_owner,
p_validate_expr_object,
p_status_id
);


-- Clear Policy from Cache
--select policy_id into v_policy_id from rtp_policy_rule
--where rule_id = p_rule_id;
P_RTP_DML_POL_CACHE_RULE_DEL(
p_rule_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_LIST_DEL
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_LIST_DEL (
                            p_list_id in integer
                            )

AS

v_cond_id      rtp_dml_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;

begin


-- Get Condition Id
select cond_id into v_cond_id
from rtp_dml_pol_cond_list
where list_id = p_list_id;
-- Get Rule Id
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = v_cond_id;

-- Clear Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);


-- Delete rtp_dml_pol_cond_list
delete from rtp_dml_pol_cond_list
where list_id = p_list_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_LIST_INS
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_LIST_INS (
                            p_cond_id in integer,
                            p_operand_1 in varchar2,
                            p_status_id in integer
                            )

AS

v_opr_code_id  rtp_dml_pol_cond.opr_code_id%TYPE;

v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;
--v_policy_id    rtp_dml_pol_rule.policy_id%TYPE;

begin

select opr_code_id into v_opr_code_id
from rtp_dml_pol_cond where cond_id = p_cond_id;

if v_opr_code_id not in (12, 13) then
raise_application_error(-20010, 'Operation Code must be only IN/NOT IN !');
end if;


-- Insert rtp_dml_pol_cond_list
insert into rtp_dml_pol_cond_list
(
list_id,
cond_id,
operand_1,
status_id
)
values
(
seq_rtp_dml_pol_cond_list.nextval,
p_cond_id,
p_operand_1,
p_status_id
);



-- Clear Policy from Cache
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = p_cond_id;
--select policy_id into v_policy_id from rtp_policy_rule
--where rule_id = v_rule_id;

P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_LIST_STAT
prompt ===============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_LIST_STAT (
                            p_list_id in integer
                            )

AS

v_curr_status_id      rtp_dml_pol_cond_list.status_id%TYPE;
v_new_status_id       rtp_dml_pol_cond_list.status_id%TYPE;

v_cond_id      rtp_dml_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;
--v_policy_id    rtp_dml_pol_rule.policy_id%TYPE;

begin

-- get curr status
select status_id into v_curr_status_id
from rtp_dml_pol_cond_list
where list_id = p_list_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Update rtp_dml_pol_cond_list status
update rtp_dml_pol_cond_list set
status_id = v_new_status_id,
date_upd = SYSDATE,
user_upd = USER
where list_id = p_list_id;


-- Clear Policy from Cache
select cond_id into v_cond_id from rtp_dml_pol_cond_list
where list_id = p_list_id;
select rule_id into v_rule_id from rtp_dml_pol_cond
where cond_id = v_cond_id;
--select policy_id into v_policy_id from rtp_policy_rule
--where rule_id = v_rule_id;

P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_LIST_UPD
prompt ==============================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_LIST_UPD (
                            p_list_id in integer,
                            p_operand_1 in varchar2
                            )

AS

v_cond_id      rtp_dml_pol_cond_list.cond_id%TYPE;
v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;
--v_policy_id    rtp_dml_pol_rule.policy_id%TYPE;

begin


-- Update rtp_dml_pol_cond_list
update rtp_dml_pol_cond_list set

operand_1 = p_operand_1,

date_upd = SYSDATE,
user_upd = USER

where list_id = p_list_id;



-- Get Cond ID
select cond_id into v_cond_id
from rtp_dml_pol_cond_list
where list_id = p_list_id;
-- Get Rule ID
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = v_cond_id;

-- Clear Policy from Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_STAT
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_STAT (
                            p_cond_id in integer
                            )

AS

v_curr_status_id      rtp_dml_pol_cond.status_id%TYPE;
v_new_status_id       rtp_dml_pol_cond.status_id%TYPE;

v_cond_eval           rtp_dml_pol_cond.cond_eval%TYPE;
v_opr_code_id         rtp_dml_pol_cond.opr_code_id%TYPE;
v_opr_code_symbol     sys_operation_code.code_group%TYPE;
cnt_in_list           integer;

v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;
v_policy_id    rtp_dml_pol_rule.policy_id%TYPE;

begin

-- get condition data
select status_id, opr_code_id, cond_eval
into v_curr_status_id, v_opr_code_id, v_cond_eval
from rtp_dml_pol_cond
where cond_id = p_cond_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;



-- BEGIN CHECK IN (NOT IN) list
if v_cond_eval = 1 then -- 1 = Operand

-- get opr_code symbol
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = v_opr_code_id;

if v_opr_code_symbol in ('IN', 'NOT IN') then

if v_new_status_id = 1 then
select count(*) into cnt_in_list from rtp_dml_pol_cond_list
where cond_id = p_cond_id and status_id = 1;
if cnt_in_list = 0 then
raise_application_error(-20010, 'At least one active operand must be active in the IN (NOT IN) list for this condition to be active !');
end if;
end if;

end if;

end if;
-- END CHECK IN (NOT IN) list



-- Update rtp_dml_pol_cond status
update rtp_dml_pol_cond set
status_id = v_new_status_id,
date_upd = SYSDATE,
user_upd = USER
where cond_id = p_cond_id;


-- Get Rule ID
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = p_cond_id;
-- Get Policy ID
select policy_id into v_policy_id
from rtp_dml_pol_rule
where rule_id = v_rule_id;

-- Clear Policy from Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COND_UPD
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COND_UPD (
                            p_cond_id in integer,
                            p_factor_id in integer,
                            p_cond_eval in integer,
                            p_opr_code_id in integer,
                            p_operand_1 in varchar2,
                            p_operand_2 in varchar2,
                            p_min_trust_level_no in integer,
                            p_validate_expr_owner in varchar2,
                            p_validate_expr_object in varchar2
                            )

AS

v_opr_code_symbol           sys_operation_code.code_group%TYPE;

v_rule_id      rtp_dml_pol_cond.rule_id%TYPE;

begin


-- BEGIN CHECK OPERAND
if p_cond_eval = 1 then

-- get opr_code_symbol
BEGIN
select code_symbol into v_opr_code_symbol
from sys_operation_code where code_id = p_opr_code_id;
EXCEPTION
WHEN NO_DATA_FOUND then
raise_application_error(-20010, 'Operation Code Symbol must be completed for Operand Condition Evaluation !');
END;

-- Check BETWEEN, NOT BETWEEN
if v_opr_code_symbol in ('BETWEEN', 'NOT BETWEEN') then

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is null then
raise_application_error(-20010, 'Operand 2 must be completed for this operation code !');
end if;

-- Check IS NULL, IS NOT NULL
elsif v_opr_code_symbol in ('IS NULL', 'IS NOT NULL') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check IN, NOT IN
elsif v_opr_code_symbol in ('IN', 'NOT IN') then

if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for this operation code ! Complete the IN (NOT IN) list !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

-- Check Other Codes
else

if p_operand_1 is null then
raise_application_error(-20010, 'Operand 1 must be completed for this operation code !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for this operation code !');
end if;

end if;

end if;
-- END CHECK OPERAND



-- BEGIN CHECK TRUST_LEVEL
if p_cond_eval = 2 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be null for Trust Level Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Trust Level Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Trust Level Condition Evaluation !');
end if;

if p_min_trust_level_no = -1 then
raise_application_error(-20010, 'Trust Level cannot be Undefined for Trust Level Condition Evaluation !');
end if;

end if;
-- END CHECK TRUST_LEVEL


-- BEGIN CHECK VALIDATE_EXPR
if p_cond_eval = 3 then

if p_opr_code_id is not null then
raise_application_error(-20010, 'Operation Code must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_1 is not null then
raise_application_error(-20010, 'Operand 1 must be empty for Validate Expression Condition Evaluation !');
end if;
if p_operand_2 is not null then
raise_application_error(-20010, 'Operand 2 must be empty for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Owner
if p_validate_expr_owner is  null then
raise_application_error(-20010, 'Validate Expression Owner must be completed for Validate Expression Condition Evaluation !');
end if;

-- Check Expr Object
if p_validate_expr_object is  null then
raise_application_error(-20010, 'Validate Expression Object must be completed for Validate Expression Condition Evaluation !');
end if;


end if;
-- END CHECK VALIDATE_EXPR



-- update rtp_dml_pol_cond
update rtp_dml_pol_cond set

factor_id = p_factor_id,
opr_code_id = p_opr_code_id,
operand_1 = p_operand_1,
operand_2 = p_operand_2,
cond_eval = p_cond_eval,
min_trust_level_no = p_min_trust_level_no,
validate_expr_owner = p_validate_expr_owner,
validate_expr_object = p_validate_expr_object,

date_upd = SYSDATE,
user_upd = USER

where cond_id = p_cond_id;


-- Get Rule Id
select rule_id into v_rule_id
from rtp_dml_pol_cond
where cond_id = p_cond_id;

-- Clear Policy from Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
v_rule_id
);


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_INS
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_INS (
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_user_apply in integer,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

begin


-- Insert rtp_dml_pol
BEGIN

insert into rtp_dml_pol
(
policy_id,
policy_name,
policy_desc,
user_apply,
use_cache,
debug_log
)
values
(
seq_rtp_dml_pol.nextval,
p_policy_name,
p_policy_desc,
p_user_apply,
p_use_cache,
p_debug_log
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_RULE_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_RULE_INS (
                            p_policy_id in number,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_status_id in integer,
                            -- FGA options
                            p_fga_obj_owner in varchar2,
                            p_fga_obj_name in varchar2,
                            p_audit_condition_type in integer,
                            p_audit_condition in varchar2,
                            p_audit_column in varchar2,
                            p_statement_SEL          integer,
                            p_statement_INS          integer,
                            p_statement_UPD          integer,
                            p_statement_DEL          integer,
                            p_audit_trail in integer,
                            p_audit_col_opt in integer
                            )

AS

v_rule_id                   rtp_dml_pol_rule.rule_id%TYPE;
v_fga_policy_name           rtp_dml_pol_rule.fga_policy_name%TYPE;

v_user_apply                rtp_dml_pol.user_apply%TYPE;

begin


-- Check Status
if p_status_id not in (0,1)  then
raise_application_error(-20010, 'Status not in 0-Active, 1-Inactive !');
end if;

-- Get Policy Data
select user_apply into v_user_apply
from rtp_dml_pol where policy_id = p_policy_id;


-- BEGIN MAKE-CHECK Audit_Condition vs Cond_Eval and Audit Condition
-- 1 = rule conditions
if p_audit_condition_type = 1 then

-- Cond Eval None cannot be used
if p_cond_eval = 0 then
raise_application_error(-20010, 'Condition Evaluation None cannot be used for Rule Authorization Type of Rule Conditions !');
end if;
-- Audit Condition cannot be used
if p_audit_condition is not null then
raise_application_error(-20010, 'Authorization Condition cannot be used for Rule Authorization Type of Rule Conditions !');
end if;


-- 2 = column condition
elsif p_audit_condition_type = 2 then

-- Check User Apply - All USers Only
if v_user_apply <> 0 then
raise_application_error(-20010, 'Rule Authorization Type of Column Condition can be used only in policies with User Appliance of All Users !');
end if;
-- Cond Eval None only can be used
if p_cond_eval <> 0 then
raise_application_error(-20010, 'Only Condition Evaluation None can be used for Rule Authorization Type of Column Conditions !');
end if;
-- Audit Condition must be used
if p_audit_condition is null then
raise_application_error(-20010, 'Authorization Condition must be used for Rule Authorization Type of Column Conditions !');
end if;


-- 3 = no condition
elsif p_audit_condition_type = 3 then

-- Cond Eval None only can be used
if p_cond_eval <> 0 then
raise_application_error(-20010, 'Only Condition Evaluation None can be used for Rule Authorization Type of No Conditions !');
end if;
-- Audit Condition cannot be used
if p_audit_condition is not null then
raise_application_error(-20010, 'Authorization Condition cannot be used for Rule Authorization Type of No Conditions !');
end if;


-- Not in 1,2,3 - raise
else
raise_application_error(-20010, 'Unknown DML Rule Audit Condition Type not in 1,2,3 !');

end if;
-- END MAKE-CHECK Audit_Condition vs Cond_Eval and Audit Condition


-- Begin Check Statement Types
if p_statement_SEL not in (0,1) then
raise_application_error (-20010, 'Wrong SEL value, non 0,1 !');
end if;

if p_statement_INS not in (0,1) then
raise_application_error (-20010, 'Wrong INS value, non 0,1 !');
end if;

if p_statement_UPD not in (0,1) then
raise_application_error (-20010, 'Wrong UPD value, non 0,1 !');
end if;

if p_statement_DEL not in (0,1) then
raise_application_error (-20010, 'Wrong DEL value, non 0,1 !');
end if;

-- check least one Statement Type selected
if p_statement_SEL = 0 and p_statement_INS = 0
and p_statement_UPD = 0 and p_statement_DEL = 0 then
raise_application_error (-20010, 'Choose at least one Statement Type !');
end if;
-- End Check Statement Types


-- BEGIN MAKE RULE's FGA_POLICY_NAME - FGA Policy to be - ONLY PLACE
-- Get Newly Inserted Rule name before - to prepare fga_policy_name
select seq_rtp_dml_pol_rule.nextval into v_rule_id from sys.dual;
-- make FGA Policy_Name - Lpad 8, 0 Standard from Rule_Name
v_fga_policy_name := 'RTP_DML_' || Lpad(to_char(v_rule_id), 8, '0');
-- END MAKE RULE's FGA_POLICY_NAME - FGA Policy to be - ONLY PLACE


-- Insert rtp_dml_pol_rule
BEGIN

insert into rtp_dml_pol_rule
(
rule_id,
policy_id,
status_id,
rule_name,
rule_desc,
cond_eval,
obj_owner,
obj_name,
fga_policy_name,
audit_condition_type,
silent_deny
)
values
(
v_rule_id,
p_policy_id,
p_status_id,
p_rule_name,
p_rule_desc,
p_cond_eval,
p_fga_obj_owner,
p_fga_obj_name,
v_fga_policy_name,
p_audit_condition_type,
1 -- 1 = Default Enabled Silent Deny on DML Rule !
);

EXCEPTION
when DUP_VAL_ON_INDEX then

-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'RTP_DML_POL_RULE_UN_AUD_POL_NM') <> 0 then
raise_application_error(-20010, 'Autogenerated FGA Policy name already in use !');
elsif Instr(sqlerrm, 'RTP_DML_POL_RULE_UN_AUD_POL') <> 0 then
raise_application_error(-20010, 'Owner, Object and FGA policy Name already in use !');
elsif Instr(sqlerrm, 'RTP_DML_POL_RULE_UN') <> 0 then
raise_application_error(-20010, 'Rule Name already in use for this Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Generate FGA - Call for Insert Only !!!
SYS.OMEGA_CORE_AUDIT.P_RTP_DML_POL_RULE_GEN(
                     v_rule_id,
                     p_status_id,
                     -- FGA Data
                     p_fga_obj_owner,
                     p_fga_obj_name,
                     v_fga_policy_name,
                     p_audit_condition_type,
                     p_audit_condition,
                     p_audit_column,
                     p_statement_SEL,
                     p_statement_INS,
                     p_statement_UPD,
                     p_statement_DEL,
                     p_audit_trail,
                     p_audit_col_opt,
                     1 -- Action INS
                     );


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_COPY
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_COPY (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2
                            )

AS

v_debug_log        rtp_dml_pol.debug_log%TYPE;
v_user_apply       rtp_dml_pol.user_apply%TYPE;
v_use_cache        rtp_dml_pol.use_cache%TYPE;

v_policy_id        rtp_dml_pol.policy_id%TYPE;

v_rule_id          rtp_dml_pol_rule.rule_id%TYPE;
v_cond_id          rtp_dml_pol_cond.cond_id%TYPE;

-- FGA Options
v_fga_obj_owner          rtp_dml_pol_rule.obj_owner%TYPE;
v_fga_obj_name           rtp_dml_pol_rule.obj_name%TYPE;
v_audit_condition_type   rtp_dml_pol_rule.audit_condition_type%TYPE;
v_audit_condition        v_rtp_dml_pol_rule_dba_aud_pol.policy_text%TYPE;
v_audit_column           varchar2(4000);

v_statement_SEL          integer;
v_statement_INS          integer;
v_statement_UPD          integer;
v_statement_DEL          integer;

v_audit_trail            v_rtp_dml_pol_rule_dba_aud_pol.audit_trail%TYPE;
v_audit_col_opt          v_rtp_dml_pol_rule_dba_aud_pol.policy_column_options%TYPE;

cursor C_Rule is select * from rtp_dml_pol_rule t
where policy_id = p_policy_id
order by t.rule_id;

cursor C_Cond (Rul_Id in integer) is select * from rtp_dml_pol_cond t
where rule_id = Rul_Id
order by t.cond_id;

cursor C_Cond_List (Cnd_Id in integer) is select * from rtp_dml_pol_cond_list t
where cond_id = Cnd_Id
order by t.list_id;

cursor C_Pol_Aud_Column (p_obj_schema in varchar2, p_obj_name in varchar2, p_policy_name in varchar2)
is select policy_column
from v_rtp_dml_sys_dba_audit_pol_cl
where object_schema = p_obj_schema
and object_name = p_obj_name
and policy_name = p_policy_name
order by policy_column;

begin


-- Get Original policy data
select debug_log, user_apply, use_cache
into  v_debug_log, v_user_apply, v_use_cache
from rtp_dml_pol
where policy_id = p_policy_id;

-- Insert New Policy
P_RTP_DML_POL_INS(
p_policy_name,
p_policy_desc,
v_user_apply,
v_use_cache,
v_debug_log
);

-- Get New inserted Policy_Id
select seq_rtp_dml_pol.currval into v_policy_id from sys.dual;

-- Begin Loop Rule
for Rec_Rule in C_Rule loop

-- Begin Make DML Rule FGA Options
select obj_owner, obj_name, audit_condition_type
into v_fga_obj_owner, v_fga_obj_name, v_audit_condition_type
from rtp_dml_pol_rule
where rule_id = Rec_Rule.Rule_Id;
-- End Make DML Rule Options

-- Begin Make FGA Options
BEGIN

select
policy_text,
Decode(SEL, 'YES', 1, 'NO', 0),
Decode(INS, 'YES', 1, 'NO', 0),
Decode(UPD, 'YES', 1, 'NO', 0),
Decode(DEL, 'YES', 1, 'NO', 0),
Decode(AUDIT_TRAIL, 'DB_EXTENDED', 1, 'DB', 2),
Decode(POLICY_COLUMN_OPTIONS, 'ANY_COLUMNS', 1, 'ALL_COLUMNS', 2)
into
v_audit_condition,
v_statement_SEL,
v_statement_INS,
v_statement_UPD,
v_statement_DEL,
v_audit_trail,
v_audit_col_opt
from v_rtp_dml_pol_rule_dba_aud_pol
where rule_id = Rec_Rule.Rule_Id;

EXCEPTION
WHEN NO_DATA_FOUND THEN
raise_application_error(-20010, 'Oracle Audit Policy not found for Rule ' || to_char(Rec_Rule.Rule_Id));
WHEN OTHERS THEN
RAISE;
END;

-- Begin Make Audit_Column
-- Reset v_audit_column
v_audit_column := null;

-- begin loop Policy Audit Condition's cursor
for Rec_Aud_Col in C_Pol_Aud_Column(Rec_Rule.Obj_Owner, Rec_Rule.Obj_Name, Rec_Rule.Fga_Policy_Name) loop
v_audit_column := v_audit_column  || Rec_Aud_Col.Policy_Column  || ',';
end loop;
-- end loop loop Policy Audit Condition's cursor
v_audit_column := Substr(v_audit_column, 1, length(v_audit_column)-1); -- Cut last Comma (,)
-- End Make Audit_Column


-- Empty Audit_Condition for  1=rule conditions, 3=no conditions
-- to avoid failure on cond_ins
if v_audit_condition_type in (1, 3) then
v_audit_condition := NULL;
end if;


-- Insert Rule
P_RTP_DML_POL_RULE_INS(
v_policy_id,
Rec_Rule.Rule_Name,
Rec_Rule.Rule_Desc,
Rec_Rule.Cond_Eval,
0, -- New DML Rule and FGA Status Disabled on Copy
-- FGA Options
v_fga_obj_owner,
v_fga_obj_name,
v_audit_condition_type,
v_audit_condition,
v_audit_column,
v_statement_SEL,
v_statement_INS,
v_statement_UPD,
v_statement_DEL,
v_audit_trail,
v_audit_col_opt
);


-- BEGIN MAKE CONDITIONS if AUDIT_CONDITION_TYPE = 1 = Rule Conditions
if v_audit_condition_type = 1 then

-- Get New inserted Rule_Id, needed for cond insert
select seq_rtp_dml_pol_rule.currval into v_rule_id from sys.dual;

    -- Begin Loop Condition
    for Rec_Cond in C_Cond(Rec_Rule.Rule_Id) loop

    -- Insert Condition
    P_RTP_DML_POL_COND_INS(
    v_rule_id,
    Rec_Cond.Factor_Id,
    Rec_Cond.Cond_Eval,
    Rec_Cond.Opr_Code_Id,
    Rec_Cond.Operand_1,
    Rec_Cond.Operand_2,
    Rec_Cond.Min_Trust_Level_No,
    Rec_Cond.Validate_Expr_Owner,
    Rec_Cond.Validate_Expr_Object,
    Rec_Cond.Status_Id
    );

    -- Get New inserted Cond_Id
    select seq_rtp_dml_pol_cond.currval into v_cond_id from sys.dual;

              -- Begin Loop Condition List
              for Rec_Cond_List in C_Cond_List(Rec_Cond.Cond_Id) loop

              -- Insert Condition List
              P_RTP_DML_POL_COND_LIST_INS(
              v_cond_id,
              Rec_Cond_List.Operand_1,
              Rec_Cond_List.Status_Id
              );

              end loop;
              -- End Loop Condition List

    end loop;
    -- End Loop Condition

end if;
-- END MAKE CONDITIONS if AUDIT_CONDITION_TYPE = 1 = Rule Conditions


end loop;
-- End Loop Rule


-- insert user_apply
insert into rtp_dml_pol_user
(policy_id, user_id, user_apply)
select v_policy_id, user_id, user_apply
from rtp_dml_pol_user
where policy_id = p_policy_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_RULE_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_RULE_DEL (
                            p_rule_id in integer
                            )

AS

-- Condition Cursor
cursor C_Cond is select * from rtp_dml_pol_cond
where rule_id = p_rule_id;

v_policy_id           rtp_dml_pol_rule.policy_id%TYPE;

-- FGA variables
v_obj_owner              rtp_dml_pol_rule.obj_owner%TYPE;
v_obj_name               rtp_dml_pol_rule.obj_name%TYPE;
v_fga_policy_name        rtp_dml_pol_rule.fga_policy_name%TYPE;

begin


-- Begin loop Conditions
for Rec in C_Cond loop

    P_RTP_DML_POL_COND_DEL(
    Rec.Cond_Id
    );

end loop;
-- End loop Conditions


-- Get Policy ID and FGA Data
select policy_id, obj_owner, obj_name, fga_policy_name
into v_policy_id, v_obj_owner, v_obj_name, v_fga_policy_name
from rtp_dml_pol_rule
where rule_id = p_rule_id;

-- Clear Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
p_rule_id
);


-- delete rtp_dml_pol_rule
delete from rtp_dml_pol_rule
where rule_id = p_rule_id;


-- Generate FGA - Call for Delete Only !!!
SYS.OMEGA_CORE_AUDIT.P_RTP_DML_POL_RULE_GEN(
                     p_rule_id,
                     0, -- Rule Status unimportant on DEL
                     v_obj_owner,
                     v_obj_name,
                     v_fga_policy_name,
                     NULL, -- p_audit_condition_type,
                     NULL, -- p_audit_condition,
                     NULL, --p_audit_column,
                     NULL, --p_statement_SEL,
                     NULL, --p_statement_INS,
                     NULL, --p_statement_UPD,
                     NULL, --p_statement_DEL,
                     NULL, --p_audit_trail,
                     NULL, --p_audit_col_opt
                     3 -- Action DEL
                     );

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_DEL
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_DEL (
                            p_policy_id in integer
                            )

AS

-- Rule Cursor
cursor C_Rule is select * from rtp_dml_pol_rule
where policy_id = p_policy_id;

begin


-- Begin Loop Rules
for Rec1 in C_Rule loop

-- Delete rtp_dml_pol_rule
P_RTP_DML_POL_RULE_DEL(
Rec1.Rule_Id
);

end loop;
-- End Loop Rules


-- delete rtp_dml_pol_user
delete from rtp_dml_pol_user
where policy_id = p_policy_id;


-- Clear Policy from Cache
--Done at Rule Level

-- Delete rtp_dml_pol
delete from rtp_dml_pol
where policy_id = p_policy_id;

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_RULE_STAT
prompt ==========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_RULE_STAT (
                            p_rule_id in integer
                            )

AS

v_curr_status_id          rtp_dml_pol_rule.status_id%TYPE;
v_new_status_id           rtp_dml_pol_rule.status_id%TYPE;

cnt_active_cond           integer;

v_policy_id               rtp_dml_pol_rule.policy_id%TYPE;
v_audit_condition_type    rtp_dml_pol_rule.audit_condition_type%TYPE;

v_obj_owner               rtp_dml_pol_rule.obj_owner%TYPE;
v_obj_name                rtp_dml_pol_rule.obj_name%TYPE;
v_fga_policy_name         rtp_dml_pol_rule.fga_policy_name%TYPE;

begin

-- get rule data
select policy_id, status_id
into v_policy_id, v_curr_status_id
from rtp_dml_pol_rule
where rule_id = p_rule_id;


-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- Begin Check Active Conditions when new status is Active
if v_new_status_id = 1 then

-- get audit_condition_type
select audit_condition_type
into v_audit_condition_type
from rtp_dml_pol_rule
where rule_id = p_rule_id;


-- Begin Check least 1 Condition Active for audit_condition_type = 1 = Rule Condition
if v_audit_condition_type = 1 then

   -- make condition count
    select count(*) into cnt_active_cond
    from rtp_dml_pol_cond
    where rule_id = p_rule_id
    and status_id = 1; -- 1=Active

   -- evaluate and raise
   if cnt_active_cond = 0 then
   raise_application_error(-20010, 'Rule with no Active Conditions cannot be set as Active !');
   end if;

end if;
-- End Check least 1 Condition Active for audit_condition_type = 1 = Rule Condition


end if;
-- End Check Active Conditions when new status is Active



-- update rtp_dml_pol_rule status
update rtp_dml_pol_rule set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;


-- Get FGA Owner(Schema)/Object Name/fga_policy_name
select obj_owner, obj_name, fga_policy_name
into v_obj_owner, v_obj_name, v_fga_policy_name
from rtp_dml_pol_rule
where rule_id = p_rule_id;


-- Generate FGA Status
SYS.OMEGA_CORE_AUDIT.P_RTP_DML_POL_RULE_STAT(
                     v_obj_owner,
                     v_obj_name,
                     v_fga_policy_name,
                     v_new_status_id
                     );

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_RULE_UPD
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_RULE_UPD (
                            p_rule_id in integer,
                            p_rule_name in varchar2,
                            p_rule_desc in varchar2,
                            p_cond_eval in integer,
                            p_silent_deny in integer,
                            p_formula in varchar2,
                            -- FGA options
                            p_fga_obj_owner in varchar2,
                            p_fga_obj_name in varchar2,
                            p_audit_condition_type in integer,
                            p_audit_condition in varchar2,
                            p_audit_column in varchar2,
                            p_statement_SEL          integer,
                            p_statement_INS          integer,
                            p_statement_UPD          integer,
                            p_statement_DEL          integer,
                            p_audit_trail in integer,
                            p_audit_col_opt in integer
                            )

AS

v_policy_id                 rtp_dml_pol_rule.policy_id%TYPE;
v_rule_status_id            rtp_dml_pol_rule.status_id%TYPE;
v_fga_policy_name           rtp_dml_pol_rule.fga_policy_name%TYPE;

v_user_apply                rtp_dml_pol.user_apply%TYPE;

begin

-- get Rule Data
select policy_id, status_id, fga_policy_name
into v_policy_id, v_rule_status_id, v_fga_policy_name
from rtp_dml_pol_rule
where rule_id = p_rule_id;

-- Get Policy Data
select user_apply into v_user_apply
from rtp_dml_pol where policy_id = v_policy_id;


-- BEGIN MAKE-CHECK AUDIT_CONDITION VS OTHERS

-- 1 = rule conditions
if p_audit_condition_type = 1 then

-- Cond Eval None cannot be used
if p_cond_eval = 0 then
raise_application_error(-20010, 'Condition Evaluation None cannot be used for Rule Authorization Type of Rule Conditions !');
end if;
-- Audit Condition cannot be used
if p_audit_condition is not null then
raise_application_error(-20010, 'Authorization Condition cannot be used for Rule Authorization Type of Rule Conditions !');
end if;


-- 2 = column condition
elsif p_audit_condition_type = 2 then

-- Check User Apply - All USers Only
if v_user_apply <> 0 then
raise_application_error(-20010, 'Rule Authorization Type of Column Condition can be used only in policies with User Appliance of All Users !');
end if;
-- Cond Eval None only can be used
if p_cond_eval <> 0 then
raise_application_error(-20010, 'Only Condition Evaluation None can be used for Rule Authorization Type of Column Conditions !');
end if;
-- Audit Condition must be used
if p_audit_condition is null then
raise_application_error(-20010, 'Authorization Condition must be used for Rule Authorization Type of Column Conditions !');
end if;


-- 3 = no condition
elsif p_audit_condition_type = 3 then

-- Cond Eval None only can be used
if p_cond_eval <> 0 then
raise_application_error(-20010, 'Only Condition Evaluation None can be used for Rule Authorization Type of No Conditions !');
end if;
-- Audit Condition cannot be used
if p_audit_condition is not null then
raise_application_error(-20010, 'Authorization Condition cannot be used for Rule Authorization Type of No Conditions !');
end if;


-- Not in 1,2,3 - raise
else
raise_application_error(-20010, 'Unknown DML Rule Audit Condition Type not in 1,2,3 !');

end if;
-- END MAKE-CHECK AUDIT_CONDITION  VS OTHERS


-- Begin Check Statement Types
if p_statement_SEL not in (0,1) then
raise_application_error (-20010, 'Wrong SEL value, non 0,1 !');
end if;

if p_statement_INS not in (0,1) then
raise_application_error (-20010, 'Wrong INS value, non 0,1 !');
end if;

if p_statement_UPD not in (0,1) then
raise_application_error (-20010, 'Wrong UPD value, non 0,1 !');
end if;

if p_statement_DEL not in (0,1) then
raise_application_error (-20010, 'Wrong DEL value, non 0,1 !');
end if;

-- check least one Statement Type selected
if p_statement_SEL = 0 and p_statement_INS = 0
and p_statement_UPD = 0 and p_statement_DEL = 0 then
raise_application_error (-20010, 'Choose at least one Statement Type !');
end if;
-- End Check Statement Types


-- update rtp_dml_pol_rule
BEGIN

update rtp_dml_pol_rule set

rule_name = p_rule_name,
rule_desc = p_rule_desc,
cond_eval = p_cond_eval,
formula = p_formula,
silent_deny = p_silent_deny,

obj_owner = p_fga_obj_owner,
obj_name = p_fga_obj_name,
audit_condition_type = p_audit_condition_type,

date_upd = SYSDATE,
user_upd = USER

where rule_id = p_rule_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then

-- UN keys naming similarity - check longest first !!!
if Instr(sqlerrm, 'RTP_DML_POL_RULE_UN_AUD_POL_NM') <> 0 then
raise_application_error(-20010, 'Autogenerated FGA Policy name already in use !');
elsif Instr(sqlerrm, 'RTP_DML_POL_RULE_UN_AUD_POL') <> 0 then
raise_application_error(-20010, 'Owner, Object and FGA policy Name already in use !');
elsif Instr(sqlerrm, 'RTP_DML_POL_RULE_UN') <> 0 then
raise_application_error(-20010, 'Rule Name already in use for this Policy !');
else
--re-raise Error if no defined found
RAISE;
end if;

END;


-- Clear Policy from Cache
P_RTP_DML_POL_CACHE_RULE_DEL(
p_rule_id
);


-- Generate FGA - Call for Update Only !!!
SYS.OMEGA_CORE_AUDIT.P_RTP_DML_POL_RULE_GEN(
                     p_rule_id,
                     v_rule_status_id,
                     -- FGA Data
                     p_fga_obj_owner,
                     p_fga_obj_name,
                     v_fga_policy_name,
                     p_audit_condition_type,
                     p_audit_condition,
                     p_audit_column,
                     p_statement_SEL,
                     p_statement_INS,
                     p_statement_UPD,
                     p_statement_DEL,
                     p_audit_trail,
                     p_audit_col_opt,
                     2 -- Action UPD
                     );

end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_STAT
prompt =====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_STAT (
                            p_policy_id in integer
                            )
-- RTP-DML Policy Status will be automatically set by Rule's Status
-- not called from user interface

AS

v_curr_status_id      rtp_dml_pol.status_id%TYPE;
v_new_status_id       rtp_dml_pol.status_id%TYPE;

cnt_active_rule       integer;

v_user_apply          rtp_dml_pol.user_apply%TYPE;
cnt_pol_user          integer;

-- Active Rules Cursor
cursor c_rule_active is
select * from rtp_dml_pol_rule
where policy_id = p_policy_id
and status_id = 1; -- 1 = Active only - for Deactivating

begin


-- get rtp_dml_pol data
select status_id, user_apply
into v_curr_status_id, v_user_apply
from rtp_dml_pol where policy_id = p_policy_id;

-- set new status
if v_curr_status_id = 0  then
v_new_status_id := 1;
elsif v_curr_status_id = 1 then
v_new_status_id := 0;
else
raise_application_error(-20010, 'Unknown status not in 0/1 !');
end if;


-- BEGIN CHECK FOR NEW STATUS ACTIVE
if v_new_status_id = 1 then

-- make count Active Rules
select count(*) into cnt_active_rule
from rtp_dml_pol_rule
where policy_id = p_policy_id and status_id = 1; -- 1=Active
-- Raise if no Active Rule
if cnt_active_rule = 0 then
raise_application_error(-20010, 'Policy with no Active Rules cannot be set as Active !');
end if;

-- Begin check Users Apply
if v_user_apply = 1 then
-- Count Users Apply
select count(*) into cnt_pol_user
from rtp_dml_pol_user
where policy_id = p_policy_id and user_apply = 1; -- 1 Users Apply
-- Raise if no Users Apply
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Apply with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Apply

-- Begin check Users Exclude
if v_user_apply = 2 then
-- Count Users Exclude
select count(*) into cnt_pol_user
from rtp_dml_pol_user
where policy_id = p_policy_id and user_apply = 2; -- 2 Users Exclude
-- Raise if no Users Exclude
if cnt_pol_user = 0 then
raise_application_error(-20010, 'Policy of Users Exclude with no user declared cannot be set as Active !');
end if;
end if;
-- End check Users Exclude

-- END CHECK FOR NEW STATUS ACTIVE
else  -- v_new_status_id = 0
-- Begin CHECK FOR NEW STATUS INACTIVE

-- Loop Active DML rules and Deactivate (Active->Inactive)
for rec_rule_active in c_rule_active loop
P_RTP_DML_POL_RULE_STAT(rec_rule_active.rule_id);
end loop;

end if;
-- END CHECK FOR NEW STATUS INACTIVE


-- update rtp_dml_pol status
update rtp_dml_pol set

status_id = v_new_status_id,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_UPD
prompt ====================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_UPD (
                            p_policy_id in integer,
                            p_policy_name in varchar2,
                            p_policy_desc in varchar2,
                            p_user_apply in integer,
                            p_use_cache in integer,
                            p_debug_log in integer
                            )

AS

v_cnt_rule_column_cond    integer;

begin


-- Begin Check Rules with Authorization Type = Column Condition
if p_user_apply <> 0 then

-- Count non Rule Condition rules
select count(*) into v_cnt_rule_column_cond
from rtp_dml_pol_rule
where policy_id = p_policy_id
and audit_condition_type = 2; -- 2 = Column Condition
-- Raise if found
if v_cnt_rule_column_cond > 0 then
raise_application_error(-20010, 'Users Apply setting for Policy containing rule with Authorization Type of Column Condition can be only All Users !');
end if;

end if;
-- End Check Rules with Authorization Type = Column Condition


-- Update rtp_dml_pol
BEGIN

update rtp_dml_pol set

policy_name = p_policy_name,
policy_desc = p_policy_desc,
user_apply = p_user_apply,
use_cache = p_use_cache,
debug_log = p_debug_log,

date_upd = SYSDATE,
user_upd = USER

where policy_id = p_policy_id ;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Policy name already in use !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_USER_DEL
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_USER_DEL (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Delete rtp_dml_pol_user
delete rtp_dml_pol_user
where policy_id = p_policy_id
and user_id = p_user_id
and user_apply = p_user_apply;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_POL_USER_INS
prompt =========================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_POL_USER_INS (
                            p_policy_id in integer,
                            p_user_id in varchar2,
                            p_user_apply in number
                            )

AS

begin


-- Insert rtp_dml_pol_user
BEGIN

insert into rtp_dml_pol_user
(
policy_id,
user_id,
user_apply
)
values
(
p_policy_id,
p_user_id,
p_user_apply
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'User appliance already declared for this Policy !' );
END;


end; -- end proc
/

prompt
prompt Creating procedure P_RTP_DML_RTC
prompt ================================
prompt
CREATE OR REPLACE PROCEDURE P_RTP_DML_RTC (
                            p_rtp_dml_rtc in varchar2
                            )

AS

begin

-- Check DMLRTC Value
if p_rtp_dml_rtc not in ('0','1') then
raise_application_error(-20010, 'Unknown RTP DML Return Code parameter not in 0/1 !');
end if;

-- update sys_param DMLRTC value
-- Parameter_Id = 3 = DMLRTC = RTP DML Return Code
update sys_param set
param_value = p_rtp_dml_rtc,
date_upd = SYSDATE,
user_upd = USER
where parameter_id = 3 ;

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_ERROR_LOG_DEL
prompt ======================================
prompt
create or replace procedure P_SYS_ERROR_LOG_DEL (
                            p_del_mode in integer,
                            p_username in varchar2,
                            p_date_log_from in timestamp,
                            p_date_log_to in timestamp
                            )

as

begin

-- Check Delete Mode
if p_del_mode not in (1,2,3) then
raise_application_error(-20010, 'Parameter Delete Mode not in 1-ALL, 2-Username, 3-Date Log !');
end if;


-- Delete 1=All
if p_del_mode = 1 then
delete from sys_error_log;

-- Delete 2=Username
elsif p_del_mode = 2 then
      -- Check Username
      if p_username is null then
      raise_application_error(-20010, 'Username not completed for Delete Mode 2-Username !');
      end if;

delete from sys_error_log
where username = p_username;

-- Delete 3=Date Log
else -- p_del_mode = 3
     -- Check date_log_from
     if p_date_log_from is null then
     raise_application_error(-20010, 'Date log From completed for Delete Mode 3-Date Log !');
     end if;
     -- Check date_log_to
     if p_date_log_to is null then
     raise_application_error(-20010, 'Date log To not completed for Delete Mode 3-Date Log !');
     end if;

delete from sys_error_log
where timestamp_sts between p_date_log_from and p_date_log_to;

end if;

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_FACTOR_TL_CACHE_DEL
prompt ============================================
prompt
create or replace procedure P_SYS_FACTOR_TL_CACHE_DEL (
                            p_factor_id in integer
                            )
-- Deletes Policy Cache, All Mod, having Trust Level Cond
is

-- ACC TL Cond cursor
cursor c_acc_cond_TL is
select distinct policy_id from acc_pol_rule
where exists (
select policy_id from acc_pol_cond
where acc_pol_cond.rule_id = acc_pol_rule.rule_id
and cond_eval = 2 -- 2 = Trust Level
and factor_id = p_factor_id
)
order by policy_id;

-- RTP_DDL TL Cond cursor
cursor c_rtp_ddl_cond_TL is
select distinct policy_id from rtp_ddl_pol_rule
where exists (
select policy_id from rtp_ddl_pol_cond
where rtp_ddl_pol_cond.rule_id = rtp_ddl_pol_rule.rule_id
and cond_eval = 2 -- 2 = Trust Level
and factor_id = p_factor_id
)
order by policy_id;

-- RTP_DML TL Cond cursor
cursor c_rtp_dml_cond_TL is
select distinct rule_id from rtp_dml_pol_rule
where exists (
select rule_id from rtp_dml_pol_cond
where rtp_dml_pol_cond.rule_id = rtp_dml_pol_rule.rule_id
and cond_eval = 2 -- 2 = Trust Level
and factor_id = p_factor_id
)
order by rule_id;


begin


-- Begin Clear ACC Cache for TL Cond Policies
for rec_cond_TL in c_acc_cond_TL loop
P_ACC_POL_CACHE_POL_DEL(
rec_cond_TL.policy_id
);
end loop;
-- End Clear ACC Cache for TL Cond Policies

-- Begin Clear RTP_DDL Cache for TL Cond Policies
for rec_cond_TL in c_rtp_ddl_cond_TL loop
P_RTP_DDL_POL_CACHE_POL_DEL(
rec_cond_TL.policy_id
);
end loop;
-- End Clear RTP_DDL Cache for TL Cond Policies

-- Begin Clear RTP_DML Cache for TL Cond Policies
for rec_cond_TL in c_rtp_dml_cond_TL loop
P_RTP_DML_POL_CACHE_RULE_DEL(
rec_cond_TL.rule_id
);
end loop;
-- End Clear RTP_DML Cache for TL Cond Policies

end ;
/

prompt
prompt Creating procedure P_SYS_FACTOR_IDENTITY_DEL
prompt ============================================
prompt
create or replace procedure P_SYS_FACTOR_IDENTITY_DEL (
                            p_identity_id in integer
                            )

is

v_factor_id   sys_factor_identity.factor_id%TYPE;

begin

-- Get Factor ID
select factor_id into v_factor_id
from sys_factor_identity
where identity_id = p_identity_id;


-- delete SYS_FACTOR_IDENTITY
delete from sys_factor_identity
where identity_id = p_identity_id;


-- Deletes Policy Cache, All Mod, having Trust Level Cond
P_SYS_FACTOR_TL_CACHE_DEL(
v_factor_id
);

end ;
/

prompt
prompt Creating procedure P_SYS_FACTOR_IDENTITY_INS
prompt ============================================
prompt
create or replace procedure P_SYS_FACTOR_IDENTITY_INS (
                            p_factor_id in integer,
                            p_factor_value in varchar2,
                            p_trust_level_no in integer
                            )

is

begin

-- insert SYS_FACTOR_IDENTITY
BEGIN

insert into sys_factor_identity (
identity_id,
factor_id,
factor_value,
trust_level_no
)
values
(
seq_sys_factor_identity.nextval,
p_factor_id,
p_factor_value,
p_trust_level_no
);

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Duplicated Value for factor !' );
END;


-- Deletes Policy Cache, All Mod, having Trust Level Cond
P_SYS_FACTOR_TL_CACHE_DEL(
p_factor_id
);


end ;
/

prompt
prompt Creating procedure P_SYS_FACTOR_IDENTITY_UPD
prompt ============================================
prompt
create or replace procedure P_SYS_FACTOR_IDENTITY_UPD (
                            p_identity_id in integer,
                            p_factor_value in varchar2,
                            p_trust_level_no in integer
                            )

is

v_factor_id   sys_factor_identity.factor_id%TYPE;

begin

-- Get Factor ID
select factor_id into v_factor_id
from sys_factor_identity
where identity_id = p_identity_id;

-- Begin update sys_factor_identity
BEGIN

update sys_factor_identity set
factor_value = p_factor_value,
trust_level_no = p_trust_level_no,
date_upd = SYSDATE,
user_upd = USER
where identity_id = p_identity_id;

EXCEPTION
when DUP_VAL_ON_INDEX then
raise_application_error(-20010, 'Duplicated Value for factor !' );
END;
-- End update sys_factor_identity


-- Deletes Policy Cache, All Mod, having Trust Level Cond
P_SYS_FACTOR_TL_CACHE_DEL(
v_factor_id
);

end ;
/

prompt
prompt Creating procedure P_SYS_MANAGE_ACC
prompt ===================================
prompt
CREATE OR REPLACE PROCEDURE P_SYS_MANAGE_ACC (
          p_trigger_status in integer
          )

AS

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_MANAGE_ACC (
               p_trigger_status
               );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_MANAGE_AUD
prompt ===================================
prompt
CREATE OR REPLACE PROCEDURE P_SYS_MANAGE_AUD (
          p_audit_trail_param_value in varchar2
          )

AS

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_MANAGE_AUD (
               p_audit_trail_param_value
               );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_MANAGE_AUD_SCHED_JOB
prompt =============================================
prompt
CREATE OR REPLACE PROCEDURE P_SYS_MANAGE_AUD_SCHED_JOB (
          p_scheduler_job_status in integer
          )

AS

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_MANAGE_AUD_SCHED_JOB (
               p_scheduler_job_status
               );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_MANAGE_RTP_DDL
prompt =======================================
prompt
CREATE OR REPLACE PROCEDURE P_SYS_MANAGE_RTP_DDL (
          p_trigger_status in integer
          )

AS

-- Calling SYS procedure for no further Audit Logs
-- and SYS extra-privilege power !!!

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_MANAGE_RTP_DDL (
               p_trigger_status
               );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_POL_DEBUG_DEL
prompt ======================================
prompt
create or replace procedure P_SYS_POL_DEBUG_DEL (
                            p_del_mode in integer,
                            p_username in varchar2,
                            p_policy_type_id in integer,
                            p_policy_id in integer,
                            p_date_log_from in timestamp,
                            p_date_log_to in timestamp
                            )

as

begin

-- Check Delete Mode
if p_del_mode not in (1,2,3,4) then
raise_application_error(-20010, 'Parameter Delete Mode not in 1-ALL, 2-Username, 3-Date Log, 4-Type and Policy !');
end if;


-- Delete 1=All
if p_del_mode = 1 then
delete from sys_pol_debug;

-- Delete 2=Username
elsif p_del_mode = 2 then
      -- Check Username
      if p_username is null then
      raise_application_error(-20010, 'Username not completed for Delete Mode 2-Username !');
      end if;

delete from sys_pol_debug
where username = p_username;

-- Delete 3=Date Log
elsif p_del_mode = 3 then
     -- Check date_log_from
     if p_date_log_from is null then
     raise_application_error(-20010, 'Date log From completed for Delete Mode 3-Date Log !');
     end if;
     -- Check date_log_to
     if p_date_log_to is null then
     raise_application_error(-20010, 'Date log To not completed for Delete Mode 3-Date Log !');
     end if;

delete from sys_pol_debug
where timestamp_sts between p_date_log_from and p_date_log_to;

-- Delete for Pol Type Id and Pol Id
else -- p_del_mode = 4
     -- Check Pol Type Id
     if p_policy_type_id is null then
     raise_application_error(-20010, 'Policy type not completed for Delete Mode 4-Type and Policy !');
     end if;
     -- Check Policy Id
     if p_policy_id is null then
     raise_application_error(-20010, 'Policy not completed for Delete Mode 4-Type and Policy !');
     end if;

delete from sys_pol_debug
where policy_type_id = p_policy_type_id
and policy_id = p_policy_id;

end if;


end; -- end proc
/

prompt
prompt Creating procedure P_SYS_SET_CURRENT_SCHEMA
prompt ===========================================
prompt
create or replace procedure P_SYS_SET_CURRENT_SCHEMA
-- Calling SYS procedure for no further Audit Logs !!!
as

v_schema_cmd   varchar2(2000);

begin

v_schema_cmd := 'alter session set current_schema=OMEGACA';

EXECUTE IMMEDIATE v_schema_cmd ;

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_TRAIL_TRANS
prompt ====================================
prompt
create or replace procedure P_SYS_TRAIL_TRANS
-- Calling SYS procedure for no further Audit Logs !!!
as

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_TRAIL_TRANS;

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_UNF_TRAIL_MARK_MLT
prompt ===========================================
prompt
create or replace procedure P_SYS_UNF_TRAIL_MARK_MLT (
				p_trail_condition in varchar2,
        p_issue_id in integer
				)
-- Calling SYS procedure for no further Audit Logs !!!
as

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_UNF_TRAIL_MARK_MLT(
                     p_trail_condition,
                     p_issue_id
                     );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_UNF_TRAIL_MARK_SNG
prompt ===========================================
prompt
create or replace procedure P_SYS_UNF_TRAIL_MARK_SNG (
				p_row_id in varchar2,
        p_issue_id in integer
				)
-- Calling SYS procedure for no further Audit Logs !!!
as

begin

SYS.OMEGA_CORE_AUDIT.P_SYS_UNF_TRAIL_MARK_SNG(
                     p_row_id,
                     p_issue_id
                     );

end; -- end proc
/

prompt
prompt Creating procedure P_SYS_VERSION_UPGRADE
prompt ========================================
prompt
CREATE OR REPLACE PROCEDURE P_SYS_VERSION_UPGRADE (
                            p_major_version in varchar2,
                            p_mntn_release in varchar2,
                            p_patch_no in varchar2,
                            p_script_name in varchar2
                            )

AS

begin

-- Insert sys_version
insert into sys_version
(
version_id,
major_version,
mntn_release,
patch_no,
script_name
)
values
(
seq_sys_version.nextval,
p_major_version,
p_mntn_release,
p_patch_no,
p_script_name
);


end; -- end proc
/

   
-- 12. Omega CA - Repository Data
prompt 12. Omega CA - Repository Data
prompt ==================================================
prompt
   
prompt 11. SYS_PARAM
-- SYS_PARAM
insert into sys_param (parameter_id, parameter_name, parameter_desc, param_value, param_type)
values (1, 'ACCSLNT', 'Silent Access Control', '1', 1);
insert into sys_param (parameter_id, parameter_name, parameter_desc, param_value, param_type)
values (2, 'AUDMAP', 'Standard Audit Trail Map', '0', 1);
insert into sys_param (parameter_id, parameter_name, parameter_desc, param_value, param_type)
values (3, 'DMLRTC', 'RTP DML Return Code', '1', 1);
insert into sys_param (parameter_id, parameter_name, parameter_desc, param_value, param_type)
values (4, 'DMLMAP', 'RTP DML Trail Map', '0', 1);
prompt
prompt 11. SYS_OBJ_TYPE
-- SYS_OBJ_TYPE
insert into sys_obj_type (obj_type, obj_cat) values ('<*>', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('ACCESS POLICY', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('ADVISOR', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('APPLY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('ASSEMBLY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CAPTURE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CHAIN', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CLASS', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('CLUSTER', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CONSUMER GROUP', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CONTEXT', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CONTROL FILE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('CREDENTIAL', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CUBE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CUBE BUILD PROCESS', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('CUBE DIMENSION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('DATABASE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('DATABASE LINK', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('DESTINATION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('DICTIONARY', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('DIMENSION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('DIRECTORY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('EDITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('EVALUATION CONTEXT', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('FILE GROUP', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('FILE WATCHER', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('FLASHBACK ARCHIVE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('FUNCTION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('IDENTITY POLICY', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('INDEX', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('INDEX PARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('INDEX SUBPARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('INDEXTYPE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JAVA CLASS', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JAVA DATA', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JAVA RESOURCE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JAVA SOURCE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JOB', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('JOB CLASS', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('LIBRARY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('LOB', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('LOB PARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('LOB SUBPARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('LOCATION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('MATERIALIZED VIEW', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('MATERIALIZED VIEW LOG', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('MEASURE FOLDER', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('METHOD', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('MINING MODEL', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('NEXT OBJECT', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('NOTIFICATION', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('OPERATOR', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('OUTLINE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('PACKAGE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('PACKAGE BODY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('PROCEDURE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('PROFILE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('PROGRAM', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('QUEUE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('RECYCLEBIN', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('RESOURCE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('RESOURCE COST', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('RESOURCE MANAGER', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('RESOURCE PLAN', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('RESTORE POINT', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('REWRITE EQUIVALENCE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('ROLE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('ROLLBACK SEGMENT', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('RULE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('RULE SET', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('SCHEDULE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('SCHEDULER GROUP', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('SCHEMA', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SEQUENCE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('SESSION', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SQL MANAGEMENT OBJECT', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SQL PROFILE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SQL TUNING SET', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SUBSCRIPTION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('SUMMARY', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('SYNONYM', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TABLE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TABLE PARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TABLE SUBPARTITION', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TABLESPACE', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('TRANSACTION', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('TRIGGER', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TYPE', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('TYPE BODY', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('USER', 'OTHER');
insert into sys_obj_type (obj_type, obj_cat) values ('VIEW', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('WINDOW', 'DBA_OBJ');
insert into sys_obj_type (obj_type, obj_cat) values ('XML SCHEMA', 'DBA_OBJ');
prompt
prompt 11. SYS_STMT
-- SYS_STMT
insert into sys_stmt (stmt_name, stmt_type) values ('<*>', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('ADMINISTER', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('ALTER', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('ALTER SESSION', 'SEC');
insert into sys_stmt (stmt_name, stmt_type) values ('ALTER SYSTEM', 'SYC');
insert into sys_stmt (stmt_name, stmt_type) values ('ANALYZE', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('ASSOCIATE STATISTICS', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('AUDIT', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('BACKUP', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('BECOME', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('CALL', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('CHANGE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('COMMENT', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('COMMIT', 'TNC');
insert into sys_stmt (stmt_name, stmt_type) values ('CREATE', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('DEBUG', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('DECLARE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('DELETE', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('DEQUEUE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('DISABLE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('DISASSOCIATE STATISTICS', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('DROP', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('ENABLE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('ENQUEUE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('EXECUTE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('EXEMPT', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('EXIT', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('EXPLAIN PLAN', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('EXPORT', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('FLASHBACK', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('GRANT', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('IMPORT', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('INDEX', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('INSERT', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('LOCK', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('LOCK TABLE', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('LOGOFF', 'SEC');
insert into sys_stmt (stmt_name, stmt_type) values ('LOGON', 'SEC');
insert into sys_stmt (stmt_name, stmt_type) values ('MANAGE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('MERGE', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('NOAUDIT', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('PURGE', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('READ', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('RENAME', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('REVOKE', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('REWRITE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('ROLLBACK', 'TNC');
insert into sys_stmt (stmt_name, stmt_type) values ('SAVEPOINT', 'TNC');
insert into sys_stmt (stmt_name, stmt_type) values ('SELECT', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('SET', 'SEC');
insert into sys_stmt (stmt_name, stmt_type) values ('SET CONSTRAINT', 'TNC');
insert into sys_stmt (stmt_name, stmt_type) values ('SET TRANSACTION', 'TNC');
insert into sys_stmt (stmt_name, stmt_type) values ('TRUNCATE', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('UNDER', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('UNDROP', 'DDL');
insert into sys_stmt (stmt_name, stmt_type) values ('UPDATE', 'DML');
insert into sys_stmt (stmt_name, stmt_type) values ('VALIDATE', 'OTHER');
insert into sys_stmt (stmt_name, stmt_type) values ('WRITE', 'OTHER');
prompt
prompt 11. ACM_SYS_TABLE_PRIVILEGE_MAP
-- ACM_SYS_TABLE_PRIVILEGE_MAP
insert into acm_sys_table_privilege_map (privilege, name) values ('0', 'ALTER');
insert into acm_sys_table_privilege_map (privilege, name) values ('1', 'AUDIT');
insert into acm_sys_table_privilege_map (privilege, name) values ('2', 'COMMENT');
insert into acm_sys_table_privilege_map (privilege, name) values ('3', 'DELETE');
insert into acm_sys_table_privilege_map (privilege, name) values ('4', 'GRANT');
insert into acm_sys_table_privilege_map (privilege, name) values ('5', 'INDEX');
insert into acm_sys_table_privilege_map (privilege, name) values ('6', 'INSERT');
insert into acm_sys_table_privilege_map (privilege, name) values ('7', 'LOCK');
insert into acm_sys_table_privilege_map (privilege, name) values ('8', 'RENAME');
insert into acm_sys_table_privilege_map (privilege, name) values ('9', 'SELECT');
insert into acm_sys_table_privilege_map (privilege, name) values ('10', 'UPDATE');
insert into acm_sys_table_privilege_map (privilege, name) values ('11', 'REFERENCES');
insert into acm_sys_table_privilege_map (privilege, name) values ('12', 'EXECUTE');
insert into acm_sys_table_privilege_map (privilege, name) values ('16', 'CREATE');
insert into acm_sys_table_privilege_map (privilege, name) values ('17', 'READ');
insert into acm_sys_table_privilege_map (privilege, name) values ('18', 'WRITE');
insert into acm_sys_table_privilege_map (privilege, name) values ('20', 'ENQUEUE');
insert into acm_sys_table_privilege_map (privilege, name) values ('21', 'DEQUEUE');
insert into acm_sys_table_privilege_map (privilege, name) values ('22', 'UNDER');
insert into acm_sys_table_privilege_map (privilege, name) values ('23', 'ON COMMIT REFRESH');
insert into acm_sys_table_privilege_map (privilege, name) values ('24', 'QUERY REWRITE');
insert into acm_sys_table_privilege_map (privilege, name) values ('26', 'DEBUG');
insert into acm_sys_table_privilege_map (privilege, name) values ('27', 'FLASHBACK');
insert into acm_sys_table_privilege_map (privilege, name) values ('28', 'MERGE VIEW');
insert into acm_sys_table_privilege_map (privilege, name) values ('29', 'USE');
insert into acm_sys_table_privilege_map (privilege, name) values ('30', 'FLASHBACK ARCHIVE');
prompt
prompt 11. ACM_SYS_TABLE_PRIVILEGE
-- ACM_SYS_TABLE_PRIVILEGE
insert into acm_sys_table_privilege (object_type, priv_name) values ('CLUSTER', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CLUSTER', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE', 'UPDATE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE DIMENSION', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE DIMENSION', 'DELETE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE DIMENSION', 'INSERT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE DIMENSION', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('CUBE DIMENSION', 'UPDATE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('DIRECTORY', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('DIRECTORY', 'READ');
insert into acm_sys_table_privilege (object_type, priv_name) values ('DIRECTORY', 'WRITE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('EDITION', 'USE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('FLASHBACK ARCHIVE', 'FLASHBACK ARCHIVE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('FUNCTION', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('FUNCTION', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('INDEXTYPE', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('JAVA CLASS', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('JAVA CLASS', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('JOB', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('LIBRARY', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'DELETE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'FLASHBACK');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'INSERT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'ON COMMIT REFRESH');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'QUERY REWRITE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MATERIALIZED VIEW', 'UPDATE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MEASURE FOLDER', 'DELETE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MEASURE FOLDER', 'INSERT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MINING MODEL', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('MINING MODEL', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('OPERATOR', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('PACKAGE', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('PACKAGE', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('PROCEDURE', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('PROCEDURE', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SCHEDULE', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SCHEDULE', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SCHEDULER GROUP', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SCHEDULER GROUP', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SEQUENCE', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('SEQUENCE', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'ALTER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'DELETE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'FLASHBACK');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'INDEX');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'INSERT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'ON COMMIT REFRESH');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'QUERY REWRITE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'REFERENCES');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TABLE', 'UPDATE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TYPE', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TYPE', 'EXECUTE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('TYPE', 'UNDER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'DEBUG');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'DELETE');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'FLASHBACK');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'INSERT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'MERGE VIEW');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'REFERENCES');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'SELECT');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'UNDER');
insert into acm_sys_table_privilege (object_type, priv_name) values ('VIEW', 'UPDATE');
prompt
prompt 11. AUD_SYS_ACTION
-- AUD_SYS_ACTION
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (0, 'UNKNOWN', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (1, 'CREATE TABLE', 'CREATE', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (2, 'INSERT', 'INSERT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (3, 'SELECT', 'SELECT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (4, 'CREATE CLUSTER', 'CREATE', 'CLUSTER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (5, 'ALTER CLUSTER', 'ALTER', 'CLUSTER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (6, 'UPDATE', 'UPDATE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (7, 'DELETE', 'DELETE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (8, 'DROP CLUSTER', 'DROP', 'CLUSTER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (9, 'CREATE INDEX', 'CREATE', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (10, 'DROP INDEX', 'DROP', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (11, 'ALTER INDEX', 'ALTER', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (12, 'DROP TABLE', 'DROP', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (13, 'CREATE SEQUENCE', 'CREATE', 'SEQUENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (14, 'ALTER SEQUENCE', 'ALTER', 'SEQUENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (15, 'ALTER TABLE', 'ALTER', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (16, 'DROP SEQUENCE', 'DROP', 'SEQUENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (17, 'GRANT OBJECT', 'GRANT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (18, 'REVOKE OBJECT', 'REVOKE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (19, 'CREATE SYNONYM', 'CREATE', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (20, 'DROP SYNONYM', 'DROP', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (21, 'CREATE VIEW', 'CREATE', 'VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (22, 'DROP VIEW', 'DROP', 'VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (23, 'VALIDATE INDEX', 'VALIDATE', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (24, 'CREATE PROCEDURE', 'CREATE', 'PROCEDURE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (25, 'ALTER PROCEDURE', 'ALTER', 'PROCEDURE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (26, 'LOCK', 'LOCK', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (27, 'NO-OP', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (28, 'RENAME', 'RENAME', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (29, 'COMMENT', 'COMMENT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (30, 'AUDIT OBJECT', 'AUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (31, 'NOAUDIT OBJECT', 'NOAUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (32, 'CREATE DATABASE LINK', 'CREATE', 'DATABASE LINK');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (33, 'DROP DATABASE LINK', 'DROP', 'DATABASE LINK');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (34, 'CREATE DATABASE', 'CREATE', 'DATABASE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (35, 'ALTER DATABASE', 'ALTER', 'DATABASE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (36, 'CREATE ROLLBACK SEG', 'CREATE', 'ROLLBACK SEGMENT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (37, 'ALTER ROLLBACK SEG', 'ALTER', 'ROLLBACK SEGMENT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (38, 'DROP ROLLBACK SEG', 'DROP', 'ROLLBACK SEGMENT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (39, 'CREATE TABLESPACE', 'CREATE', 'TABLESPACE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (40, 'ALTER TABLESPACE', 'ALTER', 'TABLESPACE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (41, 'DROP TABLESPACE', 'DROP', 'TABLESPACE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (42, 'ALTER SESSION', 'ALTER', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (43, 'ALTER USER', 'ALTER', 'USER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (44, 'COMMIT', 'COMMIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (45, 'ROLLBACK', 'ROLLBACK', 'TRANSACTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (46, 'SAVEPOINT', 'SAVEPOINT', 'TRANSACTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (47, 'PL/SQL EXECUTE', 'EXECUTE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (48, 'SET TRANSACTION', 'SET TRANSACTION', 'TRANSACTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (49, 'ALTER SYSTEM', 'ALTER SYSTEM', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (50, 'EXPLAIN', 'EXPLAIN PLAN', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (51, 'CREATE USER', 'CREATE', 'USER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (52, 'CREATE ROLE', 'CREATE', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (53, 'DROP USER', 'DROP', 'USER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (54, 'DROP ROLE', 'DROP', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (55, 'SET ROLE', 'SET', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (56, 'CREATE SCHEMA', 'CREATE', 'SCHEMA');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (57, 'CREATE CONTROL FILE', 'CREATE', 'CONTROL FILE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (59, 'CREATE TRIGGER', 'CREATE', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (60, 'ALTER TRIGGER', 'ALTER', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (61, 'DROP TRIGGER', 'DROP', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (62, 'ANALYZE TABLE', 'ANALYZE', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (63, 'ANALYZE INDEX', 'ANALYZE', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (64, 'ANALYZE CLUSTER', 'ANALYZE', 'CLUSTER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (65, 'CREATE PROFILE', 'CREATE', 'PROFILE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (66, 'DROP PROFILE', 'DROP', 'PROFILE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (67, 'ALTER PROFILE', 'ALTER', 'PROFILE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (68, 'DROP PROCEDURE', 'DROP', 'PROCEDURE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (70, 'ALTER RESOURCE COST', 'ALTER', 'RESOURCE COST');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (71, 'CREATE MATERIALIZED VIEW LOG', 'CREATE', 'MATERIALIZED VIEW LOG');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (72, 'ALTER MATERIALIZED VIEW LOG', 'ALTER', 'MATERIALIZED VIEW LOG');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (73, 'DROP MATERIALIZED VIEW LOG', 'DROP', 'MATERIALIZED VIEW LOG');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (74, 'CREATE MATERIALIZED VIEW', 'CREATE', 'MATERIALIZED VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (75, 'ALTER MATERIALIZED VIEW', 'ALTER', 'MATERIALIZED VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (76, 'DROP MATERIALIZED VIEW', 'DROP', 'MATERIALIZED VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (77, 'CREATE TYPE', 'CREATE', 'TYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (78, 'DROP TYPE', 'DROP', 'TYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (79, 'ALTER ROLE', 'ALTER', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (80, 'ALTER TYPE', 'ALTER', 'TYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (81, 'CREATE TYPE BODY', 'CREATE', 'TYPE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (82, 'ALTER TYPE BODY', 'ALTER', 'TYPE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (83, 'DROP TYPE BODY', 'DROP', 'TYPE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (84, 'DROP LIBRARY', 'DROP', 'LIBRARY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (85, 'TRUNCATE TABLE', 'TRUNCATE', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (86, 'TRUNCATE CLUSTER', 'TRUNCATE', 'CLUSTER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (88, 'ALTER VIEW', 'ALTER', 'VIEW');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (91, 'CREATE FUNCTION', 'CREATE', 'FUNCTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (92, 'ALTER FUNCTION', 'ALTER', 'FUNCTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (93, 'DROP FUNCTION', 'DROP', 'FUNCTION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (94, 'CREATE PACKAGE', 'CREATE', 'PACKAGE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (95, 'ALTER PACKAGE', 'ALTER', 'PACKAGE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (96, 'DROP PACKAGE', 'DROP', 'PACKAGE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (97, 'CREATE PACKAGE BODY', 'CREATE', 'PACKAGE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (98, 'ALTER PACKAGE BODY', 'ALTER', 'PACKAGE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (99, 'DROP PACKAGE BODY', 'DROP', 'PACKAGE BODY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (100, 'LOGON', 'LOGON', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (101, 'LOGOFF', 'LOGOFF', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (102, 'LOGOFF BY CLEANUP', 'LOGOFF', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (103, 'SESSION REC', '<*>', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (104, 'SYSTEM AUDIT', 'AUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (105, 'SYSTEM NOAUDIT', 'NOAUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (106, 'AUDIT DEFAULT', 'AUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (107, 'NOAUDIT DEFAULT', 'NOAUDIT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (108, 'SYSTEM GRANT', 'GRANT', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (109, 'SYSTEM REVOKE', 'REVOKE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (110, 'CREATE PUBLIC SYNONYM', 'CREATE', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (111, 'DROP PUBLIC SYNONYM', 'DROP', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (112, 'CREATE PUBLIC DATABASE LINK', 'CREATE', 'DATABASE LINK');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (113, 'DROP PUBLIC DATABASE LINK', 'DROP', 'DATABASE LINK');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (114, 'GRANT ROLE', 'GRANT', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (115, 'REVOKE ROLE', 'REVOKE', 'ROLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (116, 'EXECUTE PROCEDURE', 'EXECUTE', 'PROCEDURE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (117, 'USER COMMENT', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (118, 'ENABLE TRIGGER', 'ENABLE', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (119, 'DISABLE TRIGGER', 'DISABLE', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (120, 'ENABLE ALL TRIGGERS', 'ENABLE', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (121, 'DISABLE ALL TRIGGERS', 'DISABLE', 'TRIGGER');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (122, 'NETWORK ERROR', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (123, 'EXECUTE TYPE', 'EXECUTE', 'TYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (128, 'FLASHBACK', 'FLASHBACK', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (129, 'CREATE SESSION', 'CREATE', 'SESSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (130, 'ALTER MINING MODEL', 'ALTER', 'MINING MODEL');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (131, 'SELECT MINING MODEL', 'SELECT', 'MINING MODEL');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (133, 'CREATE MINING MODEL', 'CREATE', 'MINING MODEL');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (134, 'ALTER PUBLIC SYNONYM', 'ALTER', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (135, 'DIRECTORY EXECUTE', 'EXECUTE', 'DIRECTORY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (136, 'SQL*LOADER DIRECT PATH LOAD', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (137, 'DATAPUMP DIRECT PATH UNLOAD', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (157, 'CREATE DIRECTORY', 'CREATE', 'DIRECTORY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (158, 'DROP DIRECTORY', 'DROP', 'DIRECTORY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (159, 'CREATE LIBRARY', 'CREATE', 'LIBRARY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (160, 'CREATE JAVA', 'CREATE', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (161, 'ALTER JAVA', 'ALTER', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (162, 'DROP JAVA', 'DROP', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (163, 'CREATE OPERATOR', 'CREATE', 'OPERATOR');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (164, 'CREATE INDEXTYPE', 'CREATE', 'INDEXTYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (165, 'DROP INDEXTYPE', 'DROP', 'INDEXTYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (166, 'ALTER INDEXTYPE', 'ALTER', 'INDEXTYPE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (167, 'DROP OPERATOR', 'DROP', 'OPERATOR');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (168, 'ASSOCIATE STATISTICS', 'ASSOCIATE STATISTICS', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (169, 'DISASSOCIATE STATISTICS', 'DISASSOCIATE STATISTICS', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (170, 'CALL METHOD', 'CALL', 'METHOD');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (171, 'CREATE SUMMARY', 'CREATE', 'SUMMARY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (172, 'ALTER SUMMARY', 'ALTER', 'SUMMARY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (173, 'DROP SUMMARY', 'DROP', 'SUMMARY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (174, 'CREATE DIMENSION', 'CREATE', 'DIMENSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (175, 'ALTER DIMENSION', 'ALTER', 'DIMENSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (176, 'DROP DIMENSION', 'DROP', 'DIMENSION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (177, 'CREATE CONTEXT', 'CREATE', 'CONTEXT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (178, 'DROP CONTEXT', 'DROP', 'CONTEXT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (179, 'ALTER OUTLINE', 'ALTER', 'OUTLINE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (180, 'CREATE OUTLINE', 'CREATE', 'OUTLINE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (181, 'DROP OUTLINE', 'DROP', 'OUTLINE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (182, 'UPDATE INDEXES', 'UPDATE', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (183, 'ALTER OPERATOR', 'ALTER', 'OPERATOR');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (192, 'ALTER SYNONYM', 'ALTER', 'SYNONYM');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (197, 'PURGE USER_RECYCLEBIN', 'PURGE', 'RECYCLEBIN');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (198, 'PURGE DBA_RECYCLEBIN', 'PURGE', 'RECYCLEBIN');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (199, 'PURGE TABLESPACE', 'PURGE', 'TABLESPACE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (200, 'PURGE TABLE', 'PURGE', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (201, 'PURGE INDEX', 'PURGE', 'INDEX');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (202, 'UNDROP OBJECT', 'UNDROP', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (204, 'FLASHBACK DATABASE', 'FLASHBACK', 'DATABASE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (205, 'FLASHBACK TABLE', 'FLASHBACK', 'TABLE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (206, 'CREATE RESTORE POINT', 'CREATE', 'RESTORE POINT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (207, 'DROP RESTORE POINT', 'DROP', 'RESTORE POINT');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (208, 'PROXY AUTHENTICATION ONLY', '<*>', '<*>');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (209, 'DECLARE REWRITE EQUIVALENCE', 'DECLARE', 'REWRITE EQUIVALENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (210, 'ALTER REWRITE EQUIVALENCE', 'ALTER', 'REWRITE EQUIVALENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (211, 'DROP REWRITE EQUIVALENCE', 'DROP', 'REWRITE EQUIVALENCE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (212, 'CREATE EDITION', 'CREATE', 'EDITION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (213, 'ALTER EDITION', 'ALTER', 'EDITION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (214, 'DROP EDITION', 'DROP', 'EDITION');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (215, 'DROP ASSEMBLY', 'DROP', 'ASSEMBLY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (216, 'CREATE ASSEMBLY', 'CREATE', 'ASSEMBLY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (217, 'ALTER ASSEMBLY', 'ALTER', 'ASSEMBLY');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (218, 'CREATE FLASHBACK ARCHIVE', 'CREATE', 'FLASHBACK ARCHIVE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (219, 'ALTER FLASHBACK ARCHIVE', 'ALTER', 'FLASHBACK ARCHIVE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (220, 'DROP FLASHBACK ARCHIVE', 'DROP', 'FLASHBACK ARCHIVE');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (225, 'ALTER DATABASE LINK', 'ALTER', 'DATABASE LINK');
insert into aud_sys_action (action_id, action_name, stmt_name, obj_type) values (305, 'ALTER PUBLIC DATABASE LINK', 'ALTER', 'DATABASE LINK');
prompt
prompt 11. AUD_SYS_OBJ_OPT
-- AUD_SYS_OBJ_OPT
insert into aud_sys_obj_opt (obj_type, audit_option) values ('DIRECTORY', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('DIRECTORY', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('DIRECTORY', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('DIRECTORY', 'READ');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('DIRECTORY', 'WRITE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('FUNCTION', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('FUNCTION', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('FUNCTION', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA CLASS', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA CLASS', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA CLASS', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA RESOURCE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA RESOURCE', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA RESOURCE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA SOURCE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA SOURCE', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('JAVA SOURCE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('LIBRARY', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('LIBRARY', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'ALTER');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'COMMENT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'DELETE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'INDEX');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'INSERT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'LOCK');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'SELECT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MATERIALIZED VIEW', 'UPDATE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MINING MODEL', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MINING MODEL', 'COMMENT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MINING MODEL', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MINING MODEL', 'RENAME');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('MINING MODEL', 'SELECT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PACKAGE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PACKAGE', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PACKAGE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PROCEDURE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PROCEDURE', 'EXECUTE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('PROCEDURE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('SEQUENCE', 'ALTER');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('SEQUENCE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('SEQUENCE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('SEQUENCE', 'SELECT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'ALTER');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'COMMENT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'DELETE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'FLASHBACK');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'INDEX');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'INSERT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'LOCK');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'RENAME');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'SELECT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TABLE', 'UPDATE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TYPE', 'ALTER');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TYPE', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('TYPE', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'AUDIT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'COMMENT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'DELETE');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'FLASHBACK');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'GRANT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'INSERT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'LOCK');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'RENAME');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'SELECT');
insert into aud_sys_obj_opt (obj_type, audit_option) values ('VIEW', 'UPDATE');
prompt
prompt 11. AUD_SYS_OBJ_OPT_ACT
-- AUD_SYS_OBJ_OPT_ACT
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'EXECUTE', 'EXECUTE', 135, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'READ', 'READ', 0, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('DIRECTORY', 'WRITE', 'WRITE', 0, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('FUNCTION', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('FUNCTION', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('FUNCTION', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('FUNCTION', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('FUNCTION', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA CLASS', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA CLASS', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA CLASS', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA CLASS', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA CLASS', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA RESOURCE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA RESOURCE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA RESOURCE', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA RESOURCE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA RESOURCE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA SOURCE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA SOURCE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA SOURCE', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA SOURCE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('JAVA SOURCE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('LIBRARY', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('LIBRARY', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('LIBRARY', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'ALTER', 'ALTER', 75, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'COMMENT', 'COMMENT', 29, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'DELETE', 'DELETE', 7, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'INDEX', 'INDEX', 9, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'INSERT', 'INSERT', 2, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'LOCK', 'LOCK', 26, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'SELECT', 'SELECT', 3, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MATERIALIZED VIEW', 'UPDATE', 'UPDATE', 6, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'AUDIT', 'AUDIT', 30, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'AUDIT', 'NOAUDIT', 31, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'COMMENT', 'COMMENT', 29, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'GRANT', 'GRANT', 17, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'GRANT', 'REVOKE', 18, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'RENAME', 'RENAME', 28, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('MINING MODEL', 'SELECT', 'SELECT', 131, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PACKAGE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PACKAGE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PACKAGE', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PACKAGE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PACKAGE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PROCEDURE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PROCEDURE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PROCEDURE', 'EXECUTE', 'EXECUTE', 116, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PROCEDURE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('PROCEDURE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'ALTER', 'ALTER', 14, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('SEQUENCE', 'SELECT', 'SELECT', 3, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'ALTER', 'ALTER', 15, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'COMMENT', 'COMMENT', 29, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'DELETE', 'DELETE', 7, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'FLASHBACK', 'FLASHBACK', 128, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'INDEX', 'INDEX', 9, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'INSERT', 'INSERT', 2, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'LOCK', 'LOCK', 26, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'RENAME', 'RENAME', 28, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'SELECT', 'SELECT', 3, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TABLE', 'UPDATE', 'UPDATE', 6, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TYPE', 'ALTER', 'ALTER', 80, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TYPE', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TYPE', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TYPE', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('TYPE', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'AUDIT', 'AUDIT', 30, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'AUDIT', 'NOAUDIT', 31, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'COMMENT', 'COMMENT', 29, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'DELETE', 'DELETE', 7, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'FLASHBACK', 'FLASHBACK', 128, 0);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'GRANT', 'GRANT', 17, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'GRANT', 'REVOKE', 18, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'INSERT', 'INSERT', 2, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'LOCK', 'LOCK', 26, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'RENAME', 'RENAME', 28, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'SELECT', 'SELECT', 3, 1);
insert into aud_sys_obj_opt_act (obj_type, audit_option, stmt_name, action_id, act_enabled) values ('VIEW', 'UPDATE', 'UPDATE', 6, 1);
prompt
prompt 11. AUD_SYS_STMT_OPT
-- AUD_SYS_STMT_OPT
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (3, 'ALTER SYSTEM', 0, 1, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (4, 'SYSTEM AUDIT', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (5, 'CREATE SESSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (6, 'ALTER SESSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (7, 'RESTRICTED SESSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (8, 'TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (9, 'CLUSTER', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (10, 'CREATE TABLESPACE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (11, 'ALTER TABLESPACE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (12, 'MANAGE TABLESPACE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (13, 'DROP TABLESPACE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (14, 'TABLESPACE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (15, 'UNLIMITED TABLESPACE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (16, 'USER', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (17, 'ROLLBACK SEGMENT', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (18, 'TYPE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (19, 'INDEX', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (20, 'CREATE USER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (21, 'BECOME USER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (22, 'ALTER USER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (23, 'DROP USER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (24, 'SYNONYM', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (25, 'PUBLIC SYNONYM', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (26, 'VIEW', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (27, 'SEQUENCE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (28, 'DATABASE LINK', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (29, 'PUBLIC DATABASE LINK', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (30, 'CREATE ROLLBACK SEGMENT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (31, 'ALTER ROLLBACK SEGMENT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (32, 'DROP ROLLBACK SEGMENT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (33, 'ROLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (34, 'DIMENSION', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (35, 'PROCEDURE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (36, 'TRIGGER', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (37, 'PROFILE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (38, 'DIRECTORY', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (39, 'MATERIALIZED VIEW', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (40, 'CREATE TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (41, 'CREATE ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (42, 'ALTER ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (43, 'BACKUP ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (44, 'DROP ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (45, 'LOCK ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (46, 'COMMENT ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (47, 'SELECT ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (48, 'INSERT ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (49, 'UPDATE ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (50, 'DELETE ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (51, 'OUTLINE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (52, 'MINING MODEL', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (54, 'ALTER TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (57, 'LOCK TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (58, 'COMMENT TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (60, 'CREATE CLUSTER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (61, 'CREATE ANY CLUSTER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (62, 'ALTER ANY CLUSTER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (63, 'DROP ANY CLUSTER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (65, 'SELECT TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (66, 'INSERT TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (67, 'UPDATE TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (68, 'DELETE TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (69, 'GRANT TABLE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (71, 'CREATE ANY INDEX', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (72, 'ALTER ANY INDEX', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (73, 'DROP ANY INDEX', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (77, 'NOT EXISTS', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (78, 'ALL STATEMENTS', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (80, 'CREATE SYNONYM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (81, 'CREATE ANY SYNONYM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (82, 'DROP ANY SYNONYM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (83, 'SYSDBA', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (84, 'SYSOPER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (85, 'CREATE PUBLIC SYNONYM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (86, 'DROP PUBLIC SYNONYM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (90, 'CREATE VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (91, 'CREATE ANY VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (92, 'DROP ANY VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (93, 'CREATE JAVA SOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (94, 'CREATE JAVA CLASS', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (95, 'CREATE JAVA RESOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (96, 'ALTER JAVA SOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (97, 'ALTER JAVA CLASS', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (98, 'ALTER JAVA RESOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (99, 'DROP JAVA SOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (100, 'DROP JAVA CLASS', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (101, 'DROP JAVA RESOURCE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (103, 'ALTER SEQUENCE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (104, 'SELECT SEQUENCE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (105, 'CREATE SEQUENCE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (106, 'CREATE ANY SEQUENCE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (107, 'ALTER ANY SEQUENCE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (108, 'DROP ANY SEQUENCE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (109, 'SELECT ANY SEQUENCE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (111, 'GRANT SEQUENCE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (115, 'CREATE DATABASE LINK', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (120, 'CREATE PUBLIC DATABASE LINK', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (121, 'DROP PUBLIC DATABASE LINK', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (125, 'CREATE ROLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (126, 'DROP ANY ROLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (127, 'GRANT ANY ROLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (128, 'ALTER ANY ROLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (130, 'AUDIT ANY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (131, 'SYSTEM GRANT', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (135, 'ALTER DATABASE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (138, 'FORCE TRANSACTION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (139, 'FORCE ANY TRANSACTION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (140, 'CREATE PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (141, 'CREATE ANY PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (142, 'ALTER ANY PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (143, 'DROP ANY PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (144, 'EXECUTE ANY PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (146, 'EXECUTE PROCEDURE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (147, 'GRANT PROCEDURE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (151, 'CREATE TRIGGER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (152, 'CREATE ANY TRIGGER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (153, 'ALTER ANY TRIGGER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (154, 'DROP ANY TRIGGER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (160, 'CREATE PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (161, 'ALTER PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (162, 'DROP PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (163, 'ALTER RESOURCE COST', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (165, 'ANALYZE ANY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (167, 'GRANT ANY PRIVILEGE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (172, 'CREATE MATERIALIZED VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (173, 'CREATE ANY MATERIALIZED VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (174, 'ALTER ANY MATERIALIZED VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (175, 'DROP ANY MATERIALIZED VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (176, 'NETWORK', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (177, 'CREATE ANY DIRECTORY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (178, 'DROP ANY DIRECTORY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (179, 'GRANT DIRECTORY', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (180, 'CREATE TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (181, 'CREATE ANY TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (182, 'ALTER ANY TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (183, 'DROP ANY TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (184, 'EXECUTE ANY TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (186, 'UNDER ANY TYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (187, 'GRANT TYPE', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (188, 'CREATE LIBRARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (189, 'CREATE ANY LIBRARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (190, 'ALTER ANY LIBRARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (191, 'DROP ANY LIBRARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (192, 'EXECUTE ANY LIBRARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (193, 'EXECUTE LIBRARY', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (200, 'CREATE OPERATOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (201, 'CREATE ANY OPERATOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (202, 'ALTER ANY OPERATOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (203, 'DROP ANY OPERATOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (204, 'EXECUTE ANY OPERATOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (205, 'CREATE INDEXTYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (206, 'CREATE ANY INDEXTYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (207, 'ALTER ANY INDEXTYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (208, 'DROP ANY INDEXTYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (209, 'UNDER ANY VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (210, 'QUERY REWRITE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (211, 'GLOBAL QUERY REWRITE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (212, 'EXECUTE ANY INDEXTYPE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (213, 'UNDER ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (214, 'CREATE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (215, 'CREATE ANY DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (216, 'ALTER ANY DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (217, 'DROP ANY DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (218, 'MANAGE ANY QUEUE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (219, 'ENQUEUE ANY QUEUE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (220, 'DEQUEUE ANY QUEUE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (221, 'CONTEXT', 0, 1, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (222, 'CREATE ANY CONTEXT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (223, 'DROP ANY CONTEXT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (224, 'CREATE ANY OUTLINE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (225, 'ALTER ANY OUTLINE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (226, 'DROP ANY OUTLINE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (227, 'ADMINISTER RESOURCE MANAGER', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (228, 'ADMINISTER DATABASE TRIGGER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (233, 'MERGE ANY VIEW', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (234, 'ON COMMIT REFRESH', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (235, 'EXEMPT ACCESS POLICY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (236, 'RESUMABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (237, 'SELECT ANY DICTIONARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (238, 'DEBUG CONNECT SESSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (241, 'DEBUG ANY PROCEDURE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (242, 'DEBUG PROCEDURE', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (243, 'FLASHBACK ANY TABLE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (244, 'GRANT ANY OBJECT PRIVILEGE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (245, 'CREATE EVALUATION CONTEXT', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (246, 'CREATE ANY EVALUATION CONTEXT', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (247, 'ALTER ANY EVALUATION CONTEXT', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (248, 'DROP ANY EVALUATION CONTEXT', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (249, 'EXECUTE ANY EVALUATION CONTEXT', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (250, 'CREATE RULE SET', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (251, 'CREATE ANY RULE SET', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (252, 'ALTER ANY RULE SET', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (253, 'DROP ANY RULE SET', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (254, 'EXECUTE ANY RULE SET', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (255, 'EXPORT FULL DATABASE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (256, 'IMPORT FULL DATABASE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (257, 'CREATE RULE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (258, 'CREATE ANY RULE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (259, 'ALTER ANY RULE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (260, 'DROP ANY RULE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (261, 'EXECUTE ANY RULE', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (262, 'ANALYZE ANY DICTIONARY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (263, 'ADVISOR', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (264, 'CREATE JOB', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (265, 'CREATE ANY JOB', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (266, 'EXECUTE ANY PROGRAM', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (267, 'EXECUTE ANY CLASS', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (268, 'MANAGE SCHEDULER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (269, 'SELECT ANY TRANSACTION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (270, 'DROP ANY SQL PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (271, 'ALTER ANY SQL PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (272, 'ADMINISTER SQL TUNING SET', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (273, 'ADMINISTER ANY SQL TUNING SET', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (274, 'CREATE ANY SQL PROFILE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (275, 'EXEMPT IDENTITY POLICY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (276, 'MANAGE FILE GROUP', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (277, 'MANAGE ANY FILE GROUP', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (278, 'READ ANY FILE GROUP', 1, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (279, 'CHANGE NOTIFICATION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (280, 'CREATE EXTERNAL JOB', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (281, 'CREATE ANY EDITION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (282, 'DROP ANY EDITION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (283, 'ALTER ANY EDITION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (284, 'CREATE ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (285, 'CREATE ANY ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (286, 'ALTER ANY ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (287, 'DROP ANY ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (288, 'EXECUTE ANY ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (289, 'EXECUTE ASSEMBLY', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (290, 'CREATE MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (291, 'CREATE ANY MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (292, 'DROP ANY MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (293, 'SELECT ANY MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (294, 'ALTER ANY MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (295, 'COMMENT ANY MINING MODEL', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (296, 'ALTER MINING MODEL', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (297, 'COMMENT MINING MODEL', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (298, 'GRANT MINING MODEL', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (300, 'SELECT MINING MODEL', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (301, 'CREATE CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (302, 'ALTER ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (303, 'CREATE ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (304, 'DELETE ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (305, 'DROP ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (306, 'INSERT ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (307, 'SELECT ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (308, 'CREATE CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (309, 'ALTER ANY CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (310, 'CREATE ANY CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (311, 'DROP ANY CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (312, 'SELECT ANY CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (313, 'UPDATE ANY CUBE', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (314, 'CREATE MEASURE FOLDER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (315, 'CREATE ANY MEASURE FOLDER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (316, 'DELETE ANY MEASURE FOLDER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (317, 'DROP ANY MEASURE FOLDER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (318, 'INSERT ANY MEASURE FOLDER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (319, 'CREATE CUBE BUILD PROCESS', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (320, 'CREATE ANY CUBE BUILD PROCESS', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (321, 'DROP ANY CUBE BUILD PROCESS', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (322, 'UPDATE ANY CUBE BUILD PROCESS', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (323, 'COMMENT EDITION', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (324, 'GRANT EDITION', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (325, 'USE EDITION', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (326, 'UPDATE ANY CUBE DIMENSION', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (327, 'ADMINISTER SQL MANAGEMENT OBJECT', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (328, 'ALTER PUBLIC DATABASE LINK', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (329, 'ALTER DATABASE LINK', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (330, 'DIRECT_PATH LOAD', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (331, 'DIRECT_PATH UNLOAD', 0, 0, 0);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (350, 'FLASHBACK ARCHIVE ADMINISTER', 0, 0, 1);
insert into aud_sys_stmt_opt (option_id, option_name, property, is_shortcut, is_sys_priv) values (351, 'EXEMPT REDACTION POLICY', 0, 0, 1);
prompt
prompt 11. AUD_SYS_STMT_OPT_ACT
-- AUD_SYS_STMT_OPT_ACT
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (3, 'ALTER SYSTEM', '<*>', 49, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (4, 'AUDIT', '<*>', 104, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (4, 'AUDIT', '<*>', 106, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (4, 'NOAUDIT', '<*>', 105, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (4, 'NOAUDIT', '<*>', 107, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (5, 'CREATE', 'SESSION', 100, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (5, 'CREATE', 'SESSION', 101, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (5, 'CREATE', 'SESSION', 102, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (6, 'ALTER SESSION', 'SESSION', 42, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (7, '<*>', 'SESSION', 100, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (8, '<*>', 'TABLE', 1, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (8, '<*>', 'TABLE', 12, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (8, '<*>', 'TABLE', 85, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (9, '<*>', 'CLUSTER', 4, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (9, '<*>', 'CLUSTER', 5, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (9, '<*>', 'CLUSTER', 8, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (9, '<*>', 'CLUSTER', 86, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (10, 'CREATE', 'TABLESPACE', 39, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (11, 'ALTER', 'TABLESPACE', 40, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (12, 'MANAGE', 'TABLESPACE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (13, 'DROP', 'TABLESPACE', 41, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (14, '<*>', 'TABLESPACE', 39, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (14, '<*>', 'TABLESPACE', 40, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (14, '<*>', 'TABLESPACE', 41, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (15, '<*>', 'TABLESPACE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (16, '<*>', 'USER', 43, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (16, '<*>', 'USER', 51, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (16, '<*>', 'USER', 53, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (17, '<*>', 'ROLLBACK SEGMENT', 36, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (17, '<*>', 'ROLLBACK SEGMENT', 37, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (17, '<*>', 'ROLLBACK SEGMENT', 38, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 77, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 78, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 80, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 81, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 82, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (18, '<*>', 'TYPE', 83, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (19, '<*>', 'INDEX', 9, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (19, '<*>', 'INDEX', 10, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (19, '<*>', 'INDEX', 11, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (19, '<*>', 'INDEX', 63, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (20, 'CREATE', 'USER', 51, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (21, 'BECOME', 'USER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (22, 'ALTER', 'USER', 43, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (23, 'DROP', 'USER', 53, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (24, '<*>', 'SYNONYM', 19, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (24, '<*>', 'SYNONYM', 20, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (25, '<*>', 'SYNONYM', 110, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (25, '<*>', 'SYNONYM', 111, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (26, '<*>', 'VIEW', 21, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (26, '<*>', 'VIEW', 22, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (26, '<*>', 'VIEW', 88, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (27, '<*>', 'SEQUENCE', 13, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (27, '<*>', 'SEQUENCE', 16, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (28, '<*>', 'DATABASE LINK', 32, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (28, '<*>', 'DATABASE LINK', 33, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (28, '<*>', 'DATABASE LINK', 225, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (29, '<*>', 'DATABASE LINK', 112, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (29, '<*>', 'DATABASE LINK', 113, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (29, '<*>', 'DATABASE LINK', 305, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (30, 'CREATE', 'ROLLBACK SEGMENT', 36, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (31, 'ALTER', 'ROLLBACK SEGMENT', 37, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (32, 'DROP', 'ROLLBACK SEGMENT', 38, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (33, '<*>', 'ROLE', 52, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (33, '<*>', 'ROLE', 54, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (33, '<*>', 'ROLE', 55, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (33, '<*>', 'ROLE', 79, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (34, '<*>', 'DIMENSION', 174, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (34, '<*>', 'DIMENSION', 175, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (34, '<*>', 'DIMENSION', 176, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 24, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 68, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 84, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 91, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 93, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 94, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 96, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 97, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (35, '<*>', 'PROCEDURE', 159, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 59, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 61, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 118, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 119, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 120, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (36, '<*>', 'TRIGGER', 121, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (37, '<*>', 'PROFILE', 65, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (37, '<*>', 'PROFILE', 66, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (37, '<*>', 'PROFILE', 67, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (38, '<*>', 'DIRECTORY', 157, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (38, '<*>', 'DIRECTORY', 158, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (38, 'EXECUTE', 'DIRECTORY', 135, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (39, '<*>', 'MATERIALIZED VIEW', 74, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (39, '<*>', 'MATERIALIZED VIEW', 75, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (39, '<*>', 'MATERIALIZED VIEW', 76, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (40, 'CREATE', 'TABLE', 1, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (41, 'CREATE', 'TABLE', 1, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (42, 'ALTER', 'TABLE', 15, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (43, 'BACKUP', 'CLUSTER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (44, 'DROP', 'TABLE', 12, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (45, 'LOCK', 'TABLE', 26, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (46, 'COMMENT', 'TABLE', 29, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (47, 'SELECT', 'TABLE', 3, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (48, 'INSERT', 'TABLE', 2, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (49, 'UPDATE', 'TABLE', 6, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (50, 'DELETE', 'TABLE', 7, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (51, '<*>', 'OUTLINE', 179, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (51, '<*>', 'OUTLINE', 180, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (51, '<*>', 'OUTLINE', 181, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (52, '<*>', 'MINING MODEL', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (54, 'ALTER', 'TABLE', 15, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (57, 'LOCK', '<*>', 26, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (58, 'COMMENT', '<*>', 29, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (60, 'CREATE', 'CLUSTER', 4, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (61, 'CREATE', 'CLUSTER', 4, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (62, 'ALTER', 'CLUSTER', 5, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (63, 'DROP', 'CLUSTER', 8, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (65, 'SELECT', '<*>', 3, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (66, 'INSERT', '<*>', 2, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (67, 'UPDATE', '<*>', 6, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (68, 'DELETE', '<*>', 7, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (69, 'GRANT', '<*>', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (69, 'REVOKE', '<*>', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (71, 'CREATE', 'INDEX', 9, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (72, 'ALTER', 'INDEX', 11, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (73, 'DROP', 'INDEX', 10, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (77, '<*>', '<*>', 0, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (78, '<*>', '<*>', 0, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (80, 'CREATE', 'SYNONYM', 19, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (81, 'CREATE', 'SYNONYM', 19, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (82, 'DROP', 'SYNONYM', 20, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (83, '<*>', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (84, '<*>', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (85, 'CREATE', 'SYNONYM', 110, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (86, 'DROP', 'SYNONYM', 111, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (90, 'CREATE', 'VIEW', 21, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (91, 'CREATE', 'VIEW', 21, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (92, 'DROP', 'VIEW', 22, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (93, 'CREATE', 'JAVA SOURCE', 160, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (94, 'CREATE', 'JAVA CLASS', 160, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (95, 'CREATE', 'JAVA RESOURCE', 160, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (96, 'ALTER', 'JAVA SOURCE', 161, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (97, 'ALTER', 'JAVA CLASS', 161, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (98, 'ALTER', 'JAVA RESOURCE', 161, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (99, 'DROP', 'JAVA SOURCE', 162, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (100, 'DROP', 'JAVA CLASS', 162, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (101, 'DROP', 'JAVA RESOURCE', 162, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (103, 'ALTER', 'SEQUENCE', 14, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (104, 'SELECT', 'SEQUENCE', 3, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (105, 'CREATE', 'SEQUENCE', 13, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (106, 'CREATE', 'SEQUENCE', 13, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (107, 'ALTER', 'SEQUENCE', 14, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (108, 'DROP', 'SEQUENCE', 16, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (109, 'SELECT', 'SEQUENCE', 3, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (111, 'GRANT', 'SEQUENCE', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (111, 'REVOKE', 'SEQUENCE', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (115, 'CREATE', 'DATABASE LINK', 32, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (120, 'CREATE', 'DATABASE LINK', 112, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (121, 'DROP', 'DATABASE LINK', 113, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (125, 'CREATE', 'ROLE', 52, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (126, 'DROP', 'ROLE', 54, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (127, 'GRANT', 'ROLE', 108, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (127, 'REVOKE', 'ROLE', 109, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (128, 'ALTER', 'ROLE', 79, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (130, 'AUDIT', '<*>', 30, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (130, 'NOAUDIT', '<*>', 31, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (131, 'GRANT', '<*>', 108, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (131, 'GRANT', '<*>', 114, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (131, 'REVOKE', '<*>', 109, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (131, 'REVOKE', '<*>', 115, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (135, 'ALTER', 'DATABASE', 35, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (138, '<*>', 'TRANSACTION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (139, '<*>', 'TRANSACTION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (140, 'CREATE', 'PROCEDURE', 24, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (140, 'CREATE', 'PROCEDURE', 91, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (140, 'CREATE', 'PROCEDURE', 94, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (140, 'CREATE', 'PROCEDURE', 97, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (141, 'CREATE', 'PROCEDURE', 24, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (141, 'CREATE', 'PROCEDURE', 91, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (141, 'CREATE', 'PROCEDURE', 94, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (141, 'CREATE', 'PROCEDURE', 97, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (141, 'CREATE', 'PROCEDURE', 160, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (142, 'ALTER', 'PROCEDURE', 25, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (142, 'ALTER', 'PROCEDURE', 92, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (142, 'ALTER', 'PROCEDURE', 95, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (142, 'ALTER', 'PROCEDURE', 98, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (142, 'ALTER', 'PROCEDURE', 161, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (143, 'DROP', 'PROCEDURE', 68, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (143, 'DROP', 'PROCEDURE', 93, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (143, 'DROP', 'PROCEDURE', 96, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (143, 'DROP', 'PROCEDURE', 99, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (143, 'DROP', 'PROCEDURE', 162, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (144, 'EXECUTE', 'PROCEDURE', 47, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (144, 'EXECUTE', 'PROCEDURE', 116, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (146, 'EXECUTE', '<*>', 116, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (146, 'EXECUTE', '<*>', 170, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (147, 'GRANT', '<*>', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (147, 'REVOKE', '<*>', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (151, 'CREATE', 'TRIGGER', 59, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (152, 'CREATE', 'TRIGGER', 59, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (153, 'ALTER', 'TRIGGER', 15, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (153, 'ALTER', 'TRIGGER', 60, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (153, 'ALTER', 'TRIGGER', 118, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (153, 'ALTER', 'TRIGGER', 119, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (154, 'DROP', 'TRIGGER', 61, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (160, 'CREATE', 'PROFILE', 65, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (161, 'ALTER', 'PROFILE', 67, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (162, 'DROP', 'PROFILE', 66, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (163, 'ALTER', 'RESOURCE', 70, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (165, 'ANALYZE', '<*>', 62, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (165, 'ANALYZE', '<*>', 63, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (165, 'ANALYZE', '<*>', 64, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (167, 'GRANT', '<*>', 108, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (167, 'REVOKE', '<*>', 109, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (172, 'CREATE', 'MATERIALIZED VIEW', 74, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (173, 'CREATE', 'MATERIALIZED VIEW', 74, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (174, 'ALTER', 'MATERIALIZED VIEW', 75, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (175, 'DROP', 'MATERIALIZED VIEW', 76, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (176, '<*>', '<*>', 122, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (177, 'CREATE', 'DIRECTORY', 157, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (178, 'DROP', 'DIRECTORY', 158, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (179, 'GRANT', 'DIRECTORY', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (179, 'REVOKE', 'DIRECTORY', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (180, 'CREATE', 'TYPE', 77, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (180, 'CREATE', 'TYPE', 81, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (181, 'CREATE', 'TYPE', 77, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (181, 'CREATE', 'TYPE', 81, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (182, 'ALTER', 'TYPE', 80, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (182, 'ALTER', 'TYPE', 82, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (183, 'DROP', 'TYPE', 78, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (183, 'DROP', 'TYPE', 83, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (184, 'EXECUTE', 'TYPE', 123, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (186, 'UNDER', 'TYPE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (187, 'GRANT', 'TYPE', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (187, 'REVOKE', 'TYPE', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (188, 'CREATE', 'LIBRARY', 159, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (189, 'CREATE', 'LIBRARY', 159, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (190, 'ALTER', 'LIBRARY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (191, 'DROP', 'LIBRARY', 84, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (192, 'EXECUTE', 'LIBRARY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (193, 'EXECUTE', 'LIBRARY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (200, 'CREATE', 'OPERATOR', 163, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (201, 'CREATE', 'OPERATOR', 163, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (202, 'ALTER', 'OPERATOR', 183, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (203, 'DROP', 'OPERATOR', 167, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (205, 'CREATE', 'INDEXTYPE', 164, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (206, 'CREATE', 'INDEXTYPE', 164, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (207, 'ALTER', 'INDEXTYPE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (208, 'DROP', 'INDEXTYPE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (209, 'UNDER', 'VIEW', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (210, 'REWRITE', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (211, 'REWRITE', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (212, 'EXECUTE', 'INDEXTYPE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (213, 'UNDER', 'TABLE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (214, 'CREATE', 'DIMENSION', 174, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (215, 'CREATE', 'DIMENSION', 174, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (216, 'ALTER', 'DIMENSION', 175, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (217, 'DROP', 'DIMENSION', 176, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (218, 'MANAGE', 'QUEUE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (219, 'ENQUEUE', 'QUEUE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (220, 'DEQUEUE', 'QUEUE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (221, '<*>', 'CONTEXT', 177, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (221, '<*>', 'CONTEXT', 178, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (222, 'CREATE', 'CONTEXT', 177, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (223, 'DROP', 'CONTEXT', 178, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (224, 'CREATE', 'OUTLINE', 180, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (225, 'ALTER', 'OUTLINE', 179, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (226, 'DROP', 'OUTLINE', 181, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (228, 'ADMINISTER', 'TRIGGER', 59, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (228, 'ADMINISTER', 'TRIGGER', 60, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (228, 'ADMINISTER', 'TRIGGER', 118, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (228, 'ADMINISTER', 'TRIGGER', 119, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (233, 'MERGE', 'VIEW', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (234, '<*>', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (235, 'EXEMPT', 'ACCESS POLICY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (236, '<*>', '<*>', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (237, 'SELECT', 'DICTIONARY', 3, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (238, 'DEBUG', 'SESSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (242, 'DEBUG', 'PROCEDURE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (243, 'FLASHBACK', 'TABLE', 128, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (244, 'GRANT', '<*>', 17, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (244, 'REVOKE', '<*>', 18, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (249, 'EXECUTE', 'EVALUATION CONTEXT', 116, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (250, 'CREATE', 'RULE SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (251, 'CREATE', 'RULE SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (252, 'ALTER', 'RULE SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (253, 'DROP', 'RULE SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (254, 'EXECUTE', 'RULE SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (255, 'EXPORT', 'DATABASE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (256, 'IMPORT', 'DATABASE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (257, 'CREATE', 'RULE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (258, 'CREATE', 'RULE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (259, 'ALTER', 'RULE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (260, 'DROP', 'RULE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (261, 'EXECUTE', 'RULE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (262, 'ANALYZE', 'DICTIONARY', 62, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (262, 'ANALYZE', 'DICTIONARY', 63, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (262, 'ANALYZE', 'DICTIONARY', 64, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (263, '<*>', 'ADVISOR', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (267, 'EXECUTE', 'CLASS', 116, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (269, 'SELECT', 'TRANSACTION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (270, 'DROP', 'SQL PROFILE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (271, 'ALTER', 'SQL PROFILE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (272, 'ADMINISTER', 'SQL TUNING SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (273, 'ADMINISTER', 'SQL TUNING SET', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (274, 'CREATE', 'SQL PROFILE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (275, 'EXEMPT', 'IDENTITY POLICY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (276, 'MANAGE', 'FILE GROUP', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (277, 'MANAGE', 'FILE GROUP', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (278, 'READ', 'FILE GROUP', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (279, 'CHANGE', 'NOTIFICATION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (281, 'CREATE', 'EDITION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (282, 'DROP', 'EDITION', 214, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (283, 'ALTER', 'EDITION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (284, 'CREATE', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (285, 'CREATE', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (286, 'ALTER', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (287, 'DROP', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (288, 'EXECUTE', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (289, 'EXECUTE', 'ASSEMBLY', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (290, 'CREATE', 'MINING MODEL', 133, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (291, 'CREATE', 'MINING MODEL', 133, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (292, 'DROP', 'MINING MODEL', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (293, 'SELECT', 'MINING MODEL', 131, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (294, 'ALTER', 'MINING MODEL', 130, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (295, 'COMMENT', 'MINING MODEL', 29, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (296, 'ALTER', 'MINING MODEL', 130, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (297, 'COMMENT', 'MINING MODEL', 29, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (298, 'GRANT', 'MINING MODEL', 17, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (298, 'REVOKE', 'MINING MODEL', 18, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (300, 'SELECT', 'MINING MODEL', 131, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (301, 'CREATE', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (302, 'ALTER', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (303, 'CREATE', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (304, 'DELETE', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (305, 'DROP', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (306, 'INSERT', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (307, 'SELECT', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (308, 'CREATE', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (309, 'ALTER', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (310, 'CREATE', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (311, 'DROP', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (312, 'SELECT', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (313, 'UPDATE', 'CUBE', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (314, 'CREATE', 'MEASURE FOLDER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (315, 'CREATE', 'MEASURE FOLDER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (316, 'DELETE', 'MEASURE FOLDER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (317, 'DROP', 'MEASURE FOLDER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (318, 'INSERT', 'MEASURE FOLDER', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (319, 'CREATE', 'CUBE BUILD PROCESS', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (320, 'CREATE', 'CUBE BUILD PROCESS', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (321, 'DROP', 'CUBE BUILD PROCESS', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (322, 'UPDATE', 'CUBE BUILD PROCESS', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (323, 'COMMENT', 'EDITION', 29, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (324, 'GRANT', 'EDITION', 17, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (324, 'REVOKE', 'EDITION', 18, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (325, '<*>', 'EDITION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (326, 'UPDATE', 'CUBE DIMENSION', 0, 0);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (328, 'ALTER', 'DATABASE LINK', 305, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (329, 'ALTER', 'DATABASE LINK', 225, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (330, '<*>', '<*>', 136, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (331, '<*>', '<*>', 137, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (350, 'ADMINISTER', 'FLASHBACK ARCHIVE', 218, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (350, 'ADMINISTER', 'FLASHBACK ARCHIVE', 219, 1);
insert into aud_sys_stmt_opt_act (option_id, stmt_name, obj_type, action_id, act_enabled) values (350, 'ADMINISTER', 'FLASHBACK ARCHIVE', 220, 1);
prompt
prompt 11. AUD_POL
-- AUD_POL
insert into aud_pol (policy_id, policy_name, policy_desc, status_id, use_cache, type_id, debug_log)
values (0, 'Oracle Default Audits', 'Oracle Default Audits', 0, 1, 2, 0);
prompt
prompt 11. AUD_POL_STMT
-- AUD_POL_STMT
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER SYSTEM', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'SYSTEM AUDIT', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE SESSION', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE USER', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER USER', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'DROP USER', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'PUBLIC SYNONYM', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'DATABASE LINK', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ROLE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'PROFILE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE ANY TABLE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER ANY TABLE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'DROP ANY TABLE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE PUBLIC DATABASE LINK', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'GRANT ANY ROLE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'SYSTEM GRANT', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER DATABASE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE ANY PROCEDURE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER ANY PROCEDURE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'DROP ANY PROCEDURE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'ALTER PROFILE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'DROP PROFILE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'GRANT ANY PRIVILEGE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE ANY LIBRARY', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'EXEMPT ACCESS POLICY', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'GRANT ANY OBJECT PRIVILEGE', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE ANY JOB', '<*>', 1);
insert into aud_pol_stmt (aud_stmt_id, policy_id, status_id, audit_option, audit_by_user, success_failure) values (seq_aud_pol_stmt.nextval, 0, 0, 'CREATE EXTERNAL JOB', '<*>', 1);
prompt
prompt 11. SYS_FACTOR_CATEGORY
-- SYS_FACTOR_CATEGORY
insert into sys_factor_category (category_id, category_name) values (1, 'Host');
insert into sys_factor_category (category_id, category_name) values (2, 'IP Address');
insert into sys_factor_category (category_id, category_name) values (3, 'User');
insert into sys_factor_category (category_id, category_name) values (4, 'Authentication Method');
insert into sys_factor_category (category_id, category_name) values (5, 'Instance');
insert into sys_factor_category (category_id, category_name) values (6, 'Time');
insert into sys_factor_category (category_id, category_name) values (7, 'Physical');
insert into sys_factor_category (category_id, category_name) values (8, 'Application');
insert into sys_factor_category (category_id, category_name) values (9, 'Miscellaneous');
prompt
prompt 11. SYS_FACTOR
-- SYS_FACTOR
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (1, 'APPLICATION_ACTION', 'Application Action', 'Identifies the position in the module (application name) and is set through the DBMS_APPLICATION_INFO package or OCI.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (2, 'IDENTIFICATION_TYPE', 'Identification Type', 'Returns the way the user schema was created in the database. Specifically, it reflects the IDENTIFIED clause in the CREATE/ALTER USER syntax. In the list that follows, the syntax used during schema creation is followed by the identification type returned:
IDENTIFIED BY password: LOCAL
IDENTIFIED EXTERNALLY: EXTERNAL
IDENTIFIED GLOBALLY: GLOBAL SHARED
IDENTIFIED GLOBALLY AS DN: GLOBAL PRIVATE

', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (3, 'AUTHENTICATION_METHOD', 'Authentication Method', 'Returns the method of authentication. In the list that follows, the type of user is followed by the method returned.

* Password-authenticated enterprise user, local database user, or SYSDBA/SYSOPER using Password File; proxy with username using password: PASSWORD
* Kerberos-authenticated enterprise or external user: KERBEROS
* SSL-authenticated enterprise or external user: SSL
* Radius-authenticated external user: RADIUS
* OS-authenticated external user or SYSDBA/SYSOPER: OS
* DCE-authenticated external user: DCE
* Proxy with certificate, DN, or username without using password: NONE', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (4, 'BG_JOB_ID', 'Background Job ID', 'Job ID of the current session if it was established by an Oracle Database background process. Null if the session was not established by a background process.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (5, 'CLIENT_IDENTIFIER', 'Client Identifier', 'Returns an identifier that is set by the application through the DBMS_SESSION.SET_IDENTIFIER procedure, the OCI attribute OCI_ATTR_CLIENT_IDENTIFIER, or the Java class Oracle.jdbc.OracleConnection.setClientIdentifier. This attribute is used by various database components to identify lightweight application users who authenticate as the same database user.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (6, 'RETURN_CODE', 'Return Code', 'Return code generated by the action, 0 - success, other - failure', 1, 'NUMBER');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (7, 'DB_NAME', 'Database Name', 'Name of the database as specified in the DB_NAME initialization parameter', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (8, 'DB_UNIQUE_NAME', 'Database Unique Name', 'Name of the database as specified in the DB_UNIQUE_NAME initialization parameter.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (9, 'FG_JOB_ID', 'Foreground Job ID', 'Job ID of the current session if it was established by a client foreground process. Null if the session was not established by a foreground process', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (10, 'CLIENT_HOST', 'Client Host', 'Name of the host machine from which the client has connected.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (11, 'IP_ADDRESS', 'IP Address', 'IP address of the machine from which the client is connected.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (12, 'IS_DBA', 'Is DBA (SYSDBA)', 'Returns TRUE if the user has been authenticated as having DBA privileges either through the operating system or through a password file.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (13, 'LANG', 'Language', 'The ISO abbreviation for the language name, a shorter form than the existing LANGUAGE parameter.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (14, 'APPLICATION_MODULE', 'Application Module', 'The application name (module) set through the DBMS_APPLICATION_INFO package or OCI.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (15, 'NETWORK_PROTOCOL', 'Network Protocol', 'Network protocol being used for communication, as specified in the PROTOCOL=protocol portion of the connect string.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (16, 'NLS_TERRITORY', 'NLS Territory', 'The territory of the current session.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (17, 'OS_USER', 'Operating System User', 'Operating system user name of the client process that initiated the database session.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (18, 'PROXY_USER', 'Proxy User', 'Name of the database user who opened the current session on behalf of SESSION_USER.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (19, 'SERVICE_NAME', 'Service Name', 'The name of the service to which a given session is connected.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (20, 'SESSION_USER', 'Session User', 'Database user name by which the current user is authenticated. This value remains the same throughout the duration of the session.', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (21, 'TERMINAL', 'Terminal', 'The operating system identifier for the client of the current session. In distributed SQL statements, this attribute returns the identifier for your local session. In a distributed environment, this is supported only for remote SELECT statements, not for remote INSERT, UPDATE, or DELETE operations. (The return length of this parameter may vary by operating system.)', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (22, 'SERVER_HOST', 'Server Host', 'The host name of the machine on which the instance is running', 1, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (23, 'SYSTEM_DATE', 'System Date', 'Returns the system date of the operating system on which the database resides', 6, 'DATE');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (24, 'SYSTEM_DAY_OF_WEEK', 'System Day Of Week', 'Returns the system day of week, MON, TUE..., SUN of the operating system on which the database resides', 6, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (25, 'SYSTEM_HH24', 'System Hour (0-23)', 'Returns the system hour (24 format) as  0-23 of the operating system on which the database resides', 6, 'NUMBER');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (26, 'SYSTEM_MONTH', 'System Month', 'Returns the system month, JAN, FEB, MAR....., of the operating system on which the database resides', 6, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (27, 'OBJECT_OWNER', 'Object Owner', 'Owner of the object affected by the action', 9, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (28, 'OBJECT_TYPE', 'Object Type', 'Type of the object affected by the action', 9, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (29, 'OBJECT_NAME', 'Object Name', 'Name of the object affected by the action', 9, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (30, 'ACTION', 'Action Name', 'Audited or Protected Action Name', 9, 'VARCHAR2');
insert into sys_factor (factor_id, factor_code, factor_name, description, category_id, ret_data_type) values (31, 'INSTANCE_NO', 'Instance Number', 'Current instance identification number', 1, 'NUMBER');
prompt
prompt 11. SYS_FACTOR_TRUST_LEVEL
-- SYS_FACTOR_TRUST_LEVEL
insert into sys_factor_trust_level (trust_level_no, trust_level_name) values ('-1', 'Undefined');
insert into sys_factor_trust_level (trust_level_no, trust_level_name) values ('0', 'Untrusted');
insert into sys_factor_trust_level (trust_level_no, trust_level_name) values ('1', 'Low Trust');
insert into sys_factor_trust_level (trust_level_no, trust_level_name) values ('2', 'Medium Trust');
insert into sys_factor_trust_level (trust_level_no, trust_level_name) values ('3', 'High Trust');
prompt
prompt 11. SYS_POL_TYPE
-- SYS_POL_TYPE
insert into sys_pol_type (policy_type_id, policy_type_code, policy_type_name) values (1, 'ACC', 'Access Control');
insert into sys_pol_type (policy_type_id, policy_type_code, policy_type_name) values (2, 'AUD', 'Standard Audit');
insert into sys_pol_type (policy_type_id, policy_type_code, policy_type_name) values (3, 'RTP-DDL', 'Real-Time Protection DDL');
insert into sys_pol_type (policy_type_id, policy_type_code, policy_type_name) values (4, 'RTP-DML', 'Real-Time Protection DML');
prompt
prompt 11. SYS_FACTOR_POL_TYPE
-- SYS_FACTOR_POL_TYPE
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (1, 1, 1, Q'[SYS_CONTEXT('USERENV', 'ACTION')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (2, 1, 3, Q'[SYS_CONTEXT('USERENV', 'ACTION')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (3, 1, 4, Q'[SYS_CONTEXT('USERENV', 'ACTION')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (4, 2, 1, Q'[SYS_CONTEXT('USERENV', 'IDENTIFICATION_TYPE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (5, 2, 3, Q'[SYS_CONTEXT('USERENV', 'IDENTIFICATION_TYPE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (6, 2, 4, Q'[SYS_CONTEXT('USERENV', 'IDENTIFICATION_TYPE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (7, 3, 1, Q'[SYS_CONTEXT('USERENV', 'AUTHENTICATION_METHOD')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (8, 3, 3, Q'[SYS_CONTEXT('USERENV', 'AUTHENTICATION_METHOD')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (9, 3, 4, Q'[SYS_CONTEXT('USERENV', 'AUTHENTICATION_METHOD')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (10, 4, 1, Q'[SYS_CONTEXT('USERENV', 'BG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (11, 4, 3, Q'[SYS_CONTEXT('USERENV', 'BG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (12, 4, 4, Q'[SYS_CONTEXT('USERENV', 'BG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (13, 5, 1, Q'[SYS_CONTEXT('USERENV', 'CLIENT_IDENTIFIER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (14, 5, 3, Q'[SYS_CONTEXT('USERENV', 'CLIENT_IDENTIFIER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (15, 5, 4, Q'[SYS_CONTEXT('USERENV', 'CLIENT_IDENTIFIER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (16, 7, 1, Q'[SYS_CONTEXT('USERENV', 'DB_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (17, 7, 3, Q'[SYS_CONTEXT('USERENV', 'DB_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (18, 7, 4, Q'[SYS_CONTEXT('USERENV', 'DB_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (19, 8, 1, Q'[SYS_CONTEXT('USERENV', 'DB_UNIQUE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (20, 8, 3, Q'[SYS_CONTEXT('USERENV', 'DB_UNIQUE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (21, 8, 4, Q'[SYS_CONTEXT('USERENV', 'DB_UNIQUE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (22, 9, 1, Q'[SYS_CONTEXT('USERENV', 'FG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (23, 9, 3, Q'[SYS_CONTEXT('USERENV', 'FG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (24, 9, 4, Q'[SYS_CONTEXT('USERENV', 'FG_JOB_ID')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (25, 10, 1, Q'[SYS_CONTEXT('USERENV', 'HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (26, 10, 3, Q'[SYS_CONTEXT('USERENV', 'HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (27, 10, 4, Q'[SYS_CONTEXT('USERENV', 'HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (28, 11, 1, Q'[SYS_CONTEXT('USERENV', 'IP_ADDRESS')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (29, 11, 3, Q'[SYS_CONTEXT('USERENV', 'IP_ADDRESS')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (30, 11, 4, Q'[SYS_CONTEXT('USERENV', 'IP_ADDRESS')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (31, 12, 1, Q'[SYS_CONTEXT('USERENV', 'ISDBA')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (32, 12, 3, Q'[SYS_CONTEXT('USERENV', 'ISDBA')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (33, 12, 4, Q'[SYS_CONTEXT('USERENV', 'ISDBA')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (34, 13, 1, Q'[SYS_CONTEXT('USERENV', 'LANG')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (35, 13, 3, Q'[SYS_CONTEXT('USERENV', 'LANG')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (36, 13, 4, Q'[SYS_CONTEXT('USERENV', 'LANG')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (37, 14, 1, Q'[SYS_CONTEXT('USERENV', 'MODULE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (38, 14, 3, Q'[SYS_CONTEXT('USERENV', 'MODULE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (39, 14, 4, Q'[SYS_CONTEXT('USERENV', 'MODULE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (40, 15, 1, Q'[SYS_CONTEXT('USERENV', 'NETWORK_PROTOCOL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (41, 15, 3, Q'[SYS_CONTEXT('USERENV', 'NETWORK_PROTOCOL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (42, 15, 4, Q'[SYS_CONTEXT('USERENV', 'NETWORK_PROTOCOL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (43, 16, 1, Q'[SYS_CONTEXT('USERENV', 'NLS_TERRITORY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (44, 16, 3, Q'[SYS_CONTEXT('USERENV', 'NLS_TERRITORY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (45, 16, 4, Q'[SYS_CONTEXT('USERENV', 'NLS_TERRITORY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (46, 17, 1, Q'[SYS_CONTEXT('USERENV', 'OS_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (47, 17, 3, Q'[SYS_CONTEXT('USERENV', 'OS_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (48, 17, 4, Q'[SYS_CONTEXT('USERENV', 'OS_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (49, 18, 1, Q'[SYS_CONTEXT('USERENV', 'PROXY_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (50, 18, 3, Q'[SYS_CONTEXT('USERENV', 'PROXY_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (51, 18, 4, Q'[SYS_CONTEXT('USERENV', 'PROXY_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (52, 19, 1, Q'[SYS_CONTEXT('USERENV', 'SERVICE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (53, 19, 3, Q'[SYS_CONTEXT('USERENV', 'SERVICE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (54, 19, 4, Q'[SYS_CONTEXT('USERENV', 'SERVICE_NAME')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (55, 20, 1, Q'[SYS_CONTEXT('USERENV', 'SESSION_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (56, 20, 3, Q'[SYS_CONTEXT('USERENV', 'SESSION_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (57, 20, 4, Q'[SYS_CONTEXT('USERENV', 'SESSION_USER')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (58, 21, 1, Q'[SYS_CONTEXT('USERENV', 'TERMINAL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (59, 21, 3, Q'[SYS_CONTEXT('USERENV', 'TERMINAL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (60, 21, 4, Q'[SYS_CONTEXT('USERENV', 'TERMINAL')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (61, 22, 1, Q'[SYS_CONTEXT('USERENV', 'SERVER_HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (62, 22, 3, Q'[SYS_CONTEXT('USERENV', 'SERVER_HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (63, 22, 4, Q'[SYS_CONTEXT('USERENV', 'SERVER_HOST')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (64, 23, 1, Q'[TRUNC(SYSDATE)]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (65, 23, 3, Q'[TRUNC(SYSDATE)]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (66, 23, 4, Q'[TRUNC(SYSDATE)]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (67, 24, 1, Q'[TO_CHAR(SYSDATE, 'DY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (68, 24, 3, Q'[TO_CHAR(SYSDATE, 'DY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (69, 24, 4, Q'[TO_CHAR(SYSDATE, 'DY')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (70, 25, 1, Q'[TO_NUMBER(TO_CHAR(SYSDATE, 'HH24'))]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (71, 25, 3, Q'[TO_NUMBER(TO_CHAR(SYSDATE, 'HH24'))]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (72, 25, 4, Q'[TO_NUMBER(TO_CHAR(SYSDATE, 'HH24'))]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (73, 26, 1, Q'[TO_CHAR(SYSDATE, 'MON')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (74, 26, 3, Q'[TO_CHAR(SYSDATE, 'MON')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (75, 26, 4, Q'[TO_CHAR(SYSDATE, 'MON')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (76, 27, 3, Q'[ORA_DICT_OBJ_OWNER]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (77, 28, 3, Q'[ORA_DICT_OBJ_TYPE]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (78, 29, 3, Q'[ORA_DICT_OBJ_NAME]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (79, 30, 3, Q'[ORA_SYSEVENT]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (80, 31, 1, Q'[SYS_CONTEXT('USERENV', 'INSTANCE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (81, 31, 3, Q'[SYS_CONTEXT('USERENV', 'INSTANCE')]');
insert into sys_factor_pol_type (factor_policy_type_id, factor_id, policy_type_id, retrieval_expr) values (82, 31, 4, Q'[SYS_CONTEXT('USERENV', 'INSTANCE')]');
prompt
prompt 11. SYS_OPERATION_CODE
-- SYS_OPERATION_CODE
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (1, 'OPERATORS', '=', 'Equal');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (2, 'OPERATORS', '<>', 'Not Equal');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (3, 'OPERATORS', 'BETWEEN', 'Between');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (4, 'OPERATORS', '<', 'Less');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (5, 'OPERATORS', '<=', 'Less or Equal');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (6, 'OPERATORS', '>', 'Greater');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (7, 'OPERATORS', '>=', 'Greater or Equal');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (8, 'OPERATORS', 'LIKE', 'Like');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (9, 'OPERATORS', 'NOT LIKE', 'Not Like');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (10, 'OPERATORS', 'IS NULL', 'Is Null');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (11, 'OPERATORS', 'IS NOT NULL', 'Is Not Null');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (12, 'OPERATORS', 'IN', 'In');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (13, 'OPERATORS', 'NOT IN', 'Not In');
insert into sys_operation_code (code_id, code_group, code_symbol, code_value) values (14, 'OPERATORS', 'NOT BETWEEN', 'Not Between');
prompt
prompt 11. SYS_SYSTEM_PRIVILEGE_MAP
-- SYS_SYSTEM_PRIVILEGE_MAP
insert into sys_system_privilege_map (privilege, name, property) values (3, 'ALTER SYSTEM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (4, 'AUDIT SYSTEM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (5, 'CREATE SESSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (6, 'ALTER SESSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (7, 'RESTRICTED SESSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (10, 'CREATE TABLESPACE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (11, 'ALTER TABLESPACE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (12, 'MANAGE TABLESPACE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (13, 'DROP TABLESPACE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (15, 'UNLIMITED TABLESPACE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (20, 'CREATE USER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (21, 'BECOME USER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (22, 'ALTER USER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (23, 'DROP USER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (30, 'CREATE ROLLBACK SEGMENT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (31, 'ALTER ROLLBACK SEGMENT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (32, 'DROP ROLLBACK SEGMENT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (40, 'CREATE TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (41, 'CREATE ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (42, 'ALTER ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (43, 'BACKUP ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (44, 'DROP ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (45, 'LOCK ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (46, 'COMMENT ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (47, 'SELECT ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (48, 'INSERT ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (49, 'UPDATE ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (50, 'DELETE ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (60, 'CREATE CLUSTER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (61, 'CREATE ANY CLUSTER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (62, 'ALTER ANY CLUSTER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (63, 'DROP ANY CLUSTER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (71, 'CREATE ANY INDEX', 0);
insert into sys_system_privilege_map (privilege, name, property) values (72, 'ALTER ANY INDEX', 0);
insert into sys_system_privilege_map (privilege, name, property) values (73, 'DROP ANY INDEX', 0);
insert into sys_system_privilege_map (privilege, name, property) values (80, 'CREATE SYNONYM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (81, 'CREATE ANY SYNONYM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (82, 'DROP ANY SYNONYM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (83, 'SYSDBA', 0);
insert into sys_system_privilege_map (privilege, name, property) values (84, 'SYSOPER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (85, 'CREATE PUBLIC SYNONYM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (86, 'DROP PUBLIC SYNONYM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (90, 'CREATE VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (91, 'CREATE ANY VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (92, 'DROP ANY VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (105, 'CREATE SEQUENCE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (106, 'CREATE ANY SEQUENCE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (107, 'ALTER ANY SEQUENCE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (108, 'DROP ANY SEQUENCE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (109, 'SELECT ANY SEQUENCE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (115, 'CREATE DATABASE LINK', 0);
insert into sys_system_privilege_map (privilege, name, property) values (120, 'CREATE PUBLIC DATABASE LINK', 0);
insert into sys_system_privilege_map (privilege, name, property) values (121, 'DROP PUBLIC DATABASE LINK', 0);
insert into sys_system_privilege_map (privilege, name, property) values (125, 'CREATE ROLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (126, 'DROP ANY ROLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (127, 'GRANT ANY ROLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (128, 'ALTER ANY ROLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (130, 'AUDIT ANY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (135, 'ALTER DATABASE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (138, 'FORCE TRANSACTION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (139, 'FORCE ANY TRANSACTION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (140, 'CREATE PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (141, 'CREATE ANY PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (142, 'ALTER ANY PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (143, 'DROP ANY PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (144, 'EXECUTE ANY PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (151, 'CREATE TRIGGER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (152, 'CREATE ANY TRIGGER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (153, 'ALTER ANY TRIGGER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (154, 'DROP ANY TRIGGER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (160, 'CREATE PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (161, 'ALTER PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (162, 'DROP PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (163, 'ALTER RESOURCE COST', 0);
insert into sys_system_privilege_map (privilege, name, property) values (165, 'ANALYZE ANY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (167, 'GRANT ANY PRIVILEGE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (172, 'CREATE MATERIALIZED VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (173, 'CREATE ANY MATERIALIZED VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (174, 'ALTER ANY MATERIALIZED VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (175, 'DROP ANY MATERIALIZED VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (177, 'CREATE ANY DIRECTORY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (178, 'DROP ANY DIRECTORY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (180, 'CREATE TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (181, 'CREATE ANY TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (182, 'ALTER ANY TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (183, 'DROP ANY TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (184, 'EXECUTE ANY TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (186, 'UNDER ANY TYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (188, 'CREATE LIBRARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (189, 'CREATE ANY LIBRARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (190, 'ALTER ANY LIBRARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (191, 'DROP ANY LIBRARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (192, 'EXECUTE ANY LIBRARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (200, 'CREATE OPERATOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (201, 'CREATE ANY OPERATOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (202, 'ALTER ANY OPERATOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (203, 'DROP ANY OPERATOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (204, 'EXECUTE ANY OPERATOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (205, 'CREATE INDEXTYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (206, 'CREATE ANY INDEXTYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (207, 'ALTER ANY INDEXTYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (208, 'DROP ANY INDEXTYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (209, 'UNDER ANY VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (210, 'QUERY REWRITE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (211, 'GLOBAL QUERY REWRITE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (212, 'EXECUTE ANY INDEXTYPE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (213, 'UNDER ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (214, 'CREATE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (215, 'CREATE ANY DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (216, 'ALTER ANY DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (217, 'DROP ANY DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (218, 'MANAGE ANY QUEUE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (219, 'ENQUEUE ANY QUEUE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (220, 'DEQUEUE ANY QUEUE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (222, 'CREATE ANY CONTEXT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (223, 'DROP ANY CONTEXT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (224, 'CREATE ANY OUTLINE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (225, 'ALTER ANY OUTLINE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (226, 'DROP ANY OUTLINE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (227, 'ADMINISTER RESOURCE MANAGER', 1);
insert into sys_system_privilege_map (privilege, name, property) values (228, 'ADMINISTER DATABASE TRIGGER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (233, 'MERGE ANY VIEW', 0);
insert into sys_system_privilege_map (privilege, name, property) values (234, 'ON COMMIT REFRESH', 0);
insert into sys_system_privilege_map (privilege, name, property) values (235, 'EXEMPT ACCESS POLICY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (236, 'RESUMABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (237, 'SELECT ANY DICTIONARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (238, 'DEBUG CONNECT SESSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (241, 'DEBUG ANY PROCEDURE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (243, 'FLASHBACK ANY TABLE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (244, 'GRANT ANY OBJECT PRIVILEGE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (245, 'CREATE EVALUATION CONTEXT', 1);
insert into sys_system_privilege_map (privilege, name, property) values (246, 'CREATE ANY EVALUATION CONTEXT', 1);
insert into sys_system_privilege_map (privilege, name, property) values (247, 'ALTER ANY EVALUATION CONTEXT', 1);
insert into sys_system_privilege_map (privilege, name, property) values (248, 'DROP ANY EVALUATION CONTEXT', 1);
insert into sys_system_privilege_map (privilege, name, property) values (249, 'EXECUTE ANY EVALUATION CONTEXT', 1);
insert into sys_system_privilege_map (privilege, name, property) values (250, 'CREATE RULE SET', 1);
insert into sys_system_privilege_map (privilege, name, property) values (251, 'CREATE ANY RULE SET', 1);
insert into sys_system_privilege_map (privilege, name, property) values (252, 'ALTER ANY RULE SET', 1);
insert into sys_system_privilege_map (privilege, name, property) values (253, 'DROP ANY RULE SET', 1);
insert into sys_system_privilege_map (privilege, name, property) values (254, 'EXECUTE ANY RULE SET', 1);
insert into sys_system_privilege_map (privilege, name, property) values (255, 'EXPORT FULL DATABASE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (256, 'IMPORT FULL DATABASE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (257, 'CREATE RULE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (258, 'CREATE ANY RULE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (259, 'ALTER ANY RULE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (260, 'DROP ANY RULE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (261, 'EXECUTE ANY RULE', 1);
insert into sys_system_privilege_map (privilege, name, property) values (262, 'ANALYZE ANY DICTIONARY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (263, 'ADVISOR', 0);
insert into sys_system_privilege_map (privilege, name, property) values (264, 'CREATE JOB', 0);
insert into sys_system_privilege_map (privilege, name, property) values (265, 'CREATE ANY JOB', 0);
insert into sys_system_privilege_map (privilege, name, property) values (266, 'EXECUTE ANY PROGRAM', 0);
insert into sys_system_privilege_map (privilege, name, property) values (267, 'EXECUTE ANY CLASS', 0);
insert into sys_system_privilege_map (privilege, name, property) values (268, 'MANAGE SCHEDULER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (269, 'SELECT ANY TRANSACTION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (270, 'DROP ANY SQL PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (271, 'ALTER ANY SQL PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (272, 'ADMINISTER SQL TUNING SET', 0);
insert into sys_system_privilege_map (privilege, name, property) values (273, 'ADMINISTER ANY SQL TUNING SET', 0);
insert into sys_system_privilege_map (privilege, name, property) values (274, 'CREATE ANY SQL PROFILE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (275, 'EXEMPT IDENTITY POLICY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (276, 'MANAGE FILE GROUP', 1);
insert into sys_system_privilege_map (privilege, name, property) values (277, 'MANAGE ANY FILE GROUP', 1);
insert into sys_system_privilege_map (privilege, name, property) values (278, 'READ ANY FILE GROUP', 1);
insert into sys_system_privilege_map (privilege, name, property) values (279, 'CHANGE NOTIFICATION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (280, 'CREATE EXTERNAL JOB', 0);
insert into sys_system_privilege_map (privilege, name, property) values (281, 'CREATE ANY EDITION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (282, 'DROP ANY EDITION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (283, 'ALTER ANY EDITION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (284, 'CREATE ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (285, 'CREATE ANY ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (286, 'ALTER ANY ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (287, 'DROP ANY ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (288, 'EXECUTE ANY ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (289, 'EXECUTE ASSEMBLY', 0);
insert into sys_system_privilege_map (privilege, name, property) values (290, 'CREATE MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (291, 'CREATE ANY MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (292, 'DROP ANY MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (293, 'SELECT ANY MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (294, 'ALTER ANY MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (295, 'COMMENT ANY MINING MODEL', 0);
insert into sys_system_privilege_map (privilege, name, property) values (301, 'CREATE CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (302, 'ALTER ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (303, 'CREATE ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (304, 'DELETE ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (305, 'DROP ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (306, 'INSERT ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (307, 'SELECT ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (308, 'CREATE CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (309, 'ALTER ANY CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (310, 'CREATE ANY CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (311, 'DROP ANY CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (312, 'SELECT ANY CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (313, 'UPDATE ANY CUBE', 0);
insert into sys_system_privilege_map (privilege, name, property) values (314, 'CREATE MEASURE FOLDER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (315, 'CREATE ANY MEASURE FOLDER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (316, 'DELETE ANY MEASURE FOLDER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (317, 'DROP ANY MEASURE FOLDER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (318, 'INSERT ANY MEASURE FOLDER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (319, 'CREATE CUBE BUILD PROCESS', 0);
insert into sys_system_privilege_map (privilege, name, property) values (320, 'CREATE ANY CUBE BUILD PROCESS', 0);
insert into sys_system_privilege_map (privilege, name, property) values (321, 'DROP ANY CUBE BUILD PROCESS', 0);
insert into sys_system_privilege_map (privilege, name, property) values (322, 'UPDATE ANY CUBE BUILD PROCESS', 0);
insert into sys_system_privilege_map (privilege, name, property) values (326, 'UPDATE ANY CUBE DIMENSION', 0);
insert into sys_system_privilege_map (privilege, name, property) values (327, 'ADMINISTER SQL MANAGEMENT OBJECT', 0);
insert into sys_system_privilege_map (privilege, name, property) values (328, 'ALTER PUBLIC DATABASE LINK', 0);
insert into sys_system_privilege_map (privilege, name, property) values (329, 'ALTER DATABASE LINK', 0);
insert into sys_system_privilege_map (privilege, name, property) values (350, 'FLASHBACK ARCHIVE ADMINISTER', 0);
insert into sys_system_privilege_map (privilege, name, property) values (351, 'EXEMPT REDACTION POLICY', 0);
prompt
prompt 11. ITS_ISSUE
-- ITS_ISSUE
insert into its_class (class_id, class_name, class_desc) values (0, 'UNMARKED', 'UNMARKED');
prompt
prompt 11. ITS_GROUP
-- ITS_GROUP
insert into its_group (group_id, group_name, group_desc, class_id) values (0, 'UNMARKED', 'UNMARKED', 0);
prompt
prompt 11. ITS_CLASS
-- ITS_CLASS
insert into its_issue (issue_id, issue_name, issue_desc, group_id, perpetual) values (0, 'UNMARKED', 'UNMARKED', 0, 0);
   
COMMIT;
   
-- 13. Omega CA - Reports
prompt 13. Omega CA - Reports
prompt ==================================================
prompt
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 1, 'ACC Policies', 'Access Control Policies', Q'[select
a.policy_id, a.policy_name, a.policy_desc,
a.Status_Code, a.Audit_Option_Code, a.User_Apply_Code, a.Rule_Eval_Code, a.Use_Cache_Code,
a.Debug_Log_Code, a.formula,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_acc_pol a

order by a.policy_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_DESC', 'ftString', 'Policy Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION_CODE', 'ftString', 'Audit Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_EVAL_CODE', 'ftString', 'Rule Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USE_CACHE_CODE', 'ftString', 'Use Cache', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEBUG_LOG_CODE', 'ftString', 'Debug Log', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FORMULA', 'ftString', 'Formula', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 1, 'ACC Rules', 'Access Control Rules', Q'[select
a.rule_id, a.Rule_Code, a.rule_name, a.rule_desc,
b.policy_id, b.policy_name, b.Status_Code as Pol_Status,
a.Status_Code, a.Cond_Eval_Code, a.formula,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_acc_pol_rule a, v_acc_pol b
where a.policy_id = b.policy_id

order by a.rule_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_ID', 'ftInteger', 'Rule Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 1, 2, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 1, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_DESC', 'ftString', 'Rule Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Rule Status', 1, 3, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FORMULA', 'ftString', 'Formula', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 1, 'ACC Conditions', 'Access Control Conditions', Q'[select
a.cond_id, a.Cond_Code,
b.Rule_Code, b.rule_name, b.Status_Code as Rule_Status,
c.policy_id, c.policy_name, c.Status_Code as Policy_Status,
a.Status_Code,
a.factor_code, a.factor_name, a.Cond_Eval_Code, a.opr_code_symbol, a.operand_1, a.operand_2,
a.min_trust_level_no, a.trust_level_name,
a.validate_expr_owner, a.validate_expr_object,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_acc_pol_cond a, v_acc_pol_rule b, v_acc_pol c
where a.rule_id = b.rule_id
and b.policy_id = c.policy_id

order by a.cond_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_ID', 'ftInteger', 'Cond. Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_CODE', 'ftString', 'Cond. Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_STATUS', 'ftString', 'Rule Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Cond. Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPR_CODE_SYMBOL', 'ftString', 'Operator Symbol', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_1', 'ftString', 'Operand 1', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_2', 'ftString', 'Operand 2', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MIN_TRUST_LEVEL_NO', 'ftInteger', 'Min. Trust Level No', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRUST_LEVEL_NAME', 'ftString', 'Trust Level Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OWNER', 'ftString', 'Validate Expr Owner', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OBJECT', 'ftString', 'Validate Expr Object', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 1, 'ACC Policy Users', 'Access Control Policy User Appliance', Q'[select
a.policy_id, b.policy_name,
b.User_Apply_Code as Pol_User_Apply, b.Status_Code,
a.user_id, a.User_Apply_Code,
a.date_created, a.user_created

from v_acc_pol_user a, v_acc_pol b
where a.policy_id = b.policy_id

order by a.policy_id, a.user_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_USER_APPLY', 'ftString', 'Policy User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_ID', 'ftString', 'Username', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Object Privileges', 'Account Manager Object Privileges', Q'[select
a.grantee, a.Grantee_Type,
a.owner, a.table_name, a.grantor,
a.privilege, a.grantable, a.hierarchy

from v_acm_priv_obj a

order by 1, 3, 4]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE', 'ftString', 'Grantee', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE_TYPE', 'ftString', 'Grantee Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OWNER', 'ftString', 'Owner', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TABLE_NAME', 'ftString', 'Table Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTOR', 'ftString', 'Grantor', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PRIVILEGE', 'ftString', 'Privilege', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTABLE', 'ftString', 'Grantable', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'HIERARCHY', 'ftString', 'Hierarchy', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM System Privileges', 'Account Manager System Privileges', Q'[select
a.grantee, a.Grantee_Type,
a.privilege, a.admin_option

from v_acm_priv_sys a

order by 1, 3]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE', 'ftString', 'Grantee', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE_TYPE', 'ftString', 'Grantee Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PRIVILEGE', 'ftString', 'Privilege', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ADMIN_OPTION', 'ftString', 'Admin Option', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Roles', 'Account Manager Roles', Q'[select
a.role, a.password_required

from v_acm_role a

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ROLE', 'ftString', 'Role', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PASSWORD_REQUIRED', 'ftString', 'Pass. Required', 1, 2, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Profile Resources', 'Account Manager Profile Resources', Q'[select
a.profile, a.resource_name,
a.resource_type, a.limit

from v_acm_sys_dba_profiles a

order by 1, 2, 3, 4]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PROFILE', 'ftString', 'Profile', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RESOURCE_NAME', 'ftString', 'Resource Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RESOURCE_TYPE', 'ftString', 'Resource Type', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LIMIT', 'ftString', 'Limit', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Role Privileges', 'Account Manager Role Privileges', Q'[select
a.grantee, a.granted_role,
a.admin_option, a.default_role

from v_acm_sys_dba_role_privs a

order by 1, 2]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE', 'ftString', 'Grantee', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTED_ROLE', 'ftString', 'Granted Role', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ADMIN_OPTION', 'ftString', 'Admin Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEFAULT_ROLE', 'ftString', 'Default Role', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Users', 'Account Manager Users', Q'[select
a.username, a.user_id, a.account_status,
a.lock_date, a.expiry_date, a.Pass_Mode,
a.created, a.profile,
a.default_tablespace, a.temporary_tablespace,
a.initial_rsrc_consumer_group, a.external_name

from v_acm_user a

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_ID', 'ftFloat', 'User Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACCOUNT_STATUS', 'ftString', 'Account Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOCK_DATE', 'ftDateTime', 'Lock Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'EXPIRY_DATE', 'ftDateTime', 'Expiry Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PASS_MODE', 'ftString', 'Pass. Mode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PROFILE', 'ftString', 'Profile', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEFAULT_TABLESPACE', 'ftString', 'Default Tablespace', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TEMPORARY_TABLESPACE', 'ftString', 'Temporary Tablespace', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'INITIAL_RSRC_CONSUMER_GROUP', 'ftString', 'Initial Resc. Cnsm Group', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'EXTERNAL_NAME', 'ftString', 'External Name', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Oracle Object Audits', 'Standard Audit Oracle Object Audits', Q'[select *
from v_aud_dba_obj_audit_opts a

order by 1, 2, 3]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OWNER', 'ftString', 'Owner', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_TYPE', 'ftString', 'Object Type', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ALT', 'ftString', 'Alt', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUD', 'ftString', 'Aud', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COM', 'ftString', 'Com', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEL', 'ftString', 'Del', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRA', 'ftString', 'Gra', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IND', 'ftString', 'Ind', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'INS', 'ftString', 'Ins', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOC', 'ftString', 'Loc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'REN', 'ftString', 'Ren', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SEL', 'ftString', 'Sel', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'UPD', 'ftString', 'Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'EXE', 'ftString', 'Exe', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CRE', 'ftString', 'Cre', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'REA', 'ftString', 'Rea', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'WRI', 'ftString', 'Wri', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FBK', 'ftString', 'Fbk', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Oracle Object Audits Tab', 'Standard Audit Oracle Object Audits Tab', Q'[select *
from v_aud_dba_obj_audit_opts_tab a

order by 1, 2, 3, 4]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OWNER', 'ftString', 'Owner', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_TYPE', 'ftString', 'Object Type', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION', 'ftString', 'Audit Option', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPT', 'ftString', 'Audit Opt.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SUCCESS', 'ftString', 'Success', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FAILURE', 'ftString', 'Failure', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Policies', 'Standard Audit Policies', Q'[select
a.policy_id, a.policy_name, a.policy_desc,
a.Status_Code, a.Type_Code, a.Use_Cache_Code, a.Debug_Log_Code,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_aud_pol a

order by a.policy_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_DESC', 'ftString', 'Policy Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TYPE_CODE', 'ftString', 'Policy Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USE_CACHE_CODE', 'ftString', 'Use Cache', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEBUG_LOG_CODE', 'ftString', 'Debug Log', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Rules Object Audit', 'Standard Rules Object Audit', Q'[select
a.aud_obj_id, a.Aud_Obj_Code, a.policy_name, a.Status_Code,
a.sql_operation, a.object_type, a.object_owner, a.object_name,
a.Success_Failure_Code

from v_aud_pol_obj a

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUD_OBJ_ID', 'ftInteger', 'Aud. Obj. Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUD_OBJ_CODE', 'ftString', 'Aud. Obj. Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Aud. Obj. Status', 1, 2, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_OPERATION', 'ftString', 'Sql Operation', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_TYPE', 'ftString', 'Object Type', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 6, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SUCCESS_FAILURE_CODE', 'ftString', 'Success Failure', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Rules Statement Audit', 'Standard Rules Statements Audit', Q'[select
a.aud_stmt_id, a.Aud_Stmt_Code, a.policy_name, a.Status_Code,
a.audit_option, a.audit_by_user, a.Success_Failure_Code,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_aud_pol_stmt a

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUD_STMT_ID', 'ftInteger', 'Aud. Stmt. Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUD_STMT_CODE', 'ftString', 'Aud. Stmt. Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Aud. Stmt. Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION', 'ftString', 'Audit Option', 1, 2, 1, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_BY_USER', 'ftString', 'Audit By User', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SUCCESS_FAILURE_CODE', 'ftString', 'Success Failure', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Oracle Statement Audits', 'Standard Oracle Statement Audits', Q'[select
a.user_name, a.proxy_name,
a.audit_option, a.success, a.failure,
a.Is_System_Privilege

from v_aud_sys_dba_stmt_audit_opts a

order by 1, 3]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_NAME', 'ftString', 'User Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PROXY_NAME', 'ftString', 'Proxy Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION', 'ftString', 'Audit Option', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SUCCESS', 'ftString', 'Success', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FAILURE', 'ftString', 'Failure', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IS_SYSTEM_PRIVILEGE', 'ftFloat', 'Is System Priv.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Trails Sessions', 'Standard Audit Trails Sessions', Q'[select
a.timestamp_sts, a.timestamp_utc,
a.username, a.sessionid, a.action_id, a.action_name,
a.os_user, a.userhost, a.terminal, a.os_process,
a.comment_text, a.logoff_time,
a.db_name, a.dbid, a.instance_number,
a.returncode, a.return_message,
a.trail_eval

from v_sys_unf_trail a
where a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')
and action_id in (
100, -- LOGON
101, -- LOGOFF
102  -- LOGOFF BY CLEANUP
)]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_STS', 'ftDateTime', 'Audit DateTime', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_UTC', 'ftDateTime', 'Timestamp Utc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSIONID', 'ftFloat', 'Sessionid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_ID', 'ftFloat', 'Action Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_USER', 'ftString', 'OS User', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TERMINAL', 'ftString', 'Terminal', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_PROCESS', 'ftString', 'OS Process', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COMMENT_TEXT', 'ftString', 'Comment Text', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOGOFF_TIME', 'ftDateTime', 'Logoff Time', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DB_NAME', 'ftString', 'Db Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DBID', 'ftFloat', 'Dbid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'INSTANCE_NUMBER', 'ftFloat', 'Instance No.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURN_MESSAGE', 'ftString', 'Return Message', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_EVAL', 'ftString', 'Trail Eval.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'AUD Trails Security', 'Standard Audit Trails Security', Q'[select
a.timestamp_sts, a.timestamp_utc,
a.username, a.sessionid, a.os_user, a.userhost, a.terminal, a.client_id, a.os_process,
a.action_name, a.object_owner, a.object_name,
a.system_privilege,
a.obj_privilege, a.sys_privilege, a.admin_option, a.audit_option, a.grantee,

a.sql_bind, a.sql_text,

a.returncode, a.return_message,
a.trail_eval, a.issue_name

from v_sys_unf_trail a
where a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')
and a.policy_type_id = 2
and action_id in (
17, -- GRANT OBJECT
18, -- REVOKE OBJECT
108, -- SYSTEM GRANT
109, -- SYSTEM REVOKE
114, -- GRANT ROLE
115, -- REVOKE ROLE
49, -- ALTER SYSTEM
30, -- AUDIT OBJECT
31, -- NOAUDIT OBJECT
104, -- SYSTEM AUDIT
105, -- SYSTEM NOAUDIT
106, -- AUDIT DEFAULT
107 -- NOAUDIT DEFAULT
 )]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_STS', 'ftDateTime', 'Audit DateTime', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_UTC', 'ftDateTime', 'Timestamp Utc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSIONID', 'ftFloat', 'Sessionid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 2, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 3, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 4, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SYSTEM_PRIVILEGE', 'ftString', 'System Privilege', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_USER', 'ftString', 'OS User', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TERMINAL', 'ftString', 'Terminal', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CLIENT_ID', 'ftString', 'Client Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_PROCESS', 'ftString', 'OS Process', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJ_PRIVILEGE', 'ftString', 'Obj. Privilege', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SYS_PRIVILEGE', 'ftString', 'Sys. Privilege', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ADMIN_OPTION', 'ftString', 'Admin Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION', 'ftString', 'Audit Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE', 'ftString', 'Grantee', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_BIND', 'ftOraClob', 'SQL Bind', 1, 5, 0, 8);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_TEXT', 'ftOraClob', 'SQL Text', 1, 6, 0, 8);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURN_MESSAGE', 'ftString', 'Return Message', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_EVAL', 'ftString', 'Trail Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DDL Policies', 'Real-Time Protection DDL Policies', Q'[select
a.policy_id, a.policy_name, a.policy_desc,
a.Status_Code, a.Audit_Option_Code, a.User_Apply_Code, a.Rule_Eval_Code,
a.Silent_Deny_Code, a.Use_Cache_Code,
a.Debug_Log_Code, a.formula,
a.log_ddl_body, a.log_cmd,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_ddl_pol a

order by a.policy_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_DESC', 'ftString', 'Policy Desc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, 1);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION_CODE', 'ftString', 'Audit Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_EVAL_CODE', 'ftString', 'Rule Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SILENT_DENY_CODE', 'ftString', 'Silent Deny', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USE_CACHE_CODE', 'ftString', 'Use Cache', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEBUG_LOG_CODE', 'ftString', 'Debug Log', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FORMULA', 'ftString', 'Formula', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOG_DDL_BODY', 'ftInteger', 'Log DDL Body', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOG_CMD', 'ftInteger', 'Log Cmd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DDL Rules', 'Real-Time Protection DDL Rules', Q'[select
a.rule_id, a.Rule_Code, a.rule_name, a.rule_desc,
b.policy_id, b.policy_name, b.Status_Code as Pol_Status,
a.Status_Code, a.Cond_Eval_Code, a.formula,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_ddl_pol_rule a, v_rtp_ddl_pol b
where a.policy_id = b.policy_id

order by a.rule_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_ID', 'ftInteger', 'Rule Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_DESC', 'ftString', 'Rule Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Rule Status', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FORMULA', 'ftString', 'Formula', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DDL Conditions', 'Real-Time Protection DDL Conditions', Q'[select
a.cond_id, a.Cond_Code,
b.Rule_Code, b.rule_name, b.Status_Code as Rule_Status,
c.policy_id, c.policy_name, c.Status_Code as Policy_Status,
a.Status_Code,
a.factor_code, a.factor_name, a.Cond_Eval_Code, a.opr_code_symbol, a.operand_1, a.operand_2,
a.min_trust_level_no, a.trust_level_name,
a.validate_expr_owner, a.validate_expr_object,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_ddl_pol_cond a, v_rtp_ddl_pol_rule b, v_rtp_ddl_pol c
where a.rule_id = b.rule_id
and b.policy_id = c.policy_id

order by a.cond_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_ID', 'ftInteger', 'Cond. Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_CODE', 'ftString', 'Cond. Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_STATUS', 'ftString', 'Rule Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Cond. Status', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPR_CODE_SYMBOL', 'ftString', 'Opr Code Symbol', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_1', 'ftString', 'Operand 1', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_2', 'ftString', 'Operand 2', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MIN_TRUST_LEVEL_NO', 'ftInteger', 'Min. Trust Level No', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRUST_LEVEL_NAME', 'ftString', 'Trust Level Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OWNER', 'ftString', 'Validate Expr Owner', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OBJECT', 'ftString', 'Validate Expr Object', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DDL Policy Users', 'Real-Time Protection DDL Policy Users', Q'[select
a.policy_id, b.policy_name,
b.User_Apply_Code as Pol_User_Apply, b.Status_Code,
a.user_id, a.User_Apply_Code,
a.date_created, a.user_created

from v_rtp_ddl_pol_user a, v_rtp_ddl_pol b
where a.policy_id = b.policy_id

order by a.policy_id, a.user_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_USER_APPLY', 'ftString', 'Pol. User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_ID', 'ftString', 'Username', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Policies', 'Real-Time Protection DML Policies', Q'[select
a.policy_id, a.policy_name, a.policy_desc,
a.Status_Code, a.User_Apply_Code,
a.Use_Cache_Code, a.Debug_Log_Code,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_dml_pol a

order by a.policy_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_DESC', 'ftString', 'Policy Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USE_CACHE_CODE', 'ftString', 'Use Cache', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEBUG_LOG_CODE', 'ftString', 'Debug Log', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Rules', 'Real-Time Protection DML Rules', Q'[select
a.rule_id, a.Rule_Code, a.rule_name, a.rule_desc,
b.policy_id, b.policy_name, b.Status_Code as Pol_Status,
a.Status_Code, a.Cond_Eval_Code, a.formula,
a.Silent_Deny_Code, a.Audit_Condition_Type_Code as Authorization_Type,
a.obj_owner, a.obj_name,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_dml_pol_rule a, v_rtp_dml_pol b
where a.policy_id = b.policy_id

order by a.rule_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_ID', 'ftInteger', 'Rule Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_DESC', 'ftString', 'Rule Desc.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Rule Status', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FORMULA', 'ftString', 'Formula', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SILENT_DENY_CODE', 'ftString', 'Silent Deny', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUTHORIZATION_TYPE', 'ftString', 'Authorization Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJ_OWNER', 'ftString', 'Object Owner', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJ_NAME', 'ftString', 'Object Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Conditions', 'Real-Time Protection DML Conditions', Q'[select
a.cond_id, a.Cond_Code,
b.Rule_Code, b.rule_name, b.Status_Code as Rule_Status,
c.policy_id, c.policy_name, c.Status_Code as Policy_Status,
a.Status_Code,
a.factor_code, a.factor_name, a.Cond_Eval_Code, a.opr_code_symbol, a.operand_1, a.operand_2,
a.min_trust_level_no, a.trust_level_name,
a.validate_expr_owner, a.validate_expr_object,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_rtp_dml_pol_cond a, v_rtp_dml_pol_rule b, v_rtp_dml_pol c
where a.rule_id = b.rule_id
and b.policy_id = c.policy_id

order by a.cond_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_ID', 'ftInteger', 'Cond. Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_CODE', 'ftString', 'Cond. Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_CODE', 'ftString', 'Rule Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_STATUS', 'ftString', 'Rule Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Cond. Status', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_EVAL_CODE', 'ftString', 'Cond. Eval.', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPR_CODE_SYMBOL', 'ftString', 'Opr Code Symbol', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_1', 'ftString', 'Operand 1', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND_2', 'ftString', 'Operand 2', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MIN_TRUST_LEVEL_NO', 'ftInteger', 'Min. Trust Level No', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRUST_LEVEL_NAME', 'ftString', 'Trust Level Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OWNER', 'ftString', 'Validate Expr Owner', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'VALIDATE_EXPR_OBJECT', 'ftString', 'Validate Expr Object', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Policy Users', 'Real-Time Protection DML Policy Users', Q'[select
a.policy_id, b.policy_name,
b.User_Apply_Code as Pol_User_Apply, b.Status_Code,
a.user_id, a.User_Apply_Code,
a.date_created, a.user_created

from v_rtp_dml_pol_user a, v_rtp_dml_pol b
where a.policy_id = b.policy_id

order by a.policy_id, a.user_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_USER_APPLY', 'ftString', 'Pol. User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS_CODE', 'ftString', 'Policy Status', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_ID', 'ftString', 'Username', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_APPLY_CODE', 'ftString', 'User Apply', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Oracle FGA Policies', 'Real-Time Protection DML Oracle Audit (FGA) Policies', Q'[select
a.object_schema, a.object_name, a.policy_name,
a.policy_text, a.policy_column,
a.pf_schema, a.pf_package, a.pf_function,
a.enabled,
a.sel, a.ins, a.upd, a.del,
a.audit_trail, a.policy_column_options

from v_rtp_dml_sys_dba_audit_pol a]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_SCHEMA', 'ftString', 'Object Schema', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TEXT', 'ftString', 'Policy Text', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_COLUMN', 'ftString', 'Policy Column', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PF_SCHEMA', 'ftString', 'Handler Schema', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PF_PACKAGE', 'ftString', 'Handler Package', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PF_FUNCTION', 'ftString', 'Handler Function', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ENABLED', 'ftString', 'Enabled', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SEL', 'ftString', 'Sel', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'INS', 'ftString', 'Ins', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'UPD', 'ftString', 'Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEL', 'ftString', 'Del', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_TRAIL', 'ftString', 'Audit Trail', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_COLUMN_OPTIONS', 'ftString', 'Policy Column Options', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DML Oracle FGA Policies Cols.', 'Real-Time Protection DML Oracle Audit (FGA) Policies Columns', Q'[select
a.object_schema, a.object_name,
a.policy_name, a.policy_column

from v_rtp_dml_sys_dba_audit_pol_cl a]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_SCHEMA', 'ftString', 'Object Schema', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_COLUMN', 'ftString', 'Policy Column', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 5, 'System Factors', 'System Factors', Q'[select a.factor_id, a.factor_code, a.factor_name,
a.description, a.category_name,
a.ret_data_type,
a.date_upd, a.user_upd,
a.date_created, a.user_created

from v_sys_factor a

order by a.factor_code]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_ID', 'ftInteger', 'Factor Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 1, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 1, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DESCRIPTION', 'ftString', 'Description', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CATEGORY_NAME', 'ftString', 'Category Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RET_DATA_TYPE', 'ftString', 'Ret Data Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 5, 'System Factors Policy Types', 'System Factors Policy Types', Q'[select *
from v_sys_factor_pol_type a
order by a.factor_code, a.policy_type_code]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_POLICY_TYPE_ID', 'ftInteger', 'Factor Policy Type Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_ID', 'ftInteger', 'Factor Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RET_DATA_TYPE', 'ftString', 'Ret Data Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_NAME', 'ftString', 'Policy Type Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETRIEVAL_EXPR', 'ftString', 'Retrieval Expr', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 5, 'System Factor Identities', 'System Factor Identities', Q'[select *
from v_sys_factor_identity a
order by a.identity_id]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IDENTITY_ID', 'ftInteger', 'Identity Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_ID', 'ftInteger', 'Factor Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_CODE', 'ftString', 'Factor Code', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_NAME', 'ftString', 'Factor Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DESCRIPTION', 'ftString', 'Description', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FACTOR_VALUE', 'ftString', 'Factor Value', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRUST_LEVEL_NO', 'ftInteger', 'Trust Level No', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRUST_LEVEL_NAME', 'ftString', 'Trust Level Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 5, 'System Error Log', 'System Error Log', Q'[select *
from v_sys_error_log a
where a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 0);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_STS', 'ftDateTime', 'Audit DateTime', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IP_ADDRESS', 'ftString', 'Ip Address', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_USER', 'ftString', 'Os User', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BG_JOB_ID', 'ftString', 'Bg Job Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ERROR_DATA', 'ftString', 'Error Data', 1, 5, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 4, 'ADM DB Audit Purge Job Log', 'ADM DB Audit Purge Job Log', Q'[select *
from v_sys_manage_aud_sched_job_log a
where a.log_date
between To_Timestamp(:LOG_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:LOG_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'LOG_DATE_FROM', 'ftString', 'ftDateTime', 'Log Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'LOG_DATE_TO', 'ftString', 'ftDateTime', 'Log Date To', 0);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOG_ID', 'ftFloat', 'Log Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOG_DATE', 'ftDateTime', 'Log Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OWNER', 'ftString', 'Owner', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'JOB_NAME', 'ftString', 'Job Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATUS', 'ftString', 'Status', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ERROR#', 'ftFloat', 'Error#', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'REQ_START_DATE', 'ftDateTime', 'Req Start Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTUAL_START_DATE', 'ftDateTime', 'Actual Start Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RUN_DURATION', 'ftString', 'Run Duration', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'INSTANCE_ID', 'ftFloat', 'Instance Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSION_ID', 'ftString', 'Session Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SLAVE_PID', 'ftString', 'Slave Pid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CPU_USED', 'ftString', 'Cpu Used', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ADDITIONAL_INFO', 'ftString', 'Additional Info', 1, 2, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 4, 'ADM System Parameters', 'ADM System Parameters', Q'[select *
from v_sys_param a
order by a.parameter_name
]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PARAMETER_ID', 'ftInteger', 'Parameter Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PARAMETER_NAME', 'ftString', 'Parameter Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PARAMETER_DESC', 'ftString', 'Parameter Desc', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PARAM_VALUE', 'ftString', 'Param Value', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'PARAM_TYPE', 'ftInteger', 'Param Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 5, 'System Policy Debug Log', 'System Policy Debug Log', Q'[select
a.timestamp_sts, a.username,
a.policy_type_id, a.policy_type_code, a.policy_id, a.policy_name,
a.rule_id, a.rule_name,
a.cond_id, a.cond_code,
a.eval_result, a.debug_log

from v_sys_pol_debug a

where a.timestamp_sts between To_Timestamp(:DEBUG_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:DEBUG_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'DEBUG_DATE_FROM', 'ftString', 'ftDateTime', 'Debug Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'DEBUG_DATE_TO', 'ftString', 'ftDateTime', 'Debug Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_STS', 'ftDateTime', 'Audit DateTime', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_ID', 'ftInteger', 'Policy Type Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type Code', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_ID', 'ftInteger', 'Rule Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RULE_NAME', 'ftString', 'Rule Name', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_ID', 'ftInteger', 'Cond Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'COND_CODE', 'ftString', 'Cond Code', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'EVAL_RESULT', 'ftString', 'Eval Result', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DEBUG_LOG', 'ftString', 'Debug Log', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 2, 'ACM Users Tablespace Quotas', 'Account Manager Users Tablespace Quotas', Q'[select a.username, a.tablespace_name,
a.bytes, Round(a.bytes/(1024*1024*1024), 3) as GBytes,
a.max_bytes,
Case a.max_bytes
when -1 then -1
else Round(a.max_bytes/(1024*1024*1024), 3)
End as Max_GBytes,
a.blocks, a.max_blocks

from v_acm_sys_dba_ts_quotas a

order by a.username, a.tablespace_name]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ACCTMGR', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TABLESPACE_NAME', 'ftString', 'Tablespace Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BYTES', 'ftFloat', 'Bytes', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GBYTES', 'ftFloat', 'Gbytes', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MAX_BYTES', 'ftFloat', 'Max Bytes', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MAX_GBYTES', 'ftFloat', 'Max Gbytes', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BLOCKS', 'ftFloat', 'Blocks', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MAX_BLOCKS', 'ftFloat', 'Max Blocks', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'RTP DDL Policy Secured Area', 'Real-Time Protection DDL Policy Secured Area', Q'[select
a.policy_id, a.policy_name, a.policy_desc,
b.Status_Code as Pol_Status,
a.area_factor, a.Area_Factor_Name,
a.opr_code, a.operand,
a.date_created, a.user_created,
a.date_upd, a.user_upd

from v_rtp_ddl_pol_area a, v_rtp_ddl_pol b

where a.policy_id = b.policy_id

order by a.policy_id, a.area_factor]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_AUDIT', 2);
   
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_SECANALYST', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_ID', 'ftInteger', 'Policy Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_NAME', 'ftString', 'Policy Name', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_DESC', 'ftString', 'Policy Desc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POL_STATUS', 'ftString', 'Policy Status', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AREA_FACTOR', 'ftString', 'Area Factor', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AREA_FACTOR_NAME', 'ftString', 'Area Factor Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPR_CODE', 'ftString', 'Opr Code', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OPERAND', 'ftString', 'Operand', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_CREATED', 'ftDateTime', 'Date Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_CREATED', 'ftString', 'User Created', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DATE_UPD', 'ftDateTime', 'Date Upd', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USER_UPD', 'ftString', 'User Upd', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trail', 'Standard Audit Trails', Q'[select
a.timestamp_sts, a.timestamp_utc, a.policy_type_code,
a.username, a.sessionid, a.action_name,
a.object_owner, a.object_name, a.object_type,
a.os_user, a.userhost,  a.terminal, a.ip_address, a.client_id,

a.system_privilege,
a.statementid, a.entryid,
a.os_process, a.transactionid, a.scn, a.logoff_time,
a.obj_privilege, a.sys_privilege, a.admin_option, a.audit_option, a.grantee,

a.isdba, a.module, a.identification_type, a.bg_job_id, a.fg_job_id,

a.returncode, a.return_message,
a.sql_bind, a.sql_text, a.ddl_body,

a.trail_eval,
a1.issue_name, a1.group_name, a1.class_name

from v_sys_unf_trail a, v_its_issue a1

where a.ISSUE_ID = a1.issue_id
and a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

order by a.timestamp_sts]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_STS', 'ftDateTime', 'Audit DateTime', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TIMESTAMP_UTC', 'ftDateTime', 'Timestamp Utc', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSIONID', 'ftFloat', 'Sessionid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'STATEMENTID', 'ftFloat', 'Statementid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ENTRYID', 'ftFloat', 'Entryid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISDBA', 'ftString', 'IsDBA', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MODULE', 'ftString', 'Module', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SYSTEM_PRIVILEGE', 'ftString', 'System Privilege', 0, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_USER', 'ftString', 'OS User', 1, 6, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 7, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TERMINAL', 'ftString', 'Terminal', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CLIENT_ID', 'ftString', 'Client Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OS_PROCESS', 'ftString', 'OS Process', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRANSACTIONID', 'ftString', 'Transactionid', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SCN', 'ftFloat', 'SCN', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'LOGOFF_TIME', 'ftDateTime', 'Logoff Time', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJ_PRIVILEGE', 'ftString', 'Obj. Privilege', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SYS_PRIVILEGE', 'ftString', 'Sys. Privilege', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ADMIN_OPTION', 'ftString', 'Admin Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_OPTION', 'ftString', 'Audit Option', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GRANTEE', 'ftString', 'Grantee', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_BIND', 'ftOraClob', 'SQL Bind', 1, 8, 0, 8);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_TEXT', 'ftOraClob', 'SQL Text', 1, 9, 0, 8);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BG_JOB_ID', 'ftString', 'Bg. Job Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'FG_JOB_ID', 'ftString', 'Fg. Job Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURN_MESSAGE', 'ftString', 'Return Message', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_EVAL', 'ftString', 'Trail Evaluation', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'GROUP_NAME', 'ftString', 'Group Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'CLASS_NAME', 'ftString', 'Class Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'DDL_BODY', 'ftOraClob', 'DDL Body', 1, 10, 0, 8);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_TYPE', 'ftString', 'Object Type', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IP_ADDRESS', 'ftString', 'IP Address', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'IDENTIFICATION_TYPE', 'ftString', 'Ident. Type', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trail Daily', 'Unified Audit Trails Daily', Q'[select
Trunc(a.timestamp_sts) as Audit_Date,
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.sessionid, a.userhost,
a.module, a.bg_job_id,
a.returncode, a1.issue_name,
Count(*) as Trail_No

from v_sys_unf_trail a, v_its_issue a1

where a.ISSUE_ID = a1.issue_id
and a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

group by
Trunc(a.timestamp_sts),
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.sessionid, a.userhost,
a.module, a.bg_job_id,
a.returncode, a1.issue_name

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_DATE', 'ftDateTime', 'Audit Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MODULE', 'ftString', 'Module', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSIONID', 'ftFloat', 'Session Id', 1, 6, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 7, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BG_JOB_ID', 'ftString', 'Bg. Job Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_NO', 'ftFloat', 'Trail No.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trail Daily Summary', 'Unified Trail Daily Summary', Q'[select
Trunc(a.timestamp_sts) as Audit_Date,
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.userhost,
a.returncode, a1.issue_name,
Count(*) as Trail_No

from v_sys_unf_trail a, v_its_issue a1

where a.ISSUE_ID = a1.issue_id
and a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

group by
Trunc(a.timestamp_sts),
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.userhost,
a.returncode, a1.issue_name

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_DATE', 'ftDateTime', 'Audit Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 7, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_NO', 'ftFloat', 'Trail No.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trail Hours', 'Unified Trail Hours', Q'[select
Trunc(a.timestamp_sts, 'HH24') as Audit_Date_HR,
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.sessionid, a.userhost,
a.module, a.bg_job_id,
a.returncode, a1.issue_name,
Count(*) as Trail_No

from v_sys_unf_trail a, v_its_issue a1

where a.ISSUE_ID = a1.issue_id
and a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

group by
Trunc(a.timestamp_sts, 'HH24'),
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.sessionid, a.userhost,
a.module, a.bg_job_id,
a.returncode, a1.issue_name

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_DATE_HR', 'ftDateTime', 'Audit DateHR', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'MODULE', 'ftString', 'Module', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SESSIONID', 'ftFloat', 'Session Id', 1, 6, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 7, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'BG_JOB_ID', 'ftString', 'Bg. Job Id', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_NO', 'ftFloat', 'Trail No.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trail Hours Summary', 'Unified Trail Hours Summary', Q'[select
Trunc(a.timestamp_sts, 'HH24') as Audit_Date_HR,
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.userhost,
a.returncode, a1.issue_name,
Count(*) as Trail_No

from v_sys_unf_trail a, v_its_issue a1

where a.ISSUE_ID = a1.issue_id
and a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

group by
Trunc(a.timestamp_sts, 'HH24'),
a.policy_type_code, a.username,
a.action_name, a.object_owner, a.object_name,
a.userhost,
a.returncode, a1.issue_name

order by 1]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_DATE_HR', 'ftDateTime', 'Audit DateHR', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 1, 7, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ISSUE_NAME', 'ftString', 'Issue Name', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'POLICY_TYPE_CODE', 'ftString', 'Policy Type', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_NO', 'ftFloat', 'Trail No.', 0, 0, 0, NULL);
   
prompt Inserting Report
insert into rpt_rep (report_id, 
profile_id, report_name, report_desc, 
report_base_sql, rep_native 
) 
values 
(seq_rpt_rep.nextval, 3, 'Unified Trails SQL', 'Unified Trails SQL', Q'[select
Trunc(a.timestamp_sts) as Audit_Date,
to_char(substr(a.SQL_BIND, 1, 4000)) as SQL_Bind,
to_char(substr(a.SQL_TEXT, 1, 4000)) as SQL_Text,
a.username, a.action_name,
a.object_owner, a.object_name,
a.userhost, a.returncode,

Count(*) as Trail_No

from v_sys_unf_trail a
where a.timestamp_sts
between To_Timestamp(:AUD_DATE_FROM, 'dd-mm-yyyy hh24:mi:ss.FF')
and To_Timestamp(:AUD_DATE_TO, 'dd-mm-yyyy hh24:mi:ss.FF')

group by
Trunc(a.timestamp_sts),
to_char(substr(a.SQL_BIND, 1, 4000)),
to_char(substr(a.SQL_TEXT, 1, 4000)),
a.username, a.action_name,
a.object_owner, a.object_name,
a.userhost, a.returncode

order by 1, 4, 5]', 1);
   
prompt Inserting Report Privileges
insert into rpt_rep_prv (
rep_priv_id, report_id, 
priv_role, priv_id
) 
values 
(seq_rpt_rep_prv.nextval, seq_rpt_rep.currval, 'OMEGACA_ADMIN', 2);
   
prompt Inserting Report Parameters
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_FROM', 'ftString', 'ftDateTime', 'Aud Date From', 0);
   
insert into rpt_rep_prm (
param_id, report_id, 
param_name, param_data_type, 
param_display_type, param_caption, 
time_end
) 
values 
(seq_rpt_rep_prm.nextval, seq_rpt_rep.currval, 'AUD_DATE_TO', 'ftString', 'ftDateTime', 'Aud Date To', 1);
   
prompt Inserting Report Columns
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'AUDIT_DATE', 'ftDateTime', 'Audit Date', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_BIND', 'ftString', 'SQL Bind (4000)', 1, 5, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'SQL_TEXT', 'ftString', 'SQL Text (4000)', 1, 6, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERNAME', 'ftString', 'Username', 1, 1, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'ACTION_NAME', 'ftString', 'Action Name', 1, 2, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_OWNER', 'ftString', 'Object Owner', 1, 3, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'OBJECT_NAME', 'ftString', 'Object Name', 1, 4, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'USERHOST', 'ftString', 'Userhost', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'RETURNCODE', 'ftFloat', 'Returncode', 0, 0, 0, NULL);
   
insert into rpt_rep_col (
column_id, report_id, 
column_name, col_data_type, 
column_caption, search_field, 
search_order, search_active, opr_code_id
) 
values 
(seq_rpt_rep_col.nextval, seq_rpt_rep.currval, 'TRAIL_NO', 'ftFloat', 'Trail No', 0, 0, 0, NULL);
   
   
COMMIT;
   
-- 14. Omega CA - Compile
prompt 14. Omega CA - Compile
prompt ==================================================
prompt
   
-- 14.1. Omega CA - Engine Package Compile
prompt 14.1. Omega CA - Engine Package Compile
prompt ==================================================
prompt
   
alter package SYS.OMEGA_CORE_AUDIT compile body;
   
-- 14.2. Omega CA - Repository Schema Compile
prompt 14.2. Omega CA - Repository Schema Compile
prompt ==================================================
prompt
   
execute SYS.DBMS_UTILITY.COMPILE_SCHEMA('OMEGACA', TRUE, FALSE);
   
-- 15. Omega CA - Roles Privileges
prompt 15. Omega CA - Roles Privileges
prompt ==================================================
prompt
   
grant EXECUTE on P_ACC_POL_CACHE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_CACHE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_CACHE_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_CACHE_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_LIST_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_LIST_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_LIST_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_LIST_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_LIST_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_LIST_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_LIST_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_LIST_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COND_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COND_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_COPY to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_COPY to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_RULE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_RULE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_RULE_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_RULE_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_RULE_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_RULE_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_RULE_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_RULE_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_USER_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_USER_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_POL_USER_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ACC_POL_USER_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ACC_SILENT to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_OBJ_GRANT to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_OBJ_GRANT to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_OBJ_REVOKE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_OBJ_REVOKE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_ROLE_DEFAULT to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_ROLE_DEFAULT to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_ROLE_GRANT to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_ROLE_GRANT to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_ROLE_REVOKE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_ROLE_REVOKE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_SYS_GRANT to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_SYS_GRANT to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_PRIV_SYS_REVOKE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_PRIV_SYS_REVOKE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_ROLE_ALTER to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_ROLE_ALTER to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_ROLE_CREATE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_ROLE_CREATE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_ROLE_DROP to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_ROLE_DROP to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_ALTER to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_ALTER to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_CREATE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_CREATE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_DROP to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_DROP to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_PASS_EXPIRE to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_PASS_EXPIRE to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_PASS_OWN to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_PASS_OWN to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_PASS_SET to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_PASS_SET to OMEGACA_ADMIN;
grant EXECUTE on P_ACM_USER_QUOTA to OMEGACA_ACCTMGR;
grant EXECUTE on P_ACM_USER_QUOTA to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_MAP to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_CACHE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_CACHE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_CACHE_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_CACHE_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_COPY to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_COPY to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_INS to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_INS to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_OBJ_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_OBJ_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_OBJ_INS to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_OBJ_INS to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_OBJ_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_OBJ_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_OBJ_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_OBJ_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_ORA_DF_SYNC to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_ORA_DF_SYNC to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_STMT_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_STMT_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_STMT_INS to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_STMT_INS to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_STMT_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_STMT_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_STMT_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_STMT_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_POL_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_POL_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_PRIV_OBJ_NOAUDIT to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_PRIV_OBJ_NOAUDIT to OMEGACA_AUDIT;
grant EXECUTE on P_AUD_PRIV_SYS_NOAUDIT to OMEGACA_ADMIN;
grant EXECUTE on P_AUD_PRIV_SYS_NOAUDIT to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_CLASS_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_CLASS_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_CLASS_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_CLASS_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_CLASS_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_CLASS_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_GROUP_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_GROUP_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_GROUP_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_GROUP_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_GROUP_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_GROUP_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_ISSUE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_ISSUE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_ISSUE_INS to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_ISSUE_INS to OMEGACA_AUDIT;
grant EXECUTE on P_ITS_ISSUE_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_ITS_ISSUE_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_COL_DEL to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_COL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_COL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_COL_DEL to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_COL_INS to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_COL_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_COL_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_COL_INS to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_COL_UPD to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_COL_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_COL_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_COL_UPD to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_CURRVAL to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_CURRVAL to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_CURRVAL to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_CURRVAL to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_DEL to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_DEL to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_INS to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_INS to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRM_DEL to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRM_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRM_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRM_DEL to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRM_INS to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRM_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRM_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRM_INS to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRM_UPD to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRM_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRM_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRM_UPD to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRV_DEL to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRV_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRV_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRV_DEL to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRV_INS to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRV_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRV_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRV_INS to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_PRV_UPD to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_PRV_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_PRV_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_PRV_UPD to OMEGACA_SECANALYST;
grant EXECUTE on P_RPT_REP_UPD to OMEGACA_ACCTMGR;
grant EXECUTE on P_RPT_REP_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RPT_REP_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RPT_REP_UPD to OMEGACA_SECANALYST;
grant EXECUTE on P_RTP_DDL_POL_AREA_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_AREA_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_AREA_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_AREA_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_AREA_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_AREA_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_CACHE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_CACHE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_CACHE_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_CACHE_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_LIST_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COND_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COND_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_COPY to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_COPY to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_RULE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_RULE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_RULE_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_RULE_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_RULE_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_RULE_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_RULE_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_RULE_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_USER_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_USER_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DDL_POL_USER_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DDL_POL_USER_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_AUD_POLICY_DROP to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_AUD_POLICY_DROP to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_MAP to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_CACHE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_CACHE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_CACHE_RULE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_CACHE_RULE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_LIST_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COND_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COND_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_COPY to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_COPY to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_RULE_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_RULE_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_RULE_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_RULE_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_RULE_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_RULE_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_RULE_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_RULE_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_STAT to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_STAT to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_UPD to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_USER_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_USER_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_POL_USER_INS to OMEGACA_ADMIN;
grant EXECUTE on P_RTP_DML_POL_USER_INS to OMEGACA_AUDIT;
grant EXECUTE on P_RTP_DML_RTC to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_ERROR_LOG_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_ERROR_LOG_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_SYS_FACTOR_IDENTITY_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_FACTOR_IDENTITY_INS to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_FACTOR_IDENTITY_UPD to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_MANAGE_ACC to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_MANAGE_AUD to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_MANAGE_AUD_SCHED_JOB to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_MANAGE_RTP_DDL to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_POL_DEBUG_DEL to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_POL_DEBUG_DEL to OMEGACA_AUDIT;
grant EXECUTE on P_SYS_SET_CURRENT_SCHEMA to OMEGACA_ACCTMGR;
grant EXECUTE on P_SYS_SET_CURRENT_SCHEMA to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_SET_CURRENT_SCHEMA to OMEGACA_AUDIT;
grant EXECUTE on P_SYS_SET_CURRENT_SCHEMA to OMEGACA_SECANALYST;
grant EXECUTE on P_SYS_TRAIL_TRANS to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_UNF_TRAIL_MARK_MLT to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_UNF_TRAIL_MARK_MLT to OMEGACA_AUDIT;
grant EXECUTE on P_SYS_UNF_TRAIL_MARK_SNG to OMEGACA_ADMIN;
grant EXECUTE on P_SYS_UNF_TRAIL_MARK_SNG to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL to OMEGACA_SECANALYST;
grant SELECT on V_ACC_POL_CACHE to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL_CACHE to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL_CACHE to OMEGACA_SECANALYST;
grant SELECT on V_ACC_POL_COND to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL_COND to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL_COND to OMEGACA_SECANALYST;
grant SELECT on V_ACC_POL_COND_LIST to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL_COND_LIST to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL_COND_LIST to OMEGACA_SECANALYST;
grant SELECT on V_ACC_POL_RULE to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL_RULE to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL_RULE to OMEGACA_SECANALYST;
grant SELECT on V_ACC_POL_USER to OMEGACA_ADMIN;
grant SELECT on V_ACC_POL_USER to OMEGACA_AUDIT;
grant SELECT on V_ACC_POL_USER to OMEGACA_SECANALYST;
grant SELECT on V_ACM_GRANTEE to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_GRANTEE to OMEGACA_ADMIN;
grant SELECT on V_ACM_GRANTEE to OMEGACA_SECANALYST;
grant SELECT on V_ACM_PRIV_OBJ to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_PRIV_OBJ to OMEGACA_ADMIN;
grant SELECT on V_ACM_PRIV_OBJ to OMEGACA_SECANALYST;
grant SELECT on V_ACM_PRIV_SYS to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_PRIV_SYS to OMEGACA_ADMIN;
grant SELECT on V_ACM_PRIV_SYS to OMEGACA_SECANALYST;
grant SELECT on V_ACM_ROLE to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_ROLE to OMEGACA_ADMIN;
grant SELECT on V_ACM_ROLE to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_DBA_PROFILES to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_DBA_PROFILES to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_DBA_PROFILES to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_DBA_ROLE_PRIVS to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_DBA_ROLE_PRIVS to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_DBA_ROLE_PRIVS to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_DBA_TS_QUOTAS to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_DBA_TS_QUOTAS to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_DBA_TS_QUOTAS to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_PROFNAME to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_PROFNAME to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_PROFNAME to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE_MAP to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE_MAP to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_TABLE_PRIVILEGE_MAP to OMEGACA_SECANALYST;
grant SELECT on V_ACM_SYS_TABLE_PRIV_OBJ_TYPE to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_SYS_TABLE_PRIV_OBJ_TYPE to OMEGACA_ADMIN;
grant SELECT on V_ACM_SYS_TABLE_PRIV_OBJ_TYPE to OMEGACA_SECANALYST;
grant SELECT on V_ACM_USER to OMEGACA_ACCTMGR;
grant SELECT on V_ACM_USER to OMEGACA_ADMIN;
grant SELECT on V_ACM_USER to OMEGACA_AUDIT;
grant SELECT on V_ACM_USER to OMEGACA_SECANALYST;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS to OMEGACA_ADMIN;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS to OMEGACA_AUDIT;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS to OMEGACA_SECANALYST;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS_TAB to OMEGACA_ADMIN;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS_TAB to OMEGACA_AUDIT;
grant SELECT on V_AUD_DBA_OBJ_AUDIT_OPTS_TAB to OMEGACA_SECANALYST;
grant SELECT on V_AUD_POL to OMEGACA_ADMIN;
grant SELECT on V_AUD_POL to OMEGACA_AUDIT;
grant SELECT on V_AUD_POL to OMEGACA_SECANALYST;
grant SELECT on V_AUD_POL_CACHE to OMEGACA_ADMIN;
grant SELECT on V_AUD_POL_CACHE to OMEGACA_AUDIT;
grant SELECT on V_AUD_POL_CACHE to OMEGACA_SECANALYST;
grant SELECT on V_AUD_POL_OBJ to OMEGACA_ADMIN;
grant SELECT on V_AUD_POL_OBJ to OMEGACA_AUDIT;
grant SELECT on V_AUD_POL_OBJ to OMEGACA_SECANALYST;
grant SELECT on V_AUD_POL_STMT to OMEGACA_ADMIN;
grant SELECT on V_AUD_POL_STMT to OMEGACA_AUDIT;
grant SELECT on V_AUD_POL_STMT to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_ACTION to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_ACTION to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_ACTION to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_DBA_STMT_AUDIT_OPTS to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_DBA_STMT_AUDIT_OPTS to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_DBA_STMT_AUDIT_OPTS to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_OBJ_OPT to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_OBJ_OPT to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_OBJ_OPT to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_OBJ_OPT_ACT to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_OBJ_OPT_ACT to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_OBJ_OPT_ACT to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_OBJ_OPT_OBJ_TYPE to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_OBJ_OPT_OBJ_TYPE to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_OBJ_OPT_OBJ_TYPE to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_STMT_AUDIT_OPTS_MAP to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_STMT_AUDIT_OPTS_MAP to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_STMT_AUDIT_OPTS_MAP to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_STMT_OPT to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_STMT_OPT to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_STMT_OPT to OMEGACA_SECANALYST;
grant SELECT on V_AUD_SYS_STMT_OPT_ACT to OMEGACA_ADMIN;
grant SELECT on V_AUD_SYS_STMT_OPT_ACT to OMEGACA_AUDIT;
grant SELECT on V_AUD_SYS_STMT_OPT_ACT to OMEGACA_SECANALYST;
grant SELECT on V_ITS_CLASS to OMEGACA_ADMIN;
grant SELECT on V_ITS_CLASS to OMEGACA_AUDIT;
grant SELECT on V_ITS_CLASS to OMEGACA_SECANALYST;
grant SELECT on V_ITS_GROUP to OMEGACA_ADMIN;
grant SELECT on V_ITS_GROUP to OMEGACA_AUDIT;
grant SELECT on V_ITS_GROUP to OMEGACA_SECANALYST;
grant SELECT on V_ITS_ISSUE to OMEGACA_ADMIN;
grant SELECT on V_ITS_ISSUE to OMEGACA_AUDIT;
grant SELECT on V_ITS_ISSUE to OMEGACA_SECANALYST;
grant SELECT on V_OMEGACA_ROLE to OMEGACA_ACCTMGR;
grant SELECT on V_OMEGACA_ROLE to OMEGACA_ADMIN;
grant SELECT on V_OMEGACA_ROLE to OMEGACA_AUDIT;
grant SELECT on V_OMEGACA_ROLE to OMEGACA_SECANALYST;
grant SELECT on V_OMEGACA_USER_ROLE to OMEGACA_ACCTMGR;
grant SELECT on V_OMEGACA_USER_ROLE to OMEGACA_ADMIN;
grant SELECT on V_OMEGACA_USER_ROLE to OMEGACA_AUDIT;
grant SELECT on V_OMEGACA_USER_ROLE to OMEGACA_SECANALYST;
grant SELECT on V_RPT_REP to OMEGACA_ACCTMGR;
grant SELECT on V_RPT_REP to OMEGACA_ADMIN;
grant SELECT on V_RPT_REP to OMEGACA_AUDIT;
grant SELECT on V_RPT_REP to OMEGACA_SECANALYST;
grant SELECT on V_RPT_REP_ACCESS to OMEGACA_ACCTMGR;
grant SELECT on V_RPT_REP_ACCESS to OMEGACA_ADMIN;
grant SELECT on V_RPT_REP_ACCESS to OMEGACA_AUDIT;
grant SELECT on V_RPT_REP_ACCESS to OMEGACA_SECANALYST;
grant SELECT on V_RPT_REP_COL to OMEGACA_ACCTMGR;
grant SELECT on V_RPT_REP_COL to OMEGACA_ADMIN;
grant SELECT on V_RPT_REP_COL to OMEGACA_AUDIT;
grant SELECT on V_RPT_REP_COL to OMEGACA_SECANALYST;
grant SELECT on V_RPT_REP_PRM to OMEGACA_ACCTMGR;
grant SELECT on V_RPT_REP_PRM to OMEGACA_ADMIN;
grant SELECT on V_RPT_REP_PRM to OMEGACA_AUDIT;
grant SELECT on V_RPT_REP_PRM to OMEGACA_SECANALYST;
grant SELECT on V_RPT_REP_PRV to OMEGACA_ACCTMGR;
grant SELECT on V_RPT_REP_PRV to OMEGACA_ADMIN;
grant SELECT on V_RPT_REP_PRV to OMEGACA_AUDIT;
grant SELECT on V_RPT_REP_PRV to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_AREA to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_AREA to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_AREA to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_CACHE to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_CACHE to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_CACHE to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_COND to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_COND to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_COND to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_COND_LIST to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_COND_LIST to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_COND_LIST to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_RULE to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_RULE to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_RULE to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DDL_POL_USER to OMEGACA_ADMIN;
grant SELECT on V_RTP_DDL_POL_USER to OMEGACA_AUDIT;
grant SELECT on V_RTP_DDL_POL_USER to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_CACHE to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_CACHE to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_CACHE to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_COND to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_COND to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_COND to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_COND_LIST to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_COND_LIST to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_COND_LIST to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_RULE to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_RULE to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_RULE to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_RULE_DBA_AUD_POL to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_RULE_DBA_AUD_POL to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_RULE_DBA_AUD_POL to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_POL_USER to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_POL_USER to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_POL_USER to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL to OMEGACA_SECANALYST;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL_CL to OMEGACA_ADMIN;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL_CL to OMEGACA_AUDIT;
grant SELECT on V_RTP_DML_SYS_DBA_AUDIT_POL_CL to OMEGACA_SECANALYST;
grant SELECT on V_SYS_DBA_TAB_COLS to OMEGACA_ADMIN;
grant SELECT on V_SYS_DBA_TAB_COLS to OMEGACA_AUDIT;
grant SELECT on V_SYS_DBA_TAB_COLS to OMEGACA_SECANALYST;
grant SELECT on V_SYS_ERROR_LOG to OMEGACA_ADMIN;
grant SELECT on V_SYS_ERROR_LOG to OMEGACA_AUDIT;
grant SELECT on V_SYS_ERROR_LOG to OMEGACA_SECANALYST;
grant SELECT on V_SYS_FACTOR to OMEGACA_ADMIN;
grant SELECT on V_SYS_FACTOR to OMEGACA_AUDIT;
grant SELECT on V_SYS_FACTOR to OMEGACA_SECANALYST;
grant SELECT on V_SYS_FACTOR_IDENTITY to OMEGACA_ADMIN;
grant SELECT on V_SYS_FACTOR_IDENTITY to OMEGACA_AUDIT;
grant SELECT on V_SYS_FACTOR_IDENTITY to OMEGACA_SECANALYST;
grant SELECT on V_SYS_FACTOR_POL_TYPE to OMEGACA_ADMIN;
grant SELECT on V_SYS_FACTOR_POL_TYPE to OMEGACA_AUDIT;
grant SELECT on V_SYS_FACTOR_POL_TYPE to OMEGACA_SECANALYST;
grant SELECT on V_SYS_FACTOR_TRUST_LEVEL to OMEGACA_ADMIN;
grant SELECT on V_SYS_FACTOR_TRUST_LEVEL to OMEGACA_AUDIT;
grant SELECT on V_SYS_FACTOR_TRUST_LEVEL to OMEGACA_SECANALYST;
grant SELECT on V_SYS_JOB_CLASSIC to OMEGACA_ADMIN;
grant SELECT on V_SYS_JOB_CLASSIC to OMEGACA_SECANALYST;
grant SELECT on V_SYS_JOB_SCHEDULER to OMEGACA_ADMIN;
grant SELECT on V_SYS_JOB_SCHEDULER to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_ACC to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_ACC to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_AUD to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_AUD to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_AUD_SCHED_JOB to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_AUD_SCHED_JOB to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_AUD_SCHED_JOB_LOG to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_AUD_SCHED_JOB_LOG to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_RTP_DDL to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_RTP_DDL to OMEGACA_SECANALYST;
grant SELECT on V_SYS_MANAGE_RTP_DML to OMEGACA_ADMIN;
grant SELECT on V_SYS_MANAGE_RTP_DML to OMEGACA_SECANALYST;
grant SELECT on V_SYS_OBJECTS to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_OBJECTS to OMEGACA_ADMIN;
grant SELECT on V_SYS_OBJECTS to OMEGACA_AUDIT;
grant SELECT on V_SYS_OBJECTS to OMEGACA_SECANALYST;
grant SELECT on V_SYS_OBJ_TYPE to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_OBJ_TYPE to OMEGACA_ADMIN;
grant SELECT on V_SYS_OBJ_TYPE to OMEGACA_AUDIT;
grant SELECT on V_SYS_OBJ_TYPE to OMEGACA_SECANALYST;
grant SELECT on V_SYS_OPERATION_CODE to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_OPERATION_CODE to OMEGACA_ADMIN;
grant SELECT on V_SYS_OPERATION_CODE to OMEGACA_AUDIT;
grant SELECT on V_SYS_OPERATION_CODE to OMEGACA_SECANALYST;
grant SELECT on V_SYS_PARAM to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_PARAM to OMEGACA_ADMIN;
grant SELECT on V_SYS_PARAM to OMEGACA_AUDIT;
grant SELECT on V_SYS_PARAM to OMEGACA_SECANALYST;
grant SELECT on V_SYS_POL_DEBUG to OMEGACA_ADMIN;
grant SELECT on V_SYS_POL_DEBUG to OMEGACA_AUDIT;
grant SELECT on V_SYS_POL_DEBUG to OMEGACA_SECANALYST;
grant SELECT on V_SYS_POL_TYPE to OMEGACA_ADMIN;
grant SELECT on V_SYS_POL_TYPE to OMEGACA_AUDIT;
grant SELECT on V_SYS_POL_TYPE to OMEGACA_SECANALYST;
grant SELECT on V_SYS_STMT_DDL to OMEGACA_ADMIN;
grant SELECT on V_SYS_STMT_DDL to OMEGACA_AUDIT;
grant SELECT on V_SYS_STMT_DDL to OMEGACA_SECANALYST;
grant SELECT on V_SYS_SYSTEM_PRIVILEGE_MAP to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_SYSTEM_PRIVILEGE_MAP to OMEGACA_ADMIN;
grant SELECT on V_SYS_SYSTEM_PRIVILEGE_MAP to OMEGACA_AUDIT;
grant SELECT on V_SYS_SYSTEM_PRIVILEGE_MAP to OMEGACA_SECANALYST;
grant SELECT on V_SYS_TABLESPACE to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_TABLESPACE to OMEGACA_ADMIN;
grant SELECT on V_SYS_TABLESPACE to OMEGACA_AUDIT;
grant SELECT on V_SYS_TABLESPACE to OMEGACA_SECANALYST;
grant SELECT on V_SYS_UNF_TRAIL to OMEGACA_ADMIN;
grant SELECT on V_SYS_UNF_TRAIL to OMEGACA_AUDIT;
grant SELECT on V_SYS_UNF_TRAIL to OMEGACA_SECANALYST;
grant SELECT on V_SYS_VERSION to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_VERSION to OMEGACA_ADMIN;
grant SELECT on V_SYS_VERSION to OMEGACA_AUDIT;
grant SELECT on V_SYS_VERSION to OMEGACA_SECANALYST;
grant SELECT on V_SYS_VERSION_CRRNT to OMEGACA_ACCTMGR;
grant SELECT on V_SYS_VERSION_CRRNT to OMEGACA_ADMIN;
grant SELECT on V_SYS_VERSION_CRRNT to OMEGACA_AUDIT;
grant SELECT on V_SYS_VERSION_CRRNT to OMEGACA_SECANALYST;
   
-- 16. Omega CA - Admin User and Schema Lock
prompt 16. Omega CA - Admin User and Schema Lock
prompt ==================================================
prompt
   
create user OMEGACAADM identified by Omegaca123 default tablespace OMEGACA_TS;
   
grant OMEGACA_ADMIN to OMEGACAADM;
   
alter user OMEGACA account lock;
   
-- 17. Omega CA - Version
prompt 17. Omega CA - Version
prompt ==================================================
prompt
   
execute P_SYS_VERSION_UPGRADE('02', '08', '01', 'Omega_CA_02_08_01_Install.sql');
   
COMMIT;
   
-- Purge Recycle Bin
purge recyclebin;
   
SPOOL OFF
